@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqDataInformationModel.cxx,v $
+   Module:    pqDataInformationModel.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -489,7 +489,7 @@ void pqDataInformationModel::dataUpdated(pqPipelineSource* changedSource)
       continue;
       }
     
-    vtkPVDataInformation* dataInfo = port->getDataInformation(false);
+    vtkPVDataInformation* dataInfo = port->getDataInformation();
     if (!iter->DataInformationValid || dataInfo->GetMTime() > iter->MTime)
       {
       iter->MTime = dataInfo->GetMTime();
