@@ -1,13 +1,13 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqDisplayProxyEditor.h,v $
+   Module:    pqDisplayProxyEditor.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
 
    ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2. 
+   under the terms of the ParaView license version 1.2.
 
    See License_v1.2.txt for the full ParaView license.
    A copy of this license can be obtained by contacting
@@ -44,9 +44,9 @@ class pqPipelineRepresentation;
 class PQCOMPONENTS_EXPORT pqDisplayProxyEditor : public pqDisplayPanel
 {
   Q_OBJECT
-  
+
   // property adaptor for specular lighting
-  Q_PROPERTY(QVariant specularColor READ specularColor 
+  Q_PROPERTY(QVariant specularColor READ specularColor
                                     WRITE setSpecularColor)
 public:
   /// constructor
@@ -79,6 +79,9 @@ protected slots:
   void selectedMapperChanged();
   void volumeBlockSelected();
   void setSolidColor(const QColor& color);
+  void setBackfaceSolidColor(const QColor& color);
+  void setAutoAdjustSampleDistances(bool flag);
+
 protected:
 
   /// Set the display whose properties we want to edit.
@@ -87,7 +90,7 @@ protected:
 
   pqDisplayProxyEditorInternal* Internal;
   void setupGUIConnections();
-  
+
   QVariant specularColor() const;
   void setSpecularColor(QVariant);
 
