@@ -1,13 +1,13 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqDisplayProxyEditorWidget.cxx,v $
+   Module:    pqDisplayProxyEditorWidget.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
 
    ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2. 
+   under the terms of the ParaView license version 1.2.
 
    See License_v1.2.txt for the full ParaView license.
    A copy of this license can be obtained by contacting
@@ -37,23 +37,27 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QPointer>
 #include <QVBoxLayout>
 
+#include <QDebug>
+
 #include "pqApplicationCore.h"
-#include "pqBarChartDisplayProxyEditor.h"
-#include "pqDisplayPanelInterface.h"
+#include "pqBarChartDisplayPanel.h"
 #include "pqDisplayPanelDecoratorInterface.h"
+#include "pqDisplayPanelInterface.h"
 #include "pqDisplayPolicy.h"
 #include "pqDisplayProxyEditor.h"
+#include "pqLineChartDisplayPanel.h"
 #include "pqOutputPort.h"
 #include "pqPipelineRepresentation.h"
 #include "pqPipelineSource.h"
 #include "pqPluginManager.h"
 #include "pqPropertyLinks.h"
+#include "pqScatterPlotDisplayPanel.h"
 #include "pqSpreadSheetDisplayEditor.h"
 #include "pqTextDisplayPropertiesWidget.h"
 #include "pqTextRepresentation.h"
+#include "pqXYChartDisplayPanel.h"
 #include "pqUndoStack.h"
 #include "pqView.h"
-#include "pqXYPlotDisplayProxyEditor.h"
 
 /// standard display panels
 class pqStandardDisplayPanels : public QObject,
@@ -75,10 +79,13 @@ public:
 
     QString type = proxy->getProxy()->GetXMLName();
 
-    if(type == "BarChartRepresentation" ||
-       type == "XYPlotRepresentation" ||
+    if (type == "XYPlotRepresentation" ||
+       type == "XYChartRepresentation" ||
+       type == "XYBarChartRepresentation" ||
+       type == "BarChartRepresentation" ||
        type == "SpreadSheetRepresentation" ||
-       qobject_cast<pqTextRepresentation*>(proxy))
+       qobject_cast<pqTextRepresentation*>(proxy)||
+        type == "ScatterPlotRepresentation")
       {
       return true;
       }
@@ -90,35 +97,48 @@ public:
     {
     if(!proxy || !proxy->getProxy())
       {
+      qDebug() << "Proxy is null" << proxy;
       return NULL;
       }
 
     QString type = proxy->getProxy()->GetXMLName();
-    if(type == QString("XYPlotRepresentation"))
+
+    if (type == QString("XYPlotRepresentation"))
       {
-      return new pqXYPlotDisplayProxyEditor(proxy, p);
+      return new pqLineChartDisplayPanel(proxy, p);
       }
-    
-    if(type == QString("BarChartRepresentation"))
+    if (type == QString("XYChartRepresentation"))
       {
-      return new pqBarChartDisplayProxyEditor(proxy, p);
+      return new pqXYChartDisplayPanel(proxy, p);
+      }
+    if (type == QString("XYBarChartRepresentation"))
+      {
+      return new pqXYChartDisplayPanel(proxy, p);
+      }
+    if (type == QString("BarChartRepresentation"))
+      {
+      return new pqBarChartDisplayPanel(proxy, p);
       }
 
     if (type == "SpreadSheetRepresentation")
       {
       return new pqSpreadSheetDisplayEditor(proxy, p);
       }
-    
+
     if (qobject_cast<pqTextRepresentation*>(proxy))
       {
       return new pqTextDisplayPropertiesWidget(proxy, p);
       }
+    if (type == "ScatterPlotRepresentation")
+      {
+      return new pqScatterPlotDisplayPanel(proxy, p);
+      }
     return NULL;
     }
 };
 
 
-class pqDefaultDisplayPanel::pqInternal 
+class pqDefaultDisplayPanel::pqInternal
  : public Ui::DisplayProxyEditorWidget
 {
 public:
@@ -140,7 +160,7 @@ pqDefaultDisplayPanel::pqDefaultDisplayPanel(pqRepresentation* repr, QWidget* p)
     {
     this->Internal->ViewData->setCheckState(Qt::Unchecked);
     }
-  QObject::connect(this->Internal->ViewData, SIGNAL(stateChanged(int)), 
+  QObject::connect(this->Internal->ViewData, SIGNAL(stateChanged(int)),
                    this, SLOT(onStateChanged(int)));
 }
 
@@ -229,7 +249,7 @@ void pqDisplayProxyEditorWidget::onVisibilityChanged(bool state)
   pqRepresentation* disp = policy->setRepresentationVisibility(
     this->Internal->OutputPort, this->Internal->View, state);
   emit this->endUndo();
-  
+
   if (disp)
     {
     disp->renderViewEventually();
@@ -260,7 +280,7 @@ void pqDisplayProxyEditorWidget::updatePanel()
     }
 
   pqRepresentation* repr = this->Internal->Representation;
-  
+
   // search for a custom panels
   pqPluginManager* pm = pqApplicationCore::instance()->getPluginManager();
   QObjectList ifaces = pm->interfaces();
@@ -290,7 +310,7 @@ void pqDisplayProxyEditorWidget::updatePanel()
   else if(!this->Internal->DisplayPanel)
     {
     this->Internal->DisplayPanel = new pqDefaultDisplayPanel(repr, this);
-    
+
     if((this->Internal->Representation || !this->Internal->View ||
        this->Internal->View->canDisplay(this->Internal->OutputPort)) &&
       (this->Internal->OutputPort &&
@@ -300,7 +320,7 @@ void pqDisplayProxyEditorWidget::updatePanel()
       // connect to visibility so we can create a view for it
       QObject::connect(this->Internal->DisplayPanel,
                        SIGNAL(visibilityChanged(bool)),
-                       this, 
+                       this,
                        SLOT(onVisibilityChanged(bool)), Qt::QueuedConnection);
       }
     else
