@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqOptionsPage.h,v $
+   Module:    pqOptionsPage.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -77,7 +77,7 @@ public:
   pqOptionsPage(QWidget *parent=0);
   virtual ~pqOptionsPage() {}
 
-  /// \breif
+  /// \brief
   ///   Gets whether or not the apply button is used by the options.
   /// \return
   ///   True if the apply button is used by the options.
