@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program:   ParaQ
-   Module:    $RCSfile: pqPointSourceWidget.cxx,v $
+   Module:    pqPointSourceWidget.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -80,6 +80,9 @@ pqPointSourceWidget::pqPointSourceWidget(vtkSMProxy* o, vtkSMProxy* pxy, QWidget
     setValidator(new QDoubleValidator(this->Implementation->Controls.Radius));
 
   this->layout()->addWidget(&this->Implementation->ControlsContainer);
+  QLabel* label =new QLabel("<b>Note: Move mouse and use 'P' key to change point position</b>", this);
+  label->setWordWrap(1);
+  this->layout()->addWidget(label);
 
   QObject::connect(&this->Implementation->Links, SIGNAL(qtWidgetChanged()),
     this, SLOT(setModified()));
@@ -92,25 +95,21 @@ pqPointSourceWidget::~pqPointSourceWidget()
 }
 
 //-----------------------------------------------------------------------------
-void pqPointSourceWidget::resetBounds()
+void pqPointSourceWidget::resetBounds(double input_bounds[6])
 {
-  this->Superclass::resetBounds();
+  this->Superclass::resetBounds(input_bounds);
 
   vtkSMNewWidgetRepresentationProxy* widget = this->getWidgetProxy();
-  double input_bounds[6];
-  if(widget && this->getReferenceInputBounds(input_bounds))
+  double min_diameter = input_bounds[1]-input_bounds[0];
+  min_diameter = qMin(min_diameter, input_bounds[3]-input_bounds[2]);
+  min_diameter = qMin(min_diameter, input_bounds[5]-input_bounds[4]);
+  vtkSMDoubleVectorProperty* dvp = vtkSMDoubleVectorProperty::SafeDownCast(
+    widget->GetProperty("Radius"));
+  if (dvp)
     {
-    double min_diameter = input_bounds[1]-input_bounds[0];
-    min_diameter = qMin(min_diameter, input_bounds[3]-input_bounds[2]);
-    min_diameter = qMin(min_diameter, input_bounds[5]-input_bounds[4]);
-    vtkSMDoubleVectorProperty* dvp = vtkSMDoubleVectorProperty::SafeDownCast(
-      widget->GetProperty("Radius"));
-    if (dvp)
-      {
-      dvp->SetElement(0, min_diameter * 0.1);
-      }
-    widget->UpdateVTKObjects();
+    dvp->SetElement(0, min_diameter * 0.1);
     }
+  widget->UpdateVTKObjects();
 }
 
 //-----------------------------------------------------------------------------
