@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqSelectReaderDialog.h,v $
+   Module:    pqSelectReaderDialog.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -37,7 +37,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqComponentsExport.h"
 
 class pqServer;
-class pqReaderFactory;
+class vtkSMReaderFactory;
 
 /// a dialog that prompts for a reader type to open a file
 class PQCOMPONENTS_EXPORT pqSelectReaderDialog : public QDialog
@@ -47,7 +47,7 @@ public:
   /// constructor
   pqSelectReaderDialog(const QString& file,
                        pqServer* s, 
-                       pqReaderFactory* factory,
+                       vtkSMReaderFactory* factory,
                        QWidget* p = 0);
   /// destructor
   ~pqSelectReaderDialog();
@@ -55,6 +55,9 @@ public:
   /// get the reader that was chosen to read a file
   QString getReader() const;
 
+  /// get the group for the chosen reader.
+  QString getGroup() const;
+
 protected:
   class pqInternal;
   pqInternal* Internal;
