@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqSelectionInspectorPanel.h,v $
+   Module:    pqSelectionInspectorPanel.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -36,6 +36,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqComponentsExport.h"
 #include <QWidget>
 
+class vtkObject;
 class pqDataRepresentation;
 class pqOutputPort;
 class pqPipelineSource;
@@ -43,7 +44,6 @@ class pqProxy;
 class pqSelectionManager;
 class pqServer;
 class pqServerManagerModelItem;
-class pqTreeWidgetItemObject;
 class pqView;
 class QTreeWidgetItem;
 class vtkSMClientDeliveryRepresentationProxy;
@@ -83,6 +83,9 @@ protected slots:
   /// Called when the "Selection Type" combo-box is changed.
   void onSelectionTypeChanged(const QString&);
 
+  /// Called when the SelectionManager is changed.
+  void onSelectionManagerChanged(pqOutputPort* opport);
+
   /// Called when "Field Type" combo-box changes. This updates the enabled state
   /// of the "Containing Cells" combo-box, since that combo-box only makes sense
   /// for point selections.
@@ -113,7 +116,7 @@ protected slots:
 
   /// Called when user navigates beyond the end in the indices table widget. We
   /// add a new row to simplify editing.
-  void onTableGrown(pqTreeWidgetItemObject* item);
+  void onTableGrown(QTreeWidgetItem* item);
 
   /// Called when the current item in the "Indices" table changes. If composite
   /// tree is visible, we update the composite tree selection to match the
@@ -131,6 +134,12 @@ protected slots:
 
   /// Called to update the types of selections available.
   void updateSelectionTypesAvailable();
+
+  /// Called when selection color is changed, we save the selection color in
+  /// settings so that it's preserved across sessions.
+  void onSelectionColorChanged(const QColor& color);
+
+  void forceLabelGlobalId(vtkObject* caller);
 protected:
   /// Sets up the GUI by created default signal/slot bindings etc.
   void setupGUI();
@@ -175,6 +184,14 @@ protected:
   void allocateWidgets(unsigned int numWidgets);
 
   void updateFrustumInternal(bool);
+  
+  /// Called to update the types of selections available.
+  void updateSelectionTypesAvailable(pqOutputPort* opport);
+
+  /// Returns true if the port has GlobalIDs
+  bool hasGlobalIDs(pqOutputPort*);
+
+  void setGlobalIDs();
 private:
   struct pqImplementation;
   pqImplementation* const Implementation;
