@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program:   ParaView
-   Module:    $RCSfile: pqSignalAdaptorKeyFrameType.h,v $
+   Module:    pqSignalAdaptorKeyFrameType.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -49,7 +49,7 @@ class pqKeyFrameTypeWidget;
 class PQCOMPONENTS_EXPORT pqSignalAdaptorKeyFrameType : 
   public pqSignalAdaptorComboBox
 {
-  Q_OBJECT;
+  Q_OBJECT
 public:
   /// Constructor. 
   /// \c combo is the combo-box that chooses the type, while frame is
