@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqSpreadSheetDisplayEditor.cxx,v $
+   Module:    pqSpreadSheetDisplayEditor.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -39,6 +39,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 // Qt Includes.
 
 // ParaView Includes.
+#include "pqComboBoxDomain.h"
 #include "pqPropertyLinks.h"
 #include "pqRepresentation.h"
 #include "pqServer.h"
@@ -51,6 +52,7 @@ class pqSpreadSheetDisplayEditor::pqInternal : public Ui::SpreadSheetDisplayEdit
 public:
   pqPropertyLinks Links;
   pqSignalAdaptorComboBox* AttributeModeAdaptor;
+  pqComboBoxDomain* AttributeModeDomain;
   pqSignalAdaptorSpinBox* ProcessIDAdaptor;
   pqSignalAdaptorCompositeTreeWidget* CompositeTreeAdaptor;
 };
@@ -72,6 +74,7 @@ pqSpreadSheetDisplayEditor::pqSpreadSheetDisplayEditor(
       repr->getProxy()->GetProperty("CompositeDataSetIndex")), 
     /*autoUpdateVisibility=*/true,
     /*showSelectedElementCounts=*/true);
+  this->Internal->AttributeModeDomain = 0;
 
   this->setRepresentationInternal(repr);
 
@@ -95,15 +98,18 @@ void pqSpreadSheetDisplayEditor::setRepresentationInternal(pqRepresentation* rep
 {
   vtkSMProxy* reprProxy = repr->getProxy();
 
+  this->Internal->AttributeModeDomain = new pqComboBoxDomain(
+    this->Internal->AttributeMode,
+    reprProxy->GetProperty("FieldAssociation"), "enum");
   this->Internal->Links.addPropertyLink(this->Internal->ViewData,
     "checked", SIGNAL(stateChanged(int)),
     reprProxy, reprProxy->GetProperty("Visibility"));
   this->Internal->Links.addPropertyLink(this->Internal->AttributeModeAdaptor,
     "currentText", SIGNAL(currentTextChanged(const QString&)),
-    reprProxy, reprProxy->GetProperty("FieldType"));
-  this->Internal->Links.addPropertyLink(this->Internal->ProcessIDAdaptor,
-    "value", SIGNAL(valueChanged(int)),
-    reprProxy, reprProxy->GetProperty("ProcessID"));
+    reprProxy, reprProxy->GetProperty("FieldAssociation"));
+  //this->Internal->Links.addPropertyLink(this->Internal->ProcessIDAdaptor,
+  //  "value", SIGNAL(valueChanged(int)),
+  //  reprProxy, reprProxy->GetProperty("ProcessID"));
   this->Internal->Links.addPropertyLink(this->Internal->SelectionOnly,
     "checked", SIGNAL(stateChanged(int)),
     reprProxy, reprProxy->GetProperty("SelectionOnly"));
