@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqTextDisplayPropertiesWidget.cxx,v $
+   Module:    pqTextDisplayPropertiesWidget.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -39,10 +39,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <QPointer>
 
+#include "pqApplicationCore.h"
 #include "pqPropertyLinks.h"
 #include "pqRepresentation.h"
-#include "pqTextRepresentation.h"
 #include "pqSignalAdaptors.h"
+#include "pqStandardColorLinkAdaptor.h"
+#include "pqTextRepresentation.h"
+#include "pqUndoStack.h"
 
 class pqTextDisplayPropertiesWidget::pqInternal : 
   public Ui::pqTextDisplayPropertiesWidget
@@ -96,6 +99,17 @@ pqTextDisplayPropertiesWidget::pqTextDisplayPropertiesWidget(pqRepresentation* d
       this->Internal->comboTextAlign);
 
   this->setDisplay(display);
+
+  this->Internal->buttonColor->setUndoLabel("Change Color");
+  pqUndoStack* stack = pqApplicationCore::instance()->getUndoStack();
+  if (stack)
+    {
+    QObject::connect(this->Internal->buttonColor,
+      SIGNAL(beginUndo(const QString&)),
+      stack, SLOT(beginUndoSet(const QString&)));
+    QObject::connect(this->Internal->buttonColor,
+      SIGNAL(endUndo()), stack, SLOT(endUndoSet()));
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -131,12 +145,9 @@ void pqTextDisplayPropertiesWidget::setDisplay(pqRepresentation* display)
     this->Internal->Visibility, "checked", SIGNAL(stateChanged(int)),
     proxy, proxy->GetProperty("Visibility"));
 
-  QObject::connect(this->Internal->Visibility, SIGNAL(stateChanged(int)),
-    this, SLOT(onVisibilityChanged(int)));
-
   this->Internal->Links.addPropertyLink(
     this->Internal->Interactivity, "checked", SIGNAL(stateChanged(int)),
-    proxy, proxy->GetProperty("Enabled"));
+    proxy, proxy->GetProperty("Interactivity"));
   this->Internal->Links.addPropertyLink(
     this->Internal->Position1X, "value", SIGNAL(editingFinished()),
     proxy, proxy->GetProperty("Position"), 0);
@@ -157,6 +168,9 @@ void pqTextDisplayPropertiesWidget::setDisplay(pqRepresentation* display)
   this->Internal->Links.addPropertyLink(this->Internal->ColorAdaptor, 
       "color", SIGNAL(colorChanged(const QVariant&)),
       proxy, proxy->GetProperty("Color"));
+  // This manages the global property linking.
+  new pqStandardColorLinkAdaptor(this->Internal->buttonColor,
+    proxy, "Color");
   this->Internal->Links.addPropertyLink(this->Internal->FontFamilyAdaptor,
       "currentText", SIGNAL(currentTextChanged(const QString&)),
       proxy, proxy->GetProperty("FontFamily"));
@@ -189,15 +203,6 @@ void pqTextDisplayPropertiesWidget::setDisplay(pqRepresentation* display)
 
 }
 
-//-----------------------------------------------------------------------------
-void pqTextDisplayPropertiesWidget::onVisibilityChanged(int state)
-{
-  if (state == Qt::Unchecked)
-    {
-    this->Internal->Interactivity->setCheckState(Qt::Unchecked);
-    }
-}
-
 //-----------------------------------------------------------------------------
 void pqTextDisplayPropertiesWidget::onTextLocationChanged(bool checked)
 {
