@@ -1,13 +1,13 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqViewManager.cxx,v $
+   Module:    pqViewManager.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
 
    ParaView is a free software; you can redistribute it and/or modify it
-   under the terms of the ParaView license version 1.2. 
+   under the terms of the ParaView license version 1.2.
 
    See License_v1.2.txt for the full ParaView license.
    A copy of this license can be obtained by contacting
@@ -33,6 +33,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ui_pqEmptyView.h"
 
 // VTK includes.
+#include "QVTKWidget.h"
 #include "vtkErrorCode.h"
 #include "vtkImageData.h"
 #include "vtkImageIterator.h"
@@ -41,8 +42,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMAnimationSceneImageWriter.h"
 #include "vtkSmartPointer.h"
 #include "vtkSMIntVectorProperty.h"
+#include "vtkSMPropertyHelper.h"
 #include "vtkSMProxy.h"
-#include "vtkSMStateLoaderBase.h"
+#include "vtkSMProxyLocator.h"
 #include "vtkSMUtilities.h"
 
 // Qt includes.
@@ -65,7 +67,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 
 // ParaView includes.
-#include "pqActiveViewOptionsManager.h"
+#include "pqActiveObjects.h"
 #include "pqApplicationCore.h"
 #include "pqCloseViewUndoElement.h"
 #include "pqComparativeRenderView.h"
@@ -73,6 +75,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqImageUtil.h"
 #include "pqMultiViewFrame.h"
 #include "pqObjectBuilder.h"
+#include "pqOptions.h"
 #include "pqPluginManager.h"
 #include "pqServer.h"
 #include "pqServerManagerModel.h"
@@ -95,15 +98,11 @@ uint qHash(const QPointer<T> key)
   return qHash((T*)key);
 }
 //-----------------------------------------------------------------------------
-class pqViewManager::pqInternals 
+class pqViewManager::pqInternals
 {
 public:
-  QPointer<pqServer> ActiveServer;
   QPointer<pqView> ActiveView;
-  QPointer<pqUndoStack> UndoStack;
-  QPointer<pqActiveViewOptionsManager> ViewOptionsManager;
   QMenu ConvertMenu;
-  QSignalMapper* LookmarkSignalMapper;
 
 
   typedef QMap<pqMultiViewFrame*, QPointer<pqView> > FrameMapType;
@@ -117,9 +116,9 @@ public:
   bool DontCreateDeleteViewsModules;
 
   // When a frame is being closed, we create an undo element
-  // and  save it to be pushed on the stack after the 
+  // and  save it to be pushed on the stack after the
   // view in the frame has been unregistered. The sequence
-  // of operations on the undo stack is 
+  // of operations on the undo stack is
   // * unregister view
   // * close frame
   vtkSmartPointer<vtkSMUndoElement> CloseFrameUndoElement;
@@ -127,6 +126,10 @@ public:
   // Used by prepareForCapture and finishedCapture.
   QSize SavedMaxSize;
   QSize SavedSize;
+
+  typedef QMap<pqMultiViewFrame*, QPointer<QLabel> > FrameOverlaysType;
+  FrameOverlaysType FrameOverlays;
+  QTimer OverlayCleanupTimer;
 };
 
 //-----------------------------------------------------------------------------
@@ -136,12 +139,12 @@ pqViewManager::pqViewManager(QWidget* _parent/*=null*/)
   this->Internal = new pqInternals();
   this->Internal->DontCreateDeleteViewsModules = false;
   this->Internal->MaxWindowSize = QSize(QWIDGETSIZE_MAX, QWIDGETSIZE_MAX);
-  this->Internal->LookmarkSignalMapper = new QSignalMapper(this);
-  QObject::connect(this->Internal->LookmarkSignalMapper, SIGNAL(mapped(QWidget*)), 
-    this, SIGNAL(createLookmark(QWidget*)));
+  this->Internal->OverlayCleanupTimer.setInterval(2000);
+  QObject::connect(&this->Internal->OverlayCleanupTimer,
+    SIGNAL(timeout()),
+    this, SLOT(destroyFrameOverlays()));
 
-
-  pqServerManagerModel* smModel = 
+  pqServerManagerModel* smModel =
     pqApplicationCore::instance()->getServerManagerModel();
   if (!smModel)
     {
@@ -157,17 +160,17 @@ pqViewManager::pqViewManager(QWidget* _parent/*=null*/)
     this, SLOT(onViewRemoved(pqView*)));
 
   // Record creation/removal of frames.
-  QObject::connect(this, SIGNAL(frameAdded(pqMultiViewFrame*)), 
+  QObject::connect(this, SIGNAL(frameAdded(pqMultiViewFrame*)),
     this, SLOT(onFrameAdded(pqMultiViewFrame*)));
-  QObject::connect(this, SIGNAL(preFrameRemoved(pqMultiViewFrame*)), 
+  QObject::connect(this, SIGNAL(preFrameRemoved(pqMultiViewFrame*)),
     this, SLOT(onPreFrameRemoved(pqMultiViewFrame*)));
-  QObject::connect(this, SIGNAL(frameRemoved(pqMultiViewFrame*)), 
+  QObject::connect(this, SIGNAL(frameRemoved(pqMultiViewFrame*)),
     this, SLOT(onFrameRemoved(pqMultiViewFrame*)));
 
-  QObject::connect(this, 
+  QObject::connect(this,
     SIGNAL(afterSplitView(const Index&, Qt::Orientation, float, const Index&)),
     this, SLOT(onSplittingView(const Index&, Qt::Orientation, float, const Index&)));
-  
+
   QObject::connect(&this->Internal->ConvertMenu, SIGNAL(triggered(QAction*)),
     this, SLOT(onConvertToTriggered(QAction*)));
 
@@ -175,11 +178,38 @@ pqViewManager::pqViewManager(QWidget* _parent/*=null*/)
   this->init();
 
   qApp->installEventFilter(this);
+
+  // Connect the view manager to the pqActiveView.
+  QObject::connect(this, SIGNAL(activeViewChanged(pqView*)),
+    &pqActiveObjects::instance(), SLOT(setActiveView(pqView*)));
+  QObject::connect(
+    &pqActiveObjects::instance(), SIGNAL(viewChanged(pqView*)),
+    this, SLOT(setActiveView(pqView*)));
+
+  pqApplicationCore* core = pqApplicationCore::instance();
+
+  // When server disconnects, we reset the layout.
+  QObject::connect(core->getServerManagerModel(),
+    SIGNAL(finishedRemovingServer()),
+    this, SLOT(onServerDisconnect()));
+
+  // This is essential since there are various GUI components such as the
+  // pqAnimationManager that require a pqViewManager to perform certain tasks.
+  // They get access to the pqViewManager using the pqAnimationCore.
+  core->registerManager("MULTIVIEW_MANAGER", this);
+  QObject::connect(core,
+    SIGNAL(stateLoaded(vtkPVXMLElement*, vtkSMProxyLocator*)),
+    this, SLOT(loadState(vtkPVXMLElement*, vtkSMProxyLocator*)));
+  QObject::connect(core,
+    SIGNAL(stateSaved(vtkPVXMLElement*)),
+    this, SLOT(saveState(vtkPVXMLElement*)));
 }
 
 //-----------------------------------------------------------------------------
 pqViewManager::~pqViewManager()
 {
+  // they will get cleared as the application quits.
+  this->Internal->DontCreateDeleteViewsModules = true;
   // Cleanup all render modules.
   foreach (pqMultiViewFrame* frame , this->Internal->Frames.keys())
     {
@@ -191,12 +221,6 @@ pqViewManager::~pqViewManager()
   delete this->Internal;
 }
 
-//-----------------------------------------------------------------------------
-void pqViewManager::setViewOptionsManager(pqActiveViewOptionsManager* mgr)
-{
-  this->Internal->ViewOptionsManager = mgr;
-}
-
 //-----------------------------------------------------------------------------
 void pqViewManager::buildConvertMenu()
 {
@@ -225,48 +249,18 @@ void pqViewManager::buildConvertMenu()
         }
       }
     }
-    
+
   QAction* view_action = new QAction("None", this);
   view_action->setData("None");
   this->Internal->ConvertMenu.addAction(view_action);
 }
 
-//-----------------------------------------------------------------------------
-void pqViewManager::setActiveServer(pqServer* server)
-{
-  this->Internal->ActiveServer = server;
-}
-
 //-----------------------------------------------------------------------------
 pqView* pqViewManager::getActiveView() const
 {
   return this->Internal->ActiveView;
 }
 
-//-----------------------------------------------------------------------------
-void pqViewManager::setUndoStack(pqUndoStack* stack)
-{
-  if (this->Internal->UndoStack)
-    {
-    QObject::disconnect(this->Internal->UndoStack, 0, this, 0);
-    }
-
-  this->Internal->UndoStack = stack;
-
-  if (stack)
-    {
-    QObject::connect(this, SIGNAL(beginUndo(const QString&)),
-      stack, SLOT(beginUndoSet(QString)));
-    QObject::connect(this, SIGNAL(endUndo()), stack, SLOT(endUndoSet()));
-    QObject::connect(this, SIGNAL(addToUndoStack(vtkUndoElement*)),
-      stack, SLOT(addToActiveUndoSet(vtkUndoElement*)));
-    QObject::connect(this, SIGNAL(beginNonUndoableChanges()),
-      stack, SLOT(beginNonUndoableChanges()));
-    QObject::connect(this, SIGNAL(endNonUndoableChanges()),
-      stack, SLOT(endNonUndoableChanges()));
-    }
-}
-
 //-----------------------------------------------------------------------------
 void pqViewManager::updateConversionActions(pqMultiViewFrame* frame)
 {
@@ -313,13 +307,13 @@ void pqViewManager::onFrameAdded(pqMultiViewFrame* frame)
   QSignalMapper* sm = new QSignalMapper(frame);
   sm->setMapping(frame, frame);
   QObject::connect(frame, SIGNAL(activeChanged(bool)), sm, SLOT(map()));
-  QObject::connect(sm, SIGNAL(mapped(QWidget*)), 
+  QObject::connect(sm, SIGNAL(mapped(QWidget*)),
     this, SLOT(onActivate(QWidget*)));
 
   sm = new QSignalMapper(frame);
   sm->setMapping(frame, frame);
   QObject::connect(frame, SIGNAL(contextMenuRequested()), sm, SLOT(map()));
-  QObject::connect(sm, SIGNAL(mapped(QWidget*)), 
+  QObject::connect(sm, SIGNAL(mapped(QWidget*)),
     this, SLOT(onFrameContextMenuRequested(QWidget*)));
 
   // A newly added frames gets collected as an empty frame.
@@ -357,7 +351,7 @@ void pqViewManager::onFrameAdded(pqMultiViewFrame* frame)
   ui.ConvertActionsFrame->layout()->setSpacing(0);
 
   // Add buttons for all conversion actions.
-  QList<QAction*> convertActions = 
+  QList<QAction*> convertActions =
     this->Internal->ConvertMenu.actions();
   foreach (QAction* action, convertActions)
     {
@@ -385,7 +379,7 @@ void pqViewManager::onFrameRemovedInternal(pqMultiViewFrame* frame)
   this->Internal->PendingFrames.removeAll(frame);
   if (!this->Internal->Frames.contains(frame))
     {
-    // A frame with no view module has been removed. 
+    // A frame with no view module has been removed.
     return;
     }
 
@@ -417,10 +411,10 @@ void pqViewManager::onFrameRemoved(pqMultiViewFrame* frame)
 
   if (this->Internal->CloseFrameUndoElement)
     {
-    emit this->addToUndoStack(this->Internal->CloseFrameUndoElement);
+    ADD_UNDO_ELEM(this->Internal->CloseFrameUndoElement);
     this->Internal->CloseFrameUndoElement = 0;
+    END_UNDO_SET();
     }
-  emit this->endUndo();
 
   // Now activate some frame, so that we have an active view.
   if (this->Internal->Frames.size() > 0)
@@ -441,7 +435,7 @@ void pqViewManager::onFrameRemoved(pqMultiViewFrame* frame)
 //-----------------------------------------------------------------------------
 void pqViewManager::onPreFrameRemoved(pqMultiViewFrame* frame)
 {
-  emit this->beginUndo("Close View");
+  BEGIN_UNDO_SET("Close View");
 
   vtkPVXMLElement* state = vtkPVXMLElement::New();
   this->saveState(state);
@@ -455,6 +449,17 @@ void pqViewManager::onPreFrameRemoved(pqMultiViewFrame* frame)
   state->Delete();
 }
 
+//-----------------------------------------------------------------------------
+void pqViewManager::reset()
+{
+  QList<QWidget*> removed;
+  this->reset(removed);
+  foreach (QWidget* _widget, removed)
+    {
+    delete _widget;
+    }
+}
+
 //-----------------------------------------------------------------------------
 void pqViewManager::reset(QList<QWidget*> &removed)
 {
@@ -500,77 +505,6 @@ void pqViewManager::connect(pqMultiViewFrame* frame, pqView* view)
       }
     }
 
-  pqRenderView* const render_module = 
-    qobject_cast<pqRenderView*>(view);
-  if(render_module)
-    {
-    QAction* cameraAction = new QAction(QIcon(":/pqWidgets/Icons/pqEditCamera16.png"), 
-      "Adjust Camera", 
-      this);
-    cameraAction->setObjectName("CameraButton");
-    frame->addTitlebarAction(cameraAction);
-    cameraAction->setEnabled(true);
-    QObject::connect(cameraAction, SIGNAL(triggered()), 
-      this, SLOT(onCameraTriggered()));
-    }
-
-  if(view->supportsLookmarks())
-    {
-    QAction* lookmarkAction = new QAction(QIcon(":/pqWidgets/Icons/pqLookmark16.png"), 
-      "Lookmark", 
-      this);
-    lookmarkAction->setObjectName("LookmarkButton");
-    frame->addTitlebarAction(lookmarkAction);
-
-    lookmarkAction->setEnabled(true);
-    this->Internal->LookmarkSignalMapper->setMapping(lookmarkAction, frame);
-    QObject::connect(lookmarkAction, SIGNAL(triggered(bool)), 
-      this->Internal->LookmarkSignalMapper, SLOT(map()));
-    }
-
-  QAction* optionsAction = new QAction(
-    QIcon(":/pqWidgets/Icons/pqOptions16.png"), "Edit View Options", this);
-  optionsAction->setObjectName("OptionsButton");
-  optionsAction->setEnabled(false);
-  if (this->Internal->ViewOptionsManager && 
-    this->Internal->ViewOptionsManager->canShowOptions(view))
-    {
-    optionsAction->setEnabled(true);
-    }
-  frame->addTitlebarAction(optionsAction);
-  QObject::connect(optionsAction, SIGNAL(triggered()), 
-    this, SLOT(onViewOptionsRequested()));
-
-  if (view->supportsUndo())
-    {
-    // Setup undo/redo connections if the view module
-    // supports interaction undo.
-    QAction* forwardAction = new QAction(QIcon(":/pqWidgets/Icons/pqRedoCamera24.png"), 
-      "", 
-      this);
-    forwardAction->setObjectName("ForwardButton");
-    frame->addTitlebarAction(forwardAction);
-    forwardAction->setEnabled(false);
-
-    QObject::connect(forwardAction, SIGNAL( triggered ()), 
-      view, SLOT(redo()));
-    QObject::connect(view, SIGNAL(canRedoChanged(bool)),
-      forwardAction, SLOT(setEnabled(bool)));
-
-
-    QAction* backAction = new QAction(QIcon(":/pqWidgets/Icons/pqUndoCamera24.png"), 
-      "", 
-      this);
-    backAction->setObjectName("BackButton");
-    frame->addTitlebarAction(backAction);
-    backAction->setEnabled(false);
-    
-    QObject::connect(backAction, SIGNAL( triggered ()), 
-      view, SLOT(undo()));
-    QObject::connect(view, SIGNAL(canUndoChanged(bool)),
-      backAction, SLOT(setEnabled(bool)));
-    }
-
   this->Internal->Frames.insert(frame, view);
 }
 
@@ -592,61 +526,13 @@ void pqViewManager::disconnect(pqMultiViewFrame* frame, pqView* view)
     }
   frame->setMainWidget(NULL);
 
-
-  pqRenderView* const render_module = 
-    qobject_cast<pqRenderView*>(view);
-  if(render_module)
-    {
-    QAction *cameraAction= frame->getAction("CameraButton");
-    if(cameraAction)
-      {
-      frame->removeTitlebarAction(cameraAction);
-      delete cameraAction;
-      }
-    }
-
-  if(view->supportsLookmarks())
-    {
-    QAction *lookmarkAction= frame->getAction("LookmarkButton");
-    if(lookmarkAction)
-      {
-      frame->removeTitlebarAction(lookmarkAction);
-      delete lookmarkAction;
-      }
-    }
-
-  QAction *optionsAction= frame->getAction("OptionsButton");
-  if(optionsAction)
-    {
-    frame->removeTitlebarAction(optionsAction);
-    delete optionsAction;
-    }
-
-  if (view->supportsUndo())
-    {
-    QAction *forwardAction= frame->getAction("ForwardButton");
-    if(forwardAction)
-      {
-      frame->removeTitlebarAction(forwardAction);
-      delete forwardAction;
-      }
-
-
-    QAction *backAction= frame->getAction("BackButton");
-    if(backAction)
-      {
-      frame->removeTitlebarAction(backAction);
-      delete backAction;
-      }
-    }
-
-  // Search for view frame action group plugins and have them remove their 
+  // Search for view frame action group plugins and have them remove their
   // actions for this view's frame if need be.
   QObjectList ifaces =
     pqApplicationCore::instance()->getPluginManager()->interfaces();
   foreach(QObject* iface, ifaces)
     {
-    pqViewFrameActionGroupInterface* agi = 
+    pqViewFrameActionGroupInterface* agi =
         qobject_cast<pqViewFrameActionGroupInterface*>(iface);
     if(agi)
       {
@@ -671,13 +557,13 @@ void pqViewManager::assignFrame(pqView* view)
   if (this->Internal->PendingFrames.size() == 0)
     {
     // Create a new frame.
-  
-    if (this->Internal->UndoStack && (
-      this->Internal->UndoStack->getInUndo() ||
-      this->Internal->UndoStack->getInRedo()))
+
+    pqUndoStack* undoStack = pqApplicationCore::instance()->getUndoStack();
+    if (undoStack && (undoStack->getInUndo() ||
+      undoStack->getInRedo()))
       {
-      // HACK: If undo-redoing, don't split 
-      // to create a new pane, it will be created 
+      // HACK: If undo-redoing, don't split
+      // to create a new pane, it will be created
       // as a part of the undo/redo.
       this->Internal->PendingViews.push_back(view);
       return;
@@ -702,13 +588,15 @@ void pqViewManager::assignFrame(pqView* view)
       qCritical() << "Internal state of frames has got messed up!";
       return;
       }
-  
+
     this->Internal->DontCreateDeleteViewsModules = true;
     QSize cur_size = oldFrame->size();
-    if (cur_size.width() > 1.15*cur_size.height()) 
+    // Before we split, make sure that no view is currently maximized.
+    this->restoreWidget(0); // that a funny name for this un-maximize button.
+    if (cur_size.width() > 1.15*cur_size.height())
         // give a slight preference to
         // vertical splitting.
-                      
+
       {
       frame = this->splitWidgetHorizontal(oldFrame);
       }
@@ -754,7 +642,8 @@ void pqViewManager::assignFrame(pqView* view)
 //-----------------------------------------------------------------------------
 pqMultiViewFrame* pqViewManager::getFrame(pqView* view) const
 {
-  return qobject_cast<pqMultiViewFrame*>(view->getWidget()->parentWidget());
+  return view?
+    qobject_cast<pqMultiViewFrame*>(view->getWidget()->parentWidget()) : NULL;
 }
 
 //-----------------------------------------------------------------------------
@@ -837,9 +726,9 @@ void pqViewManager::onConvertToTriggered(QAction* action)
     return;
     }
 
-  emit this->beginUndo(QString("Convert View to %1").arg(type));
+  BEGIN_UNDO_SET(QString("Convert View to %1").arg(type));
 
-  pqObjectBuilder* builder = 
+  pqObjectBuilder* builder =
     pqApplicationCore::instance()-> getObjectBuilder();
   if (this->Internal->ActiveView)
     {
@@ -851,7 +740,7 @@ void pqViewManager::onConvertToTriggered(QAction* action)
     builder->createView(type, server);
     }
 
-  emit this->endUndo();
+  END_UNDO_SET();
 }
 
 //-----------------------------------------------------------------------------
@@ -873,7 +762,7 @@ void pqViewManager::onActivate(QWidget* obj)
     {
     this->Internal->ActiveView = 0;
     emit this->activeViewChanged(this->Internal->ActiveView);
-    return; 
+    return;
     }
 
   pqMultiViewFrame* frame = qobject_cast<pqMultiViewFrame*>(obj);
@@ -932,11 +821,12 @@ bool pqViewManager::eventFilter(QObject* caller, QEvent* e)
         }
       }
     }
-  else if(QApplication::instance() != caller &&
-          e->type() == QEvent::Resize)
+  else if(
+    (qobject_cast<pqMultiViewFrame*>(caller) ||
+     qobject_cast<QVTKWidget*>(caller)) && e->type() == QEvent::Resize)
     {
     // Update ViewPosition and GUISize properties on all view modules.
-    this->updateViewPositions(); 
+    this->updateViewPositions();
     }
 
   return pqMultiView::eventFilter(caller, e);
@@ -951,6 +841,8 @@ void pqViewManager::setMaxViewWindowSize(const QSize& win_size)
     {
     frame->mainWidget()->setMaximumSize(this->Internal->MaxWindowSize);
     }
+
+  emit maxViewWindowSizeSet(!win_size.isEmpty());
 }
 
 //-----------------------------------------------------------------------------
@@ -958,10 +850,10 @@ void pqViewManager::updateViewPositions()
 {
   // find a rectangle that bounds all views
   QRect totalBounds;
-  
+
   foreach(pqView* view, this->Internal->Frames)
     {
-    if (view->getWidget()->isVisible())
+    if (view->getWidget() && view->getWidget()->isVisible())
       {
       QRect bounds = view->getWidget()->rect();
       bounds.moveTo(view->getWidget()->mapToGlobal(QPoint(0,0)));
@@ -970,50 +862,105 @@ void pqViewManager::updateViewPositions()
     }
 
   /// GUISize, ViewSize and ViewPosition properties are managed
-  /// by the GUI, the undo/redo stack should not worry about 
+  /// by the GUI, the undo/redo stack should not worry about
   /// the changes made to them.
-  emit this->beginNonUndoableChanges();
+  BEGIN_UNDO_EXCLUDE();
 
   // Now we loop thorough all view modules and set the GUISize/ViewPosition.
   foreach(pqView* view, this->Internal->Frames)
     {
-    if (!view->getWidget()->isVisible())
+    // set size containing all views
+    int gui_size[2] = { totalBounds.width(), totalBounds.height() };
+    vtkSMPropertyHelper(view->getProxy(), "GUISize", true).Set(gui_size, 2);
+
+    if (!view->getWidget() || !view->getWidget()->isVisible())
+      {
+      continue;
+      }
+
+    // position relative to the bounds of all views
+    QPoint view_pos = view->getWidget()->mapToGlobal(QPoint(0,0));
+    view_pos -= totalBounds.topLeft();
+    int position[2] = { view_pos.x(), view_pos.y() };
+    vtkSMPropertyHelper(view->getProxy(), "ViewPosition", true).Set(position, 2);
+
+    // size of each view.
+    QRect bounds = view->getWidget()->rect();
+    int view_size[2] = {bounds.width(), bounds.height() };
+    vtkSMPropertyHelper(view->getProxy(), "ViewSize", true).Set(view_size, 2);
+
+    // This is causing problems with tests.
+    // view->getProxy()->UpdateProperty("ViewSize");
+    }
+
+  END_UNDO_EXCLUDE();
+  this->updateCompactViewPositions();
+
+  // Show the overlays displaying the view sizes.
+  // Disabling frame overlays for now.
+  //if (this->isVisible())
+  //  {
+  //  this->showFrameOverlays();
+  //  }
+}
+
+
+//-----------------------------------------------------------------------------
+//
+// This method is called at the end of updateViewPositions().
+// This method tries to set the properties GUISizeCompact,
+// ViewPositionCompact, and ViewSizeCompact.  For now, only the
+// vtkSMIceTMultiDisplayRenderViewProxy has these properties.
+//
+void pqViewManager::updateCompactViewPositions()
+{
+  QMap<pqMultiViewFrame*, QPair<QPoint, QSize> > ViewInfo;
+  this->computeCompactSizes(ViewInfo);
+  QSize totalGUISize = this->getMultiViewWidget()->size();
+
+  /// GUISize, ViewSize and ViewPosition properties are managed
+  /// by the GUI, the undo/redo stack should not worry about
+  /// the changes made to them.
+  BEGIN_UNDO_EXCLUDE();
+
+  // Loop for each view
+  QList<pqMultiViewFrame*> frames = ViewInfo.keys();
+  foreach(pqMultiViewFrame* frame, frames)
+    {
+    pqView * view = this->getView(frame);
+    if (!view)
       {
       continue;
       }
     vtkSMIntVectorProperty* prop = 0;
 
-    // set size containing all views
+    // Set GUISize
     prop = vtkSMIntVectorProperty::SafeDownCast(
-      view->getProxy()->GetProperty("GUISize"));
+      view->getProxy()->GetProperty("GUISizeCompact"));
     if(prop)
       {
-      prop->SetElements2(totalBounds.width(), totalBounds.height());
+      prop->SetElements2(totalGUISize.width(), totalGUISize.height());
       }
 
-    // position relative to the bounds of all views
+    // Set ViewPosition
     prop = vtkSMIntVectorProperty::SafeDownCast(
-      view->getProxy()->GetProperty("ViewPosition"));
+      view->getProxy()->GetProperty("ViewPositionCompact"));
     if(prop)
       {
-      QPoint view_pos = view->getWidget()->mapToGlobal(QPoint(0,0));
-      view_pos -= totalBounds.topLeft();
-      prop->SetElements2(view_pos.x(), view_pos.y());
+      QPoint viewPos = ViewInfo[frame].first;
+      prop->SetElements2(viewPos.x(), viewPos.y());
       }
 
-    // size of each view.
+    // Set ViewSize
     prop = vtkSMIntVectorProperty::SafeDownCast(
-      view->getProxy()->GetProperty("ViewSize"));
+      view->getProxy()->GetProperty("ViewSizeCompact"));
     if (prop)
       {
-      QRect bounds = view->getWidget()->rect();
-      prop->SetElements2(bounds.width(), bounds.height());
+      QSize viewSize = ViewInfo[frame].second;
+      prop->SetElements2(viewSize.width(), viewSize.height());
       }
-    // This is causing problems with tests.
-    // view->getProxy()->UpdateProperty("ViewSize");
     }
-
-  emit this->endNonUndoableChanges();
+  END_UNDO_EXCLUDE();
 }
 
 //-----------------------------------------------------------------------------
@@ -1046,23 +993,28 @@ void pqViewManager::saveState(vtkPVXMLElement* root)
 }
 
 //-----------------------------------------------------------------------------
-bool pqViewManager::loadState(vtkPVXMLElement* rwRoot, 
-  vtkSMStateLoaderBase* loader)
+bool pqViewManager::loadState(vtkPVXMLElement* rwRoot,
+  vtkSMProxyLocator* locator)
 {
-  if (!rwRoot || !rwRoot->GetName() || strcmp(rwRoot->GetName(), "ViewManager"))
+  if (!rwRoot || !rwRoot->GetName())
     {
-    qDebug() << "Argument must be <ViewManager /> element.";
+    // qDebug() << "Argument must be <ViewManager /> element.";
     return false;
     }
+  if (strcmp(rwRoot->GetName(), "ViewManager") != 0)
+    {
+    return this->loadState(rwRoot->FindNestedElementByName("ViewManager"),
+      locator);
+    }
 
   // When state is loaded by the server manager,
   // the View Manager will have already layed out all the view modules
   // using a default/random scheme. The role of this method
-  // is to re-arrange all the views based on the layout in the 
+  // is to re-arrange all the views based on the layout in the
   // state file.
-  this->Internal->DontCreateDeleteViewsModules = true; 
+  this->Internal->DontCreateDeleteViewsModules = true;
 
-  // We remove all "randomly" layed out frames. Note that we are not
+  // We remove all "randomly" laid out frames. Note that we are not
   // destroying the view modules, only the frames that got created
   // when the server manager state was getting loaded.
   foreach (pqMultiViewFrame* frame, this->Internal->Frames.keys())
@@ -1079,8 +1031,8 @@ bool pqViewManager::loadState(vtkPVXMLElement* rwRoot,
   this->Internal->PendingFrames.clear();
 
   this->Superclass::loadState(rwRoot);
-  this->Internal->DontCreateDeleteViewsModules = false; 
-  
+  this->Internal->DontCreateDeleteViewsModules = false;
+
   this->Internal->Frames.clear();
   for(unsigned int cc=0; cc < rwRoot->GetNumberOfNestedElements(); cc++)
     {
@@ -1094,7 +1046,7 @@ bool pqViewManager::loadState(vtkPVXMLElement* rwRoot,
       int id = 0;
       elem->GetScalarAttribute("view_module", &id);
       vtkSmartPointer<vtkSMProxy> viewModule;
-      viewModule.TakeReference(loader->NewProxy(id));
+      viewModule = locator->LocateProxy(id);
       if (!viewModule.GetPointer())
         {
         qCritical() << "Failed to locate view module mentioned in state!";
@@ -1223,10 +1175,10 @@ void pqViewManager::frameDrop(pqMultiViewFrame* acceptingFrame,
           }
         }
       }
-    
+
     if(originatingFrame && originatingFrame != acceptingFrame)
       {
-      this->hide(); 
+      this->hide();
       //Switch the originalFrame with the frame;
 
       Index originatingIndex=this->indexOf(originatingFrame);
@@ -1240,7 +1192,7 @@ void pqViewManager::frameDrop(pqMultiViewFrame* acceptingFrame,
 
       this->updateViewPositions();
       delete tempFrame;
-      
+
       this->show();
       }
     e->accept();
@@ -1252,23 +1204,17 @@ void pqViewManager::frameDrop(pqMultiViewFrame* acceptingFrame,
 }
 
 //-----------------------------------------------------------------------------
-void pqViewManager::onSplittingView(const Index& index, 
+void pqViewManager::onSplittingView(const Index& index,
   Qt::Orientation orientation, float fraction, const Index& childIndex)
 {
-  emit this->beginUndo("Split View");
+  BEGIN_UNDO_SET("Split View");
 
   pqSplitViewUndoElement* elem = pqSplitViewUndoElement::New();
   elem->SplitView(index, orientation, fraction, childIndex);
-  emit this->addToUndoStack(elem);
+  ADD_UNDO_ELEM(elem);
   elem->Delete();
 
-  emit this->endUndo();
-}
-
-//-----------------------------------------------------------------------------
-void pqViewManager::onCameraTriggered()
-{
-  emit this->triggerCameraAdjustment(this->Internal->ActiveView);
+  END_UNDO_SET();
 }
 
 #define PADDING_COMPENSATION QSize(16, 16);
@@ -1363,10 +1309,94 @@ vtkImageData* pqViewManager::captureImage(int _width, int _height)
 }
 
 //-----------------------------------------------------------------------------
-void pqViewManager::onViewOptionsRequested()
+void pqViewManager::maximizeWidget(QWidget* wdg)
 {
-  if (this->Internal->ViewOptionsManager)
+  this->Superclass::maximizeWidget(wdg);
+  this->updateViewPositions();
+}
+
+//-----------------------------------------------------------------------------
+void pqViewManager::restoreWidget(QWidget* wdg)
+{
+  this->Superclass::restoreWidget(wdg);
+  this->updateViewPositions();
+}
+
+//-----------------------------------------------------------------------------
+void pqViewManager::setActiveView(pqView* view)
+{
+  if (this->Internal->ActiveView == view)
     {
-    this->Internal->ViewOptionsManager->showOptions();
+    return;
+    }
+
+  // Locate the frame for the view and activate it.
+  pqMultiViewFrame* frame = this->getFrame(view);
+  if (frame)
+    {
+    frame->setActive(true);
+    }
+  else if (this->Internal->ActiveView)
+    {
+    frame = this->getFrame(this->Internal->ActiveView);
+    if (frame)
+      {
+      frame->setActive(false);
+      }
     }
 }
+
+//-----------------------------------------------------------------------------
+void pqViewManager::onServerDisconnect()
+{
+  QList<QWidget*> removed;
+  this->reset(removed);
+  foreach (QWidget* _widget, removed)
+    {
+    delete _widget;
+    }
+}
+
+//-----------------------------------------------------------------------------
+void pqViewManager::showFrameOverlays()
+{
+  // when running tests, don't show the overlay labels as they may interfere
+  // with the screen captures.
+  if (pqApplicationCore::instance()->getOptions()->GetDisableRegistry())
+    {
+    return;
+    }
+  this->Internal->OverlayCleanupTimer.start();
+
+  pqInternals::FrameMapType::iterator iter;
+  for (iter = this->Internal->Frames.begin();
+    iter != this->Internal->Frames.end(); ++iter)
+    {
+    if (iter.value() == NULL)
+      {
+      continue;
+      }
+    QLabel* label = this->Internal->FrameOverlays[iter.key()];
+    if (label == NULL)
+      {
+      label = new QLabel("Overlay Text", iter.key(), Qt::ToolTip);
+      this->Internal->FrameOverlays[iter.key()] = label;
+      }
+    QSize curFrameSize(iter.value()->getWidget()->size());
+    label->move(iter.value()->getWidget()->mapToGlobal(
+        QPoint(curFrameSize.width()/2-30, curFrameSize.height()/2-10)));
+    label->setText(QString(" (%1, %2) ").arg(curFrameSize.width()).arg(
+        curFrameSize.height()));
+    label->show();
+    }
+}
+
+//-----------------------------------------------------------------------------
+void pqViewManager::destroyFrameOverlays()
+{
+  foreach (QLabel* label, this->Internal->FrameOverlays)
+    {
+    delete label;
+    }
+  this->Internal->FrameOverlays.clear();
+}
