@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqAnimationScene.cxx,v $
+   Module:    pqAnimationScene.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -32,14 +32,18 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqAnimationScene.h"
 
 #include "vtkAnimationCue.h"
+#include "vtkBoundingBox.h"
 #include "vtkCommand.h"
 #include "vtkEventQtSlotConnect.h"
+#include "vtkPoints.h"
 #include "vtkProcessModule.h"
-#include "vtkSMViewProxy.h"
 #include "vtkSMAnimationSceneProxy.h"
 #include "vtkSmartPointer.h"
+#include "vtkSMPropertyHelper.h"
 #include "vtkSMPropertyLink.h"
 #include "vtkSMProxyProperty.h"
+#include "vtkSMUtilities.h"
+#include "vtkSMViewProxy.h"
 
 #include <QPointer>
 #include <QSet>
@@ -51,6 +55,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqObjectBuilder.h"
 #include "pqServer.h"
 #include "pqServerManagerModel.h"
+#include "pqServerManagerSelectionModel.h"
+#include "pqSettings.h"
 #include "pqSMAdaptor.h"
 #include "pqSMProxy.h"
 #include "pqTimeKeeper.h"
@@ -65,12 +71,10 @@ static uint qHash(QPointer<T> p)
 class pqAnimationScene::pqInternals
 {
 public:
-  vtkSmartPointer<vtkSMPropertyLink> TimestepValuesLink;
   QSet<QPointer<pqAnimationCue> > Cues;
   QPointer<pqAnimationCue> GlobalTimeCue;
   pqInternals()
     {
-    this->TimestepValuesLink = vtkSmartPointer<vtkSMPropertyLink>::New();
     }
 };
 
@@ -101,15 +105,12 @@ pqAnimationScene::pqAnimationScene(const QString& group, const QString& name,
   connector->Connect(
     proxy->GetProperty("NumberOfFrames"), vtkCommand::ModifiedEvent,
     this, SIGNAL(frameCountChanged()));
-  connector->Connect(
-    proxy->GetProperty("TimeSteps"), vtkCommand::ModifiedEvent,
-    this, SIGNAL(timeStepsChanged()));
 
   connector->Connect(
-    proxy->GetProperty("StartTime"), vtkCommand::ModifiedEvent,
+    proxy->GetProperty("StartTimeInfo"), vtkCommand::ModifiedEvent,
     this, SIGNAL(clockTimeRangesChanged()));
   connector->Connect(
-    proxy->GetProperty("EndTime"), vtkCommand::ModifiedEvent,
+    proxy->GetProperty("EndTimeInfo"), vtkCommand::ModifiedEvent,
     this, SIGNAL(clockTimeRangesChanged()));
   connector->Connect(
     proxy->GetProperty("AnimationTime"), vtkCommand::ModifiedEvent,
@@ -143,6 +144,9 @@ void  pqAnimationScene::setDefaultPropertyValues()
     this->getServer()->getTimeKeeper()->getProxy(),
     "Time", 0);
   this->setAnimationTime(0.0);
+
+  // Sync to application settings.
+  this->updateApplicationSettings();
 }
 
 //-----------------------------------------------------------------------------
@@ -150,63 +154,45 @@ void pqAnimationScene::setupTimeTrack()
 {
   pqTimeKeeper* timekeeper = this->getServer()->getTimeKeeper();
 
-  QObject::connect(timekeeper, SIGNAL(timeStepsChanged()),
-    this, SLOT(updateTimeRanges()));
-
   vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(
     this->getProxy()->GetProperty("TimeKeeper"));
-  if (pp && pp->GetNumberOfProxies() == 0)
+  if (pp)
     {
+    pp->RemoveAllProxies();
     pp->AddProxy(timekeeper->getProxy());
     this->getProxy()->UpdateVTKObjects();
     }
 
-  // Link timekeeper properties.
-  this->Internals->TimestepValuesLink->AddLinkedProperty(
-    timekeeper->getProxy(), "TimestepValues", vtkSMLink::INPUT);
-  this->Internals->TimestepValuesLink->AddLinkedProperty(
-    this->getProxy(), "TimeSteps", vtkSMLink::OUTPUT);
-  timekeeper->getProxy()->GetProperty("TimestepValues")->Modified();
-  this->updateTimeRanges();
+  QObject::connect(timekeeper, SIGNAL(timeStepsChanged()),
+    this, SLOT(updateTimeSteps()));
+  QObject::connect(timekeeper, SIGNAL(timeRangeChanged()),
+    this, SLOT(updateTimeSteps()));
+  this->updateTimeSteps();
 }
 
 //-----------------------------------------------------------------------------
-void pqAnimationScene::updateTimeRanges()
+void pqAnimationScene::updateTimeSteps()
 {
   pqTimeKeeper* timekeeper = this->getServer()->getTimeKeeper();
   if (pqApplicationCore::instance()->isLoadingState())
     {
     // If we are currently loading state then we don't want to change
     // the currently set start/end times.
+
+    // however we still do need to relay the timeStepsChanged signal to ensure
+    // that GUI components are updated correctly.
+    emit this->timeStepsChanged();
     return;
     }
 
-  QPair<double, double> range = timekeeper->getTimeRange();
   vtkSMProxy* sceneProxy = this->getProxy();
 
-  // Only adjust the time range if the one in the timekeeper looks valid.
-  if (range.first < range.second)
-    {
-    QList<QVariant> locks = pqSMAdaptor::getMultipleElementProperty(
-                                sceneProxy->GetProperty("ClockTimeRangeLocks"));
-    if (!locks[0].toBool())
-      {
-      pqSMAdaptor::setElementProperty(
-                     sceneProxy->GetProperty("StartTime"), range.first);
-      }
-    if (!locks[1].toBool())
-      {
-      pqSMAdaptor::setElementProperty(
-                    sceneProxy->GetProperty("EndTime"), range.second);
-      }
-    }
-
   // Adjust the play mode based on whether or not we have time steps.
   vtkSMProperty *playModeProperty = sceneProxy->GetProperty("PlayMode");
-  if (timekeeper->getNumberOfTimeStepValues() == 0)
+  if (timekeeper->getNumberOfTimeStepValues() <= 1)
     {
     if (pqSMAdaptor::getEnumerationProperty(playModeProperty)
-        == "Snap To TimeSteps" )
+      == "Snap To TimeSteps" )
       {
       pqSMAdaptor::setEnumerationProperty(playModeProperty, "Sequence");
       }
@@ -215,29 +201,46 @@ void pqAnimationScene::updateTimeRanges()
     {
     pqSMAdaptor::setEnumerationProperty(playModeProperty, "Snap To TimeSteps");
     }
-  sceneProxy->UpdateVTKObjects();
 
-  // If the animation time is not in the scene time range, set it to the min
-  // value.
+  sceneProxy->UpdateVTKObjects();
+  // This will internally adjust the Start and End times for the animation scene
+  // based of the Locks for the times. We not simply need to copy the info
+  // property values.
+
+
+  /// If the animation time is not in the scene time range, set it to the min
+  /// value.
   double min = pqSMAdaptor::getElementProperty(
-    sceneProxy->GetProperty("StartTime")).toDouble();
+    sceneProxy->GetProperty("StartTimeInfo")).toDouble();
   double max = pqSMAdaptor::getElementProperty(
-    sceneProxy->GetProperty("EndTime")).toDouble();
+    sceneProxy->GetProperty("EndTimeInfo")).toDouble();
   double cur = pqSMAdaptor::getElementProperty(
     sceneProxy->GetProperty("AnimationTime")).toDouble();
+
+  // Ensure that the values of the properties match the times used.
+  pqSMAdaptor::setElementProperty(sceneProxy->GetProperty("StartTime"), min);
+  pqSMAdaptor::setElementProperty(sceneProxy->GetProperty("EndTime"), max);
+  sceneProxy->UpdateVTKObjects();
   if (cur < min || cur > max)
     {
     this->setAnimationTime(min);
     }
+  emit this->timeStepsChanged();
+}
+
+//-----------------------------------------------------------------------------
+QList<double> pqAnimationScene::getTimeSteps() const
+{
+  return this->getServer()->getTimeKeeper()->getTimeSteps();;
 }
 
 //-----------------------------------------------------------------------------
 QPair<double, double> pqAnimationScene::getClockTimeRange() const
 {
   double start = pqSMAdaptor::getElementProperty(
-    this->getProxy()->GetProperty("StartTime")).toDouble();
+    this->getProxy()->GetProperty("StartTimeInfo")).toDouble();
   double end = pqSMAdaptor::getElementProperty(
-    this->getProxy()->GetProperty("EndTime")).toDouble();
+    this->getProxy()->GetProperty("EndTimeInfo")).toDouble();
   return QPair<double,double>(start, end);
 }
 
@@ -339,6 +342,129 @@ pqAnimationCue* pqAnimationScene::createCue(vtkSMProxy* proxy,
     proxy, propertyname, index);
 }
 
+//-----------------------------------------------------------------------------
+static void pqAnimationSceneResetCameraKeyFrameToCurrent(vtkSMProxy* ren,
+                                                         vtkSMProxy* dest)
+{
+  ren->UpdatePropertyInformation();
+  const char* names[] = { "Position", "FocalPoint", "ViewUp", "ViewAngle",  0 };
+  const char* snames[] = { "CameraPositionInfo", "CameraFocalPointInfo", 
+    "CameraViewUpInfo",  "CameraViewAngle", 0 };
+  for (int cc=0; names[cc] && snames[cc]; cc++)
+    {
+    QList<QVariant> p =
+      pqSMAdaptor::getMultipleElementProperty(ren->GetProperty(snames[cc]));
+    pqSMAdaptor::setMultipleElementProperty(dest->GetProperty(names[cc]),p);
+    }
+}
+
+//-----------------------------------------------------------------------------
+/// Initialize the cue with some default key frames.
+void pqAnimationScene::initializeCue(
+  vtkSMProxy* proxy, const char* propertyname, int index,
+  pqAnimationCue* cue)
+{
+  // (This code has simply been moved from pqAnimationViewWidget to keep it
+  // centralized in the "controller". Ideally this may even move to the server
+  // manager layer -- but I'll do that in the next iteration as the location
+  // for the controller materializes.)
+
+  QString cueType = cue->getProxy()->GetXMLName();
+  if (cueType == "KeyFrameAnimationCue")
+    {
+    // Create a pair of default keyframes for this new cue.
+    vtkSMProxy* kf1 = cue->insertKeyFrame(0);
+    vtkSMProxy* kf2 = cue->insertKeyFrame(1);
+
+    // Initialize default values for the newly keyframes based on the domain
+    // for the property to be animated.
+    vtkSMProperty* prop = proxy->GetProperty(propertyname);
+    QList<QVariant> mins;
+    QList<QVariant> maxs;
+    if (index == -1 && prop)
+      {
+      QList<QList<QVariant> > domains =
+        pqSMAdaptor::getMultipleElementPropertyDomain(prop);
+      QList<QVariant> currents = pqSMAdaptor::getMultipleElementProperty(prop);
+      for (int i=0; i<currents.size(); i++)
+        {
+        if (domains.size() > i && domains[i].size())
+          {
+          mins.append(domains[i][0].isValid() ? domains[i][0] : currents[i]);
+          maxs.append(domains[i][1].isValid() ? domains[i][1] : currents[i]);
+          }
+        else
+          {
+          mins.append(currents[i]);
+          maxs.append(currents[i]);
+          }
+        }
+      }
+    else
+      {
+      QList<QVariant> domain =
+        pqSMAdaptor::getMultipleElementPropertyDomain(prop, index);
+      QVariant current = pqSMAdaptor::getMultipleElementProperty(prop, index);
+      if (domain.size() && domain[0].isValid())
+        {
+        mins.append(domain[0]);
+        }
+      else
+        {
+        mins.append(current);
+        }
+      if (domain.size() && domain[1].isValid())
+        {
+        maxs.append(domain[1]);
+        }
+      else
+        {
+        maxs.append(current);
+        }
+      }
+
+    pqSMAdaptor::setMultipleElementProperty(
+      kf1->GetProperty("KeyValues"), mins);
+    pqSMAdaptor::setMultipleElementProperty(
+      kf2->GetProperty("KeyValues"), maxs);
+    kf1->UpdateVTKObjects();
+    kf2->UpdateVTKObjects();
+    }
+  else if (cueType == "CameraAnimationCue")
+    {
+    cue->setKeyFrameType("CameraKeyFrame");
+
+    // Setup default animation to revolve around the selected objects (if any)
+    // in a plane normal to the current view-up vector.
+    pqSMAdaptor::setElementProperty(
+      cue->getProxy()->GetProperty("Mode"), 1); // PATH-based animation.
+    vtkSMProxy* kf0 = cue->insertKeyFrame(0);
+    vtkSMProxy* kf1 = cue->insertKeyFrame(1);
+    pqAnimationSceneResetCameraKeyFrameToCurrent(proxy, kf0);
+    pqAnimationSceneResetCameraKeyFrameToCurrent(proxy, kf1);
+    kf0->UpdateVTKObjects();
+    kf1->UpdateVTKObjects();
+
+    double bounds[6] = {-1, 1, -1, 1, -1, 1};
+    pqApplicationCore::instance()->getSelectionModel()->getSelectionDataBounds(
+      bounds);
+
+    vtkBoundingBox bbox(bounds);
+    double center[3];
+    bbox.GetCenter(center);
+    vtkPoints* pts = vtkSMUtilities::CreateOrbit(center,
+      vtkSMPropertyHelper(kf0, "ViewUp").GetAsDoublePtr(),
+      5*bbox.GetMaxLength()/2.0, 10);
+    vtkSMPropertyHelper(kf0, "PositionPathPoints").Set(
+      reinterpret_cast<double*>(pts->GetVoidPointer(0)),
+      pts->GetNumberOfPoints()*3);
+    vtkSMPropertyHelper(kf0, "ClosedPositionPath").Set(1);
+    vtkSMPropertyHelper(kf0, "FocalPathPoints").Set(center, 3);
+    kf0->UpdateVTKObjects();
+    pts->Delete();
+    }
+}
+
 //-----------------------------------------------------------------------------
 pqAnimationCue* pqAnimationScene::createCueInternal(const QString& cuetype,
   vtkSMProxy* proxy, const char* propertyname, int index) 
@@ -368,6 +494,8 @@ pqAnimationCue* pqAnimationScene::createCueInternal(const QString& cuetype,
   pqSMAdaptor::addProxyProperty(sceneProxy->GetProperty("Cues"), cueProxy);
   sceneProxy->UpdateVTKObjects();
 
+  this->initializeCue(proxy, propertyname, index, cue);
+
   // We don't directly add this cue to the internal Cues, it will get added
   // as a side effect of the change in the "Cues" property.
   return cue;
@@ -484,3 +612,41 @@ void pqAnimationScene::onTick(vtkObject*, unsigned long, void*, void* info)
   this->setAnimationTime(cueInfo->AnimationTime);
   emit this->tick(progress);
 }
+
+//-----------------------------------------------------------------------------
+void pqAnimationScene::updateApplicationSettings()
+{
+  vtkSMAnimationSceneProxy *sceneProxy = this->getAnimationSceneProxy();
+  pqSMAdaptor::setElementProperty(sceneProxy->GetProperty("Caching"),
+                                  this->getCacheGeometrySetting());
+  pqSMAdaptor::setElementProperty(sceneProxy->GetProperty("CacheLimit"),
+                                  this->getCacheLimitSetting());
+}
+
+//-----------------------------------------------------------------------------
+void pqAnimationScene::setCacheGeometrySetting(bool flag)
+{
+  pqSettings *settings = pqApplicationCore::instance()->settings();
+  settings->setValue("Animation/CacheGeometry", flag);
+}
+
+//-----------------------------------------------------------------------------
+bool pqAnimationScene::getCacheGeometrySetting()
+{
+  pqSettings *settings = pqApplicationCore::instance()->settings();
+  return settings->value("Animation/CacheGeometry", true).toBool();
+}
+
+//-----------------------------------------------------------------------------
+void pqAnimationScene::setCacheLimitSetting(int kilobytes)
+{
+  pqSettings *settings = pqApplicationCore::instance()->settings();
+  settings->setValue("Animation/CacheLimit", kilobytes);
+}
+
+//-----------------------------------------------------------------------------
+int pqAnimationScene::getCacheLimitSetting()
+{
+  pqSettings *settings = pqApplicationCore::instance()->settings();
+  return settings->value("Animation/CacheLimit", 100*1024).toInt();
+}
