@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqDataRepresentation.cxx,v $
+   Module:    pqDataRepresentation.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -32,6 +32,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqDataRepresentation.h"
 
 #include "vtkEventQtSlotConnect.h"
+#include "vtkPVDataInformation.h"
 #include "vtkSMDataRepresentationProxy.h"
 #include "vtkSMInputProperty.h"
 #include "vtkSMSourceProxy.h"
@@ -208,6 +209,18 @@ unsigned long pqDataRepresentation::getFullResMemorySize()
   return 0;
 }
 
+//-----------------------------------------------------------------------------
+bool pqDataRepresentation::getDataBounds(double bounds[6])
+{
+  vtkPVDataInformation* info = this->getRepresentedDataInformation(true);
+  if (!info)
+    {
+    return false;
+    }
+  info->GetBounds(bounds);
+  return true;
+}
+
 //-----------------------------------------------------------------------------
 vtkPVDataInformation* pqDataRepresentation::getRepresentedDataInformation(
   bool update/*=true*/) const
@@ -224,19 +237,23 @@ vtkPVDataInformation* pqDataRepresentation::getRepresentedDataInformation(
 //-----------------------------------------------------------------------------
 vtkPVDataInformation* pqDataRepresentation::getInputDataInformation() const
 {
-  if (!this->getInput())
+  if (!this->getOutputPortFromInput())
     {
     return 0;
     }
 
-  vtkSMSourceProxy* source = vtkSMSourceProxy::SafeDownCast(
-    this->getInput()->getProxy());
-  if (source)
+  return this->getOutputPortFromInput()->getDataInformation();
+}
+
+//-----------------------------------------------------------------------------
+vtkPVTemporalDataInformation* pqDataRepresentation::getInputTemporalDataInformation() const
+{
+  if (!this->getOutputPortFromInput())
     {
-    return source->GetDataInformation(
-      this->getOutputPortFromInput()->getPortNumber());
+    return 0;
     }
-  return 0;
+
+  return this->getOutputPortFromInput()->getTemporalDataInformation();
 }
 
 //-----------------------------------------------------------------------------
