@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqDataRepresentation.h,v $
+   Module:    pqDataRepresentation.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -40,6 +40,7 @@ class pqPipelineSource;
 class pqScalarOpacityFunction;
 class pqScalarsToColors;
 class vtkPVDataInformation;
+class vtkPVTemporalDataInformation;
 
 /// pqDataRepresentation is the superclass for a display for a pqPipelineSource
 /// i.e. the input for this display proxy is a pqPiplineSource.
@@ -66,12 +67,20 @@ public:
   /// as input. 
   vtkPVDataInformation* getInputDataInformation() const;
 
+  /// Returns the temporal data information for the input. This can be a very
+  /// slow process. Use with extreme caution!!!
+  vtkPVTemporalDataInformation* getInputTemporalDataInformation() const;
+
   /// Returns the represented data information. Depending on the representation
   /// this may differ from the input data information eg. if the representation
   /// shows an outline of the data, the this method will return the information
   /// about the polydata forming the outline not the input dataset.
   vtkPVDataInformation* getRepresentedDataInformation(bool update=true) const;
 
+  /// Get the data bounds for the input of this display.
+  /// Returns if the operation was successful.
+  bool getDataBounds(double bounds[6]);
+
   /// Returns the lookuptable proxy, if any.
   /// Most consumer displays take a lookup table. This method
   /// provides access to the Lookup table, if one exists.
