@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqFileDialog.h,v $
+   Module:    pqFileDialog.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -109,6 +109,9 @@ public:
   /// set the file mode
   void setFileMode(FileMode);
 
+  /// set the most recently used file extension
+  void setRecentlyUsedExtension(const QString& fileExtension);
+
   /// Returns the set of files
   QStringList getSelectedFiles();
 
@@ -137,10 +140,12 @@ private slots:
   void onNavigateDown(const QModelIndex&);
   void onFilterChange(const QString&);
 
+  void onClickedRecent(const QModelIndex&);
   void onClickedFavorite(const QModelIndex&);
   void onClickedFile(const QModelIndex&);
   
   void onActivateFavorite(const QModelIndex&);
+  void onActivateRecent(const QModelIndex&);
   void onActivateFile(const QModelIndex&);
   
   void onTextEdited(const QString&);
