@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqLookupTableManager.h,v $
+   Module:    pqLookupTableManager.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -36,8 +36,11 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqCoreExport.h"
 
 class pqProxy;
+class pqScalarBarRepresentation;
 class pqScalarsToColors;
+class pqScalarOpacityFunction;
 class pqServer;
+class pqView;
 
 /// pqLookupTableManager is the manager that manages color lookup objects.
 /// This is an abstract class that defines the API for any LUT manager.
@@ -55,10 +58,32 @@ public:
   /// can implemenent their own policy for managing lookup tables.
   virtual pqScalarsToColors* getLookupTable(pqServer* server, 
     const QString& arrayname, int number_of_components, int component) = 0;
+    
+  /// Returns the pqScalarOpacityFunction object for the piecewise
+  /// function used to map scalars to opacity.
+  virtual pqScalarOpacityFunction* getScalarOpacityFunction(pqServer* server, 
+    const QString& arrayname, int number_of_components, int component) = 0;
 
-  /// Saves the state of the lut so that the next time a new LUT is created, it
+  /// Saves the state of the lut/opacity-function so that 
+  /// the next time a new LUT/opacity-function is created, it
   /// will have the same state as this one.
-  virtual void saveAsDefault(pqScalarsToColors*)=0;
+  virtual void saveLUTAsDefault(pqScalarsToColors*)=0;
+  virtual void saveOpacityFunctionAsDefault(pqScalarOpacityFunction*)=0;
+  
+  /// Set the scalar bar's visibility for the given lookup table in the given
+  /// view. This may result in creating of a new scalar bar.
+  /// This assumes that the pqScalarsToColors passed as an argument is indeed
+  /// managed by this pqLookupTableManager (that's needed to determine the
+  /// default labels for the scalar bar if a new scalar bar is created).
+  /// Returns the scalar bar, if any.
+  virtual pqScalarBarRepresentation* setScalarBarVisibility(
+    pqView* view, pqScalarsToColors*, bool visible);
+
+  /// Used to get the array the \c lut is associated with.
+  /// Return false if no such association exists.
+  virtual bool getLookupTableProperties(pqScalarsToColors* lut,
+    QString& arrayname, int &numComponents, int &component)=0;
+
 public slots:
   /// Called to update scalar ranges of all lookup tables.
   virtual void updateLookupTableScalarRanges()=0;
@@ -80,6 +105,12 @@ protected:
 
   /// Called when a LUT is removed.
   virtual void onRemoveLookupTable(pqScalarsToColors* lut) = 0;
+  
+  /// Called when a OpactiyFunction is added.
+  virtual void onAddOpacityFunction(pqScalarOpacityFunction*){}
+
+  /// Called when a OpactiyFunction is removed.
+  virtual void onRemoveOpacityFunction(pqScalarOpacityFunction*){}
 
 };
 
