@@ -48,6 +48,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QtDebug>
 #include <QFileInfo>
 
+#include "pqAnimationCue.h"
 #include "pqAnimationScene.h"
 #include "pqApplicationCore.h"
 #include "pqDataRepresentation.h"
@@ -908,6 +909,26 @@ void pqObjectBuilder::removeServer(pqServer* server)
   core->getServerManagerModel()->endRemoveServer();
 }
 
+//-----------------------------------------------------------------------------
+void pqObjectBuilder::destroy(pqAnimationCue* cue)
+{
+  if (!cue)
+    {
+    return;
+    }
+
+  vtkSMProxyManager* pxm = vtkSMProxyManager::GetProxyManager();
+
+  QList<vtkSMProxy*> keyframes = cue->getKeyFrames();
+  // unregister all the keyframes.
+  foreach (vtkSMProxy* kf, keyframes)
+    {
+    pxm->UnRegisterProxy("animation",
+      pxm->GetProxyName("animation", kf), kf);
+    }
+  this->destroy(static_cast<pqProxy*>(cue));
+}
+
 //-----------------------------------------------------------------------------
 void pqObjectBuilder::initializeInheritedProperties(pqDataRepresentation* repr)
 {
