@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqObjectBuilder.h,v $
+   Module:    pqObjectBuilder.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -35,7 +35,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <QObject>
 #include "pqCoreExport.h"
 #include <QMap>
+#include <QVariant>
 
+class pqAnimationCue;
 class pqAnimationScene;
 class pqDataRepresentation;
 class pqNameCount;
@@ -46,9 +48,9 @@ class pqRepresentation;
 class pqScalarBarRepresentation;
 class pqScalarsToColors;
 class pqServer;
+class pqServerResource;
 class pqView;
 class vtkSMProxy;
-class pqServerResource;
 
 /// pqObjectBuilder is loosely based on the \c Builder design pattern.
 /// It is used to create as well as destroy complex objects such as 
@@ -91,11 +93,22 @@ public:
   virtual pqPipelineSource* createFilter(
     const QString& group, const QString& name,
     QMap<QString, QList<pqOutputPort*> > namedInputs, pqServer* server);
+  /// Creates a filter with the given Server Manager group (\c sm_group) and
+  /// name (\c sm_name). If the filter accepts multiple inputs, all the inputs
+  /// provided in the list are set as input, instead only the first one
+  /// is set as the input. All inputs must be on the same server.
+  /// This also takes properties to initialize the filter with.
+  /// Note: a separate function was added as opposed to making the last
+  /// parameter with a default value due to bug in gcc < 4.4
+  virtual pqPipelineSource* createFilter(
+    const QString& group, const QString& name,
+    QMap<QString, QList<pqOutputPort*> > namedInputs, pqServer* server,
+    const QMap<QString, QVariant>& properties);
 
   /// Convenience method that takes a single input source.
   virtual pqPipelineSource* createFilter(
     const QString& group, const QString& name,
-    pqPipelineSource* input);
+    pqPipelineSource* input, int output_port = 0);
 
   /// Creates a reader of the given server manager group (\c sm_group) and 
   /// name (\c sm_name) on the given \c server. On success, returns the
@@ -145,6 +158,9 @@ public:
   // one cannot delete the source.
   virtual void destroy(pqPipelineSource* source);
 
+  /// Destroys an animation cue and all keyframe objects, if any in that cue.
+  virtual void destroy(pqAnimationCue* cue);
+
   /// Convenience method, simply unregisters the Server Manager proxy 
   /// which the pqProxy represents.
   virtual void destroy(pqProxy* proxy);
@@ -167,7 +183,7 @@ public:
   /// This is a convenience method to return the name of the
   /// property on the proxy, if any, which can be used to set the filename.
   /// If no such property exists, this retruns a null string.
-  QString getFileNamePropertyName(vtkSMProxy*)  const;
+  static QString getFileNamePropertyName(vtkSMProxy*);
   
   // HACK: pqSimpleServerStartup needs to fire the
   // finishedAddingServer() signal on successful
@@ -265,7 +281,8 @@ protected:
   /// a new name will be assigned to it.
   virtual vtkSMProxy* createProxyInternal(const QString& sm_group, 
     const QString& sm_name, pqServer* server, 
-    const QString& reg_group, const QString& reg_name=QString());
+    const QString& reg_group, const QString& reg_name,
+    const QMap<QString, QVariant>& properties);
 
   /// Unregisters a proxy.
   virtual void destroyProxyInternal(pqProxy* proxy);
