@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqPipelineRepresentation.cxx,v $
+   Module:    pqPipelineRepresentation.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -45,8 +45,12 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkPVArrayInformation.h"
 #include "vtkPVDataSetAttributesInformation.h"
 #include "vtkPVGeometryInformation.h"
+#include "vtkPVTemporalDataInformation.h"
+#include "vtkScalarsToColors.h"
 #include "vtkSmartPointer.h" 
 #include "vtkSMDoubleVectorProperty.h"
+#include "vtkSMGlobalPropertiesManager.h"
+#include "vtkSMPropertyHelper.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMProxyProperty.h"
 #include "vtkSMPVRepresentationProxy.h"
@@ -62,6 +66,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // ParaView includes.
 #include "pqApplicationCore.h"
+#include "pqDisplayPolicy.h"
 #include "pqLookupTableManager.h"
 #include "pqObjectBuilder.h"
 #include "pqOutputPort.h"
@@ -75,7 +80,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqServerManagerModel.h"
 #include "pqSettings.h"
 #include "pqSMAdaptor.h"
-#include "pqDisplayPolicy.h"
+#include "pqUndoStack.h"
 
 //-----------------------------------------------------------------------------
 class pqPipelineRepresentation::pqInternal
@@ -83,12 +88,12 @@ class pqPipelineRepresentation::pqInternal
 public:
   vtkSmartPointer<vtkSMPropRepresentationProxy> RepresentationProxy;
   vtkSmartPointer<vtkEventQtSlotConnect> VTKConnect;
-  pqScalarOpacityFunction *Opacity;
+//  pqScalarOpacityFunction *Opacity;
 
   pqInternal()
     {
     this->VTKConnect = vtkSmartPointer<vtkEventQtSlotConnect>::New();
-    this->Opacity = 0;
+//    this->Opacity = 0;
     }
 
   // Convenience method to get array information.
@@ -166,6 +171,15 @@ pqPipelineRepresentation::pqPipelineRepresentation(
 
   QObject::connect(this, SIGNAL(visibilityChanged(bool)),
     this, SLOT(updateScalarBarVisibility(bool)));
+
+  // Whenever the pipeline gets be updated, it's possible that the scalar ranges
+  // change. If that happens, we try to ensure that the lookuptable range is big
+  // enough to show the entire data (unless of course, the user locked the
+  // lookuptable ranges).
+  this->Internal->VTKConnect->Connect(
+    display, vtkCommand::UpdateDataEvent,
+    this, SLOT(onDataUpdated()));
+  this->UpdateLUTRangesOnDataUpdate = true;
 }
 
 //-----------------------------------------------------------------------------
@@ -193,15 +207,11 @@ pqScalarOpacityFunction* pqPipelineRepresentation::getScalarOpacityFunction()
 {
   if(this->getRepresentationType() == vtkSMPVRepresentationProxy::VOLUME)
     {
-    if(!this->Internal->Opacity)
-      {
-      // TODO: Add the opacity function to the server manager model.
-      this->Internal->Opacity = new pqScalarOpacityFunction(
-        "piecewise_functions", "PiecewiseFunction",
-        this->getScalarOpacityFunctionProxy(), this->getServer(), this);
-      }
+    pqServerManagerModel* smmodel = 
+      pqApplicationCore::instance()->getServerManagerModel();
+    vtkSMProxy* opf = this->getScalarOpacityFunctionProxy();
 
-    return this->Internal->Opacity;
+    return (opf? smmodel->findItem<pqScalarOpacityFunction*>(opf): 0);
     }
 
   return 0;
@@ -231,6 +241,30 @@ void pqPipelineRepresentation::createHelperProxies()
     }
 }
 
+//-----------------------------------------------------------------------------
+void pqPipelineRepresentation::onInputChanged()
+{
+  if (this->getInput())
+    {
+    QObject::disconnect(this->getInput(),
+      SIGNAL(modifiedStateChanged(pqServerManagerModelItem*)),
+      this, SLOT(onInputAccepted()));
+    }
+
+  this->Superclass::onInputChanged();
+
+  if (this->getInput())
+    {
+    /// We need to try to update the LUT ranges only when the user manually
+    /// changed the input source object (not necessarily ever pipeline update
+    /// which can happen when time changes -- for example). So we listen to this
+    /// signal. BUG #10062.
+    QObject::connect(this->getInput(),
+      SIGNAL(modifiedStateChanged(pqServerManagerModelItem*)),
+      this, SLOT(onInputAccepted()));
+    }
+}
+
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::setDefaultPropertyValues()
 {
@@ -246,7 +280,9 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     return;
     }
 
-  this->createHelperProxies();
+  // The HelperProxy is not needed any more since now the OpacityFunction is 
+  // created from LookupTableManager (Bug# 0008876)
+  // this->createHelperProxies();
 
   vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
   if (!repr)
@@ -256,13 +292,26 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
 
   pqSMAdaptor::setEnumerationProperty(repr->GetProperty("SelectionRepresentation"),
     "Wireframe");
-  pqSMAdaptor::setMultipleElementProperty(repr->GetProperty("SelectionColor"),
-    0, 1.0);
-  pqSMAdaptor::setMultipleElementProperty(repr->GetProperty("SelectionColor"),
-    1, 0.0);
-  pqSMAdaptor::setMultipleElementProperty(repr->GetProperty("SelectionColor"),
-    2, 1.0);
   pqSMAdaptor::setElementProperty(repr->GetProperty("SelectionLineWidth"), 2);
+  pqSMAdaptor::setElementProperty(repr->GetProperty("SelectionPointSize"), 5);
+
+  // Set up some global property links by default.
+  vtkSMGlobalPropertiesManager* globalPropertiesManager =
+    pqApplicationCore::instance()->getGlobalPropertiesManager();
+  // Note that the representation created for the 2D view doesn't even have
+  // these properties.
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "SelectionColor", repr, "SelectionColor");
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "SurfaceColor", repr, "DiffuseColor");
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "ForegroundColor", repr, "AmbientColor");
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "EdgeColor", repr, "EdgeColor");
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "SurfaceColor", repr, "BackfaceDiffuseColor");
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "ForegroundColor", repr, "CubeAxesColor");
 
   // if the source created a new point scalar, use it
   // else if the source created a new cell scalar, use it
@@ -278,7 +327,7 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
   // Get the time that this representation is going to use.
   vtkPVDataInformation* dataInfo = 0;
 
-  dataInfo = this->getOutputPortFromInput()->getDataInformation(true);
+  dataInfo = this->getOutputPortFromInput()->getDataInformation();
 
   // get data set type
   // and set the default representation
@@ -375,6 +424,9 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
       GetRepresentedDataInformation();
     }
 
+  vtkPVArrayInformation* chosenArrayInfo = 0;
+  int chosenFieldType = 0;
+
   // Look for a new point array.
   // I do not think the logic is exactly as describerd in this methods
   // comment.  I believe this method only looks at "Scalars".
@@ -383,53 +435,60 @@ void pqPipelineRepresentation::setDefaultPropertyValues()
     attrInfo = geomInfo->GetPointDataInformation();
     inAttrInfo = inGeomInfo? inGeomInfo->GetPointDataInformation() : 0;
     pqPipelineRepresentation::getColorArray(attrInfo, inAttrInfo, arrayInfo);
-    if(arrayInfo)
+    if (arrayInfo)
       {
-      this->colorByArray(arrayInfo->GetName(), 
-                         vtkSMDataRepresentationProxy::POINT_DATA);
-      return;
+      chosenFieldType = vtkSMDataRepresentationProxy::POINT_DATA;
+      chosenArrayInfo = arrayInfo;
       }
     }
     
   // Check for new cell scalars.
-  if (geomInfo)
+  if (!chosenArrayInfo && geomInfo)
     {
     attrInfo = geomInfo->GetCellDataInformation();
     inAttrInfo = inGeomInfo? inGeomInfo->GetCellDataInformation() : 0;
     pqPipelineRepresentation::getColorArray(attrInfo, inAttrInfo, arrayInfo);
-    if(arrayInfo)
+    if (arrayInfo)
       {
-      this->colorByArray(arrayInfo->GetName(), 
-                         vtkSMDataRepresentationProxy::CELL_DATA);
-      return;
+      chosenFieldType = vtkSMDataRepresentationProxy::CELL_DATA;
+      chosenArrayInfo = arrayInfo;
       }
     }
    
-  if (geomInfo)
+  if (!chosenArrayInfo && geomInfo)
     {
     // Check for scalars in geometry
     attrInfo = geomInfo->GetPointDataInformation();
     this->getColorArray(attrInfo, inAttrInfo, arrayInfo);
-    if(arrayInfo)
+    if (arrayInfo)
       {
-      this->colorByArray(arrayInfo->GetName(), 
-                         vtkSMDataRepresentationProxy::POINT_DATA);
-      return;
+      chosenArrayInfo = arrayInfo;
+      chosenFieldType = vtkSMDataRepresentationProxy::POINT_DATA;
       }
     }
 
-  if (geomInfo)
+  if (!chosenArrayInfo && geomInfo)
     {
     // Check for scalars in geometry
     attrInfo = geomInfo->GetCellDataInformation();
     this->getColorArray(attrInfo, inAttrInfo, arrayInfo);
     if(arrayInfo)
       {
-      this->colorByArray(arrayInfo->GetName(), 
-                         vtkSMDataRepresentationProxy::CELL_DATA);
-      return;
+      chosenArrayInfo = arrayInfo;
+      chosenFieldType = vtkSMDataRepresentationProxy::CELL_DATA;
       }
     }
+
+  if (chosenArrayInfo)
+    {
+    if (chosenArrayInfo->GetDataType() == VTK_UNSIGNED_CHAR &&
+        chosenArrayInfo->GetNumberOfComponents() <= 4)
+        {
+        pqSMAdaptor::setElementProperty(repr->GetProperty("MapScalars"), 0);
+        }
+    this->colorByArray(chosenArrayInfo->GetName(), chosenFieldType);
+    return;
+    }
   
   QList<QString> myColorFields = this->getColorFields();
 
@@ -485,13 +544,21 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
     pqSMAdaptor::setElementProperty(
       repr->GetProperty("ColorArrayName"), "");
     repr->UpdateVTKObjects();
+
+    // BUG #6818. If user switched to solid color, we need to update the lut
+    // visibility.
+    pqScalarsToColors* lut = this->getLookupTable();
+    if (lut)
+      {
+      lut->hideUnusedScalarBars();
+      }
     return;
     }
 
   pqApplicationCore* core = pqApplicationCore::instance();
   pqLookupTableManager* lut_mgr = core->getLookupTableManager();
   vtkSMProxy* lut = 0;
-
+  vtkSMProxy* opf = 0;
   if (lut_mgr)
     {
     int number_of_components = this->getNumberOfComponents(
@@ -499,6 +566,9 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
     pqScalarsToColors* pqlut = lut_mgr->getLookupTable(
       this->getServer(), arrayname, number_of_components, 0);
     lut = (pqlut)? pqlut->getProxy() : 0;
+    pqScalarOpacityFunction* pqOPF = lut_mgr->getScalarOpacityFunction(
+      this->getServer(), arrayname, number_of_components, 0);
+    opf = (pqOPF)? pqOPF->getProxy() : 0;
     }
   else
     {
@@ -528,6 +598,8 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
       {
       lut = pp->GetProxy(0);
       }
+      
+    opf = this->createOpacityFunctionProxy(repr);
     }
 
   if (!lut)
@@ -539,23 +611,30 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
     return;
     }
 
-  vtkSMProxy* oldlutProxy = 
-    pqSMAdaptor::getProxyProperty(repr->GetProperty("LookupTable"));
-  pqScalarsToColors* old_stc = 0;
-  if (oldlutProxy != lut)
-    {
-    // Locate pqScalarsToColors for the old LUT and update 
-    // it's scalar bar visibility.
-    pqServerManagerModel* smmodel = core->getServerManagerModel();
-    old_stc = smmodel->findItem<pqScalarsToColors*>(oldlutProxy);
-    }
-  
+  // Locate pqScalarsToColors for the old LUT and update 
+  // it's scalar bar visibility.
+  pqScalarsToColors* old_stc = this->getLookupTable();
   pqSMAdaptor::setProxyProperty(
     repr->GetProperty("LookupTable"), lut);
+    
+  // set the opacity function
+  if(opf)
+    {
+    pqSMAdaptor::setProxyProperty(
+      repr->GetProperty("ScalarOpacityFunction"), opf);
+    repr->UpdateVTKObjects();
+    }
 
+  bool current_scalar_bar_visibility = false;
   // If old LUT was present update the visibility of the scalar bars
-  if (old_stc)
+  if (old_stc && old_stc->getProxy() != lut)
       {
+      pqScalarBarRepresentation* scalar_bar = old_stc->getScalarBar(
+        qobject_cast<pqRenderViewBase*>(this->getView()));
+      if (scalar_bar)
+        {
+        current_scalar_bar_visibility = scalar_bar->isVisible();
+        }
       old_stc->hideUnusedScalarBars();
       }
 
@@ -575,6 +654,14 @@ void pqPipelineRepresentation::colorByArray(const char* arrayname, int fieldtype
   repr->UpdateVTKObjects();
 
   this->updateLookupTableScalarRange();
+
+  
+  if (current_scalar_bar_visibility && lut_mgr && this->getLookupTable())
+    {
+    lut_mgr->setScalarBarVisibility(this->getView(),
+      this->getLookupTable(),
+      current_scalar_bar_visibility);
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -665,6 +752,77 @@ void pqPipelineRepresentation::resetLookupTableScalarRange()
     }
 }
 
+//-----------------------------------------------------------------------------
+void pqPipelineRepresentation::resetLookupTableScalarRangeOverTime()
+{
+  vtkSMPropRepresentationProxy* repr = this->getRepresentationProxy();
+  pqScalarsToColors* lut = this->getLookupTable();
+  QString colorField = this->getColorField(true);
+
+  if (lut && colorField != "" && 
+    colorField != pqPipelineRepresentation::solidColor())
+    {
+    int attribute_type = vtkSMPropertyHelper(repr,
+      "ColorAttributeType").GetAsInt();
+    vtkPVTemporalDataInformation* dataInfo = 
+      this->getInputTemporalDataInformation();
+    vtkPVArrayInformation* arrayInfo = dataInfo->GetAttributeInformation(
+      attribute_type)->GetArrayInformation(colorField.toAscii().data());
+    if (arrayInfo)
+      {
+      int component = vtkSMPropertyHelper(lut->getProxy(),
+        "VectorComponent").GetAsInt();
+        if (vtkSMPropertyHelper(
+            lut->getProxy(), "VectorMode").GetAsInt() ==
+          vtkScalarsToColors::MAGNITUDE)
+          {
+          component = -1;
+          }
+      double range[2];
+      arrayInfo->GetComponentRange(component, range);
+      lut->setScalarRange(range[0], range[1]);
+
+      // scalar opacity is treated as slave to the lookup table.
+      pqScalarOpacityFunction* opacity = this->getScalarOpacityFunction();
+      if (opacity)
+        {
+        opacity->setScalarRange(range[0], range[1]);
+        }
+      }
+    }
+}
+
+//-----------------------------------------------------------------------------
+void pqPipelineRepresentation::onInputAccepted()
+{
+  // BUG #10062
+  // This slot gets called when the input to the representation is "accepted".
+  // We mark this representation's LUT ranges dirty so that when the pipeline
+  // finally updates, we can reset the LUT ranges.
+  if (this->getInput()->modifiedState() == pqProxy::MODIFIED)
+    {
+    this->UpdateLUTRangesOnDataUpdate = true;
+    }
+}
+
+//-----------------------------------------------------------------------------
+void pqPipelineRepresentation::onDataUpdated()
+{
+  if (this->UpdateLUTRangesOnDataUpdate ||
+    pqScalarsToColors::colorRangeScalingMode() ==
+    pqScalarsToColors::GROW_ON_UPDATED)
+    {
+    // BUG #10062
+    // Since this part of the code happens every time the pipeline is updated, we
+    // don't need to record it on the undo stack. It will happen automatically
+    // each time.
+    BEGIN_UNDO_EXCLUDE();
+    this->UpdateLUTRangesOnDataUpdate = false;
+    this->updateLookupTableScalarRange();
+    END_UNDO_EXCLUDE();
+    }
+}
+
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::updateLookupTableScalarRange()
 {
@@ -745,7 +903,8 @@ QList<QString> pqPipelineRepresentation::getColorFields()
     ret.append(pqPipelineRepresentation::solidColor());
     }
 
-  vtkPVDataInformation* geomInfo = repr->GetRepresentedDataInformation();
+  vtkPVDataInformation* geomInfo = NULL;
+  geomInfo = repr->GetRepresentedDataInformation(true);
   if(!geomInfo)
     {
     return ret;
@@ -760,7 +919,7 @@ QList<QString> pqPipelineRepresentation::getColorFields()
     vtkPVDataInformation* dataInfo = NULL;
     if(this->getInput())
       {
-      dataInfo = this->getOutputPortFromInput()->getDataInformation(false);
+      dataInfo = this->getOutputPortFromInput()->getDataInformation();
       }
     if(dataInfo)
       {
@@ -993,22 +1152,6 @@ QString pqPipelineRepresentation::getColorField(bool raw)
   return pqPipelineRepresentation::solidColor();
 }
 
-//-----------------------------------------------------------------------------
-bool pqPipelineRepresentation::getDataBounds(double bounds[6])
-{
-  vtkSMPropRepresentationProxy* repr = 
-    this->getRepresentationProxy();
-
-  vtkPVDataInformation* info = repr? 
-    repr->GetRepresentedDataInformation() : 0;
-  if(!info)
-    {
-    return false;
-    }
-  info->GetBounds(bounds);
-  return true;
-}
-
 //-----------------------------------------------------------------------------
 void pqPipelineRepresentation::setRepresentation(int representation)
 {
@@ -1140,3 +1283,37 @@ double pqPipelineRepresentation::getUnstructuredGridOutlineThreshold()
 
   return 0.5; //  1/2 million cells.
 }
+
+//-----------------------------------------------------------------------------
+vtkSMProxy* pqPipelineRepresentation::createOpacityFunctionProxy(
+  vtkSMPropRepresentationProxy* repr)
+{
+  if (!repr || !repr->GetProperty("ScalarOpacityFunction"))
+    {
+    return NULL;
+    }
+
+  vtkSMProxy* opacityFunction = 0;
+  vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(
+    repr->GetProperty("ScalarOpacityFunction"));
+  if (pp->GetNumberOfProxies() == 0)
+    {
+    pqObjectBuilder* builder = pqApplicationCore::instance()->getObjectBuilder();
+    opacityFunction = builder->createProxy(
+      "piecewise_functions", "PiecewiseFunction", 
+      this->getServer(), "piecewise_functions");
+    // Setup default opactiy function to go from 0 to 1.
+    QList<QVariant> values;
+    values << 0.0 << 0.0 << 1.0 << 1.0;
+    
+    pqSMAdaptor::setMultipleElementProperty(
+      opacityFunction->GetProperty("Points"), values);
+    opacityFunction->UpdateVTKObjects();
+    }
+  else
+    {
+    opacityFunction = pp->GetProxy(0);
+    }
+
+  return opacityFunction;
+}
