@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqPropertyLinks.cxx,v $
+   Module:    pqPropertyLinks.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -38,11 +38,13 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 // Qt includes
 #include <QString>
+#include <QStringList>
 #include <QPointer>
 #include <QVariant>
 #include <QSet>
 #include <QSignalMapper>
 #include <QTimer>
+#include <QtDebug>
 
 // VTK includes
 #include "vtkEventQtSlotConnect.h"
@@ -248,6 +250,7 @@ void pqPropertyLinksConnection::smLinkedPropertyChanged()
       break;
     case pqSMAdaptor::MULTIPLE_ELEMENTS:
     case pqSMAdaptor::COMPOSITE_TREE:
+    case pqSMAdaptor::SIL:
         {
         if(this->Internal->Index == -1)
           {
@@ -379,13 +382,27 @@ void pqPropertyLinksConnection::qtLinkedPropertyChanged()
         {
         if(this->Internal->UseUncheckedProperties)
           {
-          pqSMAdaptor::setUncheckedFileListProperty(
-            this->Internal->Property, prop.toString());
+          if (!prop.canConvert<QStringList>())
+            {
+            qWarning() << "File list is not a list.";
+            }
+          else
+            {
+            pqSMAdaptor::setUncheckedFileListProperty(
+                           this->Internal->Property, prop.value<QStringList>());
+            }
           }
         else
           {
-          pqSMAdaptor::setFileListProperty(
-            this->Internal->Property, prop.toString());
+          if (!prop.canConvert<QStringList>())
+            {
+            qWarning() << "File list is not a list.";
+            }
+          else
+            {
+            pqSMAdaptor::setFileListProperty(
+                           this->Internal->Property, prop.value<QStringList>());
+            }
           if(this->Internal->AutoUpdate)
             {
             this->Internal->Proxy->UpdateVTKObjects();
@@ -439,6 +456,7 @@ void pqPropertyLinksConnection::qtLinkedPropertyChanged()
           }
         }
       break;
+    case pqSMAdaptor::SIL:
     case pqSMAdaptor::MULTIPLE_ELEMENTS:
     case pqSMAdaptor::COMPOSITE_TREE:
         {
@@ -565,6 +583,11 @@ void pqPropertyLinks::addPropertyLink(QObject* qObject, const char* qProperty,
   if(!Proxy || !Property || !qObject || !qProperty || !signal)
     {
     qWarning("Invalid parameters to add link\n");
+    qDebug() << "Proxy:" << Proxy << Proxy->GetClassName();
+    qDebug() << "Property:" << Property;
+    qDebug() << "qObject:" << qObject;
+    qDebug() << "qProperty:" << qProperty;
+    qDebug() << "signal:" << signal;
     return;
     }
   
