@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqRenderView.cxx,v $
+   Module:    pqRenderView.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -42,6 +42,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkPVTrackballRotate.h"
 #include "vtkPVTrackballZoom.h"
 #include "vtkSelection.h"
+#include "vtkSelectionNode.h"
 #include "vtkSmartPointer.h"
 #include "vtkSMInteractionUndoStackBuilder.h"
 #include "vtkSMIntVectorProperty.h"
@@ -53,6 +54,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMSourceProxy.h"
 #include "vtkSMUndoStack.h"
 #include "vtkTrackballPan.h"
+#include "vtkSMPropertyHelper.h"
+#include "vtkSMGlobalPropertiesManager.h"
 
 // Qt includes.
 #include <QFileInfo>
@@ -71,6 +74,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqApplicationCore.h"
 #include "pqDataRepresentation.h"
 #include "pqLinkViewWidget.h"
+#include "pqOptions.h"
 #include "pqOutputPort.h"
 #include "pqPipelineSource.h"
 #include "pqServer.h"
@@ -221,8 +225,20 @@ void pqRenderView::initializeWidgets()
   this->Internal->OrientationAxesWidget->SetEnabled(1);
   this->Internal->OrientationAxesWidget->SetInteractive(0);
 
+  // Set up some global property links by default.
+  vtkSMGlobalPropertiesManager* globalPropertiesManager =
+    pqApplicationCore::instance()->getGlobalPropertiesManager();
+  this->getConnector()->Connect(
+    globalPropertiesManager->GetProperty("TextAnnotationColor"),
+    vtkCommand::ModifiedEvent, this, SLOT(textAnnotationColorChanged()));
+  this->textAnnotationColorChanged();
+
   // setup the center axes.
   this->initializeCenterAxes();
+  
+  // ensure that center axis visibility etc. is updated as per user's
+  // preferences.
+  this->restoreAnnotationSettings();
 
   this->Internal->UndoStackBuilder->SetRenderView(renModule);
 }
@@ -235,8 +251,11 @@ void pqRenderView::initializeWidgets()
 void pqRenderView::setDefaultPropertyValues()
 {
   vtkSMProxy* proxy = this->getProxy();
-  pqSMAdaptor::setElementProperty(proxy->GetProperty("UseLight"), 1);
-  pqSMAdaptor::setElementProperty(proxy->GetProperty("LightSwitch"), 0);
+  if (!pqApplicationCore::instance()->getOptions()->GetDisableLightKit())
+    {
+    pqSMAdaptor::setElementProperty(proxy->GetProperty("UseLight"), 1);
+    pqSMAdaptor::setElementProperty(proxy->GetProperty("LightSwitch"), 0);
+    }
   this->Superclass::setDefaultPropertyValues();
   this->clearUndoStack();
 }
@@ -245,10 +264,13 @@ void pqRenderView::setDefaultPropertyValues()
 void pqRenderView::restoreDefaultLightSettings()
 {
   this->Superclass::restoreDefaultLightSettings();
-  vtkSMProxy* proxy = this->getProxy();
-  pqSMAdaptor::setElementProperty(proxy->GetProperty("UseLight"), 1);
-  pqSMAdaptor::setElementProperty(proxy->GetProperty("LightSwitch"), 0);
-  proxy->UpdateVTKObjects();
+  if (!pqApplicationCore::instance()->getOptions()->GetDisableLightKit())
+    {
+    vtkSMProxy* proxy = this->getProxy();
+    pqSMAdaptor::setElementProperty(proxy->GetProperty("UseLight"), 1);
+    pqSMAdaptor::setElementProperty(proxy->GetProperty("LightSwitch"), 0);
+    proxy->UpdateVTKObjects();
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -307,6 +329,7 @@ void pqRenderView::resetCamera()
   this->fakeInteraction(true);
   this->getRenderViewProxy()->ResetCamera();
   this->fakeInteraction(false);
+  this->render();
 }
 
 //-----------------------------------------------------------------------------
@@ -499,55 +522,59 @@ bool pqRenderView::getCenterAxesVisibility() const
 }
 
 //-----------------------------------------------------------------------------
-void pqRenderView::restoreSettings(bool only_global)
+void pqRenderView::restoreAnnotationSettings()
 {
-  this->Superclass::restoreSettings(only_global);
-  
-  // Now load default values from the QSettings, if available.
   pqSettings* settings = pqApplicationCore::instance()->settings();
   QString sgroup = this->viewSettingsGroup();
   settings->beginGroup(sgroup);
-  if (!only_global)
+  // Orientation Axes settings.
+  settings->beginGroup("OrientationAxes");
+  if (settings->contains("Visibility"))
     {
-    // Orientation Axes settings.
-    settings->beginGroup("OrientationAxes");
-    if (settings->contains("Visibility"))
-      {
-      this->setOrientationAxesVisibility(
-        settings->value("Visibility").toBool());
-      }
-    if (settings->contains("Interactivity"))
-      {
-      this->setOrientationAxesInteractivity(
-        settings->value("Interactivity").toBool());
-      }
-    if (settings->contains("OutlineColor"))
-      {
-      this->setOrientationAxesOutlineColor(
-        settings->value("OutlineColor").value<QColor>());
-      }
-    if (settings->contains("LabelColor"))
-      {
-      this->setOrientationAxesLabelColor(
-        settings->value("LabelColor").value<QColor>());
-      }
-    settings->endGroup();
-
-    // Center Axes settings.
-    settings->beginGroup("CenterAxes");
-    if (settings->contains("Visibility"))
-      {
-      this->setCenterAxesVisibility(
-        settings->value("Visibility").toBool());
-      }
-    if (settings->contains("ResetCenterWithCamera"))
-      {
-      this->ResetCenterWithCamera =
-        settings->value("ResetCenterWithCamera").toBool();
-      }
-    settings->endGroup();
+    this->setOrientationAxesVisibility(
+      settings->value("Visibility").toBool());
+    }
+  if (settings->contains("Interactivity"))
+    {
+    this->setOrientationAxesInteractivity(
+      settings->value("Interactivity").toBool());
+    }
+  if (settings->contains("OutlineColor"))
+    {
+    this->setOrientationAxesOutlineColor(
+      settings->value("OutlineColor").value<QColor>());
+    }
+  if (settings->contains("LabelColor"))
+    {
+    this->setOrientationAxesLabelColor(
+      settings->value("LabelColor").value<QColor>());
     }
   settings->endGroup();
+
+  // Center Axes settings.
+  settings->beginGroup("CenterAxes");
+  if (settings->contains("Visibility"))
+    {
+    this->setCenterAxesVisibility(
+      settings->value("Visibility").toBool());
+    }
+  if (settings->contains("ResetCenterWithCamera"))
+    {
+    this->ResetCenterWithCamera =
+      settings->value("ResetCenterWithCamera").toBool();
+    }
+  settings->endGroup();
+  settings->endGroup();
+}
+
+//-----------------------------------------------------------------------------
+void pqRenderView::restoreSettings(bool only_global)
+{
+  this->Superclass::restoreSettings(only_global);
+  if (!only_global)
+    {
+    this->restoreAnnotationSettings();
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -836,15 +863,14 @@ void pqRenderView::collectSelectionPorts(
       continue;
       }
     pqOutputPort* opPort = pqRepr->getOutputPortFromInput();
+    vtkSMSourceProxy* selectedSource = vtkSMSourceProxy::SafeDownCast(
+      opPort->getSource()->getProxy());
 
     if (select_blocks)
       {
-      vtkSMSourceProxy* selectedSource = vtkSMSourceProxy::SafeDownCast(
-        opPort->getSource()->getProxy());
-
-      // convert the index based selection to vtkSelection::BLOCKS selection.
+      // convert the index based selection to vtkSelectionNode::BLOCKS selection.
       vtkSMSourceProxy* newSelSource = vtkSMSourceProxy::SafeDownCast(
-        vtkSMSelectionHelper::ConvertSelection(vtkSelection::BLOCKS,
+        vtkSMSelectionHelper::ConvertSelection(vtkSelectionNode::BLOCKS,
           selectionSource,
           selectedSource, opPort->getPortNumber()));
       selectionSource.TakeReference(newSelSource);
@@ -853,7 +879,8 @@ void pqRenderView::collectSelectionPorts(
     if (expand)
       {
       vtkSMSelectionHelper::MergeSelection(selectionSource,
-        opPort->getSelectionInput());
+        opPort->getSelectionInput(),
+        selectedSource, opPort->getPortNumber());
       }
     opPort->setSelectionInput(selectionSource, 0);
     output_ports.append(opPort);
@@ -954,7 +981,6 @@ void pqRenderView::selectFrustumPoints(int rect[4])
   this->emitSelectionSignal(output_ports);
 }
 
-
 //-----------------------------------------------------------------------------
 void pqRenderView::selectBlock(int rectangle[4], bool expand)
 {
@@ -964,3 +990,16 @@ void pqRenderView::selectBlock(int rectangle[4], bool expand)
   this->blockSignals(block);
   this->emitSelectionSignal(opPorts);
 }
+
+//-----------------------------------------------------------------------------
+void pqRenderView::textAnnotationColorChanged()
+{
+  // Set up some global property links by default.
+  vtkSMGlobalPropertiesManager* globalPropertiesManager =
+    pqApplicationCore::instance()->getGlobalPropertiesManager();
+  double value[3];
+  vtkSMPropertyHelper(globalPropertiesManager, "TextAnnotationColor").Get(
+    value, 3);
+  this->Internal->OrientationAxesWidget->SetAxisLabelColor(value[0], value[1],
+    value[2]);
+}
