@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqRenderViewBase.cxx,v $
+   Module:    pqRenderViewBase.cxx
 
    Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -38,6 +38,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkImageData.h"
 #include "vtkProcessModule.h"
 #include "vtkPVDataInformation.h"
+#include "vtkPVXMLElement.h"
+#include "vtkSMGlobalPropertiesManager.h"
 #include "vtkSMProperty.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMSourceProxy.h"
@@ -56,6 +58,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqOutputPort.h"
 #include "pqPipelineSource.h"
 #include "pqServer.h"
+#include "pqServerManagerModel.h"
 #include "pqSettings.h"
 #include "pqSMAdaptor.h"
 
@@ -185,7 +188,13 @@ void pqRenderViewBase::setDefaultPropertyValues()
   pqSMAdaptor::setElementProperty(proxy->GetProperty("LODThreshold"), 5);
   pqSMAdaptor::setElementProperty(proxy->GetProperty("RemoteRenderThreshold"), 3);
   pqSMAdaptor::setElementProperty(proxy->GetProperty("TileDisplayCompositeThreshold"), 3);
-  pqSMAdaptor::setElementProperty(proxy->GetProperty("SquirtLevel"), 3);
+
+  // Compressor setting to pull from application wide settings cache.
+  pqSMAdaptor::setElementProperty(proxy->GetProperty("CompressorConfig"),"NULL");
+  // pqSMAdaptor::setElementProperty(proxy->GetProperty("CompressionEnabled"),-1);
+  pqSMAdaptor::setElementProperty(proxy->GetProperty("CompressorConfig"),"vtkSquirtCompressor 0 3");
+  // pqSMAdaptor::setElementProperty(proxy->GetProperty("CompressionEnabled"),1);
+
   // when PV_NO_OFFSCREEN_SCREENSHOTS is set, by default, we disable offscreen
   // screenshots.
   if (getenv("PV_NO_OFFSCREEN_SCREENSHOTS"))
@@ -194,11 +203,10 @@ void pqRenderViewBase::setDefaultPropertyValues()
       proxy->GetProperty("UseOffscreenRenderingForScreenshots"), 0);
     }
 
-  const int* bg = this->defaultBackgroundColor();
-  vtkSMProperty* backgroundProperty = proxy->GetProperty("Background");
-  pqSMAdaptor::setMultipleElementProperty(backgroundProperty, 0, bg[0]/255.0);
-  pqSMAdaptor::setMultipleElementProperty(backgroundProperty, 1, bg[1]/255.0);
-  pqSMAdaptor::setMultipleElementProperty(backgroundProperty, 2, bg[2]/255.0);
+  vtkSMGlobalPropertiesManager* globalPropertiesManager =
+    pqApplicationCore::instance()->getGlobalPropertiesManager();
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "BackgroundColor", proxy, "Background");
   proxy->UpdateVTKObjects();
 
   this->restoreSettings(false);
@@ -284,6 +292,10 @@ vtkSMProxy* pqRenderViewBase::createCameraManipulator(
     {
     strManipName = "TrackballPan1";
     }
+  else if (name.compare("Multi-Rotate") == 0)
+    {
+    strManipName = "TrackballMultiRotate";
+    }
   else
     {
     strManipName = "None";
@@ -314,6 +326,12 @@ const int* pqRenderViewBase::defaultBackgroundColor() const
   return defaultBackground;
 }
 
+//-----------------------------------------------------------------------------
+void pqRenderViewBase::resetDisplay()
+{
+  this->resetCamera();
+}
+
 //-----------------------------------------------------------------------------
 static const char* pqRenderViewModuleLightSettings [] = {
   "LightSwitch",
@@ -346,11 +364,13 @@ static const char* pqGlobalRenderViewModuleMiscSettings [] = {
   "RemoteRenderThreshold",
   "TileDisplayCompositeThreshold",
   "ImageReductionFactor",
-  "SquirtLevel",
+  "CompressorConfig",
+  "CompressionEnabled",
   "OrderedCompositing",
   "StillRenderImageReductionFactor",
   "CollectGeometryThreshold",
   "DepthPeeling",
+  "MaximumNumberOfPeels",
   "UseOffscreenRenderingForScreenshots",
   NULL
   };
@@ -379,7 +399,6 @@ static const char* pqRenderViewModuleLightSettingsMulti[] = {
   };
 
 static const char* pqRenderViewModuleMiscSettingsMulti[] = {
-  "Background",
   NULL  // keep last
   };
 
@@ -600,10 +619,41 @@ bool pqRenderViewBase::canDisplay(pqOutputPort* opPort) const
     {
     return false;
     }
-  if (opPort->getDataInformation(false)->GetDataSetType() == -1)
+
+  vtkPVXMLElement* hints = sourceProxy->GetHints();
+  if (hints)
+    {
+    // If the source has an hint as follows, then it's a text producer and must
+    // be is display-able.
+    //  <Hints>
+    //    <OutputPort name="..." index="..." type="text" />
+    //  </Hints>
+
+    unsigned int numElems = hints->GetNumberOfNestedElements(); 
+    for (unsigned int cc=0; cc < numElems; cc++)
+      {
+      int index;
+      vtkPVXMLElement* child = hints->GetNestedElement(cc);
+      if (child->GetName() &&
+        strcmp(child->GetName(), "OutputPort") == 0 &&
+        child->GetScalarAttribute("index", &index) &&
+        index == opPort->getPortNumber() &&
+        child->GetAttribute("type") &&
+        strcmp(child->GetAttribute("type"), "text") == 0)
+        {
+        return true;
+        }
+      }
+    }
+  
+  vtkPVDataInformation* dinfo = opPort->getDataInformation();
+  if (dinfo->GetDataSetType() == -1 || 
+    dinfo->GetDataSetType() == VTK_TABLE)
     {
     return false;
     }
+
+
   return true;
 }
 
@@ -653,3 +703,22 @@ bool pqRenderViewBase::saveImage(int width, int height, const QString& filename)
     }
   return (error_code == vtkErrorCode::NoError);
 }
+
+//-----------------------------------------------------------------------------
+void pqRenderViewBase::setStereo(int mode)
+{
+  QList<pqView*> views =
+    pqApplicationCore::instance()->getServerManagerModel()->findItems<pqView*>();
+  foreach (pqView* view, views)
+    {
+    vtkSMProxy* viewProxy = view->getProxy();
+    pqSMAdaptor::setElementProperty(viewProxy->GetProperty("StereoRender"),
+      mode != 0);
+    if (mode)
+      {
+      pqSMAdaptor::setElementProperty(viewProxy->GetProperty("StereoType"),
+        mode);
+      }
+    viewProxy->UpdateVTKObjects();
+    }
+}
