@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqScalarBarRepresentation.cxx,v $
+   Module:    pqScalarBarRepresentation.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -33,6 +33,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "vtkCommand.h"
 #include "vtkEventQtSlotConnect.h"
+#include "vtkSMGlobalPropertiesManager.h"
 #include "vtkSMProperty.h"
 #include "vtkSMPropertyModificationUndoElement.h"
 #include "vtkSMProxy.h"
@@ -95,6 +96,14 @@ pqScalarBarRepresentation::pqScalarBarRepresentation(const QString& group,
     }
 }
 
+//-----------------------------------------------------------------------------
+void pqScalarBarRepresentation::setVisible(bool visible)
+{
+  pqSMAdaptor::setElementProperty(this->getProxy()->GetProperty("Enabled"),
+    (visible? 1 : 0));
+  this->Superclass::setVisible(visible);
+}
+
 //-----------------------------------------------------------------------------
 pqScalarBarRepresentation::~pqScalarBarRepresentation()
 {
@@ -168,43 +177,20 @@ void pqScalarBarRepresentation::setTitle(const QString& name, const QString& com
   this->getProxy()->UpdateVTKObjects();
 }
 
-//-----------------------------------------------------------------------------
-void pqScalarBarRepresentation::makeTitle(pqPipelineRepresentation* display)
-{
-  if (!this->Internal->LookupTable)
-    {
-    qDebug() << "Cannot setup title when not connected to any LUT.";
-    return;
-    }
-
-  QString arrayname = display->getColorField(true);
-  if (arrayname == "Solid Color" || arrayname == "")
-    {
-    // cannot decide title without array name.
-    return;
-    }
-
-  pqScalarsToColors::Mode mode = this->Internal->LookupTable->getVectorMode();
-  int component_no = this->Internal->LookupTable->getVectorComponent();
-  int num_components = display->getColorFieldNumberOfComponents(
-    display->getColorField(false));
-
-  QString component = (num_components > 1)? "Magnitude" : "";
-  if (num_components > 1 && 
-    mode == pqScalarsToColors::COMPONENT && component_no >= 0)
-    {
-    component = pqScalarBarRepresentation::getDefaultComponentLabel(
-      component_no,  num_components);
-    }
-  this->setTitle(arrayname, component);
-}
-
 //-----------------------------------------------------------------------------
 QString pqScalarBarRepresentation::getDefaultComponentLabel(
   int component_no, int num_components)
 {
   QString component;
-  if (num_components <= 3 && component_no < 3)
+  if (num_components <= 1)
+    {
+    component = "";
+    }
+  else if (component_no == -1)
+    {
+    component = "Magnitude";
+    }
+  else if (num_components <= 3 && component_no < 3)
     {
     const char* titles[] = { "X", "Y", "Z"};
     component = titles[component_no];
@@ -242,6 +228,15 @@ void pqScalarBarRepresentation::setDefaultPropertyValues()
   pqSMAdaptor::setElementProperty(proxy->GetProperty("TitleFontSize"), 12);
   pqSMAdaptor::setElementProperty(proxy->GetProperty("LabelFontSize"), 12);
 
+  // setup global property link. By default, color is linked with
+  // TextAnnotationColor.
+  vtkSMGlobalPropertiesManager* globalPropertiesManager =
+    pqApplicationCore::instance()->getGlobalPropertiesManager();
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "TextAnnotationColor", proxy, "TitleColor");
+  globalPropertiesManager->SetGlobalPropertyLink(
+    "TextAnnotationColor", proxy, "LabelColor");
+
   proxy->UpdateVTKObjects();
 }
 
