@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqScalarBarRepresentation.h,v $
+   Module:    pqScalarBarRepresentation.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -54,12 +54,6 @@ public:
   /// Get the lookup table this scalar bar shows, if any.
   pqScalarsToColors* getLookupTable() const;
 
-  /// Calls this method to set up a title for the scalar bar
-  /// using the color by array name from the display.
-  /// The component used to color with is obtained from the 
-  /// LookupTable already stored by this object.
-  void makeTitle(pqPipelineRepresentation* display);
-
   /// A scalar bar title is divided into two parts (any of which can be empty).
   /// Typically the first is the array name and the second is the component.
   /// This method returns the pair.
@@ -68,8 +62,13 @@ public:
   /// Set the title formed by combining two parts.
   void setTitle(const QString& name, const QString& component);
 
-  /// set by pqPipelineRepresentation when it forces the visiblity of the scalar
-  /// bar to be off.
+  /// Set the visibility. Note that this affects the visibility of the
+  /// display in the view it has been added to, if any. This method does not 
+  /// call a re-render on the view, caller must call that explicitly.
+  virtual void setVisible(bool visible);
+
+  /// set by pqPipelineRepresentation when it forces the visibility of the
+  /// scalar bar to be off.
   void setAutoHidden(bool h)
     { this->AutoHidden = h; }
   bool getAutoHidden() const
