@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqScalarBarVisibilityAdaptor.cxx,v $
+   Module:    pqScalarBarVisibilityAdaptor.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -42,7 +42,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqScalarBarRepresentation.h"
 #include "pqScalarsToColors.h"
 #include "pqUndoStack.h"
-
+#include "pqLookupTableManager.h"
 //-----------------------------------------------------------------------------
 class pqScalarBarVisibilityAdaptor::pqInternal
 {
@@ -63,15 +63,6 @@ pqScalarBarVisibilityAdaptor::pqScalarBarVisibilityAdaptor(QAction* p)
     p, SLOT(setEnabled(bool)), Qt::QueuedConnection);
   QObject::connect(this, SIGNAL(scalarBarVisible(bool)),
     p, SLOT(setChecked(bool)));
-
-  pqUndoStack* us = pqApplicationCore::instance()->getUndoStack();
-  if (us)
-    {
-    QObject::connect(this, SIGNAL(begin(const QString&)),
-      us, SLOT(beginUndoSet(const QString&)));
-    QObject::connect(this, SIGNAL(end()),
-      us, SLOT(endUndoSet()));
-    }
 }
 
 //-----------------------------------------------------------------------------
@@ -124,34 +115,22 @@ void pqScalarBarVisibilityAdaptor::setScalarBarVisibility(bool visible)
     return;
     }
 
-  pqScalarBarRepresentation* sb = 
-    lut->getScalarBar(this->Internal->ActiveRenderView);
-
-  if (!sb && !visible)
+  pqApplicationCore* core = pqApplicationCore::instance();
+  pqLookupTableManager* lut_mgr = core->getLookupTableManager();
+  if (!lut_mgr)
     {
-    // nothing to do, scalar bar already invisible.
+    qCritical() << "pqScalarBarVisibilityAdaptor needs a pqLookupTableManager";
     return;
     }
 
-  emit this->begin("Toggle Color Legend Visibility");
-  if (!sb)
+  BEGIN_UNDO_SET( "Toggle Color Legend Visibility");
+  pqScalarBarRepresentation* scalar_bar =
+    lut_mgr->setScalarBarVisibility(this->Internal->ActiveRenderView, lut, visible);
+  END_UNDO_SET();
+  if (scalar_bar)
     {
-    pqObjectBuilder* builder = 
-      pqApplicationCore::instance()->getObjectBuilder();
-    sb = builder->createScalarBarDisplay(lut, this->Internal->ActiveRenderView);
-    sb->makeTitle(this->Internal->ActiveDisplay);
+    scalar_bar->renderViewEventually();
     }
-  if (!sb)
-    {
-    qDebug() << "Failed to locate/create scalar bar.";
-    return;
-    }
-  sb->setVisible(visible);
-
-  emit this->end();
-
-  sb->renderViewEventually();
-
   this->updateState();
 }
 
