@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqStandardServerManagerModelInterface.cxx,v $
+   Module:    pqStandardServerManagerModelInterface.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -35,6 +35,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMProxy.h"
 #include "vtkSMRenderViewProxy.h"
 #include "vtkSMPVRepresentationProxy.h"
+#include "vtkSMScatterPlotRepresentationProxy.h"
 // Qt Includes.
 #include <QtDebug>
 
@@ -48,6 +49,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "pqRenderView.h"
 #include "pqScalarBarRepresentation.h"
 #include "pqScalarsToColors.h"
+#include "pqScalarOpacityFunction.h"
+#include "pqScatterPlotRepresentation.h"
 #include "pqTimeKeeper.h"
 #include "pqViewModuleInterface.h"
 
@@ -105,6 +108,10 @@ pqProxy* pqStandardServerManagerModelInterface::createPQProxy(
     {
     return new pqScalarsToColors(group, name, proxy, server, 0);
     }
+  else if (group == "piecewise_functions")
+    {
+    return new pqScalarOpacityFunction(group, name, proxy, server, 0);
+    }
   else if (group == "scalar_bars")
     {
     return new pqScalarBarRepresentation(group, name, proxy, server, 0);
@@ -126,6 +133,11 @@ pqProxy* pqStandardServerManagerModelInterface::createPQProxy(
       return new pqPipelineRepresentation(group, name, 
         vtkSMPropRepresentationProxy::SafeDownCast(proxy), server, 0);
       }
+    if (proxy->IsA("vtkSMScatterPlotRepresentationProxy"))
+      {
+      return new pqScatterPlotRepresentation(group, name,
+        vtkSMScatterPlotRepresentationProxy::SafeDownCast(proxy), server, 0);
+      }
     if (proxy->IsA("vtkSMDataRepresentationProxy"))
       {
       // If everything fails, simply create a pqDataRepresentation object.
