@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqUndoStack.cxx,v $
+   Module:    pqUndoStack.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -39,6 +39,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkSMUndoRedoStateLoader.h"
 #include "vtkSMUndoStackBuilder.h"
 #include "vtkSMUndoStack.h"
+#include "vtkPVXMLElement.h"  // vistrails
+#include "vtkSMIdBasedProxyLocator.h"  // vistrails
 
 
 #include <QtDebug>
@@ -46,7 +48,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include "pqApplicationCore.h"
 #include "pqHelperProxyRegisterUndoElement.h"
-#include "pqPendingDisplayUndoElement.h"
+#include "pqProxyModifiedStateUndoElement.h"
 #include "pqProxyUnRegisterUndoElement.h"
 #include "pqServer.h"
 
@@ -96,11 +98,11 @@ pqUndoStack::pqUndoStack(bool clientOnly,
   loader->RegisterElement(elem);
   elem->Delete();
 
-  elem = pqPendingDisplayUndoElement::New();
+  elem = pqProxyUnRegisterUndoElement::New();
   loader->RegisterElement(elem);
   elem->Delete();
 
-  elem = pqProxyUnRegisterUndoElement::New();
+  elem = pqProxyModifiedStateUndoElement::New();
   loader->RegisterElement(elem);
   elem->Delete();
 
@@ -195,6 +197,22 @@ void pqUndoStack::onStackChanged()
   emit this->redoLabelChanged(redo_label);
 }
 
+//begin vistrails
+vtkUndoSet* pqUndoStack::getLastUndoSet() {
+    return this->Implementation->UndoStack->getLastUndoSet();
+}
+
+vtkUndoSet* pqUndoStack::getUndoSetFromXML(vtkPVXMLElement *root) {
+  vtkSMIdBasedProxyLocator* locator = vtkSMIdBasedProxyLocator::New();
+  locator->SetConnectionID(this->Implementation->UndoStackBuilder->GetConnectionID());
+  locator->SetDeserializer(this->Implementation->StateLoader);
+  vtkUndoSet* undoSet = this->Implementation->StateLoader->LoadUndoRedoSet(root, locator);
+  locator->Delete();
+
+  return undoSet;
+}
+//end vistrails
+
 //-----------------------------------------------------------------------------
 void pqUndoStack::beginUndoSet(QString label)
 {
@@ -249,6 +267,18 @@ void pqUndoStack::undo()
   emit this->undone();
 }
 
+
+// vistrails begin
+void pqUndoStack::Push(const char *label, vtkUndoSet *set) {
+  this->beginNonUndoableChanges();
+  this->Implementation->UndoStack->Push(
+    this->Implementation->UndoStackBuilder->GetConnectionID(), label, set);
+  this->endNonUndoableChanges();
+}
+// vistrails end
+
+
+
 //-----------------------------------------------------------------------------
 void pqUndoStack::redo()
 {
