@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqView.cxx,v $
+   Module:    pqView.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -37,6 +37,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "vtkProcessModule.h"
 #include "vtkSmartPointer.h"
 #include "vtkSMProxyProperty.h"
+#include "vtkSMSourceProxy.h"
 #include "vtkSMViewProxy.h"
 #include "vtkImageData.h"
 
@@ -78,9 +79,22 @@ public:
   // List of representation shown by this view.
   QList<QPointer<pqRepresentation> > Representations;
 
+  // The annotation link for linking selections and annotations
+  // between views.
+  vtkSMSourceProxy* AnnotationLink;
+
   pqViewInternal()
     {
     this->VTKConnect = vtkSmartPointer<vtkEventQtSlotConnect>::New();
+    this->AnnotationLink = 0;
+    }
+
+  ~pqViewInternal()
+    {
+    if (this->AnnotationLink)
+      {
+      this->AnnotationLink->Delete();
+      }
     }
 
   QTimer RenderTimer;
@@ -150,6 +164,11 @@ vtkSMViewProxy* pqView::getViewProxy() const
   return vtkSMViewProxy::SafeDownCast(this->getProxy());
 }
 
+vtkView* pqView::getClientSideView() const
+{
+  return 0;
+}
+
 //-----------------------------------------------------------------------------
 void pqView::initialize()
 {
@@ -365,3 +384,24 @@ vtkImageData* pqView::captureImage(const QSize& fullsize)
     }
   return vtkimage;
 }
+
+//-----------------------------------------------------------------------------
+void pqView::setAnnotationLink(vtkSMSourceProxy* link)
+{
+  if (this->Internal->AnnotationLink != link)
+    {
+    vtkSMSourceProxy* tempSGMacroVar = this->Internal->AnnotationLink;
+    this->Internal->AnnotationLink = link;
+    if (this->Internal->AnnotationLink != NULL) { this->Internal->AnnotationLink->Register(0); }
+    if (tempSGMacroVar != NULL)
+      {
+      tempSGMacroVar->UnRegister(0);
+      }
+    }
+}
+
+//-----------------------------------------------------------------------------
+vtkSMSourceProxy* pqView::getAnnotationLink()
+{
+  return this->Internal->AnnotationLink;
+}
