@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqPythonShell.h,v $
+   Module:    pqPythonShell.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -62,8 +62,19 @@ public:
   /// Prints some text on the shell.
   void printMessage(const QString&);
 
+  /// Calls MakeCurrent in the internal vtkPVPythonInteractiveInterpretor instance
+  void makeCurrent();
+
+  /// Calls ReleaseControl in the internal vtkPVPythonInteractiveInterpretor instance
+  void releaseControl();
+
+  /// Given a python variable name, lookup its attributes and return them in a
+  /// string list.
+  QStringList getPythonAttributes(const QString& name);
+
 signals:
   void executing(bool);
+  void getInputLine(QString& input);
 
 public slots:
   void clear();
@@ -73,6 +84,8 @@ private slots:
   void printStderr(vtkObject*, unsigned long, void*, void*);
   void printStdout(vtkObject*, unsigned long, void*, void*);
 
+  void readInputLine(vtkObject*, unsigned long, void*, void*);
+
   void onExecuteCommand(const QString&);
 
 private:
@@ -87,6 +100,7 @@ private:
 
   void printStderr(const QString&);
   void printStdout(const QString&);
+
 };
 
 #endif // !_pqPythonShell_h
