@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqAbstractActivateEventPlayer.cxx,v $
+   Module:    pqAbstractActivateEventPlayer.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -55,6 +55,30 @@ bool pqAbstractActivateEventPlayer::playEvent(QObject* Object,
   if(Command != "activate")
     return false;
 
+  if (QMenuBar* const menu_bar  = qobject_cast<QMenuBar*>(Object))
+    {
+    QMenu* sub_menu = menu_bar->findChild<QMenu*>(Arguments);
+    if (sub_menu)
+      {
+      QAction* action = 0;
+      foreach (QAction* cur_action, menu_bar->actions())
+        {
+        if (cur_action->menu() == sub_menu)
+          {
+          action = cur_action;
+          break;
+          }
+        }
+      if (action)
+        {
+        menu_bar->setActiveAction(action);
+        return true;
+        }
+      }
+    Error = true;
+    return true;
+    }
+
   if(QMenu* const object = qobject_cast<QMenu*>(Object))
     {
     
@@ -107,31 +131,18 @@ bool pqAbstractActivateEventPlayer::playEvent(QObject* Object,
       if(QMenuBar* menu_bar = qobject_cast<QMenuBar*>(p))
         {
         menu_bar->setActiveAction(next->menuAction());
-        while(!next->isVisible())
+        int max_wait = 0;
+        while(!next->isVisible() && (++max_wait) <= 10)
           {
           pqEventDispatcher::processEventsAndWait(100);
           }
         }
       else if(QMenu* menu = qobject_cast<QMenu*>(p))
         {
-#if QT_VERSION < 0x040103
-        QRect geom = menu->actionGeometry(next->menuAction());
-        QMouseEvent button_press(QEvent::MouseButtonPress, 
-                                 geom.center(), 
-                                 Qt::LeftButton, Qt::LeftButton, 0);
-        QApplication::sendEvent(menu, &button_press);
-        // process events before mouse up to help our sub menu show up
-        pqEventDispatcher::processEventsAndWait(0);
-        
-        QMouseEvent button_release(QEvent::MouseButtonRelease, 
-                                   geom.center(), 
-                                   Qt::LeftButton, 0, 0);
-        QApplication::sendEvent(menu, &button_release);
-#else
         menu->setActiveAction(next->menuAction());
-#endif
         
-        while(!next->isVisible())
+        int max_wait = 0;
+        while(!next->isVisible() && (++max_wait) <= 10)
           {
           pqEventDispatcher::processEventsAndWait(100);
           }
@@ -149,12 +160,21 @@ bool pqAbstractActivateEventPlayer::playEvent(QObject* Object,
     QApplication::sendEvent(object, &keyDown);
     QApplication::sendEvent(object, &keyUp);
 
+    //QApplication::processEvents();
     return true;
     }
 
   if(QAbstractButton* const object = qobject_cast<QAbstractButton*>(Object))
     {
     object->click();
+    //QApplication::processEvents();
+    return true;
+    }
+
+  if (QAction* const action = qobject_cast<QAction*>(Object))
+    {
+    action->activate(QAction::Trigger);
+    //QApplication::processEvents();
     return true;
     }
   
