@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqAbstractBooleanEventPlayer.cxx,v $
+   Module:    pqAbstractBooleanEventPlayer.cxx
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -34,6 +34,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #include <QAbstractButton>
 #include <QtDebug>
+#include <QAction>
 
 pqAbstractBooleanEventPlayer::pqAbstractBooleanEventPlayer(QObject* p)
   : pqWidgetEventPlayer(p)
@@ -54,6 +55,15 @@ bool pqAbstractBooleanEventPlayer::playEvent(QObject* Object, const QString& Com
     return true;
     }
 
+  if (QAction* const action = qobject_cast<QAction*>(Object))
+    {
+    if (action->isChecked() != value)
+      {
+      action->trigger();
+      }
+    return true;
+    }
+
   qCritical() << "calling set_boolean on unhandled type " << Object;
   Error = true;
   return true;
