@@ -1,7 +1,7 @@
 /*=========================================================================
 
    Program: ParaView
-   Module:    $RCSfile: pqEventDispatcher.h,v $
+   Module:    pqEventDispatcher.h
 
    Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
    All rights reserved.
@@ -36,45 +36,55 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "QtTestingExport.h"
 
 #include <QObject>
+#include <QTimer>
+#include <QTime>
 
 class pqEventPlayer;
 class pqEventSource;
 
-class QTTESTING_EXPORT pqEventDispatcher :
-  public QObject
+/// pqEventDispatcher is responsible for taking each "event" from the test and
+/// then "playing" it using the player. The dispatcher is the critical component
+/// of this playback since it decides when it's time to dispatch the next
+/// "event" from the test.
+class QTTESTING_EXPORT pqEventDispatcher : public QObject
 {
   Q_OBJECT
-  
+  typedef QObject Superclass; 
 public:
-  pqEventDispatcher();
+  pqEventDispatcher(QObject* parent=0);
   ~pqEventDispatcher();
 
-  /** Retrieves events from the given event source, dispatching them to
-  the given event player for test case playback.  Note that playback is
-  asynchronous - the call to playEvents() returns immediately.  Callers
-  must ensure that the source, dispatcher, and player objects remain
-  in-scope until either the succeeded() or failed() signal is emitted
-  to indicate that playback has finished. */
-  void playEvents(pqEventSource& source, pqEventPlayer& player);
+  /// Retrieves events from the given event source, dispatching them to
+  /// the given event player for test case playback. This call blocks until all
+  /// the events from the source have been played back (or failure). Returns
+  /// true if playback was successful.
+  bool playEvents(pqEventSource& source, pqEventPlayer& player);
 
   /** Wait function provided for players that need to wait for the GUI
       to perform a certain action */
   static void processEventsAndWait(int ms);
 
-signals:
-  void succeeded();
-  void failed();
-  void readyPlayNextEvent();
+protected slots:
+  /// Plays a single event. this->PlayBackFinished and this->PlayBackStatus are
+  /// updated by this method.
+  void playEvent(int indent=0);
+  void playEventOnBlocking();
 
-private slots:
-  void playNextEvent();
-  void checkPlayNextEvent();
+  /// Called when the mainThread is about to block.
+  void aboutToBlock();
 
-private:
-  void stopPlayback();
+  /// Called when the mainThread wakes up.
+  void awake();
 
-  class pqImplementation;
-  pqImplementation* const Implementation;
+protected:
+  bool PlayBackFinished;
+  bool PlayBackStatus;
+  static bool DeferMenuTimeouts;
+
+  pqEventSource* ActiveSource;
+  pqEventPlayer* ActivePlayer;
+  QTimer BlockTimer;
+  QTime PlaybackStartTime;
 };
 
 #endif // !_pqEventDispatcher_h
