@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkCacheSizeKeeper.cxx,v $
+  Module:    vtkCacheSizeKeeper.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -18,7 +18,6 @@
 
 
 vtkStandardNewMacro(vtkCacheSizeKeeper);
-vtkCxxRevisionMacro(vtkCacheSizeKeeper, "$Revision: 1.2 $");
 //-----------------------------------------------------------------------------
 vtkCacheSizeKeeper::vtkCacheSizeKeeper()
 {
