@@ -1,6 +1,6 @@
 /*=========================================================================
 
-  Module:    $RCSfile: vtkPVOptions.cxx,v $
+  Module:    vtkPVOptions.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -12,17 +12,18 @@
 
 =========================================================================*/
 #include "vtkPVOptions.h"
-#include "vtkPVOptionsXMLParser.h"
+
 #include "vtkObjectFactory.h"
 #include "vtkPVConfig.h" //For PARAVIEW_ALWAYS_SECURE_CONNECTION option
+#include "vtkPVOptionsXMLParser.h"
 
 #include <vtksys/CommandLineArguments.hxx>
 #include <vtksys/SystemTools.hxx>
 
 
+
 //----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkPVOptions);
-vtkCxxRevisionMacro(vtkPVOptions, "$Revision: 1.45 $");
 
 //----------------------------------------------------------------------------
 vtkPVOptions::vtkPVOptions()
@@ -74,6 +75,9 @@ vtkPVOptions::vtkPVOptions()
   this->UseOffscreenRendering = 0;
   this->DisableComposite = 0;
   this->ConnectID = 0;
+  this->LogFileName = 0;
+  this->StereoType = 0;
+  this->SetStereoType("Red-Blue");
 
   this->Timeout = 0;
 
@@ -99,11 +103,17 @@ vtkPVOptions::~vtkPVOptions()
   this->SetClientHostName(0);
   this->SetMachinesFileName(0);
   this->SetStateFileName(0);
+  this->SetLogFileName(0);
+  this->SetStereoType(0);
 }
 
 //----------------------------------------------------------------------------
 void vtkPVOptions::Initialize()
 {
+  this->AddArgument("--cslog", 0, &this->LogFileName,
+                    "ClientServerStream log file.",
+                    vtkPVOptions::ALLPROCESS);
+
   this->AddArgument("--data", 0, &this->ParaViewDataName,
                     "Load the specified data. "
                     "To specify file series replace the numeral with a '.' eg. "
@@ -144,6 +154,12 @@ void vtkPVOptions::Initialize()
                            "Tell the application to enable stereo rendering"
                            " (only when running on a single process).",
                            vtkPVOptions::PVCLIENT | vtkPVOptions::PARAVIEW);
+  this->AddArgument("--stereo-type", 0, &this->StereoType,
+                           "Specify the stereo type. This valid only when "
+                           "--stereo is specified. Possible values are "
+                           "\"Crystal Eyes\", \"Red-Blue\", \"Interlaced\", "
+                           "\"Dresden\", \"Anaglyph\", \"Checkerboard\"",
+                           vtkPVOptions::PVCLIENT | vtkPVOptions::PARAVIEW);
   /*
   this->AddArgument("--server-host", "-sh", &this->ServerHostName,
                     "Tell the client the host name of the data server.",
@@ -199,10 +215,11 @@ void vtkPVOptions::Initialize()
                     "after which the server may timeout. The client typically shows warning "
                     "messages before the server times out.",
                     vtkPVOptions::PVDATA_SERVER|vtkPVOptions::PVSERVER);
-  
-  // This should be deprecated when I get the time 
-  this->AddArgument("--cave-configuration", "-cc", &this->CaveConfigurationFileName,
-    "Specify the file that defines the displays for a cave. It is used only with CaveRenderModule.");
+ 
+  // Disabling for now since we don't support Cave anymore.
+  // this->AddArgument("--cave-configuration", "-cc", &this->CaveConfigurationFileName,
+  // "Specify the file that defines the displays for a cave. It is used only with CaveRenderModule.");
+
   this->AddArgument("--machines", "-m", &this->MachinesFileName, 
                     "Specify the network configurations file for the render server.");
 
@@ -304,6 +321,13 @@ int vtkPVOptions::DeprecatedArgument(const char* argument)
   return this->Superclass::DeprecatedArgument(argument);
 }
 
+//----------------------------------------------------------------------------
+vtkSelfConnection* vtkPVOptions::NewSelfConnection()
+{
+  // Let vtkProcessModuleConnectionManager do the default thing.
+  return NULL;
+}
+
 //----------------------------------------------------------------------------
 void vtkPVOptions::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -404,4 +428,7 @@ void vtkPVOptions::PrintSelf(ostream& os, vtkIndent indent)
   
   os << indent << "StateFileName: "
     << (this->StateFileName?this->StateFileName:"(none)") << endl;
+  os << indent << "LogFileName: "
+    << (this->LogFileName? this->LogFileName : "(none)") << endl; 
+
 }
