@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVPluginLoader.h,v $
+  Module:    vtkPVPluginLoader.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -22,50 +22,90 @@
 
 #include "vtkObject.h"
 
+class vtkIntArray;
+class vtkPVPlugin;
+class vtkPVPluginInformation;
 class vtkStringArray;
 
 class VTK_EXPORT vtkPVPluginLoader : public vtkObject
 {
 public:
   static vtkPVPluginLoader* New();
-  vtkTypeRevisionMacro(vtkPVPluginLoader, vtkObject);
+  vtkTypeMacro(vtkPVPluginLoader, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
-  // set the filename and load the plugin
+  // set/get the filename and load the plugin
   void SetFileName(const char* file);
-  vtkGetStringMacro(FileName);
+  const char* GetFileName();
+
+//BTX
+  // Description:
+  // Loads the paraview plugin.
+  void Load(vtkPVPlugin*);
+//ETX
+  
+  // Description:
+  // Get the Server Manager PluginInformation object
+  vtkGetObjectMacro(PluginInfo, vtkPVPluginInformation);
   
   // Description:
   // Get the Server Manager XML from a loaded plugin
   // the string array contains chunks of XML to process
   vtkGetObjectMacro(ServerManagerXML, vtkStringArray);
 
-  // Desctiption:
+  // Description:
+  // Get a list of Python modules from a loaded plugin.  The string array
+  // contains full names of Python modules.
+  vtkGetObjectMacro(PythonModuleNames, vtkStringArray);
+
+  // Description:
+  // Get the Python source for the Python modules in a loaded plugin.  The
+  // string array contains the Python source for a given module.  The entries in
+  // this array correspond to the entries of the same index in the
+  // PythonModuleNames array.
+  vtkGetObjectMacro(PythonModuleSources, vtkStringArray);
+
+  // Description:
+  // Get a list of flags specifying whether a given module is really a package.
+  // A 1 for package, 0 for module.  The entries in this array correspond to the
+  // entries of the same index in the PythonModuleNames and PythonModuleSources
+  // arrays.
+  vtkGetObjectMacro(PythonPackageFlags, vtkIntArray);
+    
+  // Description:
+  // Get the plugin name string
+  const char* GetPluginName();
+    
+  // Description:
+  // Get the plugin version string
+  const char* GetPluginVersion();
+  
+  // Description:
   // Get whether the plugin is loaded
-  vtkGetMacro(Loaded, int);
-  
-  // Desctiption:
+  int GetLoaded(); 
+   
+  // Description:
   // Get the error string if the plugin failed to load
-  vtkGetStringMacro(Error);
+  const char* GetError();
   
-  // Desctiption:
+  // Description:
   // Get a string of standard search paths (path1;path2;path3)
   // search paths are based on PV_PLUGIN_PATH,
   // plugin dir relative to executable.
-  vtkGetStringMacro(SearchPaths);
+  const char* GetSearchPaths();
 
 protected:
   vtkPVPluginLoader();
   ~vtkPVPluginLoader();
   
-  vtkSetStringMacro(Error);
+  vtkPVPluginInformation* PluginInfo;
 
-  char* FileName;
-  int Loaded;
   vtkStringArray* ServerManagerXML;
-  char* Error;
-  char* SearchPaths;
+  vtkStringArray* PythonModuleNames;
+  vtkStringArray* PythonModuleSources;
+  vtkIntArray*    PythonPackageFlags;
+  bool DebugPlugin;
 
 private:
   vtkPVPluginLoader(const vtkPVPluginLoader&); // Not implemented.
