@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkCSVWriter.cxx,v $
+  Module:    vtkCSVWriter.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -25,13 +25,14 @@
 #include "vtkPointSet.h"
 #include "vtkPolyData.h"
 #include "vtkPolyLineToRectilinearGridFilter.h"
-#include "vtkRectilinearGrid.h"
+#include "vtkTable.h"
 #include "vtkSmartPointer.h"
 
 #include <vtkstd/vector>
+#include <vtksys/ios/sstream>
 
 vtkStandardNewMacro(vtkCSVWriter);
-vtkCxxRevisionMacro(vtkCSVWriter, "$Revision: 1.8 $");
+
 //-----------------------------------------------------------------------------
 vtkCSVWriter::vtkCSVWriter()
 {
@@ -57,7 +58,7 @@ vtkCSVWriter::~vtkCSVWriter()
 int vtkCSVWriter::FillInputPortInformation(
   int vtkNotUsed(port), vtkInformation* info)
 {
-  info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet");
+  info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkTable");
   return 1;
 }
 
@@ -90,7 +91,8 @@ bool vtkCSVWriter::OpenFile()
 //-----------------------------------------------------------------------------
 template <class iterT>
 void vtkCSVWriterGetDataString(
-  iterT* iter, vtkIdType tupleIndex, ofstream* stream, vtkCSVWriter* writer)
+  iterT* iter, vtkIdType tupleIndex, ofstream* stream, vtkCSVWriter* writer,
+  bool* first)
 {
   int numComps = iter->GetNumberOfComponents();
   vtkIdType index = tupleIndex* numComps;
@@ -98,12 +100,20 @@ void vtkCSVWriterGetDataString(
     {
     if ((index+cc) < iter->GetNumberOfValues())
       {
-      (*stream) << writer->GetFieldDelimiter()
-        << iter->GetValue(index+cc);
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
+      (*stream) << iter->GetValue(index+cc);
       }
     else
       {
-      (*stream) << writer->GetFieldDelimiter();
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
       }
     }
 }
@@ -111,8 +121,8 @@ void vtkCSVWriterGetDataString(
 //-----------------------------------------------------------------------------
 VTK_TEMPLATE_SPECIALIZE
 void vtkCSVWriterGetDataString(
-  vtkArrayIteratorTemplate<vtkStdString>* iter, vtkIdType tupleIndex, 
-  ofstream* stream, vtkCSVWriter* writer)
+  vtkArrayIteratorTemplate<vtkStdString>* iter, vtkIdType tupleIndex,
+  ofstream* stream, vtkCSVWriter* writer, bool* first)
 {
   int numComps = iter->GetNumberOfComponents();
   vtkIdType index = tupleIndex* numComps;
@@ -120,23 +130,92 @@ void vtkCSVWriterGetDataString(
     {
     if ((index+cc) < iter->GetNumberOfValues())
       {
-      (*stream) << writer->GetFieldDelimiter()
-        << writer->GetString(iter->GetValue(index+cc));
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
+      (*stream) << writer->GetString(iter->GetValue(index+cc));
       }
     else
       {
-      (*stream) << writer->GetFieldDelimiter();
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
       }
     }
 }
 
+//-----------------------------------------------------------------------------
+VTK_TEMPLATE_SPECIALIZE
+void vtkCSVWriterGetDataString(
+  vtkArrayIteratorTemplate<char>* iter, vtkIdType tupleIndex,
+  ofstream* stream, vtkCSVWriter* writer, bool* first)
+{
+  int numComps = iter->GetNumberOfComponents();
+  vtkIdType index = tupleIndex* numComps;
+  for (int cc=0; cc < numComps; cc++)
+    {
+    if ((index+cc) < iter->GetNumberOfValues())
+      {
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
+      (*stream) << static_cast<int>( iter->GetValue(index+cc) );
+      }
+    else
+      {
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
+      }
+    }
+}
+
+//-----------------------------------------------------------------------------
+VTK_TEMPLATE_SPECIALIZE
+void vtkCSVWriterGetDataString(
+  vtkArrayIteratorTemplate<unsigned char>* iter, vtkIdType tupleIndex,
+  ofstream* stream, vtkCSVWriter* writer, bool* first)
+{
+  int numComps = iter->GetNumberOfComponents();
+  vtkIdType index = tupleIndex* numComps;
+  for (int cc=0; cc < numComps; cc++)
+    {
+    if ((index+cc) < iter->GetNumberOfValues())
+      {
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
+      (*stream) << static_cast<int>( iter->GetValue(index+cc) );
+      }
+    else
+      {
+      if (*first == false)
+        {
+        (*stream) << writer->GetFieldDelimiter();
+        }
+      *first = false;
+      }
+    }
+}
+
+
 //-----------------------------------------------------------------------------
 vtkStdString vtkCSVWriter::GetString(vtkStdString string)
 {
   if (this->UseStringDelimiter && this->StringDelimiter)
     {
     vtkStdString temp = this->StringDelimiter;
-    temp += string + this->StringDelimiter; 
+    temp += string + this->StringDelimiter;
     return temp;
     }
   return string;
@@ -145,153 +224,71 @@ vtkStdString vtkCSVWriter::GetString(vtkStdString string)
 //-----------------------------------------------------------------------------
 void vtkCSVWriter::WriteData()
 {
-  vtkRectilinearGrid* rg = vtkRectilinearGrid::SafeDownCast(this->GetInput());
+  vtkTable* rg = vtkTable::SafeDownCast(this->GetInput());
   if (rg)
     {
-    this->WriteRectilinearGridData(rg);
+    this->WriteTable(rg);
     }
   else
     {
-    vtkDataSet* ds = vtkDataSet::SafeDownCast(this->GetInput());
-    if (ds)
-      {
-      const char* const pdInfoStr =
-        "vtkCSVWriter: input data type needs to be of type vtkPolyData";
-      vtkPointSet* ps = vtkPointSet::SafeDownCast(ds);
-      if (ps)
-        {
-        vtkPolyData* pd = vtkPolyData::SafeDownCast(ps);
-        if (pd)
-          {
-          vtkPolyData* clone = vtkPolyData::New();
-          clone->ShallowCopy(pd);
-
-          const char* const infoStr =
-            "input data type is a vtkPolyData."
-            " Converting via vtkPolyLineToRectilinearGridFilter";
-          vtkDebugMacro(<< infoStr);
-          vtkPolyLineToRectilinearGridFilter* p2rgf =
-            vtkPolyLineToRectilinearGridFilter::New();
-          p2rgf->SetInput(clone);
-
-          p2rgf->Update();
-          this->WriteRectilinearGridData(p2rgf->GetOutput());
-
-          p2rgf->Delete();
-          clone->Delete();
-          }
-        else
-          {
-          vtkDebugMacro(<< pdInfoStr);
-          vtkWarningMacro(<< pdInfoStr);
-          }
-        }
-      else
-        {
-        vtkDebugMacro(<< pdInfoStr);
-        vtkWarningMacro(<< pdInfoStr);
-        }
-      }
-    else
-      {
-      vtkErrorMacro(<< "Bad Ju Ju! The input to vtkCSVWriter must be a vtkDataSet");
-      }
+    vtkErrorMacro(<< "CSVWriter can only write vtkTable.");
     }
 }
 
 //-----------------------------------------------------------------------------
-void vtkCSVWriter::WriteRectilinearGridData(vtkRectilinearGrid* rectilinearGrid)
+void vtkCSVWriter::WriteTable(vtkTable* table)
 {
-  vtkIdType numPoints = rectilinearGrid->GetNumberOfPoints();
-  vtkPointData* pd = rectilinearGrid->GetPointData();
-  vtkCellData* cd = rectilinearGrid->GetCellData();
-  int dims[3];
-  int non_unit_dims = 0;
-  int cc;
-  rectilinearGrid->GetDimensions(dims);
-  for (cc=0; cc < 3; cc++)
-    {
-    non_unit_dims += (dims[cc] > 1)?  1:  0;
-    }
-  if (non_unit_dims > 1)
-    {
-    vtkErrorMacro("The rectilinear grid must be 1D to be save as CSV.");
-    return;
-    }
-
+  vtkIdType numRows = table->GetNumberOfRows();
+  vtkDataSetAttributes* dsa = table->GetRowData();
   if (!this->OpenFile())
     {
     return;
     }
 
+  vtkstd::vector<vtkSmartPointer<vtkArrayIterator> > columnsIters;
+
+  int cc;
+  int numArrays = dsa->GetNumberOfArrays();
+  bool first = true;
   // Write headers:
-  (*this->Stream) << this->GetString("X::Point")
-    << this->FieldDelimiter
-    << this->GetString("Y::Point")
-    << this->FieldDelimiter
-    << this->GetString("Z::Point");
-
-  vtkstd::vector<vtkSmartPointer<vtkArrayIterator> > pointIters;
-  vtkstd::vector<vtkSmartPointer<vtkArrayIterator> > cellIters;
-
-  int pdNumArrays = pd->GetNumberOfArrays();
-  for (cc=0; cc < pdNumArrays; cc++)
+  for (cc=0; cc < numArrays; cc++)
     {
-    vtkAbstractArray* array = pd->GetAbstractArray(cc);
+    vtkAbstractArray* array = dsa->GetAbstractArray(cc);
     for (int comp=0; comp < array->GetNumberOfComponents(); comp++)
       {
-      (*this->Stream) << this->FieldDelimiter
-        << this->GetString(vtkStdString(array->GetName())+"::PointData");
-      }
-     vtkArrayIterator* iter = array->NewIterator();
-    pointIters.push_back(iter);
-    iter->Delete();
-    }
+      if (!first)
+        {
+        (*this->Stream) << this->FieldDelimiter;
+        }
+      first = false;
 
-  int cdNumArrays = cd->GetNumberOfArrays();
-  for (cc=0; cc < cdNumArrays; cc++)
-    {
-    vtkAbstractArray* array = cd->GetAbstractArray(cc);
-    for (int comp=0; comp < array->GetNumberOfComponents(); comp++)
-      {
-      (*this->Stream) << this->FieldDelimiter
-        << this->GetString(vtkStdString(array->GetName())+"::CellData");
+      vtksys_ios::ostringstream array_name;
+      array_name << array->GetName();
+      if (array->GetNumberOfComponents() > 1)
+        {
+        array_name << ":" << comp;
+        }
+      (*this->Stream) << this->GetString(array_name.str());
       }
     vtkArrayIterator* iter = array->NewIterator();
-    cellIters.push_back(iter);
+    columnsIters.push_back(iter);
     iter->Delete();
     }
   (*this->Stream) << "\n";
 
-  for (vtkIdType index=0; index < numPoints; index++)
+  for (vtkIdType index=0; index < numRows; index++)
     {
-    double point[3];
-    rectilinearGrid->GetPoint(index, point);
-    (*this->Stream)
-      << point[0] << this->FieldDelimiter
-      << point[1] << this->FieldDelimiter
-      << point[2];
+    first = true;
     vtkstd::vector<vtkSmartPointer<vtkArrayIterator> >::iterator iter;
-    for (iter = pointIters.begin(); iter != pointIters.end(); ++iter)
+    for (iter = columnsIters.begin(); iter != columnsIters.end(); ++iter)
       {
       switch ((*iter)->GetDataType())
         {
         vtkArrayIteratorTemplateMacro(
           vtkCSVWriterGetDataString(static_cast<VTK_TT*>(iter->GetPointer()),
-            index, this->Stream, this));
+            index, this->Stream, this, &first));
         }
       }
-
-    for (iter = cellIters.begin(); iter != cellIters.end(); ++iter)
-      {
-      switch ((*iter)->GetDataType())
-        {
-        vtkArrayIteratorTemplateMacro(
-          vtkCSVWriterGetDataString(static_cast<VTK_TT*>(iter->GetPointer()),
-            index, this->Stream, this));
-        }
-      }
-
     (*this->Stream) << "\n";
     }
 
@@ -302,11 +299,11 @@ void vtkCSVWriter::WriteRectilinearGridData(vtkRectilinearGrid* rectilinearGrid)
 void vtkCSVWriter::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "FieldDelimiter: " << (this->FieldDelimiter ? 
+  os << indent << "FieldDelimiter: " << (this->FieldDelimiter ?
     this->FieldDelimiter : "(none)") << endl;
   os << indent << "StringDelimiter: " << (this->StringDelimiter ?
     this->StringDelimiter : "(none)") << endl;
   os << indent << "UseStringDelimiter: " << this->UseStringDelimiter << endl;
-  os << indent << "FileName: " << (this->FileName? this->FileName : "none") 
+  os << indent << "FileName: " << (this->FileName? this->FileName : "none")
     << endl;
 }
