@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkIntegrateFlowThroughSurface.cxx,v $
+  Module:    vtkIntegrateFlowThroughSurface.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -31,7 +31,6 @@
 #include "vtkUnstructuredGrid.h"
 #include "vtkSmartPointer.h"
 
-vtkCxxRevisionMacro(vtkIntegrateFlowThroughSurface, "$Revision: 1.7 $");
 vtkStandardNewMacro(vtkIntegrateFlowThroughSurface);
 
 //-----------------------------------------------------------------------------
@@ -106,7 +105,7 @@ int vtkIntegrateFlowThroughSurface::RequestData(
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
   
-  // get the input and ouptut
+  // get the input and output
   vtkSmartPointer<vtkDataObject> input = inInfo->Get(vtkDataObject::DATA_OBJECT());
 
   vtkDataSet *dsInput = vtkDataSet::SafeDownCast(
