@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPPhastaReader.cxx,v $
+  Module:    vtkPPhastaReader.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -55,7 +55,6 @@ struct vtkPPhastaReaderInternal
 };
 
 //----------------------------------------------------------------------------
-vtkCxxRevisionMacro(vtkPPhastaReader, "$Revision: 1.5 $");
 vtkStandardNewMacro(vtkPPhastaReader);
 
 //----------------------------------------------------------------------------
@@ -158,13 +157,16 @@ int vtkPPhastaReader::RequestData(vtkInformation*,
     outInfo->Get(vtkDataObject::DATA_OBJECT()));
   output->SetNumberOfBlocks(1);
   vtkMultiPieceDataSet* MultiPieceDataSet = vtkMultiPieceDataSet::New();
+  MultiPieceDataSet->SetNumberOfPieces(numPieces);
   output->SetBlock(0, MultiPieceDataSet);
   MultiPieceDataSet->Delete();
 
   const char* geometryPattern = 0;
-  int geomHasPiece, geomHasTime;
+  int geomHasPiece = 0;
+  int geomHasTime = 0;
   const char* fieldPattern = 0;
-  int fieldHasPiece, fieldHasTime;
+  int fieldHasPiece = 0;
+  int fieldHasTime = 0;
 
   unsigned int numElements = rootElement->GetNumberOfNestedElements();
   for (unsigned int i=0; i<numElements; i++)
@@ -310,7 +312,7 @@ int vtkPPhastaReader::RequestData(vtkInformation*,
     vtkSmartPointer<vtkUnstructuredGrid> copy = 
       vtkSmartPointer<vtkUnstructuredGrid>::New();
     copy->ShallowCopy(this->Reader->GetOutput());
-    MultiPieceDataSet->SetPiece(MultiPieceDataSet->GetNumberOfPieces(),copy);
+    MultiPieceDataSet->SetPiece(loadingPiece, copy);
     }
   
   delete [] geom_name;
@@ -587,6 +589,26 @@ int vtkPPhastaReader::RequestInformation(vtkInformation*,
   return 1;
 }
 
+//-----------------------------------------------------------------------------
+int vtkPPhastaReader::CanReadFile(const char *filename)
+{
+  vtkSmartPointer<vtkPVXMLParser> parser
+    = vtkSmartPointer<vtkPVXMLParser>::New();
+  parser->SuppressErrorMessagesOn();
+  parser->SetFileName(filename);
+
+  // Make sure we can parse the XML metafile.
+  if (!parser->Parse()) return 0;
+
+  // Make sure the XML file has a root element and it is of the right tag.
+  vtkPVXMLElement *rootElement = parser->GetRootElement();
+  if (!rootElement) return 0;
+  if (strcmp(rootElement->GetName(), "PhastaMetaFile") != 0) return 0;
+
+  // The file clearly is supposed to be a Phasta file.
+  return 1;
+}
+
 //----------------------------------------------------------------------------
 void vtkPPhastaReader::PrintSelf(ostream& os, vtkIndent indent)
 {
