@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVDReader.cxx,v $
+  Module:    vtkPVDReader.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -23,7 +23,6 @@
 #include <vtkstd/algorithm>
 #include <vtkstd/vector>
 
-vtkCxxRevisionMacro(vtkPVDReader, "$Revision: 1.7 $");
 vtkStandardNewMacro(vtkPVDReader);
 
 
