@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVGenericRenderWindowInteractor.cxx,v $
+  Module:    vtkPVGenericRenderWindowInteractor.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -35,11 +35,11 @@ public:
     this->Target = target;
     }
 
-  virtual void Execute(vtkObject* vtkNotUsed(caller), unsigned long event, void* data)
+  virtual void Execute(vtkObject* vtkNotUsed(caller), unsigned long event, void*
+    vtkNotUsed(data))
     {
     if (this->Target)
       {
-      this->Target->InvokeEvent(event, data);
       if (event == vtkCommand::StartInteractionEvent)
         {
         this->Target->SetInteractiveRenderEnabled(1);
@@ -66,7 +66,6 @@ protected:
 
 //----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkPVGenericRenderWindowInteractor);
-vtkCxxRevisionMacro(vtkPVGenericRenderWindowInteractor, "$Revision: 1.7 $");
 vtkCxxSetObjectMacro(vtkPVGenericRenderWindowInteractor,Renderer,vtkRenderer);
 
 //----------------------------------------------------------------------------
