@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVGeometryFilter.h,v $
+  Module:    vtkPVGeometryFilter.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -21,7 +21,6 @@
 #define __vtkPVGeometryFilter_h
 
 #include "vtkPolyDataAlgorithm.h"
-
 class vtkAppendPolyData;
 class vtkCallbackCommand;
 class vtkDataObject;
@@ -43,7 +42,7 @@ class VTK_EXPORT vtkPVGeometryFilter : public vtkPolyDataAlgorithm
 {
 public:
   static vtkPVGeometryFilter *New();
-  vtkTypeRevisionMacro(vtkPVGeometryFilter,vtkPolyDataAlgorithm);
+  vtkTypeMacro(vtkPVGeometryFilter,vtkPolyDataAlgorithm);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -102,10 +101,21 @@ public:
   vtkGetMacro(PassThroughPointIds,int);
   vtkBooleanMacro(PassThroughPointIds,int);
   
+  // Description:
+  // If off, which is the default, extracts the surface of the data fed 
+  // into the geometry filter. If on, it produces a bounding box for the 
+  // input to the filter that is producing that data instead.
+  vtkSetMacro(MakeOutlineOfInput,int);
+  vtkGetMacro(MakeOutlineOfInput,int);
+  vtkBooleanMacro(MakeOutlineOfInput,int);
+
+//BTX
 protected:
   vtkPVGeometryFilter();
   ~vtkPVGeometryFilter();
 
+  class vtkPolyDataVector;
+
   virtual int RequestInformation(vtkInformation* request,
                                  vtkInformationVector** inputVector,
                                  vtkInformationVector* outputVector);
@@ -138,10 +148,9 @@ protected:
     vtkPolyData* input, vtkPolyData* output, int doCommunicate);
   void OctreeExecute(
     vtkHyperOctree* input, vtkPolyData* output, int doCommunicate);
-  void DataSetSurfaceExecute(vtkDataSet* input, vtkPolyData* output);
   void ExecuteCellNormals(vtkPolyData* output, int doCommunicate);
   int ExecuteCompositeDataSet(vtkCompositeDataSet* mgInput, 
-                              vtkAppendPolyData* append, 
+                              vtkPolyDataVector &outputs,
                               int& numInputs);
 
   void ChangeUseStripsInternal(int val, int force);
@@ -158,7 +167,7 @@ protected:
   
   int CheckAttributes(vtkDataObject* input);
 
-  vtkCompositeDataSet* FillPartialArrays(vtkCompositeDataSet* input);
+  void FillPartialArrays(vtkPolyDataVector& inputs);
 
   // Callback registered with the InternalProgressObserver.
   static void InternalProgressCallbackFunction(vtkObject*, unsigned long,
@@ -171,11 +180,23 @@ protected:
 
   virtual void ReportReferences(vtkGarbageCollector*);
 
+  // Description:
+  // Overridden to request ghost-cells for vtkUnstructuredGrid inputs so that we
+  // don't generate internal surfaces.
+  virtual int RequestUpdateExtent(vtkInformation*,
+                                  vtkInformationVector**,
+                                  vtkInformationVector*);
+
+
+  // Convenience method to purge ghost cells.
+  void RemoveGhostCells(vtkPolyData*);
+
   int PassThroughCellIds;
   int PassThroughPointIds;
   int ForceUseStrips;
   vtkTimeStamp     StripSettingMTime;
   int StripModFirstPass;
+  int MakeOutlineOfInput;
 
 private:
   vtkPVGeometryFilter(const vtkPVGeometryFilter&); // Not implemented
@@ -185,6 +206,9 @@ private:
   void AddHierarchicalIndex(vtkPolyData* pd, unsigned int level, unsigned int index);
 
   unsigned int CompositeIndex;
+
+  class BoundsReductionOperation;
+//ETX
 };
 
 #endif
