@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVJoystickFlyOut.h,v $
+  Module:    vtkPVJoystickFlyOut.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,7 +26,7 @@ class VTK_EXPORT vtkPVJoystickFlyOut : public vtkPVJoystickFly
 {
 public:
   static vtkPVJoystickFlyOut *New();
-  vtkTypeRevisionMacro(vtkPVJoystickFlyOut, vtkPVJoystickFly);
+  vtkTypeMacro(vtkPVJoystickFlyOut, vtkPVJoystickFly);
   void PrintSelf(ostream& os, vtkIndent indent);
   
 protected:
