@@ -1,6 +1,6 @@
 /*=========================================================================
 
-  Module:    $RCSfile: vtkPVMain.cxx,v $
+  Module:    vtkPVMain.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -49,10 +49,9 @@
 #endif
 
 vtkStandardNewMacro(vtkPVMain);
-vtkCxxRevisionMacro(vtkPVMain, "$Revision: 1.23 $");
-
-int vtkPVMain::InitializeMPI = 1;
 
+int vtkPVMain::UseMPI = 1;
+int vtkPVMain::FinalizeMPI = 0;
 
 //----------------------------------------------------------------------------
 vtkPVMain::vtkPVMain()
@@ -61,15 +60,15 @@ vtkPVMain::vtkPVMain()
 }
 
 //----------------------------------------------------------------------------
-void vtkPVMain::SetInitializeMPI(int s)
+void vtkPVMain::SetUseMPI(int s)
 {
-  vtkPVMain::InitializeMPI = s;
+  vtkPVMain::UseMPI = s;
 }
 
 //----------------------------------------------------------------------------
-int vtkPVMain::GetInitializeMPI()
+int vtkPVMain::GetUseMPI()
 {
-  return vtkPVMain::InitializeMPI;
+  return vtkPVMain::UseMPI;
 }
 
 //----------------------------------------------------------------------------
@@ -89,26 +88,28 @@ vtkPVMain::~vtkPVMain()
 void vtkPVMain::Initialize(int* argc, char** argv[])
 {
 #ifdef VTK_USE_MPI
-  if (vtkPVMain::InitializeMPI)
+  if(vtkPVMain::UseMPI)
     {
-    // MPICH changes the current working directory after MPI_Init. We fix that
-    // by changing the CWD back to the original one after MPI_Init.
-    vtkstd::string cwd = vtksys::SystemTools::GetCurrentWorkingDirectory(true);
+    int flag = 0;
+    MPI_Initialized(&flag);
+    if(flag == 0)
+      {
+      // MPICH changes the current working directory after MPI_Init. We fix that
+      // by changing the CWD back to the original one after MPI_Init.
+      vtkstd::string cwd = vtksys::SystemTools::GetCurrentWorkingDirectory(true);
+      
+      // This is here to avoid false leak messages from vtkDebugLeaks when
+      // using mpich. It appears that the root process which spawns all the
+      // main processes waits in MPI_Init() and calls exit() when
+      // the others are done, causing apparent memory leaks for any objects
+      // created before MPI_Init().
+      MPI_Init(argc, argv);
+      
+      // restore CWD to what it was before the MPI intialization.
+      vtksys::SystemTools::ChangeDirectory(cwd.c_str());
 
-    // This is here to avoid false leak messages from vtkDebugLeaks when
-    // using mpich. It appears that the root process which spawns all the
-    // main processes waits in MPI_Init() and calls exit() when
-    // the others are done, causing apparent memory leaks for any objects
-    // created before MPI_Init().
-    int myId = 0;
-    MPI_Init(argc, argv);
-    // Might as well get our process ID here.  I use it to determine
-    // Whether to initialize tk.  Once again, splitting Tk and Tcl 
-    // initialization would clean things up.
-    MPI_Comm_rank(MPI_COMM_WORLD,&myId);
-
-    // restore CWD to what it was before the MPI intialization.
-    vtksys::SystemTools::ChangeDirectory(cwd.c_str());
+      vtkPVMain::FinalizeMPI = 1;
+      }
     }
 #else
   (void)argc;
@@ -149,7 +150,7 @@ void vtkPVMain::Initialize(int* argc, char** argv[])
 void vtkPVMain::Finalize()
 {
 #ifdef VTK_USE_MPI
-  if (vtkPVMain::InitializeMPI)
+  if (vtkPVMain::FinalizeMPI)
     {
     MPI_Barrier(MPI_COMM_WORLD);
     MPI_Finalize();
@@ -186,12 +187,21 @@ int vtkPVMain::Initialize(vtkPVOptions* options,
 
   // Don't prompt the user with startup errors on unix.
 #if defined(_WIN32) && !defined(__CYGWIN__)
-  vtkOutputWindow::GetInstance()->PromptUserOn();
+  if(getenv("DASHBOARD_TEST_FROM_CTEST") ||
+    getenv("DART_TEST_FROM_DART"))
+    {
+    vtkOutputWindow::GetInstance()->PromptUserOff();
+    }
+  else
+    {
+    vtkOutputWindow::GetInstance()->PromptUserOn();
+    }
 #else
   vtkOutputWindow::GetInstance()->PromptUserOff();
 #endif
 
   int display_help = 0;
+  bool ret_failure = false;
   vtksys_ios::ostringstream sscerr;
   if (argv && !options->Parse(argc, argv) )
     {
@@ -209,8 +219,9 @@ int vtkPVMain::Initialize(vtkPVOptions* options,
     {
     sscerr << options->GetHelp() << endl;
     vtkOutputWindow::GetInstance()->DisplayText( sscerr.str().c_str() );
-    return 1;
+    ret_failure = true;
     }
+
   if (options->GetTellVersion() ) 
     {
     int MajorVersion = PARAVIEW_VERSION_MAJOR;
@@ -218,7 +229,7 @@ int vtkPVMain::Initialize(vtkPVOptions* options,
     char name[128];
     sprintf(name, "ParaView%d.%d\n", MajorVersion, MinorVersion);
     vtkOutputWindow::GetInstance()->DisplayText(name);
-    return 1;
+    ret_failure = true;
     }
 
   // Create the process module for initializing the processes.
@@ -228,7 +239,7 @@ int vtkPVMain::Initialize(vtkPVOptions* options,
   this->ProcessModule->SetOptions(options);
   vtkProcessModule::SetProcessModule(this->ProcessModule);
   // PM can use MPI only if MPI was initialized.
-  this->ProcessModule->SetUseMPI(vtkPVMain::InitializeMPI);
+  this->ProcessModule->SetUseMPI(vtkPVMain::UseMPI);
   if(helper)
     {
     helper->SetProcessModule(this->ProcessModule);
@@ -239,7 +250,7 @@ int vtkPVMain::Initialize(vtkPVOptions* options,
 
   (*initInterp)(this->ProcessModule);
 
-  return 0;
+  return ret_failure? 1 : 0;
 }
 
 //-----------------------------------------------------------------------------
