@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVServerObject.h,v $
+  Module:    vtkPVServerObject.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,7 +26,7 @@ class VTK_EXPORT vtkPVServerObject : public vtkObject
 {
 public:
   static vtkPVServerObject* New();
-  vtkTypeRevisionMacro(vtkPVServerObject, vtkObject);
+  vtkTypeMacro(vtkPVServerObject, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
