@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkSpyPlotReader.cxx,v $
+Module:    vtkSpyPlotReader.cxx
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -62,7 +62,6 @@ PURPOSE.  See the above copyright notice for more information.
 #define coutVector6(x) (x)[0] << " " << (x)[1] << " " << (x)[2] << " " << (x)[3] << " " << (x)[4] << " " << (x)[5]
 #define coutVector3(x) (x)[0] << " " << (x)[1] << " " << (x)[2]
 
-vtkCxxRevisionMacro(vtkSpyPlotReader, "$Revision: 1.68 $");
 vtkStandardNewMacro(vtkSpyPlotReader);
 vtkCxxSetObjectMacro(vtkSpyPlotReader,GlobalController,vtkMultiProcessController);
 
@@ -103,6 +102,8 @@ vtkSpyPlotReader::vtkSpyPlotReader()
   this->GenerateLevelArray=0; // by default, do not generate level array.
   this->GenerateBlockIdArray=0; // by default, do not generate block id array.
   this->GenerateActiveBlockArray = 0; // by default do not generate active array
+  this->GenerateTracerArray = 0; // by default do not generate tracer array
+  this->IsAMR = 1;
 
   this->TimeRequestedFromPipeline = false;
 }
@@ -126,14 +127,20 @@ vtkSpyPlotReader::~vtkSpyPlotReader()
 //-----------------------------------------------------------------------------
 // Create either vtkHierarchicalBoxDataSet or vtkMultiBlockDataSet based on
 // whether the dataset is AMR.
-int vtkSpyPlotReader::RequestDataObject(vtkInformation *vtkNotUsed(req),
+int vtkSpyPlotReader::RequestDataObject(vtkInformation *req,
   vtkInformationVector **vtkNotUsed(inV),
   vtkInformationVector *outV)
 {
   vtkInformation *outInfo = outV->GetInformationObject(0);
   vtkCompositeDataSet* outData = NULL;
 
-  // IsAMR is updated during the RequestInformation pass.
+  // Call UpdateFile (which sets IsAMR) because RequestInformation isn't called
+  // before RequestDataObject
+  this->UpdateFile (req, outV);
+  
+  // We only need IsAMR set from UpdateFile, reset the CurrentFile
+  this->SetCurrentFileName (0);
+
   if (this->IsAMR)
     {
     outData = vtkHierarchicalBoxDataSet::New();
@@ -153,8 +160,8 @@ int vtkSpyPlotReader::RequestDataObject(vtkInformation *vtkNotUsed(req),
 //-----------------------------------------------------------------------------
 // Read the case file and the first binary file do get meta
 // informations (number of files, number of fields, number of timestep).
-int vtkSpyPlotReader::RequestInformation(vtkInformation *request, 
-                                         vtkInformationVector **inputVector, 
+int vtkSpyPlotReader::RequestInformation(vtkInformation *request,
+                                         vtkInformationVector **inputVector,
                                          vtkInformationVector *outputVector)
 {
   if(this->GlobalController==0)
@@ -166,7 +173,7 @@ int vtkSpyPlotReader::RequestInformation(vtkInformation *request,
     {
     return 0;
     }
-  
+
   vtkInformation *info=outputVector->GetInformationObject(0);
   info->Set(vtkStreamingDemandDrivenPipeline::MAXIMUM_NUMBER_OF_PIECES(),-1);
 
@@ -177,6 +184,13 @@ int vtkSpyPlotReader::RequestInformation(vtkInformation *request,
     return 0;
     }
 
+  return this->UpdateFile (request, outputVector);
+}
+
+//-----------------------------------------------------------------------------
+int vtkSpyPlotReader::UpdateFile (vtkInformation* request,
+                                  vtkInformationVector* outputVector)
+{
   ifstream ifs(this->FileName);
   if(!ifs)
     {
@@ -210,10 +224,12 @@ int vtkSpyPlotReader::RequestInformation(vtkInformation *request,
 int vtkSpyPlotReader::UpdateSpyDataFile(vtkInformation* request, 
                                         vtkInformationVector* outputVector)
 {
+  // cerr << "spydatafile\n";
   // See if this is part of a series
   vtkstd::string extension = 
     vtksys::SystemTools::GetFilenameLastExtension(this->FileName);
-  int currentNum, esize, isASeries=0;
+  int currentNum=0, isASeries=0;
+  size_t esize;
   esize = extension.size();
   if (esize > 0 )
     {
@@ -222,7 +238,7 @@ int vtkSpyPlotReader::UpdateSpyDataFile(vtkInformation* request,
     // from the check
     const char *a = extension.c_str();
     char *ep;
-    int b = 0;
+    size_t b = 0;
     if (a[0] == '.')
       {
       b = 1;
@@ -272,8 +288,10 @@ int vtkSpyPlotReader::UpdateSpyDataFile(vtkInformation* request,
   if(this->GetCurrentFileName()!=0 &&
      strcmp(this->FileName,this->GetCurrentFileName())==0)
     {
+    //cerr << "Not setting much else\n";
     return 1;
     }
+  // cerr << "setting Current file name " << this->FileName << endl;
   this->SetCurrentFileName(this->FileName);
   this->Map->Clean(0);
   vtkstd::string fileNoExt = 
@@ -292,6 +310,7 @@ int vtkSpyPlotReader::UpdateSpyDataFile(vtkInformation* request,
   while ( 1 )
     {
     sprintf(buffer, "%s/%s.%d",filePath.c_str(), fileNoExt.c_str(), idx);
+    // cerr << "buffer1 == " << buffer << endl;
     if ( !vtksys::SystemTools::FileExists(buffer) )
       {
       int next = idx;
@@ -319,6 +338,7 @@ int vtkSpyPlotReader::UpdateSpyDataFile(vtkInformation* request,
   while ( 1 )
     {
     sprintf(buffer, "%s/%s.%d", filePath.c_str(), fileNoExt.c_str(), idx);
+    // cerr << "buffer2 == " << buffer << endl;
     if ( !vtksys::SystemTools::FileExists(buffer) )
       {
       int next = idx;
@@ -343,12 +363,14 @@ int vtkSpyPlotReader::UpdateSpyDataFile(vtkInformation* request,
   for ( idx = minimum; idx <= maximum; ++ idx )
     {
     sprintf(buffer, "%s/%s.%d", filePath.c_str(), fileNoExt.c_str(), idx);
+    // cerr << "buffer3 == " << buffer << endl;
     this->Map->Files[buffer]=0;
     vtkDebugMacro( << __LINE__ << " Create new uni reader: " 
                    << this->Map->Files[buffer] );
     }
   // Okay now open just the first file to get meta data
   vtkDebugMacro("Reading Meta Data in UpdateCaseFile(ExecuteInformation) from file: " << this->Map->Files.begin()->first.c_str());
+  // cerr << "updating meta... " << endl;
   return this->UpdateMetaData(request, outputVector);
 }
 
@@ -520,7 +542,13 @@ enum
 };
 
 template<class DataType>
-int vtkSpyPlotRemoveBadGhostCells(DataType* dataType, vtkDataArray* dataArray, int realExtents[6], int realDims[3], int ptDims[3], int realPtDims[3])
+int vtkSpyPlotRemoveBadGhostCells(
+        DataType* dataType,
+        vtkDataArray* dataArray,
+        int realExtents[6],
+        int realDims[3],
+        int ptDims[3],
+        int realPtDims[3])
 {
   /*
     vtkDebugMacro( "//////////////////////////////////////////////////////////////////////////////////" );
@@ -791,9 +819,13 @@ int vtkSpyPlotReader::RequestData(
   int rightHasBounds = 0;
   int leftHasBounds = 0;
 
-  // TODO collect the functions that gather meta data 
-  // in one place and collect the data in a single pass
-  // TODO move the MakeCurrent outside of meta data gather funcs
+  vtkHierarchicalBoxDataSet *hbds 
+        = vtkHierarchicalBoxDataSet::SafeDownCast(cds);
+
+  // TODO The following three calls compute meta data
+  // this could be done in a single pass, and the meta data
+  // should be vtkInformationKeys defined in vtkHierarchicalBoxDataSet
+  // rather than placed in the field data as it is here.
 
   // Note that in the process of getting the bounds 
   // all of the readers will get updated appropriately
@@ -807,18 +839,18 @@ int vtkSpyPlotReader::RequestData(
   this->SetGlobalMinLevelAndSpacing( blockIterator );
   // export global bounds, minimum level, spacing, and box size
   // in field data arrays for use by downstream filters
-  vtkHierarchicalBoxDataSet *hbds 
-        = vtkHierarchicalBoxDataSet::SafeDownCast(cds);
   if ( hbds )
     {
     this->AddAttributes(hbds);
     }
 
+  int needTracers = 1;
+
   // read in the data
   if (nBlocks!=0)
     {
-    // TODO This filter can use the arrays
-    // in field data instead.
+    // TODO This seems wrong, shouldn't the bounds key be defined in
+    // the hierarchical dataset?
     double b[6];
     this->Bounds->GetBounds(b);
     info->Set(vtkExtractCTHPart::BOUNDS(), b, 6);
@@ -839,6 +871,23 @@ int vtkSpyPlotReader::RequestData(
       int numFields=blockIterator->GetNumberOfFields();
       uniReader=blockIterator->GetUniReader();
 
+      if (this->GenerateTracerArray == 1 && needTracers)
+        {
+        vtkFieldData *fd = cds->GetFieldData ();
+        vtkDataArray *array= fd->GetArray("Tracer Coordinates");
+        if (array != 0)
+          {
+          fd->RemoveArray ("Tracer Coordinates");
+          }
+        vtkFloatArray *tracers = uniReader->GetTracers ();
+        if (tracers != 0) 
+          {
+          tracers->SetName ("Tracer Coordinates");
+          fd->AddArray (tracers);
+          }
+        needTracers = 0;
+        }
+
       int dims[3];
       int blockID = blockIterator->GetBlockID();
       int level = 0;
@@ -1120,7 +1169,7 @@ int vtkSpyPlotReader::MergeVectors(vtkDataSetAttributes* da,
     return 0;
     }
   const char *n1, *n2, *n3;
-  int e1, e2, e3;
+  size_t e1, e2, e3;
   n1 = a1->GetName();
   n2 = a2->GetName();
   n3 = a3->GetName();
@@ -1221,7 +1270,7 @@ int vtkSpyPlotReader::MergeVectors(vtkDataSetAttributes* da,
     return 0;
     }
   const char *n1, *n2;
-  int e1, e2;
+  size_t e1, e2;
   n1 = a1->GetName();
   n2 = a2->GetName();
   if (n1 == 0 || n2 == 0)
@@ -1307,7 +1356,7 @@ int vtkSpyPlotReader::CanReadFile(const char* fname)
   char magic[8];
   if ( !spis.ReadString(magic, 8) )
     {
-    vtkErrorMacro( "Cannot read magic" );
+    vtkDebugMacro( "Cannot read magic" );
     return 0;
     }
   if ( strncmp(magic, "spydata", 7) != 0 &&
@@ -1348,7 +1397,8 @@ void vtkSpyPlotReader::SetMergeXYZComponents(int merge)
   this->Modified();
 }
 //-----------------------------------------------------------------------------
-void vtkSpyPlotReader::PrintBlockList(vtkHierarchicalBoxDataSet *hbds, int myProcId)
+void vtkSpyPlotReader::PrintBlockList(vtkHierarchicalBoxDataSet *hbds, int
+  vtkNotUsed(myProcId))
 {
   unsigned int numberOfLevels=hbds->GetNumberOfLevels();
   unsigned int level;
@@ -1356,20 +1406,20 @@ void vtkSpyPlotReader::PrintBlockList(vtkHierarchicalBoxDataSet *hbds, int myPro
   numberOfLevels=hbds->GetNumberOfLevels();
   for (level = 0; level<numberOfLevels; level++)
     {
-    cout<<myProcId<<" level="<<level<<"/"<<numberOfLevels<<endl;
+   // cout<<myProcId<<" level="<<level<<"/"<<numberOfLevels<<endl;
     int totalNumberOfDataSets=hbds->GetNumberOfDataSets(level);
     int i;
     for (i = 0; i<totalNumberOfDataSets; i++)
       {
-      cout<<myProcId<<" dataset="<<i<<"/"<<totalNumberOfDataSets;
+     // cout<<myProcId<<" dataset="<<i<<"/"<<totalNumberOfDataSets;
       vtkAMRBox box;
        if(hbds->GetDataSet(level,i,box)==0)
         {
-        cout<<" Void"<<endl;
+       // cout<<" Void"<<endl;
         }
       else
         {
-        cout<<" Exists"<<endl;
+       // cout<<" Exists"<<endl;
         }
       }
     }
@@ -1800,33 +1850,24 @@ int vtkSpyPlotReader::PrepareAMRData(vtkHierarchicalBoxDataSet *hb,
                                          level, spacing,
                                          origin, extents,
                                          realExtents,
-                                         realDims); 
+                                         realDims);
 
-/*  double bds[6];
-  this->Bounds->GetBounds(bds);
-  cerr << "{\n";
-  cerr << "level:       [" << *level << "]\n";
-  cerr << "Origin:      [" << origin[0] << "," << origin[1] << "," << origin[2] << "]\n";
-  cerr << "Spacing:     [" << spacing[0] << "," << spacing[1] << "," << spacing[2] << "]\n";
-  cerr << "extents:     [" << extents[0] << "," << extents[1] << "," << extents[2] << "|"
-                           << extents[3] << "," << extents[4] << "," << extents[5] << "]\n";
-  cerr << "realExtents: [" << realExtents[0] << "," << realExtents[1] << "," << realExtents[2] << ","
-                           << realExtents[3] << "," << realExtents[4] << "," << realExtents[5] << "]\n";
-  cerr << "realDims:    [" << realDims[0] << "," << realDims[1] << "," << realDims[2] << "]\n";
-  cerr << "bounds:      [" << bds[0] << "," << bds[1] << "," << bds[2] << ","
-                           << bds[3] << "," << bds[4] << "," << bds[5] << "]\n";
-  cerr << "}\n"*/;
-
-  int loCorner[3], hiCorner[3];
-  loCorner[0] = realExtents[0];
-  hiCorner[0] = realExtents[1];
-  loCorner[1] = realExtents[2];
-  hiCorner[1] = realExtents[3];
-  loCorner[2] = realExtents[4];
-  hiCorner[2] = realExtents[5];
-
-  vtkAMRBox box(3,loCorner,hiCorner);
+//   double bds[6];
+//   this->Bounds->GetBounds(bds);
+//   cerr << "{\n";
+//   cerr << "level:       [" << *level << "]\n";
+//   cerr << "Origin:      [" << origin[0] << "," << origin[1] << "," << origin[2] << "]\n";
+//   cerr << "Spacing:     [" << spacing[0] << "," << spacing[1] << "," << spacing[2] << "]\n";
+//   cerr << "extents:     [" << extents[0] << "," << extents[1] << "," << extents[2] << "|"
+//                            << extents[3] << "," << extents[4] << "," << extents[5] << "]\n";
+//   cerr << "realExtents: [" << realExtents[0] << "," << realExtents[1] << "," << realExtents[2] << ","
+//                            << realExtents[3] << "," << realExtents[4] << "," << realExtents[5] << "]\n";
+//   cerr << "realDims:    [" << realDims[0] << "," << realDims[1] << "," << realDims[2] << "]\n";
+//   cerr << "bounds:      [" << bds[0] << "," << bds[1] << "," << bds[2] << ","
+//                            << bds[3] << "," << bds[4] << "," << bds[5] << "]\n";
+//   cerr << "}\n";
 
+  vtkAMRBox box(realExtents);
   vtkUniformGrid* ug = vtkUniformGrid::New();
   hb->SetDataSet(*level, hb->GetNumberOfDataSets(*level), box, ug);
   ug->SetSpacing(spacing);
@@ -1834,6 +1875,7 @@ int vtkSpyPlotReader::PrepareAMRData(vtkHierarchicalBoxDataSet *hb,
   ug->SetOrigin(origin);
   *cd = ug->GetCellData();
   ug->Delete();
+
   return needsFixing;
 }
 
@@ -2011,7 +2053,6 @@ void vtkSpyPlotReader::UpdateBadGhostFieldData(int numFields, int dims[3],
       //vtkDebugMacro( << __LINE__ << " Read data block: " << blockID 
       // << " " << field << "  [" << array->GetName() << "]" );
       cd->AddArray(array);
-      //array->Print(cout);
 
       if ( !fixed )
         {
