@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTransferFunctionEditorRepresentationShapes2D.cxx,v $
+  Module:    vtkTransferFunctionEditorRepresentationShapes2D.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -16,7 +16,6 @@
 
 #include "vtkObjectFactory.h"
 
-vtkCxxRevisionMacro(vtkTransferFunctionEditorRepresentationShapes2D, "$Revision: 1.1 $");
 vtkStandardNewMacro(vtkTransferFunctionEditorRepresentationShapes2D);
 
 //----------------------------------------------------------------------------
