@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkXMLPVAnimationWriter.cxx,v $
+  Module:    vtkXMLPVAnimationWriter.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -29,7 +29,6 @@
 
 //----------------------------------------------------------------------------
 vtkStandardNewMacro(vtkXMLPVAnimationWriter);
-vtkCxxRevisionMacro(vtkXMLPVAnimationWriter, "$Revision: 1.10 $");
 
 //----------------------------------------------------------------------------
 class vtkXMLPVAnimationWriterInternals
