@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMArrayListDomain.cxx,v $
+  Module:    vtkSMArrayListDomain.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -14,6 +14,7 @@
 =========================================================================*/
 #include "vtkSMArrayListDomain.h"
 
+#include "vtkDataObject.h"
 #include "vtkDataSetAttributes.h"
 #include "vtkObjectFactory.h"
 #include "vtkPVArrayInformation.h"
@@ -23,6 +24,7 @@
 #include "vtkSMDomainIterator.h"
 #include "vtkSMInputArrayDomain.h"
 #include "vtkSMInputProperty.h"
+#include "vtkSMIntVectorProperty.h"
 #include "vtkSMSourceProxy.h"
 #include "vtkSMStringVectorProperty.h"
 
@@ -33,12 +35,12 @@
 #include "vtkStdString.h"
 
 vtkStandardNewMacro(vtkSMArrayListDomain);
-vtkCxxRevisionMacro(vtkSMArrayListDomain, "$Revision: 1.18 $");
 
 struct vtkSMArrayListDomainInternals
 {
   vtkstd::map<vtkStdString, int> PartialMap;
   vtkstd::vector<int> DataTypes;
+  vtkstd::vector<int> FieldAssociation;
 };
 
 //---------------------------------------------------------------------------
@@ -46,7 +48,9 @@ vtkSMArrayListDomain::vtkSMArrayListDomain()
 {
   this->AttributeType = vtkDataSetAttributes::SCALARS;
   this->DefaultElement = 0;
+  this->Association = 0;
   this->InputDomainName = 0;
+  this->NoneString = 0;
   this->ALDInternals = new vtkSMArrayListDomainInternals;
 }
 
@@ -54,6 +58,7 @@ vtkSMArrayListDomain::vtkSMArrayListDomain()
 vtkSMArrayListDomain::~vtkSMArrayListDomain()
 {
   this->SetInputDomainName(0);
+  this->SetNoneString(0);
   delete this->ALDInternals;
 }
 
@@ -64,11 +69,62 @@ int vtkSMArrayListDomain::IsArrayPartial(unsigned int idx)
   return this->ALDInternals->PartialMap[name];
 }
 
+//---------------------------------------------------------------------------
+int vtkSMArrayListDomain::GetFieldAssociation(unsigned int idx)
+{
+  if (this->ALDInternals->FieldAssociation.size() > idx)
+    {
+    return this->ALDInternals->FieldAssociation[idx];
+    }
+
+  return -1;
+}
+//---------------------------------------------------------------------------
+unsigned int vtkSMArrayListDomain::AddString(const char* string)
+{
+  // by default we don't assume any association.
+  this->ALDInternals->FieldAssociation.push_back(
+    vtkDataObject::NUMBER_OF_ASSOCIATIONS);
+
+  return this->Superclass::AddString(string);
+}
+
+//---------------------------------------------------------------------------
+void vtkSMArrayListDomain::RemoveAllStrings()
+{
+  this->ALDInternals->FieldAssociation.clear();
+  this->ALDInternals->PartialMap.clear();
+  this->Superclass::RemoveAllStrings();
+}
+
+//---------------------------------------------------------------------------
+int vtkSMArrayListDomain::RemoveString(const char* string)
+{
+  int index = this->Superclass::RemoveString(string);
+  if (index != -1)
+    {
+    int cc=0;
+    vtkstd::vector<int>::iterator iter;
+    for (iter=this->ALDInternals->FieldAssociation.begin();
+      iter != this->ALDInternals->FieldAssociation.end();
+      iter++, cc++)
+      {
+      if (cc==index)
+        {
+        this->ALDInternals->FieldAssociation.erase(iter);
+        break;
+        }
+      }
+    }
+  return index;
+}
+
 //---------------------------------------------------------------------------
 void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
                                      int outputport,
                                      vtkPVDataSetAttributesInformation* info, 
-                                     vtkSMInputArrayDomain* iad)
+                                     vtkSMInputArrayDomain* iad,
+                                     int association)
 {
   this->DefaultElement = 0;
 
@@ -79,13 +135,14 @@ void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
   for (int idx = 0; idx < num; ++idx)
     {
     vtkPVArrayInformation* arrayInfo = info->GetArrayInformation(idx);
-    if ( iad->IsFieldValid(sp, outputport, info->GetArrayInformation(idx)) )
+    if ( iad->IsFieldValid(sp, outputport, info->GetArrayInformation(idx), 1) )
       {
       this->ALDInternals->PartialMap[arrayInfo->GetName()] = arrayInfo->GetIsPartial();
-      int nAcceptedTypes=this->ALDInternals->DataTypes.size();
+      int nAcceptedTypes=static_cast<int>(this->ALDInternals->DataTypes.size());
       if ( nAcceptedTypes==0 )
         {
         unsigned int newidx = this->AddString(arrayInfo->GetName());
+        this->ALDInternals->FieldAssociation[newidx] = association;
         if (arrayInfo == attrInfo)
           {
           attrIdx = newidx;
@@ -97,6 +154,7 @@ void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
         if (!thisDataType || (arrayInfo->GetDataType() == thisDataType))
           {
           unsigned int newidx = this->AddString(arrayInfo->GetName());
+          this->ALDInternals->FieldAssociation[newidx] = association;
           if (arrayInfo == attrInfo)
             {
             attrIdx = newidx;
@@ -108,6 +166,7 @@ void vtkSMArrayListDomain::AddArrays(vtkSMSourceProxy* sp,
   if (attrIdx >= 0)
     {
     this->SetDefaultElement(attrIdx);
+    this->Association = association;
     }
 }
 
@@ -125,33 +184,66 @@ void vtkSMArrayListDomain::Update(vtkSMSourceProxy* sp,
     return;
     }
 
-  if ( iad->GetAttributeType() == vtkSMInputArrayDomain::ANY )
+  int attribute_type = iad->GetAttributeType();
+
+  vtkSMIntVectorProperty* ivp = vtkSMIntVectorProperty::SafeDownCast(
+    this->GetRequiredProperty("FieldDataSelection"));
+  if (ivp && ivp->GetNumberOfElements() == 1)
     {
-    this->AddArrays(sp, outputport, info->GetPointDataInformation(), iad);
-    this->AddArrays(sp, outputport, info->GetCellDataInformation(), iad);
-    this->AddArrays(sp, outputport, info->GetVertexDataInformation(), iad);
-    this->AddArrays(sp, outputport, info->GetEdgeDataInformation(), iad);
-    this->AddArrays(sp, outputport, info->GetRowDataInformation(), iad);
+    if (ivp->GetNumberOfUncheckedElements() == 1)
+      {
+      attribute_type = ivp->GetUncheckedElement(0);
+      }
+    else
+      {
+      attribute_type = ivp->GetElement(0);
+      }
     }
-  else if ( iad->GetAttributeType() == vtkSMInputArrayDomain::POINT )
+
+  switch (attribute_type)
     {
-    this->AddArrays(sp, outputport, info->GetPointDataInformation(), iad);
-    }
-  else if ( iad->GetAttributeType() == vtkSMInputArrayDomain::CELL )
-    {
-    this->AddArrays(sp, outputport, info->GetCellDataInformation(), iad);
-    }
-  else if ( iad->GetAttributeType() == vtkSMInputArrayDomain::VERTEX)
-    {
-    this->AddArrays(sp, outputport, info->GetVertexDataInformation(), iad);
-    }
-  else if ( iad->GetAttributeType() == vtkSMInputArrayDomain::EDGE)
-    {
-    this->AddArrays(sp, outputport, info->GetEdgeDataInformation(), iad);
-    }
-  else if ( iad->GetAttributeType() == vtkSMInputArrayDomain::ROW)
-    {
-    this->AddArrays(sp, outputport, info->GetRowDataInformation(), iad);
+  case vtkSMInputArrayDomain::ANY:
+    this->AddArrays(sp, outputport, info->GetPointDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_POINTS);
+    this->AddArrays(sp, outputport, info->GetCellDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_CELLS);
+    this->AddArrays(sp, outputport, info->GetVertexDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_VERTICES);
+    this->AddArrays(sp, outputport, info->GetEdgeDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_EDGES);
+    this->AddArrays(sp, outputport, info->GetRowDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_ROWS);
+    break;
+
+  case vtkSMInputArrayDomain::POINT:
+    this->AddArrays(sp, outputport, info->GetPointDataInformation(), iad,
+      vtkDataObject:: FIELD_ASSOCIATION_POINTS);
+    this->Association = vtkDataObject:: FIELD_ASSOCIATION_POINTS;
+    break;
+
+  case vtkSMInputArrayDomain::CELL:
+    this->AddArrays(sp, outputport, info->GetCellDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_CELLS);
+    this->Association = vtkDataObject:: FIELD_ASSOCIATION_CELLS;
+    break;
+
+  case vtkSMInputArrayDomain::VERTEX:
+    this->AddArrays(sp, outputport, info->GetVertexDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_VERTICES);
+    this->Association = vtkDataObject:: FIELD_ASSOCIATION_VERTICES;
+    break;
+
+  case vtkSMInputArrayDomain::EDGE:
+    this->AddArrays(sp, outputport, info->GetEdgeDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_EDGES);
+    this->Association = vtkDataObject:: FIELD_ASSOCIATION_EDGES;
+    break;
+
+  case vtkSMInputArrayDomain::ROW:
+    this->AddArrays(sp, outputport, info->GetRowDataInformation(), iad,
+      vtkDataObject::FIELD_ASSOCIATION_ROWS);
+    this->Association = vtkDataObject:: FIELD_ASSOCIATION_ROWS;
+    break;
     }
 
   this->InvokeModified();
@@ -229,6 +321,12 @@ void vtkSMArrayListDomain::Update(vtkSMProxyProperty* pp)
 void vtkSMArrayListDomain::Update(vtkSMProperty*)
 {
   this->RemoveAllStrings();
+  if (this->NoneString)
+    {
+    this->AddString(this->NoneString);
+    this->ALDInternals->FieldAssociation[0] = 
+      vtkDataObject::NUMBER_OF_ASSOCIATIONS;
+    }
 
   vtkSMProxyProperty* pp = vtkSMProxyProperty::SafeDownCast(
     this->GetRequiredProperty("Input"));
@@ -251,6 +349,13 @@ int vtkSMArrayListDomain::ReadXMLAttributes(
     this->SetInputDomainName(input_domain_name);
     }
 
+  // Search for attribute type with matching name.
+  const char* none_string = element->GetAttribute("none_string");
+  if (none_string)
+    {
+      this->SetNoneString(none_string);
+    }
+
   // Search for attribute type with matching name.
   const char* attribute_type = element->GetAttribute("attribute_type");
   unsigned int i = vtkDataSetAttributes::NUM_ATTRIBUTES;
@@ -381,27 +486,34 @@ int vtkSMArrayListDomain::SetDefaultValues(vtkSMProperty* prop)
     return 0;
     }
 
+  const char* array = 0;
   if (this->GetNumberOfStrings() > 0)
     {
-    const char* array = this->GetString(this->DefaultElement);
+    array = this->GetString(this->DefaultElement);
     const char* defaultValue = svp->GetDefaultValue(0);
     unsigned int temp;
     if (defaultValue && this->IsInDomain(defaultValue, temp))
       {
       array = defaultValue;
       }
+    }
 
     if (svp->GetNumberOfElements() == 5)
       {
-      svp->SetElement(4, array);
-      return 1;
+      vtksys_ios::ostringstream ass;
+      ass << this->Association;
+      svp->SetElement(3, ass.str().c_str());
+      if (array)
+        {
+        svp->SetElement(4, array);
+        return 1;
+        }
       }
-    else if (svp->GetNumberOfElements() == 1)
+    else if (svp->GetNumberOfElements() == 1 && array)
       {
       svp->SetElement(0, array);
       return 1;
       }
-    }
 
   return this->Superclass::SetDefaultValues(prop);
 }
@@ -412,7 +524,7 @@ void vtkSMArrayListDomain::PrintSelf(ostream& os, vtkIndent indent)
   this->Superclass::PrintSelf(os, indent);
   os << indent << "DefaultElement: " << this->DefaultElement << endl;
   os << indent << "AttributeType: " << this->AttributeType << endl;
-  int nDataTypes=this->ALDInternals->DataTypes.size();
+  int nDataTypes=static_cast<int>(this->ALDInternals->DataTypes.size());
   for (int i=0; i<nDataTypes; ++i)
     {
     os << indent << "DataType: " << this->ALDInternals->DataTypes[i] << endl;
