@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMArrayListDomain.h,v $
+  Module:    vtkSMArrayListDomain.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -32,12 +32,19 @@
 //      from vtkType.h
 //    - VTK_VOID, and 0 are equivalent to not specifying, meaning any data type
 //      is allowed
+// * none_string - when specified, this string appears as the first entry in
+//      the list and can be used to show "None", or "Not available" etc.
 // @endverbatim
 // Additionally, vtkSMArrayListDomain support 'default_values' attribute which
 // specifies a string (only 1 string value is supported). When
 // SetDefaultValues() is called, if the array name specified as 'default_values'
 // is present in the domain, then that will be used, otherwise, it simply uses
 // the first available array (which is default).
+//
+// Additionally, vtkSMArrayListDomain takes an  option required property with
+// function "FieldDataSelection" which can be a vtkSMIntVectorProperty with a
+// single value. If preset, this property's value is used to determine what type
+// of field-data i.e. point-data, cell-data etc. is currently available.
 // .SECTION See Also
 // vtkSMDomain vtkSMProxyProperty vtkSMInputArrayDomain
 
@@ -59,7 +66,7 @@ class VTK_EXPORT vtkSMArrayListDomain : public vtkSMStringListDomain
 {
 public:
   static vtkSMArrayListDomain* New();
-  vtkTypeRevisionMacro(vtkSMArrayListDomain, vtkSMStringListDomain);
+  vtkTypeMacro(vtkSMArrayListDomain, vtkSMStringListDomain);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -82,6 +89,10 @@ public:
   // false otherwise. See vtkPVArrayInformation for more information.
   int IsArrayPartial(unsigned int idx);
 
+  // Description:
+  // Get field association for the array.
+  int GetFieldAssociation(unsigned int idx);
+
   // Description:
   // Return the attribute type. The values are listed in
   // vtkDataSetAttributes.h.
@@ -98,6 +109,18 @@ public:
   // Returns 1 if the domain updated the property.
   virtual int SetDefaultValues(vtkSMProperty*);
 
+  // Description:
+  // Adds a new string to the domain.
+  unsigned int AddString(const char* string);
+
+  // Description:
+  // Removes a string from the domain.
+  virtual int RemoveString(const char* string);
+
+  // Description:
+  // Removes all strings from the domain.
+  virtual void RemoveAllStrings();
+
 protected:
   vtkSMArrayListDomain();
   ~vtkSMArrayListDomain();
@@ -112,7 +135,8 @@ protected:
   void AddArrays(vtkSMSourceProxy* sp, 
                  int outputport,
                  vtkPVDataSetAttributesInformation* info, 
-                 vtkSMInputArrayDomain* iad);
+                 vtkSMInputArrayDomain* iad,
+                 int association);
   void Update(vtkSMSourceProxy* sp, vtkSMInputArrayDomain* iad, int outputport);
   void Update(vtkSMProxyProperty* pp, vtkSMSourceProxy* sp, int outputport);
   void Update(vtkSMProxyProperty* pp);
@@ -125,13 +149,20 @@ protected:
 
   int AttributeType;
   int Attribute;
+  int Association;
   unsigned int DefaultElement;
 
-  vtkSetStringMacro(InputDomainName);
+  // Description:
+  // InputDomainName refers to a input property domain that describes
+  // the type of array is needed by this property.
   vtkGetStringMacro(InputDomainName);
+  vtkSetStringMacro(InputDomainName);
+
+  vtkSetStringMacro(NoneString);
+  vtkGetStringMacro(NoneString);
 
   char* InputDomainName;
-
+  char* NoneString;
 private:
   vtkSMArrayListDomain(const vtkSMArrayListDomain&); // Not implemented
   void operator=(const vtkSMArrayListDomain&); // Not implemented
