@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMArrayRangeDomain.cxx,v $
+  Module:    vtkSMArrayRangeDomain.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,6 @@
 #include "vtkSMStringVectorProperty.h"
 
 vtkStandardNewMacro(vtkSMArrayRangeDomain);
-vtkCxxRevisionMacro(vtkSMArrayRangeDomain, "$Revision: 1.16 $");
 
 //---------------------------------------------------------------------------
 vtkSMArrayRangeDomain::vtkSMArrayRangeDomain()
