@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMAxesRepresentationProxy.cxx,v $
+  Module:    vtkSMAxesRepresentationProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkSMViewProxy.h"
 
 vtkStandardNewMacro(vtkSMAxesRepresentationProxy);
-vtkCxxRevisionMacro(vtkSMAxesRepresentationProxy, "$Revision: 1.3 $");
 
 //----------------------------------------------------------------------------
 vtkSMAxesRepresentationProxy::vtkSMAxesRepresentationProxy()
