@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMCameraLink.cxx,v $
+  Module:    vtkSMCameraLink.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -21,12 +21,10 @@
 #include "vtkSmartPointer.h"
 #include "vtkSMProperty.h"
 #include "vtkSMRenderViewProxy.h"
-#include "vtkSMStateLoader.h"
 
 #include <vtkstd/list>
 
 vtkStandardNewMacro(vtkSMCameraLink);
-vtkCxxRevisionMacro(vtkSMCameraLink, "$Revision: 1.18 $");
 
 //---------------------------------------------------------------------------
 class vtkSMCameraLink::vtkInternals
@@ -124,6 +122,7 @@ const char* vtkSMCameraLink::vtkInternals::LinkedPropertyNames[] =
 {
   /* from */  /* to */
   "CameraPositionInfo", "CameraPosition",
+  "CameraViewAngleInfo", "CameraViewAngle",
   "CameraFocalPointInfo", "CameraFocalPoint",
   "CameraViewUpInfo", "CameraViewUp",
   "CenterOfRotation", "CenterOfRotation",
@@ -339,12 +338,6 @@ void vtkSMCameraLink::SaveState(const char* linkname, vtkPVXMLElement* parent)
   root->Delete();
 }
 
-//---------------------------------------------------------------------------
-int vtkSMCameraLink::LoadState(vtkPVXMLElement* linkElement, vtkSMStateLoader* loader)
-{
-  return this->Superclass::LoadState(linkElement, loader);
-}
-
 //---------------------------------------------------------------------------
 void vtkSMCameraLink::PrintSelf(ostream& os, vtkIndent indent)
 {
