@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMClientDeliveryRepresentationProxy.cxx,v $
+  Module:    vtkSMClientDeliveryRepresentationProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -28,10 +28,10 @@
 #include "vtkSMStringVectorProperty.h"
 
 vtkStandardNewMacro(vtkSMClientDeliveryRepresentationProxy);
-vtkCxxRevisionMacro(vtkSMClientDeliveryRepresentationProxy, "$Revision: 1.20 $");
 //----------------------------------------------------------------------------
 vtkSMClientDeliveryRepresentationProxy::vtkSMClientDeliveryRepresentationProxy()
 {
+  this->PreProcessorProxy = 0;
   this->StrategyProxy = 0;
   this->PostProcessorProxy = 0;
 
@@ -49,6 +49,7 @@ vtkSMClientDeliveryRepresentationProxy::~vtkSMClientDeliveryRepresentationProxy(
     this->StrategyProxy->Delete();
     }
   this->StrategyProxy = 0;
+  this->PreProcessorProxy = 0;
   this->PostProcessorProxy = 0;
   if (this->PreGatherHelper)
     {
@@ -99,6 +100,14 @@ bool vtkSMClientDeliveryRepresentationProxy::BeginCreateVTKObjects()
     return false;
     }
 
+  this->PreProcessorProxy = vtkSMSourceProxy::SafeDownCast(
+    this->GetSubProxy("PreProcessor"));
+  if (this->PreProcessorProxy)
+    {
+    this->PreProcessorProxy->SetServers(
+      vtkProcessModule::DATA_SERVER);
+    }
+
   this->PostProcessorProxy = vtkSMSourceProxy::SafeDownCast(
     this->GetSubProxy("PostProcessor"));
   if (this->PostProcessorProxy)
@@ -114,8 +123,14 @@ bool vtkSMClientDeliveryRepresentationProxy::EndCreateVTKObjects()
 {
   // Setup selection pipeline connections.
   vtkSMSourceProxy* input = this->GetInputProxy();
-  this->CreatePipeline(input, this->OutputPort);
-
+  int port = this->OutputPort;
+  if (this->PreProcessorProxy)
+    {
+    this->Connect(input, this->PreProcessorProxy, "Input", port);
+    input = this->PreProcessorProxy;
+    port = 0;
+    }
+  this->CreatePipeline(input, port);
   return this->Superclass::EndCreateVTKObjects();
 }
 
