@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMClientDeliveryRepresentationProxy.h,v $
+  Module:    vtkSMClientDeliveryRepresentationProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -32,7 +32,7 @@ class VTK_EXPORT vtkSMClientDeliveryRepresentationProxy :
 {
 public:
   static vtkSMClientDeliveryRepresentationProxy* New();
-  vtkTypeRevisionMacro(vtkSMClientDeliveryRepresentationProxy, vtkSMDataRepresentationProxy);
+  vtkTypeMacro(vtkSMClientDeliveryRepresentationProxy, vtkSMDataRepresentationProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -48,7 +48,7 @@ public:
   // Called to update the Display. Default implementation does nothing.
   // Argument is the view requesting the update. Can be null in the
   // case when something other than a view is requesting the update.
-  virtual void Update() { this->Update(0); };
+  virtual void Update() { this->Superclass::Update(); };
   virtual void Update(vtkSMViewProxy* view);
 
   //BTX
@@ -111,6 +111,7 @@ protected:
   // Create the data pipeline.
   virtual void CreatePipeline(vtkSMSourceProxy* input, int outputport);
 
+  vtkSMSourceProxy* PreProcessorProxy;
   vtkSMClientDeliveryStrategyProxy* StrategyProxy;
   vtkSMSourceProxy* PostProcessorProxy;
   vtkSMProxy* PreGatherHelper;
