@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMDataRepresentationProxy.cxx,v $
+  Module:    vtkSMDataRepresentationProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -53,7 +53,6 @@ protected:
 };
 
 
-vtkCxxRevisionMacro(vtkSMDataRepresentationProxy, "$Revision: 1.10 $");
 vtkCxxSetObjectMacro(vtkSMDataRepresentationProxy, InputProxy, vtkSMSourceProxy);
 //----------------------------------------------------------------------------
 vtkSMDataRepresentationProxy::vtkSMDataRepresentationProxy()
@@ -329,6 +328,13 @@ vtkPVDataInformation* vtkSMDataRepresentationProxy::GetRepresentedDataInformatio
     return 0;
     }
 
+  // Don't call update, UpdateDataInformation() will update the sub-pipeline
+  // until the place from which the data information is obtained if needed.
+  //if (update)
+  //  {
+  //  this->Update();
+  //  }
+
   // We don't use active stratgies since active strategies are returned only
   // when visibile.
   vtkSMRepresentationStrategyVector::iterator iter;
@@ -337,7 +343,6 @@ vtkPVDataInformation* vtkSMDataRepresentationProxy::GetRepresentedDataInformatio
     {
     if (update)
       {
-      // update part of pipeline to obtain correct data size information.
       iter->GetPointer()->UpdateDataInformation();
       }
     return iter->GetPointer()->GetRepresentedDataInformation();
