@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMDataTypeDomain.cxx,v $
+  Module:    vtkSMDataTypeDomain.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,6 @@
 
 
 vtkStandardNewMacro(vtkSMDataTypeDomain);
-vtkCxxRevisionMacro(vtkSMDataTypeDomain, "$Revision: 1.15 $");
 
 struct vtkSMDataTypeDomainInternals
 {
