@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMEnumerationDomain.h,v $
+  Module:    vtkSMEnumerationDomain.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -37,7 +37,7 @@ class VTK_EXPORT vtkSMEnumerationDomain : public vtkSMDomain
 {
 public:
   static vtkSMEnumerationDomain* New();
-  vtkTypeRevisionMacro(vtkSMEnumerationDomain, vtkSMDomain);
+  vtkTypeMacro(vtkSMEnumerationDomain, vtkSMDomain);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -64,6 +64,10 @@ public:
   // Returns the descriptive string of an enumeration entry.
   const char* GetEntryText(unsigned int idx);
 
+  // Description:
+  // Returns the text for an enumeration value.
+  const char* GetEntryTextForValue(int value);
+
   // Description:
   // Return 1 is the text is present in the enumeration, otherwise 0.
   int HasEntryText(const char* text);
@@ -92,6 +96,11 @@ public:
   // Update self based on the "unchecked" values of all required
   // properties. Overwritten by sub-classes.
   virtual void Update(vtkSMProperty* property);
+
+  // Description:
+  // Overridden to ensure that the property's default value is valid for the
+  // enumeration, if not it will be set to the first enumeration value. 
+  virtual int SetDefaultValues(vtkSMProperty*);
 protected:
   vtkSMEnumerationDomain();
   ~vtkSMEnumerationDomain();
