@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMIceTDesktopRenderViewProxy.cxx,v $
+  Module:    vtkSMIceTDesktopRenderViewProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -18,17 +18,16 @@
 #include "vtkInformation.h"
 #include "vtkObjectFactory.h"
 #include "vtkProcessModule.h"
+#include "vtkRenderWindow.h"
 #include "vtkSMClientServerRenderSyncManagerHelper.h"
 #include "vtkSMIntVectorProperty.h"
 
 vtkStandardNewMacro(vtkSMIceTDesktopRenderViewProxy);
-vtkCxxRevisionMacro(vtkSMIceTDesktopRenderViewProxy, "$Revision: 1.15 $");
 
 //----------------------------------------------------------------------------
 vtkSMIceTDesktopRenderViewProxy::vtkSMIceTDesktopRenderViewProxy()
 {
   this->RenderSyncManager = 0;
-  this->SquirtLevel = 0;
 }
 
 //----------------------------------------------------------------------------
@@ -126,19 +125,23 @@ bool vtkSMIceTDesktopRenderViewProxy::BeginCreateVTKObjects()
   ivp->SetElement(0, this->EnableTiles? 0 : 1);
   this->RenderSyncManager->UpdateVTKObjects();
 
-  // We need to create vtkIceTRenderer on the server side and vtkRenderer on
-  // the client.
-  this->RendererProxy->SetServers(vtkProcessModule::CLIENT);
-  this->RendererProxy->UpdateVTKObjects();
+  if (this->UsingIceTRenderers)
+    {
+    // We need to create vtkIceTRenderer on the server side and vtkRenderer on
+    // the client.
+    this->RendererProxy->SetServers(vtkProcessModule::CLIENT);
+    this->RendererProxy->GetID(); // this calls CreateVTKObjects().
+    
+    stream  << vtkClientServerStream::New 
+            << "vtkIceTRenderer" 
+            << this->RendererProxy->GetID()
+            << vtkClientServerStream::End;
+    pm->SendStream(this->ConnectionID, vtkProcessModule::RENDER_SERVER, stream);
+    this->RendererProxy->SetServers(
+                                    vtkProcessModule::CLIENT|vtkProcessModule::RENDER_SERVER);
+    this->RendererProxy->UpdateVTKObjects();
+    }
 
-  stream  << vtkClientServerStream::New 
-          << "vtkIceTRenderer" 
-          << this->RendererProxy->GetID()
-          << vtkClientServerStream::End;
-  pm->SendStream(this->ConnectionID, vtkProcessModule::RENDER_SERVER, stream);
-  this->RendererProxy->SetServers(
-    vtkProcessModule::CLIENT|vtkProcessModule::RENDER_SERVER);
- 
   return true;
 }
 
@@ -199,8 +202,16 @@ void vtkSMIceTDesktopRenderViewProxy::BeginStillRender()
 {
   this->Superclass::BeginStillRender();
 
-  // Make squirt compression loss-less, if enabled.
-  this->SetSquirtLevelInternal(this->SquirtLevel ? 1 : 0);
+  // Signal the desktop delivery client that it must now
+  // employ loss-less compression if compression is enabled.
+  vtkSMProperty *prop
+    = this->RenderSyncManager->GetProperty("LossLessCompression");
+  vtkSMIntVectorProperty* ivp=dynamic_cast<vtkSMIntVectorProperty*>(prop);
+  if (ivp)
+    {
+    ivp->SetElement(0,1);
+    this->RenderSyncManager->UpdateProperty("LossLessCompression");
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -208,8 +219,17 @@ void vtkSMIceTDesktopRenderViewProxy::BeginInteractiveRender()
 {
   this->Superclass::BeginInteractiveRender();
 
-  // Use user-specified squirt compression.
-  this->SetSquirtLevelInternal(this->SquirtLevel);
+  // Signal the desktop delivery client that it may
+  // now use lossy-compression if it's enabled and
+  // the compressor can provide it.
+  vtkSMProperty *prop
+    = this->RenderSyncManager->GetProperty("LossLessCompression");
+  vtkSMIntVectorProperty* ivp=dynamic_cast<vtkSMIntVectorProperty*>(prop);
+  if (ivp)
+    {
+    ivp->SetElement(0,0);
+    this->RenderSyncManager->UpdateProperty("LossLessCompression");
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -226,18 +246,6 @@ void vtkSMIceTDesktopRenderViewProxy::SetImageReductionFactorInternal(int factor
     }
 }
 
-//----------------------------------------------------------------------------
-void vtkSMIceTDesktopRenderViewProxy::SetSquirtLevelInternal(int level)
-{
-  vtkSMIntVectorProperty* ivp = vtkSMIntVectorProperty::SafeDownCast(
-    this->RenderSyncManager->GetProperty("SquirtLevel"));
-  if (ivp)
-    {
-    ivp->SetElement(0, level);
-    this->RenderSyncManager->UpdateProperty("SquirtLevel");
-    }
-}
-
 //----------------------------------------------------------------------------
 void vtkSMIceTDesktopRenderViewProxy::SetUseCompositing(bool usecompositing)
 {
@@ -263,13 +271,10 @@ void vtkSMIceTDesktopRenderViewProxy::SetGUISize(int x, int y)
   // non-client server modes alone.
   this->vtkSMRenderViewProxy::SetGUISize(x, y);
 
-  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-  vtkClientServerStream stream;
-  stream  << vtkClientServerStream::Invoke 
-          << this->RenderSyncManager->GetID()
-          << "SetGUISize" << x << y
-          << vtkClientServerStream::End;
-  pm->SendStream(this->ConnectionID, vtkProcessModule::CLIENT, stream);
+  // We don't have to pass the GUI size or view positions to the
+  // RenderSyncManager at all since if no values are set the
+  // vtkPVDesktopDeliveryClient uses the client side render window properties
+  // which is exactly what we want.
 }
 
 //----------------------------------------------------------------------------
@@ -279,13 +284,10 @@ void vtkSMIceTDesktopRenderViewProxy::SetViewPosition(int x, int y)
   // non-client server modes alone.
   this->vtkSMRenderViewProxy::SetViewPosition(x, y);
 
-  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-  vtkClientServerStream stream;
-  stream  << vtkClientServerStream::Invoke 
-          << this->RenderSyncManager->GetID()
-          << "SetWindowPosition" << x << y
-          << vtkClientServerStream::End;
-  pm->SendStream(this->ConnectionID, vtkProcessModule::CLIENT, stream);
+  // We don't have to pass the GUI size or view positions to the
+  // RenderSyncManager at all since if no values are set the
+  // vtkPVDesktopDeliveryClient uses the client side render window properties
+  // which is exactly what we want.
 }
 
 //----------------------------------------------------------------------------
@@ -350,11 +352,16 @@ double vtkSMIceTDesktopRenderViewProxy::GetZBufferValue(int x, int y)
   return res.GetArgument(0, 0, &result)? result : 0;
 }
 
+//----------------------------------------------------------------------------
+void vtkSMIceTDesktopRenderViewProxy::SetViewSize(int width, int height)
+{
+  this->RenderWindow->SetSize(width, height);
+}
+
 //----------------------------------------------------------------------------
 void vtkSMIceTDesktopRenderViewProxy::PrintSelf(ostream& os, vtkIndent indent)
 {
   this->Superclass::PrintSelf(os, indent);
-  os << indent << "SquirtLevel: " << this->SquirtLevel << endl;
 }
 
 
