@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMInformationHelper.cxx,v $
+  Module:    vtkSMInformationHelper.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -14,7 +14,6 @@
 =========================================================================*/
 #include "vtkSMInformationHelper.h"
 
-vtkCxxRevisionMacro(vtkSMInformationHelper, "$Revision: 1.1 $");
 
 //---------------------------------------------------------------------------
 vtkSMInformationHelper::vtkSMInformationHelper()
