@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMInputArrayDomain.cxx,v $
+  Module:    vtkSMInputArrayDomain.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,7 +26,6 @@
 #include "vtkSMStringVectorProperty.h"
 
 vtkStandardNewMacro(vtkSMInputArrayDomain);
-vtkCxxRevisionMacro(vtkSMInputArrayDomain, "$Revision: 1.16 $");
 
 //---------------------------------------------------------------------------
 static const char* const vtkSMInputArrayDomainAttributeTypes[] = {
@@ -35,7 +34,8 @@ static const char* const vtkSMInputArrayDomainAttributeTypes[] = {
   "any",
   "vertex",
   "edge",
-  "row"
+  "row",
+  "none"
 };
 
 //---------------------------------------------------------------------------
@@ -152,6 +152,16 @@ int vtkSMInputArrayDomain::IsInDomain(vtkSMSourceProxy* proxy,
       }
     }
 
+  if (this->AttributeType == vtkSMInputArrayDomain::NONE||
+      this->AttributeType == vtkSMInputArrayDomain::ANY)
+    {
+    if (this->AttributeInfoContainsArray(proxy, outputport,
+                                         info->GetFieldDataInformation()))
+      {
+      return 1;
+      }
+    }
+
 
   return 0;
 }
@@ -234,6 +244,10 @@ int vtkSMInputArrayDomain::IsFieldValid(
         {
         attributeType = vtkSMInputArrayDomain::ROW;
         }
+      else if (val == vtkDataObject::FIELD_ASSOCIATION_NONE)
+        {
+        attributeType = vtkSMInputArrayDomain::NONE;
+        }
       }
     }
 
@@ -272,6 +286,13 @@ int vtkSMInputArrayDomain::IsFieldValid(
     isField = this->CheckForArray(arrayInfo, info->GetRowDataInformation());
     }
 
+  if (!isField &&
+      (attributeType == vtkSMInputArrayDomain::NONE||
+       attributeType == vtkSMInputArrayDomain::ANY) )
+    {
+    isField = this->CheckForArray(arrayInfo, info->GetFieldDataInformation());
+    }
+
   if (!isField)
     {
     return 0;
