@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMMultiProcessRenderView.cxx,v $
+  Module:    vtkSMMultiProcessRenderView.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkSMProxyManager.h"
 #include "vtkSMRepresentationStrategy.h"
 
-vtkCxxRevisionMacro(vtkSMMultiProcessRenderView, "$Revision: 1.8 $");
 //----------------------------------------------------------------------------
 vtkSMMultiProcessRenderView::vtkSMMultiProcessRenderView()
 {
@@ -40,6 +39,13 @@ vtkSMMultiProcessRenderView::~vtkSMMultiProcessRenderView()
 vtkSMRepresentationStrategy* vtkSMMultiProcessRenderView::NewStrategyInternal(
   int dataType)
 {
+  if (this->NewStrategyHelper)
+    {
+    return this->NewStrategyHelper->NewStrategyInternal(dataType);
+    }
+
+  
+ 
   vtkSMProxyManager* pxm = vtkSMObject::GetProxyManager();
   vtkSMRepresentationStrategy* strategy = 0;
 
@@ -122,7 +128,7 @@ void vtkSMMultiProcessRenderView::BeginInteractiveRender()
   // partially) if required to obtain correct data sizes.
 
   this->LastCompositingDecision = 
-    this->GetCompositingDecision(this->GetVisibleDisplayedDataSize(), 0);
+    this->GetCompositingDecision(this->GetVisibileFullResDataSize(), 0);
 
   this->SetUseCompositing(this->LastCompositingDecision);
 }
@@ -192,6 +198,14 @@ vtkSelection *vtkSMMultiProcessRenderView::SelectVisibleCells(
   //make this ugly hack unecessary.
   double compThresh = this->GetRemoteRenderThreshold();
   this->SetRemoteRenderThreshold(0.0);
+  if (this->LastCompositingDecision == 0)
+    {
+    // On some configurations (typically dashboards), if we try to select on
+    // forcing a remote render directly, it causes some OpenGL related
+    // segfaults. To overcome those, just trigger a remote render if this is the
+    // first server-side render.
+    this->StillRender();
+    }
   vtkSelection* reply = 
     this->Superclass::SelectVisibleCells(x0, y0, x1, y1, ofPoints);
   this->SetRemoteRenderThreshold(compThresh);
