@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMOutlineRepresentationProxy.cxx,v $
+  Module:    vtkSMOutlineRepresentationProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -15,24 +15,25 @@
 #include "vtkSMOutlineRepresentationProxy.h"
 
 #include "vtkAbstractMapper.h"
+#include "vtkBoundingBox.h"
 #include "vtkInformation.h"
 #include "vtkObjectFactory.h"
 #include "vtkProcessModule.h"
 #include "vtkProp3D.h"
 #include "vtkSelection.h"
+#include "vtkSelectionNode.h"
 #include "vtkSmartPointer.h"
-#include "vtkTransform.h"
 #include "vtkSMDoubleVectorProperty.h"
 #include "vtkSMIntVectorProperty.h"
+#include "vtkSMPropertyHelper.h"
 #include "vtkSMRepresentationStrategy.h"
 #include "vtkSMSelectionHelper.h"
 #include "vtkSMSourceProxy.h"
 #include "vtkSMStringVectorProperty.h"
 #include "vtkSMViewProxy.h"
-#include "vtkBoundingBox.h"
+#include "vtkTransform.h"
 
 vtkStandardNewMacro(vtkSMOutlineRepresentationProxy);
-vtkCxxRevisionMacro(vtkSMOutlineRepresentationProxy, "$Revision: 1.14 $");
 //----------------------------------------------------------------------------
 vtkSMOutlineRepresentationProxy::vtkSMOutlineRepresentationProxy()
 {
@@ -124,6 +125,10 @@ bool vtkSMOutlineRepresentationProxy::EndCreateVTKObjects()
     this->OutlineFilter->UpdateProperty("UseOutline");
     }
 
+  vtkSMPropertyHelper(this->Property, "Ambient").Set(1);
+  vtkSMPropertyHelper(this->Property, "Diffuse").Set(0);
+  vtkSMPropertyHelper(this->Property, "Specular").Set(0);
+  this->Property->UpdateVTKObjects();
 
   return this->Superclass::EndCreateVTKObjects();
 }
@@ -209,25 +214,24 @@ vtkSMProxy* vtkSMOutlineRepresentationProxy::ConvertSelection(
 
   vtkSmartPointer<vtkSelection> mySelection = 
     vtkSmartPointer<vtkSelection>::New();
-  mySelection->GetProperties()->Copy(userSel->GetProperties(), 0);
 
-  unsigned int numChildren = userSel->GetNumberOfChildren();
-  for (unsigned int cc=0; cc < numChildren; cc++)
+  unsigned int numNodes = userSel->GetNumberOfNodes();
+  for (unsigned int cc=0; cc < numNodes; cc++)
     {
-    vtkSelection* child = userSel->GetChild(cc);
-    vtkInformation* properties = child->GetProperties();
+    vtkSelectionNode* node = userSel->GetNode(cc);
+    vtkInformation* properties = node->GetProperties();
     // If there is no PROP_ID or PROP key set, we assume the selection
     // is valid on all representations
     bool hasProp = true;
-    if (properties->Has(vtkSelection::PROP_ID()))
+    if (properties->Has(vtkSelectionNode::PROP_ID()))
       {
       hasProp = false;
       }
-    else if(properties->Has(vtkSelection::PROP()))
+    else if(properties->Has(vtkSelectionNode::PROP()))
       {
       hasProp = false;
       vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
-      if (properties->Get(vtkSelection::PROP()) == 
+      if (properties->Get(vtkSelectionNode::PROP()) == 
         pm->GetObjectFromID(this->Prop3D->GetID()))
         {
         hasProp = true;
@@ -235,14 +239,14 @@ vtkSMProxy* vtkSMOutlineRepresentationProxy::ConvertSelection(
       }
     if(hasProp)
       {
-      vtkSelection* myChild = vtkSelection::New();
-      myChild->ShallowCopy(child);
-      mySelection->AddChild(myChild);
-      myChild->Delete();
+      vtkSelectionNode* myNode = vtkSelectionNode::New();
+      myNode->ShallowCopy(node);
+      mySelection->AddNode(myNode);
+      myNode->Delete();
       }
     }
 
-  if (mySelection->GetNumberOfChildren() == 0)
+  if (mySelection->GetNumberOfNodes() == 0)
     {
     return 0;
     }
