@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMProperty.h,v $
+  Module:    vtkSMProperty.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -72,7 +72,7 @@ class vtkSMDomain;
 class vtkSMDomainIterator;
 class vtkSMInformationHelper;
 class vtkSMProxy;
-class vtkSMStateLoaderBase;
+class vtkSMProxyLocator;
 class vtkSMXMLParser;
 //BTX
 struct vtkSMPropertyInternals;
@@ -82,7 +82,7 @@ class VTK_EXPORT vtkSMProperty : public vtkSMObject
 {
 public:
   static vtkSMProperty* New();
-  vtkTypeRevisionMacro(vtkSMProperty, vtkSMObject);
+  vtkTypeMacro(vtkSMProperty, vtkSMObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -132,6 +132,10 @@ public:
   // Returns a domain give a name. 
   vtkSMDomain* GetDomain(const char* name);
 
+  // Description:
+  // Returns the first domain which is of the specified type.
+  vtkSMDomain* FindDomain(const char* classname);
+
   // Description:
   // Returns the number of domains this property has. This can be 
   // used to specify a valid index for GetDomain(index).
@@ -242,6 +246,17 @@ public:
       }
     }
 
+  // Description:
+  // Provides access to the information helper used by this property, if any.
+  vtkGetObjectMacro(InformationHelper, vtkSMInformationHelper);
+
+  // Description:
+  // Get the proxy to which this property belongs. Note that is this property is
+  // belong to a sub-proxy of a proxy, the returned value will indeed be that
+  // sub-proxy (and not the outer container proxy).
+  vtkSMProxy* GetParent()
+    { return this->Proxy; }
+
 protected:
   vtkSMProperty();
   ~vtkSMProperty();
@@ -330,7 +345,7 @@ protected:
   // If \c loadLastPushedValues is set, then last pushed values
   // are loaded from the xml if present. If not present, the value 
   // of the property remains unchanged.
-  virtual int LoadState(vtkPVXMLElement* element, vtkSMStateLoaderBase* loader,
+  virtual int LoadState(vtkPVXMLElement* element, vtkSMProxyLocator* loader,
     int loadLastPushedValues=0);
 
   // Description:
@@ -358,10 +373,6 @@ protected:
 
   static int CheckDomains;
   
-  // Set during xml parsing only. Do not use outside ReadXMLAttributes().
-  vtkSMProxy* Proxy;
-  void SetProxy(vtkSMProxy* proxy);
-
   vtkSetMacro(InformationOnly, int);
   int InformationOnly;
 
@@ -393,6 +404,14 @@ protected:
   // This gets cleared when Modified() is called.
   vtkGetMacro(PendingModifiedEvents, bool);
 
+  // Proxy is not reference-counted to avoid reference loops.
+  void SetParent(vtkSMProxy* proxy)
+    {
+    this->Proxy = proxy;
+    }
+
+  vtkSMProxy* Proxy;
+
 private:
   vtkSMProperty(const vtkSMProperty&); // Not implemented
   void operator=(const vtkSMProperty&); // Not implemented
