@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMProxyManager.cxx,v $
+  Module:    vtkSMProxyManager.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -31,15 +31,20 @@
 #include "vtkSMProxyDefinitionIterator.h"
 #include "vtkSMProxy.h"
 #include "vtkSMProxyIterator.h"
+#include "vtkSMProxyLocator.h"
 #include "vtkSMProxyProperty.h"
+#include "vtkSMReaderFactory.h"
 #include "vtkSMStateLoader.h"
 #include "vtkSMUndoStack.h"
+#include "vtkSMWriterFactory.h"
+#include "vtkSMXMLParser.h"
 #include "vtkStdString.h"
 #include "vtkStringList.h"
 
 #include <vtkstd/map>
 #include <vtkstd/set>
 #include <vtkstd/vector>
+#include <vtksys/DateStamp.h> // For date stamp
 #include <vtksys/ios/sstream>
 #include <vtksys/RegularExpression.hxx>
 
@@ -62,6 +67,9 @@ public:
 };
 #endif
 
+
+#define PARAVIEW_SOURCE_VERSION "paraview version " PARAVIEW_VERSION_FULL ", Date: " vtksys_DATE_STAMP_STRING
+
 class vtkSMProxyManagerProxySet : public vtkstd::set<vtkSMProxy*> {};
 
 //*****************************************************************************
@@ -94,7 +102,6 @@ protected:
 
 //*****************************************************************************
 vtkStandardNewMacro(vtkSMProxyManager);
-vtkCxxRevisionMacro(vtkSMProxyManager, "$Revision: 1.74 $");
 //---------------------------------------------------------------------------
 vtkSMProxyManager::vtkSMProxyManager()
 {
@@ -107,6 +114,9 @@ vtkSMProxyManager::vtkSMProxyManager()
   this->AddObserver(vtkCommand::RegisterEvent, obs);
   this->AddObserver(vtkCommand::UnRegisterEvent, obs);
 #endif
+
+  this->ReaderFactory = vtkSMReaderFactory::New();
+  this->WriterFactory = vtkSMWriterFactory::New();
 }
 
 //---------------------------------------------------------------------------
@@ -117,6 +127,18 @@ vtkSMProxyManager::~vtkSMProxyManager()
 
   this->Observer->SetTarget(0);
   this->Observer->Delete();
+
+  this->ReaderFactory->Delete();
+  this->ReaderFactory = 0;
+
+  this->WriterFactory->Delete();
+  this->WriterFactory = 0;
+}
+
+//----------------------------------------------------------------------------
+const char* vtkSMProxyManager::GetParaViewSourceVersion()
+{
+  return PARAVIEW_SOURCE_VERSION;
 }
 
 //----------------------------------------------------------------------------
@@ -193,7 +215,26 @@ void vtkSMProxyManager::AddElement(const char* groupName,
 {
   vtkSMProxyManagerElementMapType& elementMap = 
     this->Internals->GroupMap[groupName];
-  elementMap[name] = element;
+
+  if (element->GetName() && strcmp(element->GetName(), "Extension") == 0)
+    {
+    // This is an extension for an existing definition.
+    vtkSMProxyManagerElementMapType::iterator iter = elementMap.find(name);
+    if (iter == elementMap.end())
+      {
+      vtkWarningMacro("Extension for (" << groupName << ", " << name 
+        << ") ignored since could not find core definition.");
+      return;
+      }
+    for (unsigned int cc=0; cc < element->GetNumberOfNestedElements(); cc++)
+      {
+      iter->second->AddNestedElement(element->GetNestedElement(cc));
+      }
+    }
+  else
+    {
+    elementMap[name] = element;
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -693,8 +734,7 @@ void vtkSMProxyManager::UnRegisterProxy(const char* group, const char* name,
         info.Proxy = it3->GetPointer()->Proxy;
         info.GroupName = it->first.c_str();
         info.ProxyName = it2->first.c_str();
-        info.IsCompoundProxyDefinition = 0;
-        info.IsLink = 0;
+        info.Type = RegisteredProxyInformation::PROXY;
 
         this->InvokeEvent(vtkCommand::UnRegisterEvent, &info);
         this->UnMarkProxyAsModified(info.Proxy);
@@ -729,8 +769,7 @@ void vtkSMProxyManager::UnRegisterProxy(const char* group, const char* name)
         info.Proxy = it3->GetPointer()->Proxy;
         info.GroupName = it->first.c_str();
         info.ProxyName = it2->first.c_str();
-        info.IsCompoundProxyDefinition = 0;
-        info.IsLink = 0;
+        info.Type = RegisteredProxyInformation::PROXY;
       
         this->InvokeEvent(vtkCommand::UnRegisterEvent, &info);
         this->UnMarkProxyAsModified(info.Proxy);
@@ -778,7 +817,7 @@ void vtkSMProxyManager::UnRegisterProxy(vtkSMProxy* proxy)
   for (; it != this->Internals->RegisteredProxyMap.end(); it++)
     {
     vtkSMProxyManagerProxyMapType::iterator it2;
-    for (it->second.begin(); it2 != it->second.end(); ++it2)
+    for (it2 = it->second.begin(); it2 != it->second.end(); ++it2)
       {
       if (it2->second.Contains(proxy))
         {
@@ -831,6 +870,11 @@ void vtkSMProxyManager::RegisterProxy(const char* groupname,
                                       const char* name, 
                                       vtkSMProxy* proxy)
 {
+  if (!proxy)
+    {
+    return;
+    }
+
   vtkSMProxyManagerProxyListType &proxy_list =
     this->Internals->RegisteredProxyMap[groupname][name];
   if (proxy_list.Contains(proxy))
@@ -846,6 +890,8 @@ void vtkSMProxyManager::RegisterProxy(const char* groupname,
   // Add observers to note proxy modification.
   proxyInfo->ModifiedObserverTag = proxy->AddObserver(
     vtkCommand::PropertyModifiedEvent, this->Observer);
+  proxyInfo->StateChangedObserverTag = proxy->AddObserver(
+    vtkCommand::StateChangedEvent, this->Observer);
   proxyInfo->UpdateObserverTag = proxy->AddObserver(vtkCommand::UpdateEvent,
     this->Observer);
   proxyInfo->UpdateInformationObserverTag = proxy->AddObserver(
@@ -857,8 +903,7 @@ void vtkSMProxyManager::RegisterProxy(const char* groupname,
   info.Proxy = proxy;
   info.GroupName = groupname;
   info.ProxyName = name;
-  info.IsCompoundProxyDefinition = 0;
-  info.IsLink = 0;
+  info.Type = RegisteredProxyInformation::PROXY;
 
   this->InvokeEvent(vtkCommand::RegisterEvent, &info);
 }
@@ -983,8 +1028,7 @@ void vtkSMProxyManager::RegisterLink(const char* name, vtkSMLink* link)
   info.Proxy = 0;
   info.GroupName = 0;
   info.ProxyName = name;
-  info.IsCompoundProxyDefinition = 0;
-  info.IsLink = 1;
+  info.Type = RegisteredProxyInformation::LINK;
   this->InvokeEvent(vtkCommand::RegisterEvent, &info);
 }
 
@@ -1011,8 +1055,7 @@ void vtkSMProxyManager::UnRegisterLink(const char* name)
     info.Proxy = 0;
     info.GroupName = 0;
     info.ProxyName = name;
-    info.IsCompoundProxyDefinition = 0;
-    info.IsLink = 1;
+    info.Type = RegisteredProxyInformation::LINK;
     this->Internals->RegisteredLinkMap.erase(it);
     this->InvokeEvent(vtkCommand::UnRegisterEvent, &info);
     }
@@ -1053,6 +1096,23 @@ void vtkSMProxyManager::ExecuteEvent(vtkObject* obj, unsigned long event,
       }
     break;
 
+  case vtkCommand::StateChangedEvent:
+      {
+      // I wonder if I need to mark the proxy modified. Cause when state
+      // changes, the properties are pushed as well so ideally we should call
+      // MarkProxyAsModified() and then UnMarkProxyAsModified() :).
+      // this->MarkProxyAsModified(proxy);
+
+      StateChangedInformation info;
+      info.Proxy = proxy;
+      info.StateChangeElement = reinterpret_cast<vtkPVXMLElement*>(data);
+      if (info.StateChangeElement)
+        {
+        this->InvokeEvent(vtkCommand::StateChangedEvent, &info);
+        }
+      }
+    break;
+
   case vtkCommand::UpdateInformationEvent:
     this->InvokeEvent(vtkCommand::UpdateInformationEvent, proxy);
     break;
@@ -1116,8 +1176,14 @@ void vtkSMProxyManager::LoadState(vtkPVXMLElement* rootElement, vtkIdType id,
     {
     spLoader = loader;
     }
-  spLoader->SetConnectionID(id);
-  spLoader->LoadState(rootElement);
+  spLoader->GetProxyLocator()->SetConnectionID(id);
+  if (spLoader->LoadState(rootElement))
+    {
+    LoadStateInformation info;
+    info.RootElement = rootElement;
+    info.ProxyLocator = spLoader->GetProxyLocator();
+    this->InvokeEvent(vtkCommand::LoadStateEvent, &info);
+    }
 }
 
 //---------------------------------------------------------------------------
@@ -1147,18 +1213,39 @@ void vtkSMProxyManager::SaveState(const char* filename)
   rootElement->Delete();
 }
 
-
 //---------------------------------------------------------------------------
 vtkPVXMLElement* vtkSMProxyManager::SaveState()
 {
-  return this->SaveStateInternal(
+  vtkPVXMLElement* smstate = this->SaveStateInternal(
     vtkProcessModuleConnectionManager::GetNullConnectionID(), 0, 0);
+
+  vtkPVXMLElement* root = vtkPVXMLElement::New();
+  root->SetName("GenericParaViewApplication");
+  root->AddNestedElement(smstate);
+  smstate->FastDelete();
+
+  LoadStateInformation info;
+  info.RootElement = root;
+  info.ProxyLocator = NULL;
+  this->InvokeEvent(vtkCommand::SaveStateEvent, &info);
+  return root;
 }
 
 //---------------------------------------------------------------------------
 vtkPVXMLElement* vtkSMProxyManager::SaveState(vtkIdType connectionID)
 {
-  return this->SaveStateInternal(connectionID, 0, 0);
+  vtkPVXMLElement* smstate = this->SaveStateInternal(connectionID, 0, 0);
+
+  vtkPVXMLElement* root = vtkPVXMLElement::New();
+  root->SetName("GenericParaViewApplication");
+  root->AddNestedElement(smstate);
+  smstate->FastDelete();
+
+  LoadStateInformation info;
+  info.RootElement = root;
+  info.ProxyLocator = NULL;
+  this->InvokeEvent(vtkCommand::SaveStateEvent, &info);
+  return root;
 }
 
 //---------------------------------------------------------------------------
@@ -1367,6 +1454,12 @@ vtkPVXMLElement* vtkSMProxyManager::SaveStateInternal(vtkIdType connectionID,
     links->Delete();
     }
 
+  vtkPVXMLElement* globalProps = vtkPVXMLElement::New();
+  globalProps->SetName("GlobalPropertiesManagers");
+  this->SaveGlobalPropertiesManagers(globalProps);
+  rootElement->AddNestedElement(globalProps);
+  globalProps->Delete();
+
   return rootElement;
 }
 
@@ -1409,8 +1502,7 @@ void vtkSMProxyManager::UnRegisterCustomProxyDefinition(
     info.Proxy = 0;
     info.GroupName = group;
     info.ProxyName = name;
-    info.IsCompoundProxyDefinition = 1;
-    info.IsLink = 0;
+    info.Type = RegisteredProxyInformation::COMPOUND_PROXY_DEFINITION;
     this->InvokeEvent(vtkCommand::UnRegisterEvent, &info);
     elementMap.erase(iter);
     return;
@@ -1457,8 +1549,7 @@ void vtkSMProxyManager::RegisterCustomProxyDefinition(
   info.Proxy = 0;
   info.GroupName = group;
   info.ProxyName = name;
-  info.IsCompoundProxyDefinition = 1;
-  info.IsLink = 0;
+  info.Type = RegisteredProxyInformation::COMPOUND_PROXY_DEFINITION;
   this->InvokeEvent(vtkCommand::RegisterEvent, &info);
 }
 
@@ -1579,6 +1670,21 @@ void vtkSMProxyManager::SaveRegisteredLinks(vtkPVXMLElement* rootElement)
     }
 }
 
+//---------------------------------------------------------------------------
+void vtkSMProxyManager::SaveGlobalPropertiesManagers(vtkPVXMLElement* root)
+{
+  vtkSMProxyManagerInternals::GlobalPropertiesManagersType::iterator iter;
+  for (iter = this->Internals->GlobalPropertiesManagers.begin();
+    iter != this->Internals->GlobalPropertiesManagers.end(); ++iter)
+    {
+    vtkPVXMLElement* elem = iter->second->SaveLinkState(root);
+    if (elem)
+      {
+      elem->AddAttribute("name", iter->first.c_str());
+      }
+    }
+}
+
 //---------------------------------------------------------------------------
 vtkPVXMLElement* vtkSMProxyManager::GetProxyHints(
   const char* groupName, const char* proxyName)
@@ -1614,39 +1720,149 @@ vtkPVXMLElement* vtkSMProxyManager::GetPropertyHints(
 }
 
 //---------------------------------------------------------------------------
-// Description:
-// Register a proxy manager extension. Returns true if the registration is
-// successful.
-bool vtkSMProxyManager::RegisterExtension(vtkSMProxyManagerExtension* ext)
+void vtkSMProxyManager::RegisterSelectionModel(
+  const char* name, vtkSMProxySelectionModel* model)
 {
-  if (!ext || !ext->CheckCompatibility(this->GetVersionMajor(), 
-      this->GetVersionMinor(), this->GetVersionPatch()))
+  if (!model)
     {
-    return false;
+    vtkErrorMacro("Cannot register a null model.");
+    return;
+    }
+  if (!name)
+    {
+    vtkErrorMacro("Cannot register model with no name.");
+    return;
     }
 
-  ext->Register(this);
-  this->UnRegisterExtension(ext);
-  this->Internals->Extensions.push_back(ext);
-  ext->UnRegister(this);
-  return true;
+  vtkSMProxySelectionModel* curmodel = this->GetSelectionModel(name);
+  if (curmodel && curmodel == model)
+    {
+    // already registered.
+    return;
+    }
+
+  if (curmodel)
+    {
+    vtkWarningMacro("Replacing existing selection model: " << name);
+    }
+  this->Internals->SelectionModels[name] = model;
 }
 
 //---------------------------------------------------------------------------
-// Description:
-// Unregister a previously register extension.
-void vtkSMProxyManager::UnRegisterExtension(vtkSMProxyManagerExtension* ext)
+void vtkSMProxyManager::UnRegisterSelectionModel( const char* name)
 {
-  vtkSMProxyManagerInternals::ExtensionsType::iterator iter;
-  for (iter = this->Internals->Extensions.begin();
-    iter != this->Internals->Extensions.end(); ++iter)
+  this->Internals->SelectionModels.erase(name);
+}
+
+//---------------------------------------------------------------------------
+vtkSMProxySelectionModel* vtkSMProxyManager::GetSelectionModel(
+  const char* name)
+{
+  vtkSMProxyManagerInternals::SelectionModelsType::iterator iter =
+    this->Internals->SelectionModels.find(name);
+  if (iter == this->Internals->SelectionModels.end())
     {
-    if (iter->GetPointer() == ext)
+    return 0;
+    }
+
+  return iter->second;
+}
+
+//---------------------------------------------------------------------------
+void vtkSMProxyManager::SetGlobalPropertiesManager(const char* name,
+    vtkSMGlobalPropertiesManager* mgr)
+{
+  vtkSMGlobalPropertiesManager* old_mgr = this->GetGlobalPropertiesManager(name);
+  if (old_mgr == mgr)
+    {
+    return;
+    }
+  this->RemoveGlobalPropertiesManager(name);
+  this->Internals->GlobalPropertiesManagers[name] = mgr;
+
+  RegisteredProxyInformation info;
+  info.Proxy = mgr;
+  info.GroupName = NULL;
+  info.ProxyName = name;
+  info.Type = RegisteredProxyInformation::GLOBAL_PROPERTIES_MANAGER;
+  this->InvokeEvent(vtkCommand::RegisterEvent, &info);
+}
+
+//---------------------------------------------------------------------------
+const char* vtkSMProxyManager::GetGlobalPropertiesManagerName(
+  vtkSMGlobalPropertiesManager* mgr)
+{
+  vtkSMProxyManagerInternals::GlobalPropertiesManagersType::iterator iter;
+  for (iter = this->Internals->GlobalPropertiesManagers.begin();
+    iter != this->Internals->GlobalPropertiesManagers.end(); ++iter)
+    {
+    if (iter->second == mgr)
       {
-      this->Internals->Extensions.erase(iter);
-      break;
+      return iter->first.c_str();
       }
     }
+  return 0;
+}
+
+//---------------------------------------------------------------------------
+vtkSMGlobalPropertiesManager* vtkSMProxyManager::GetGlobalPropertiesManager(
+  const char* name)
+{
+  return this->Internals->GlobalPropertiesManagers[name].GetPointer();
+}
+
+//---------------------------------------------------------------------------
+void vtkSMProxyManager::RemoveGlobalPropertiesManager(const char* name)
+{
+  vtkSMGlobalPropertiesManager* gm = this->GetGlobalPropertiesManager(name);
+  if (gm)
+    {
+    RegisteredProxyInformation info;
+    info.Proxy = gm;
+    info.GroupName = NULL;
+    info.ProxyName = name;
+    info.Type = RegisteredProxyInformation::GLOBAL_PROPERTIES_MANAGER;
+    this->InvokeEvent(vtkCommand::UnRegisterEvent, &info);
+    }
+  this->Internals->GlobalPropertiesManagers.erase(name);
+}
+
+//---------------------------------------------------------------------------
+unsigned int vtkSMProxyManager::GetNumberOfGlobalPropertiesManagers()
+{
+  return static_cast<unsigned int>(
+    this->Internals->GlobalPropertiesManagers.size());
+}
+
+//---------------------------------------------------------------------------
+vtkSMGlobalPropertiesManager* vtkSMProxyManager::GetGlobalPropertiesManager(
+  unsigned int index)
+{
+  unsigned int cur =0;
+  vtkSMProxyManagerInternals::GlobalPropertiesManagersType::iterator iter;
+  for (iter = this->Internals->GlobalPropertiesManagers.begin();
+    iter != this->Internals->GlobalPropertiesManagers.end(); ++iter, ++cur)
+    {
+    if (cur == index)
+      {
+      return iter->second;
+      }
+    }
+
+  return NULL;
+}
+
+//---------------------------------------------------------------------------
+bool vtkSMProxyManager::LoadConfigurationXML(const char* xml)
+{
+  vtkSmartPointer<vtkSMXMLParser> parser =
+    vtkSmartPointer<vtkSMXMLParser>::New();
+  if (xml && parser->Parse(xml))
+    {
+    parser->ProcessConfiguration(this);
+    return true;
+    }
+  return false;
 }
 
 //---------------------------------------------------------------------------
