@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMProxyProperty.cxx,v $
+  Module:    vtkSMProxyProperty.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -21,18 +21,18 @@
 #include "vtkSMProxy.h"
 #include "vtkSMProxyGroupDomain.h"
 #include "vtkSMProxyManager.h"
-#include "vtkSMStateLoaderBase.h"
+#include "vtkSMProxyLocator.h"
 #include "vtkSmartPointer.h"
 
 #include <vtkstd/algorithm>
 #include <vtkstd/map>
 #include <vtkstd/set>
 #include <vtkstd/vector>
+#include <vtkstd/iterator>
 
 #include "vtkStdString.h"
 
 vtkStandardNewMacro(vtkSMProxyProperty);
-vtkCxxRevisionMacro(vtkSMProxyProperty, "$Revision: 1.54 $");
 
 struct vtkSMProxyPropertyInternals
 {
@@ -519,7 +519,8 @@ int vtkSMProxyProperty::ReadXMLAttributes(vtkSMProxy* parent,
   int retVal = element->GetScalarAttribute("repeat_command", &repeat_command);
   if(retVal) 
     { 
-    this->SetRepeatCommand(repeat_command); 
+    this->SetRepeatCommand(repeat_command);
+    this->Repeatable = repeat_command;
     }
 
   const char* remove_command = element->GetAttribute("remove_command");
@@ -535,19 +536,25 @@ int vtkSMProxyProperty::ReadXMLAttributes(vtkSMProxy* parent,
     }
 
 
-  if (this->RemoveCommand && !this->GetUpdateSelf())
-    {
-    vtkErrorMacro("Due to reference counting issue, remove command can "
-      "only be used for update self properties. " << endl <<
-      "Offending property: " << this->XMLName);
-    }
+  //if (this->RemoveCommand && !this->GetUpdateSelf())
+  //  {
+  //  vtkErrorMacro("Due to reference counting issue, remove command can "
+  //    "only be used for update self properties. " << endl <<
+  //    "Offending property: " << this->XMLName);
+  //  }
   return ret;
 }
 
 //---------------------------------------------------------------------------
 int vtkSMProxyProperty::LoadState(vtkPVXMLElement* element,
-  vtkSMStateLoaderBase* loader, int loadLastPushedValues/*=0*/)
+  vtkSMProxyLocator* loader, int loadLastPushedValues/*=0*/)
 {
+  if (!loader)
+    {
+    // no loader specified, state remains unchanged.
+    return 1;
+    }
+
   int prevImUpdate = this->ImmediateUpdate;
 
   // Wait until all values are set before update (if ImmediateUpdate)
@@ -588,11 +595,10 @@ int vtkSMProxyProperty::LoadState(vtkPVXMLElement* element,
         {
         if (id)
           {
-          vtkSMProxy* proxy = loader->NewProxy(id);
+          vtkSMProxy* proxy = loader->LocateProxy(id);
           if (proxy)
             {
             this->AddProxy(proxy, 0);
-            proxy->Delete();
             }
           else
             {
@@ -626,12 +632,9 @@ void vtkSMProxyProperty::ChildSaveState(vtkPVXMLElement* propertyElement,
   propertyElement->AddAttribute("number_of_elements", numProxies);
   for (unsigned int idx=0; idx<numProxies; idx++)
     {
-    vtkSMProxy* proxy = this->GetProxy(idx);
-    if (proxy)
+    vtkPVXMLElement* proxyElement = this->SaveProxyElementState(idx, false);
+    if (proxyElement)
       {
-      vtkPVXMLElement* proxyElement = vtkPVXMLElement::New();
-      proxyElement->SetName("Proxy");
-      proxyElement->AddAttribute("value", proxy->GetSelfIDAsString());
       propertyElement->AddNestedElement(proxyElement);
       proxyElement->Delete();
       }
@@ -645,12 +648,9 @@ void vtkSMProxyProperty::ChildSaveState(vtkPVXMLElement* propertyElement,
     element->AddAttribute("number_of_elements", numProxies);
     for (unsigned int cc=0; cc < numProxies; cc++)
       {
-      vtkSMProxy* proxy = this->PPInternals->PreviousProxies[cc];
-      if (proxy)
+      vtkPVXMLElement* proxyElement = this->SaveProxyElementState(cc, true);
+      if (proxyElement)
         {
-        vtkPVXMLElement* proxyElement = vtkPVXMLElement::New();
-        proxyElement->SetName("Proxy");
-        proxyElement->AddAttribute("value", proxy->GetSelfIDAsString());
         element->AddNestedElement(proxyElement);
         proxyElement->Delete();
         }
@@ -660,6 +660,24 @@ void vtkSMProxyProperty::ChildSaveState(vtkPVXMLElement* propertyElement,
     }
 }
 
+//---------------------------------------------------------------------------
+vtkPVXMLElement* vtkSMProxyProperty::SaveProxyElementState(
+  unsigned int idx, bool use_previous_proxies)
+{
+  // We can assume idx is valid since it's called by ChildSaveState().
+  vtkSMProxy* proxy = use_previous_proxies? 
+    this->PPInternals->PreviousProxies[idx].GetPointer():
+    this->GetProxy(idx);
+  vtkPVXMLElement* proxyElement = 0;
+  if (proxy)
+    {
+    proxyElement = vtkPVXMLElement::New();
+    proxyElement->SetName("Proxy");
+    proxyElement->AddAttribute("value", proxy->GetSelfIDAsString());
+    }
+  return proxyElement;
+}
+
 //---------------------------------------------------------------------------
 void vtkSMProxyProperty::DeepCopy(vtkSMProperty* src, 
   const char* exceptionClass, int proxyPropertyCopyFlag)
