@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMRepresentationStrategy.h,v $
+  Module:    vtkSMRepresentationStrategy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -35,7 +35,7 @@ class vtkSMSourceProxy;
 class VTK_EXPORT vtkSMRepresentationStrategy : public vtkSMProxy
 {
 public:
-  vtkTypeRevisionMacro(vtkSMRepresentationStrategy, vtkSMProxy);
+  vtkTypeMacro(vtkSMRepresentationStrategy, vtkSMProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -140,7 +140,7 @@ public:
   // information about data sizes etc from the server without actually
   // undertaking any expensive data transfers.
   // Similar to Update(), the LOD subpipline is updated only if LOD is used.
-  void UpdateDataInformation();
+  virtual void UpdateDataInformation();
 
   // Description:
   // Returns the current data information for the represented data.
@@ -182,7 +182,7 @@ protected:
 
   // Description:
   // Called before objects are created.
-  virtual void BeginCreateVTKObjects(){};
+  virtual void BeginCreateVTKObjects();
 
   // Description:
   // Called after objects are created.
@@ -202,13 +202,15 @@ protected:
   // Gather the information of the displayed data (non-LOD).
   // Update the part of the pipeline needed to gather full information
   // and then gather that information. 
-  virtual void GatherInformation(vtkPVInformation*)= 0;
+  virtual void GatherInformation(vtkPVInformation*) = 0;
 
   // Description:
   // Gather the information of the displayed data (lod);
   // Update the part of the pipeline needed to gather full information
   // and then gather that information. 
-  virtual void GatherLODInformation(vtkPVInformation*) = 0;
+  // Default implementation simply calls GatherInformation().
+  virtual void GatherLODInformation(vtkPVInformation* info)
+    { this->GatherInformation(info); }
 
   // Description:
   // Update the LOD pipeline. Subclasses must override this method
@@ -223,8 +225,6 @@ protected:
   // Subclasses must override this method
   // to provide their own implementation and then call the superclass
   // to ensure that various flags are updated correctly.
-  // This method should respect caching, if supported. Call
-  // UseCache() to check if caching is to be employed.
   virtual void UpdatePipeline();
 
   // Description:
@@ -272,9 +272,15 @@ protected:
       }
     }
 
+  // Description:
+  // Returns true is data is valid.
+  virtual bool GetDataValid()
+    { return this->DataValid; }
 
-  vtkSMSourceProxy* Input;
-  int OutputPort;
+  // Description:
+  // Returns true is LOD data is valid.
+  virtual bool GetLODDataValid()
+    { return this->LODDataValid; }
 
   bool UseCache;
   bool UseLOD;
@@ -294,10 +300,26 @@ protected:
   bool KeepLODPipelineUpdated;
 
   vtkInformation* ViewInformation;
+
+  vtkSMSourceProxy* Input;
+  int OutputPort;
+
+private:
+  // Description:
+  // Cleans cache. Called in InvalidatePipeline() and InvalidateLODPipeline().
+  // Cache is not cleaned if caching is enabled since it implies that we are
+  // building cache.
+  void CleanCacheIfObsolete();
+
+  // Flag used to avoid unnecessary "RemoveAllCaches" requests being set to the
+  // server.
+  bool SomethingCached;
+
 private:
   vtkSMRepresentationStrategy(const vtkSMRepresentationStrategy&); // Not implemented
   void operator=(const vtkSMRepresentationStrategy&); // Not implemented
 
+  vtkSMSourceProxy* CacheKeeper;
   bool EnableLOD;
 
   vtkCommand* Observer;
