@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMServerProxyManagerReviver.cxx,v $
+  Module:    vtkSMServerProxyManagerReviver.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -25,6 +25,7 @@
 #include "vtkSMProxy.h"
 #include "vtkSMProxyIterator.h"
 #include "vtkSMProxyManager.h"
+#include "vtkSMProxyLocator.h"
 
 #include "vtkPVConfig.h" // for PARAVIEW_USE_ICE_T
 #include "vtkToolkits.h" // for VTK_USE_MPI
@@ -33,7 +34,6 @@
 #include <vtksys/ios/sstream>
 
 vtkStandardNewMacro(vtkSMServerProxyManagerReviver);
-vtkCxxRevisionMacro(vtkSMServerProxyManagerReviver, "$Revision: 1.17 $");
 //-----------------------------------------------------------------------------
 vtkSMServerProxyManagerReviver::vtkSMServerProxyManagerReviver()
 {
@@ -82,6 +82,11 @@ int vtkSMServerProxyManagerReviver::ReviveRemoteServerManager(vtkIdType cid)
   iter->Delete();
 
   // 2) Cleanup client side proxy manager objects for the cid.
+  // No need to do SendStreamToClientOnlyOn() this anymore since
+  // CreateVTKObjects() is never called when
+  // reviving proxies. In fact, doing this can cause issues since we have now
+  // changed the StateLoader to call UpdateVTKObjects() as and when the proxies
+  // are created and their state loaded completely.
   // pm->SendStreamToClientOnlyOn();
   pxm->UnRegisterProxies(cid);  
   // pm->SendStreamToClientOnlyOff();
@@ -134,23 +139,23 @@ int vtkSMServerProxyManagerReviver::ReviveServerServerManager(
 
   vtkSMPQStateLoader* loader = vtkSMPQStateLoader::New();
   // The state is loaded on the self connection.
-  loader->SetConnectionID(
+  loader->GetProxyLocator()->SetConnectionID(
     vtkProcessModuleConnectionManager::GetSelfConnectionID());
-  loader->SetReviveProxies(1);
+  loader->GetProxyLocator()->SetReviveProxies(1);
 
   // The process module on the client side keeps track of the unique IDs.
   // We need to synchornize the IDs on the client side, so that when new IDs
   // are assigned, the ones already used aren't reassigned.
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   pm->ReserveID(id);
-  pm->SendStreamToClientOnlyOn();
+  //pm->SendStreamToClientOnlyOn();
   vtkProcessModule::DebugLog("Pre--FilterStateXML");
   this->FilterStateXML(parser->GetRootElement());
   vtkProcessModule::DebugLog("Post--FilterStateXML");
   
   int ret = loader->LoadState(parser->GetRootElement());
   vtkProcessModule::DebugLog("Post--LoadState");
-  pm->SendStreamToClientOnlyOff();
+  //pm->SendStreamToClientOnlyOff();
   
   vtkSMProxyManager* pxm = vtkSMProxyManager::GetProxyManager();
   vtkProcessModule::DebugLog("Pre--UpdateRegisteredProxies");
