@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMSimpleStrategy.cxx,v $
+  Module:    vtkSMSimpleStrategy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -23,7 +23,6 @@
 #include "vtkSMSourceProxy.h"
 
 vtkStandardNewMacro(vtkSMSimpleStrategy);
-vtkCxxRevisionMacro(vtkSMSimpleStrategy, "$Revision: 1.13 $");
 //----------------------------------------------------------------------------
 vtkSMSimpleStrategy::vtkSMSimpleStrategy()
 {
@@ -31,8 +30,6 @@ vtkSMSimpleStrategy::vtkSMSimpleStrategy()
   this->UpdateSuppressor = 0;
   this->UpdateSuppressorLOD = 0;
   this->SetEnableLOD(true);
-  this->SomethingCached = false;
-  this->SomethingCachedLOD = false;
 }
 
 //----------------------------------------------------------------------------
@@ -82,15 +79,14 @@ void vtkSMSimpleStrategy::CreateLODPipeline(vtkSMSourceProxy* input, int outputp
 //----------------------------------------------------------------------------
 void vtkSMSimpleStrategy::GatherInformation(vtkPVInformation* info)
 {
-  this->UpdatePipeline(); // Update to get the geometry information;
-                          // used to get sizes etc. to make collection
-                          // decisions etc.
+  // It's essential that we don't call UpdatePipeline() on our subclasses since
+  // they may still be in a state that's not fully determined eg. status of
+  // compositing etc.
+  this->vtkSMSimpleStrategy::UpdatePipeline();
 
-  // For simple strategy information sub-pipline is same as the full pipeline
-  // since no data movements are involved.
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   pm->GatherInformation(this->ConnectionID,
-    vtkProcessModule::DATA_SERVER_ROOT,
+    this->UpdateSuppressor->GetServers(),
     info,
     this->UpdateSuppressor->GetID());
 }
@@ -98,13 +94,14 @@ void vtkSMSimpleStrategy::GatherInformation(vtkPVInformation* info)
 //----------------------------------------------------------------------------
 void vtkSMSimpleStrategy::GatherLODInformation(vtkPVInformation* info)
 {
-  this->UpdateLODPipeline();
+  // It's essential that we don't call UpdatePipeline() on our subclasses since
+  // they may still be in a state that's not fully determined eg. status of
+  // compositing etc.
+  this->vtkSMSimpleStrategy::UpdateLODPipeline();
 
-  // For simple strategy information sub-pipline is same as the full pipeline
-  // since no data movements are involved.
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
   pm->GatherInformation(this->ConnectionID,
-    vtkProcessModule::DATA_SERVER_ROOT,
+    this->UpdateSuppressorLOD->GetServers(),
     info,
     this->UpdateSuppressorLOD->GetID());
 }
@@ -112,66 +109,35 @@ void vtkSMSimpleStrategy::GatherLODInformation(vtkPVInformation* info)
 //----------------------------------------------------------------------------
 void vtkSMSimpleStrategy::UpdatePipeline()
 {
-  if (this->GetUseCache())
+  // We check to see if the part of the pipeline that will up updated by this
+  // class needs any update. Then alone do we call update.
+  if (this->vtkSMSimpleStrategy::GetDataValid())
     {
-    this->SomethingCached = true;
-    vtkSMDoubleVectorProperty* dvp = vtkSMDoubleVectorProperty::SafeDownCast(
-      this->UpdateSuppressor->GetProperty("CacheUpdate"));
-    dvp->SetElement(0, this->CacheTime);
-    this->UpdateSuppressor->UpdateProperty("CacheUpdate", 1);
-    }
-  else
-    {
-    this->UpdateSuppressor->InvokeCommand("ForceUpdate");
-    // This is called for its side-effects; i.e. to force a PostUpdateData()
-    this->UpdateSuppressor->UpdatePipeline();
+    return;
     }
+
+  // It's essential to call UpdatePipeline() on the superclass first since
+  // that's the one that sets up CacheKeeper state correctly.
   this->Superclass::UpdatePipeline();
+  
+  this->UpdateSuppressor->InvokeCommand("ForceUpdate");
+  // This is called for its side-effects; i.e. to force a PostUpdateData()
+  this->UpdateSuppressor->UpdatePipeline();
 }
 
 //----------------------------------------------------------------------------
 void vtkSMSimpleStrategy::UpdateLODPipeline()
 {
-  if (this->GetUseCache())
+  if (this->vtkSMSimpleStrategy::GetLODDataValid())
     {
-    this->SomethingCachedLOD = true;
-    vtkSMDoubleVectorProperty* dvp = vtkSMDoubleVectorProperty::SafeDownCast(
-      this->UpdateSuppressorLOD->GetProperty("CacheUpdate"));
-    dvp->SetElement(0, this->CacheTime);
-    this->UpdateSuppressorLOD->UpdateProperty("CacheUpdate", 1);
-    }
-  else
-    {
-    this->UpdateSuppressorLOD->InvokeCommand("ForceUpdate");
+    return;
     }
 
   this->Superclass::UpdateLODPipeline();
-}
 
-//----------------------------------------------------------------------------
-void vtkSMSimpleStrategy::InvalidatePipeline()
-{
-  // Cache is cleaned up whenever something changes and caching is not currently
-  // enabled.
-  if (this->SomethingCached && !this->GetUseCache())
-    {
-    this->SomethingCached = false;
-    this->UpdateSuppressor->InvokeCommand("RemoveAllCaches");
-    }
-
-  this->Superclass::InvalidatePipeline();
-}
-
-//----------------------------------------------------------------------------
-void vtkSMSimpleStrategy::InvalidateLODPipeline()
-{
-  if (this->SomethingCachedLOD && !this->GetUseCache())
-    {
-    this->SomethingCachedLOD = false;
-    this->UpdateSuppressorLOD->InvokeCommand("RemoveAllCaches");
-    }
-
-  this->Superclass::InvalidateLODPipeline();
+  this->UpdateSuppressorLOD->InvokeCommand("ForceUpdate");
+  // This is called for its side-effects; i.e. to force a PostUpdateData()
+  this->UpdateSuppressorLOD->UpdatePipeline();
 }
 
 //----------------------------------------------------------------------------
