@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMSourceProxy.cxx,v $
+  Module:    vtkSMSourceProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -43,7 +43,6 @@
 
 //---------------------------------------------------------------------------
 vtkStandardNewMacro(vtkSMSourceProxy);
-vtkCxxRevisionMacro(vtkSMSourceProxy, "$Revision: 1.65 $");
 
 // This struct will keep all information associated with the output port.
 struct vtkSMSourceProxyOutputPort
@@ -272,11 +271,14 @@ int vtkSMSourceProxy::ReadXMLAttributes(vtkSMProxyManager* pm,
 // TODO this should update information properties.
 void vtkSMSourceProxy::UpdatePipeline()
 {
-  int i;
+  if (!this->NeedsUpdate)
+    {
+    return;
+    }
 
   this->CreateOutputPorts(); 
   int num = this->GetNumberOfOutputPorts();
-  for (i=0; i < num; ++i)
+  for (int i=0; i < num; ++i)
     {
     this->GetOutputPort(i)->UpdatePipeline();
     }
@@ -465,6 +467,7 @@ void vtkSMSourceProxy::CreateOutputPortsInternal(vtkSMProxy* op)
     opPort->SetServers(this->Servers);
     opPort->InitializeWithIDs(portID, producerID, execID);
     opPort->SetPortIndex(j);
+    opPort->SetSourceProxy(this);
     this->PInternals->OutputPorts[j].Port = opPort;
     opPort->Delete();
     }
@@ -498,6 +501,10 @@ void vtkSMSourceProxy::SetOutputPort(unsigned int index, const char* name,
   this->PInternals->OutputPorts[index].Name = name;
   this->PInternals->OutputPorts[index].Port = port;
   this->PInternals->OutputPorts[index].Documentation = doc;
+  if (port)
+    {
+    port->SetSourceProxy(this);
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -643,10 +650,9 @@ vtkPVXMLElement* vtkSMSourceProxy::SaveRevivalState(vtkPVXMLElement* root)
 }
 
 //---------------------------------------------------------------------------
-int vtkSMSourceProxy::LoadRevivalState(vtkPVXMLElement* revivalElem,
-  vtkSMStateLoaderBase* loader)
+int vtkSMSourceProxy::LoadRevivalState(vtkPVXMLElement* revivalElem)
 {
-  if (!this->Superclass::LoadRevivalState(revivalElem, loader))
+  if (!this->Superclass::LoadRevivalState(revivalElem))
     {
     return 0;
     }
@@ -661,7 +667,7 @@ int vtkSMSourceProxy::LoadRevivalState(vtkPVXMLElement* revivalElem,
       vtkSmartPointer<vtkSMOutputPort> opPort = vtkSmartPointer<vtkSMOutputPort>::New();
       opPort->SetConnectionID(this->ConnectionID);
       opPort->SetServers(this->Servers);
-      if (opPort->LoadRevivalState(curElement->GetNestedElement(0), loader))
+      if (opPort->LoadRevivalState(curElement->GetNestedElement(0)))
         {
         this->PInternals->EnsureOutputPortsSize(index+1);
         this->PInternals->OutputPorts[index].Port = opPort;
