@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMSourceProxy.h,v $
+  Module:    vtkSMSourceProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -46,7 +46,7 @@ class VTK_EXPORT vtkSMSourceProxy : public vtkSMProxy
 {
 public:
   static vtkSMSourceProxy* New();
-  vtkTypeRevisionMacro(vtkSMSourceProxy, vtkSMProxy);
+  vtkTypeMacro(vtkSMSourceProxy, vtkSMProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -154,8 +154,7 @@ public:
   // object IDs.
   // Overridden to save information pertinant to reviving the output ports.
   virtual vtkPVXMLElement* SaveRevivalState(vtkPVXMLElement* root);
-  virtual int LoadRevivalState(vtkPVXMLElement* revivalElement, 
-    vtkSMStateLoaderBase* loader);
+  virtual int LoadRevivalState(vtkPVXMLElement* revivalElement);
 
   // Description:
   // Creates extract selection proxies for each output port if not already
