@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMStateVersionController.cxx,v $
+  Module:    vtkSMStateVersionController.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtksys/ios/sstream"
 
 vtkStandardNewMacro(vtkSMStateVersionController);
-vtkCxxRevisionMacro(vtkSMStateVersionController, "$Revision: 1.12 $");
 //----------------------------------------------------------------------------
 vtkSMStateVersionController::vtkSMStateVersionController()
 {
@@ -71,7 +70,7 @@ bool vtkSMStateVersionController::Process(vtkPVXMLElement* root)
       }
     status = status && this->Process_3_0_To_3_2(root) ;
 
-    // Since now the state file has been update to version 3.1.0, we must update
+    // Since now the state file has been updated to version 3.2.0, we must update
     // the version number to reflect that.
     int updated_version[3] = {3, 2, 0};
     this->UpdateVersion(version, updated_version);
@@ -82,16 +81,37 @@ bool vtkSMStateVersionController::Process(vtkPVXMLElement* root)
     {
     status = status && this->Process_3_2_To_3_4(root) ;
 
-    // Since now the state file has been update to version 3.1.0, we must update
+    // Since now the state file has been updated to version 3.4.0, we must update
     // the version number to reflect that.
     int updated_version[3] = {3, 4, 0};
     this->UpdateVersion(version, updated_version);
     }
-  return true;
+
+  if (this->GetMajor(version)==3 &&
+    this->GetMinor(version) < 6)
+    {
+    status = status && this->Process_3_4_to_3_6(root);
+    // Since now the state file has been updated to version 3.6.0, we must update
+    // the version number to reflect that.
+    int updated_version[3] = {3, 6, 0};
+    this->UpdateVersion(version, updated_version);
+    }
+    
+  if ( this->GetMajor( version ) == 3 && this->GetMinor( version ) < 8 )
+    {
+    status = status && this->Process_3_6_to_3_8( root );
+    // Since now the state file has been updated to version 3.8.0, we must update
+    // the version number to reflect that.
+    int updated_version[3] = { 3, 8, 0 };
+    this->UpdateVersion( version, updated_version );
+    }
+
+  return status;
 }
 
-namespace
+namespace // namespace begin
 {
+
 //----------------------------------------------------------------------------
 bool ConvertViewModulesToViews(
   vtkPVXMLElement* root, void* callData)
@@ -305,8 +325,17 @@ bool ConvertPVAnimationSceneToAnimationScene(
     vtkSMStateVersionController*>(callData);
   return self->ConvertPVAnimationSceneToAnimationScene(root);
 }
+
+//----------------------------------------------------------------------------
+bool ConvertStreamTracer( vtkPVXMLElement * root, void * callData )
+{
+  vtkSMStateVersionController * self 
+    = reinterpret_cast< vtkSMStateVersionController * >( callData );
+  return self->ConvertStreamTracer( root );
 }
-;
+
+}; // namespace end
+
 //----------------------------------------------------------------------------
 bool vtkSMStateVersionController::Process_3_0_To_3_2(vtkPVXMLElement* root)
 {
@@ -664,6 +693,150 @@ bool vtkSMStateVersionController::Process_3_2_To_3_4(vtkPVXMLElement* root)
   return true;
 }
 
+bool ElementFound(
+  vtkPVXMLElement* vtkNotUsed(parent), void* callData)
+{
+  *(reinterpret_cast<bool*>(callData)) = true;
+  return true;
+}
+
+//----------------------------------------------------------------------------
+bool vtkSMStateVersionController::Process_3_4_to_3_6(vtkPVXMLElement* root)
+{
+    {
+    // If there's a "CSVReader", it's an irrecoverable error since the output
+    // format for CSVReader changed in 3.6 to be true table so old rectilinear
+    // grid pipelines won't really work.
+    const char* attrs[] = {"type", "CSVReader", 0};
+    bool found = false;
+    this->Select(root, "Proxy", attrs, &::ElementFound, &found);
+    if (found)
+      {
+      vtkErrorMacro("Your state file uses a \"CSVReader\"."
+        "The CSVReader has undergone major changes in 3.6 and hence this state"
+        " file is not recoverable.");
+      return false;
+      }
+    }
+
+    {
+    // "CTHFragmentConnect" was removed from the open source version due to
+    // export control issues. 
+    const char* attrs[] = {"type", "CTHFragmentConnect", 0};
+    bool found = false;
+    this->Select(root, "Proxy", attrs, &::ElementFound, &found);
+    if (found)
+      {
+      vtkErrorMacro("Your state file uses a \"CTHFragmentConnect\"."
+        "CTHFragmentConnect is no longer available in ParaView.");
+      return false;
+      }
+    }
+
+    {
+    // "CTHFragmentIntersect" was removed from the open source version due to
+    // export control issues. 
+    const char* attrs[] = {"type", "CTHFragmentIntersect", 0};
+    bool found = false;
+    this->Select(root, "Proxy", attrs, &::ElementFound, &found);
+    if (found)
+      {
+      vtkErrorMacro("Your state file uses a \"CTHFragmentIntersect\"."
+        "CTHFragmentIntersect is no longer available in ParaView.");
+      return false;
+      }
+    }
+
+    {
+    // If Plot Views are present, warn about them. Suggest that they may have to
+    // recreate the view.
+    const char* attrs0[] = {"type", "XYPlotView", 0};
+    const char* attrs1[] = {"type", "BarChartView", 0};
+    bool found = false;
+    this->Select(root, "Proxy", attrs0, &::ElementFound, &found);
+    if (!found)
+      {
+      this->Select(root, "Proxy", attrs1, &::ElementFound, &found);
+      }
+    if (found)
+      {
+      vtkWarningMacro("Your state file uses plot views. "
+        "Plot views have undergone considerable changes in 3.6 and it's"
+        " possible that the state may not be loaded correctly. "
+        "In that case, simply close the plot views, and recreate them.");
+      }
+    }
+
+    {
+    // If "ExodusReader" is present, we give up since legacy exodus is no longer
+    // supported.
+    const char* attrs[] = {"type", "ExodusReader", 0};
+    bool found = false;
+    this->Select(root, "Proxy", attrs, &::ElementFound, &found);
+    if (found)
+      {
+      vtkErrorMacro("Your state file uses a \"ExodusReader\"."
+        " ExodusReader was replaced by ExodusIIReader in 3.6."
+        " We are unable to support legacy exodus state files.");
+      return false;
+      }
+    }
+
+    {
+    // Convert "Programmable Filter" to "ProgrammableFilter".
+    const char* attrs[] = {"type", "Programmable Filter", 0};
+    const char* newAttrs[] = {"type", "ProgrammableFilter", 0};
+    this->SelectAndSetAttributes(root, "Proxy", attrs, newAttrs);
+    }
+
+  return true;
+}
+
+//----------------------------------------------------------------------------
+bool vtkSMStateVersionController::ConvertStreamTracer(vtkPVXMLElement* parent)
+{
+  // Replace property "InitialIntegrationStepUnit" with property 
+  // "IntegrationStepUnit", ignoring properties "MinimumIntegrationStepUnit",
+  // "MaximumIntegrationStepUnit", and "MaximumPropagationUnit".
+  const char* attrs[]    = { "name", "InitialIntegrationStepUnit", 0 };
+  const char* newAttrs[] = { "name", "IntegrationStepUnit",        0 };
+  this->SelectAndSetAttributes( parent, "Property", attrs, newAttrs );
+  return true;
+}
+
+//----------------------------------------------------------------------------
+bool vtkSMStateVersionController::Process_3_6_to_3_8( vtkPVXMLElement * root )
+{
+    {
+    // Upon any occurrence of StreamTracer or ArbitrarySourceStreamTracer, a
+    // warning message pops up, indicating the changes to vtkStreamTracer
+    bool found0 = false;
+    bool found1 = false;
+    const char * attrs0[] = { "type", "StreamTracer",                0 };
+    const char * attrs1[] = { "type", "ArbitrarySourceStreamTracer", 0 };
+    this->Select( root, "Proxy", attrs0, &::ElementFound, &found0 );
+    this->Select( root, "Proxy", attrs1, &::ElementFound, &found1 );
+    
+    if ( found0 || found1 )
+      {
+      vtkWarningMacro( "Your state file uses (vtk)StreamTracer. "
+        "vtkStreamTracer has undergone considerable changes in 3.8 and it's"
+        " possible that the state may not be loaded correctly or some of"
+        " the settings may be converted to values other than specified." );
+      }
+    }
+    
+    {
+    // Replace abandoned properties of vtkStreamTracer with new ones
+    const char* attrs0[] = { "type", "StreamTracer",                0 };
+    const char* attrs1[] = { "type", "ArbitrarySourceStreamTracer", 0 };
+    this->Select( root, "Proxy", attrs0, &::ConvertStreamTracer, this );
+    this->Select( root, "Proxy", attrs1, &::ConvertStreamTracer, this );
+    }
+    
+  return true;
+}
+
 //----------------------------------------------------------------------------
 void vtkSMStateVersionController::PrintSelf(ostream& os, vtkIndent indent)
 {
