@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMTextSourceRepresentationProxy.h,v $
+  Module:    vtkSMTextSourceRepresentationProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -19,37 +19,21 @@
 #ifndef __vtkSMTextSourceRepresentationProxy_h
 #define __vtkSMTextSourceRepresentationProxy_h
 
-#include "vtkSMDataRepresentationProxy.h"
+#include "vtkSMClientDeliveryRepresentationProxy.h"
 
 class vtkSMTextWidgetRepresentationProxy;
 class vtkSMViewProxy;
 
-class VTK_EXPORT vtkSMTextSourceRepresentationProxy : public vtkSMDataRepresentationProxy
+class VTK_EXPORT vtkSMTextSourceRepresentationProxy : public vtkSMClientDeliveryRepresentationProxy
 {
 public:
   static vtkSMTextSourceRepresentationProxy* New();
-  vtkTypeRevisionMacro(vtkSMTextSourceRepresentationProxy, vtkSMDataRepresentationProxy);
+  vtkTypeMacro(vtkSMTextSourceRepresentationProxy, vtkSMClientDeliveryRepresentationProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
-  // Called when setting input using the Input property.
-  // Subclasses must override this method to set the input 
-  // to the display pipeline.
-  virtual void AddInput(unsigned int inputPort,
-                        vtkSMSourceProxy* input,
-                        unsigned int outputPort,
-                        const char* method);
-  virtual void AddInput(vtkSMSourceProxy* input,
-                        const char* method)
-  {
-    this->AddInput(0, input, 0, method);
-  }
-
-  // Description:
-  // This method returns if the Update() or UpdateDistributedGeometry()
-  // calls will actually lead to an Update. This is used by the render module
-  // to decide if it can expect any pipeline updates.
-  virtual bool UpdateRequired() { return this->Dirty? true : false; }
+  // Set the visibility for the representation.
+  void SetVisibility(int);
 
   // Description:
   // Called to update the Display. Default implementation does nothing.
@@ -59,11 +43,10 @@ public:
   virtual void Update(vtkSMViewProxy* view);
 
   // Description:
-  // Overridden to make the Strategy modified as well.
-  // The strategy is not marked dirty if the modifiedProxy == this, 
-  // thus if the changes to representation itself invalidates the data pipelines
-  // it must explicity mark the strategy invalid.
-  virtual void MarkDirty(vtkSMProxy* modifiedProxy);
+  // Get the bounds for the representation.
+  // Overridden to now return any bounds since Text has no bounds.
+  virtual bool GetBounds(double*)
+    { return false; }
 
 // BTX
 protected:
@@ -76,11 +59,6 @@ protected:
   // on the subproxies.
   // If this method returns false, CreateVTKObjects() is aborted.
   virtual bool BeginCreateVTKObjects();
-
-  // Description:
-  // This method is called after CreateVTKObjects(). 
-  // This gives subclasses an opportunity to do some post-creation
-  // initialization.
   virtual bool EndCreateVTKObjects();
 
   // Description:
@@ -95,18 +73,7 @@ protected:
   // Currently a representation can be added to only one view.
   virtual bool RemoveFromView(vtkSMViewProxy* view);
 
-  // Description:
-  // Pass the actual update time to use to all strategies.
-  // When not using strategies, make sure that this method is overridden to pass
-  // the update time correctly.
-  virtual void SetUpdateTimeInternal(double time);
-
   vtkSMTextWidgetRepresentationProxy* TextWidgetProxy;
-
-  vtkSMSourceProxy* UpdateSuppressorProxy;
-  vtkSMSourceProxy* CollectProxy;
-  bool Dirty;
-
 private:
   vtkSMTextSourceRepresentationProxy(const vtkSMTextSourceRepresentationProxy&); // Not implemented
   void operator=(const vtkSMTextSourceRepresentationProxy&); // Not implemented
