@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMTimeStepsInformationHelper.cxx,v $
+  Module:    vtkSMTimeStepsInformationHelper.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -20,7 +20,6 @@
 #include "vtkSMDoubleVectorProperty.h"
 
 vtkStandardNewMacro(vtkSMTimeStepsInformationHelper);
-vtkCxxRevisionMacro(vtkSMTimeStepsInformationHelper, "$Revision: 1.7 $");
 
 //---------------------------------------------------------------------------
 vtkSMTimeStepsInformationHelper::vtkSMTimeStepsInformationHelper()
