@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMUndoStack.cxx,v $
+  Module:    vtkSMUndoStack.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -19,6 +19,7 @@
 #include "vtkProcessModuleConnectionManager.h"
 #include "vtkProcessModule.h"
 #include "vtkPVXMLElement.h"
+#include "vtkSMIdBasedProxyLocator.h"
 #include "vtkSMProxyManager.h"
 #include "vtkSMUndoRedoStateLoader.h"
 #include "vtkUndoSet.h"
@@ -62,7 +63,7 @@ class vtkSMUndoStackUndoSet : public vtkUndoSet
 {
 public:
   static vtkSMUndoStackUndoSet* New();
-  vtkTypeRevisionMacro(vtkSMUndoStackUndoSet, vtkUndoSet);
+  vtkTypeMacro(vtkSMUndoStackUndoSet, vtkUndoSet);
  
   virtual int Undo() 
     {
@@ -108,6 +109,45 @@ public:
     return status;
     }
 
+  //begin vistrails
+  vtkUndoSet* getLastUndoSet()
+  {
+    vtkPVXMLElement* state;
+    if (this->State)
+      {
+      state = this->State;
+      state->Register(this);
+      }
+    else
+      {
+      vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
+      state = pm->NewNextUndo(this->ConnectionID);
+      }
+    if (state) {
+      if (!this->UndoRedoManager->GetStateLoader())
+      {
+        vtkSMUndoRedoStateLoader* sl = vtkSMUndoRedoStateLoader::New();
+        this->UndoRedoManager->SetStateLoader(sl);
+        sl->Delete();
+      }
+
+
+    vtkSMIdBasedProxyLocator* locator = vtkSMIdBasedProxyLocator::New();
+    locator->SetConnectionID(this->ConnectionID);
+    locator->SetDeserializer(this->UndoRedoManager->StateLoader);
+    vtkUndoSet* undo = this->UndoRedoManager->StateLoader->LoadUndoRedoSet(state, locator);
+    locator->Delete();
+
+      //this->UndoRedoManager->GetStateLoader()->ClearCreatedProxies();
+    state->Delete();
+
+      return undo;
+    }
+    return NULL;
+
+  }
+//end vistrails
+
   void SetConnectionID(vtkIdType id)
     {
     this->ConnectionID = id;
@@ -148,11 +188,9 @@ private:
 };
 
 vtkStandardNewMacro(vtkSMUndoStackUndoSet);
-vtkCxxRevisionMacro(vtkSMUndoStackUndoSet, "$Revision: 1.14 $");
 //*****************************************************************************
 
 vtkStandardNewMacro(vtkSMUndoStack);
-vtkCxxRevisionMacro(vtkSMUndoStack, "$Revision: 1.14 $");
 vtkCxxSetObjectMacro(vtkSMUndoStack, StateLoader, vtkSMUndoRedoStateLoader);
 //-----------------------------------------------------------------------------
 vtkSMUndoStack::vtkSMUndoStack()
@@ -201,8 +239,8 @@ void vtkSMUndoStack::Push(vtkIdType cid, const char* label, vtkUndoSet* set)
     }
   
   vtkPVXMLElement* state = set->SaveState(NULL);
-//    if (!this->ClientOnly)
-//      state->PrintXML();
+  //if (!this->ClientOnly)
+  //  state->PrintXML();
 
   /*
    * FIXME: Until we start supporting multiple client, it really unnecessary to push
@@ -256,8 +294,11 @@ int vtkSMUndoStack::ProcessUndo(vtkIdType id, vtkPVXMLElement* root)
     this->SetStateLoader(sl);
     sl->Delete();
     }
-  this->StateLoader->SetConnectionID(id); 
-  vtkUndoSet* undo = this->StateLoader->LoadUndoRedoSet(root);
+
+  vtkSMIdBasedProxyLocator* locator = vtkSMIdBasedProxyLocator::New();
+  locator->SetConnectionID(id);
+  locator->SetDeserializer(this->StateLoader);
+  vtkUndoSet* undo = this->StateLoader->LoadUndoRedoSet(root, locator);
   int status = 0;
   if (undo)
     {
@@ -266,10 +307,7 @@ int vtkSMUndoStack::ProcessUndo(vtkIdType id, vtkPVXMLElement* root)
     // Update modified proxies.
     // vtkSMProxyManager::GetProxyManager()->UpdateRegisteredProxies(1);
     }
-
-  // This is essential otherwise we have un-intentional references to proxies
-  // in the state loader.
-  this->StateLoader->ClearCreatedProxies();
+  locator->Delete();
   return status;
 }
 
@@ -282,8 +320,11 @@ int vtkSMUndoStack::ProcessRedo(vtkIdType id, vtkPVXMLElement* root)
     this->SetStateLoader(sl);
     sl->Delete();
     }
-  this->StateLoader->SetConnectionID(id); 
-  vtkUndoSet* redo = this->StateLoader->LoadUndoRedoSet(root);
+
+  vtkSMIdBasedProxyLocator* locator = vtkSMIdBasedProxyLocator::New();
+  locator->SetConnectionID(id);
+  locator->SetDeserializer(this->StateLoader);
+  vtkUndoSet* redo = this->StateLoader->LoadUndoRedoSet(root, locator);
   int status = 0;
   if (redo)
     {
@@ -292,14 +333,10 @@ int vtkSMUndoStack::ProcessRedo(vtkIdType id, vtkPVXMLElement* root)
     // Update modified proxies.
     // vtkSMProxyManager::GetProxyManager()->UpdateRegisteredProxies(1);
     }
-
-  // This is essential otherwise we have un-intentional references to proxies
-  // in the state loader.
-  this->StateLoader->ClearCreatedProxies();
+  locator->Delete();
   return status;
 }
 
-
 //-----------------------------------------------------------------------------
 int vtkSMUndoStack::Undo()
 {
@@ -380,3 +417,17 @@ void vtkSMUndoStack::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "ClientOnly: " << this->ClientOnly << endl;
 }
 
+//-----------------------------------------------------------------------------
+//begin vistrails
+vtkUndoSet* vtkSMUndoStack::getLastUndoSet() {
+  if (this->Internal->UndoStack.empty())
+    {
+    return NULL;
+    }
+  vtkSMUndoStackUndoSet *us = 
+    vtkSMUndoStackUndoSet::SafeDownCast(
+      this->Internal->UndoStack.back().UndoSet.GetPointer());
+  return us->getLastUndoSet();
+}
+//end vistrails
+
