@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMUnstructuredGridParallelStrategy.h,v $
+  Module:    vtkSMUnstructuredGridParallelStrategy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -27,7 +27,7 @@ class VTK_EXPORT vtkSMUnstructuredGridParallelStrategy : public vtkSMUnstructure
 {
 public:
   static vtkSMUnstructuredGridParallelStrategy* New();
-  vtkTypeRevisionMacro(vtkSMUnstructuredGridParallelStrategy, vtkSMUnstructuredDataParallelStrategy);
+  vtkTypeMacro(vtkSMUnstructuredGridParallelStrategy, vtkSMUnstructuredDataParallelStrategy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
 //BTX
