@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMUpdateSuppressorProxy.h,v $
+  Module:    vtkSMUpdateSuppressorProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,9 +26,22 @@ class VTK_EXPORT vtkSMUpdateSuppressorProxy : public vtkSMSourceProxy
 {
 public:
   static vtkSMUpdateSuppressorProxy* New();
-  vtkTypeRevisionMacro(vtkSMUpdateSuppressorProxy, vtkSMSourceProxy);
+  vtkTypeMacro(vtkSMUpdateSuppressorProxy, vtkSMSourceProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
+  //// Description:
+  //// Calls Update() on all sources. It also creates output ports if
+  //// they are not already created.
+  //virtual void UpdatePipeline();
+
+  //// Description:
+  //// Calls Update() on all sources with the given time request. 
+  //// It also creates output ports if they are not already created.
+  //virtual void UpdatePipeline(double time);
+
+  // Description:
+  // Results in calling ForceUpdate() if the pipeline is dirty. 
+  void ForceUpdate();
 
 protected:
   vtkSMUpdateSuppressorProxy();
