@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMViewProxy.cxx,v $
+  Module:    vtkSMViewProxy.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -122,7 +122,6 @@ void vtkSMViewProxy::CleanMultiViewInitializer()
 }
 
 vtkStandardNewMacro(vtkSMViewProxy);
-vtkCxxRevisionMacro(vtkSMViewProxy, "$Revision: 1.18 $");
 
 vtkInformationKeyMacro(vtkSMViewProxy, USE_CACHE, Integer);
 vtkInformationKeyMacro(vtkSMViewProxy, CACHE_TIME, Double);
@@ -155,6 +154,8 @@ vtkSMViewProxy::vtkSMViewProxy()
   this->Information->Set(CACHE_TIME(), this->CacheTime);
 
   this->InRender = false;
+
+  this->NewStrategyHelper = NULL;
 }
 
 //----------------------------------------------------------------------------
@@ -273,14 +274,6 @@ void vtkSMViewProxy::AddRepresentationInternal(vtkSMRepresentationProxy* repr)
 
   this->Representations->AddItem(repr);
 
-  // If representation is modified, we invalidate the data information.
-  repr->AddObserver(vtkCommand::ModifiedEvent, this->Observer);
-
-  // If representation pipeline is updated, we invalidate the data info.
-  repr->AddObserver(vtkCommand::EndEvent, this->Observer);
-
-  // repr->AddObserver(vtkCommand::SelectionChanged, this->Observer);
-
   // Pass the view update time to the representation.
   if (this->ViewUpdateTimeInitialized)
     {
@@ -304,8 +297,6 @@ void vtkSMViewProxy::RemoveRepresentationInternal(vtkSMRepresentationProxy* repr
   this->InvalidateDataSizes();
 
   repr->SetViewInformation(0);
-
-  repr->RemoveObserver(this->Observer);
   this->Representations->RemoveItem(repr);
   // Don't access repr after removing, it may be already deleted.
 }
@@ -366,6 +357,10 @@ void vtkSMViewProxy::StillRender()
     }
 
   this->InRender = true;
+  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
+  pm->SendPrepareProgress(this->ConnectionID);
+
+  this->InvalidateDataSizes();
 
   this->BeginStillRender();
 
@@ -374,6 +369,7 @@ void vtkSMViewProxy::StillRender()
   this->PerformRender();
 
   this->EndStillRender();
+  pm->SendCleanupPendingProgress(this->ConnectionID);
   this->InRender = false;
 }
 
@@ -386,6 +382,10 @@ void vtkSMViewProxy::InteractiveRender()
     }
 
   this->InRender = true;
+  vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
+  pm->SendPrepareProgress(this->ConnectionID);
+
+  this->InvalidateDataSizes();
 
   this->BeginInteractiveRender();
 
@@ -394,6 +394,7 @@ void vtkSMViewProxy::InteractiveRender()
   this->PerformRender();
 
   this->EndInteractiveRender();
+  pm->SendCleanupPendingProgress(this->ConnectionID);
   this->InRender = false;
 }
 
@@ -401,15 +402,11 @@ void vtkSMViewProxy::InteractiveRender()
 void vtkSMViewProxy::UpdateAllRepresentations()
 {
   vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
+  pm->SendPrepareProgress(this->ConnectionID);
+
   vtkSmartPointer<vtkCollectionIterator> iter;
   iter.TakeReference(this->Representations->NewIterator());
 
-  // We are calling SendPrepareProgress-SendCleanupPendingProgress
-  // only if any representation is indeed going to update. 
-  // I wonder of this condition is required and we can;t always
-  // called these methods. But since there's minimal effort in calling 
-  // these conditionally, I am letting it be (erring on the safer side).
-  bool enable_progress = false;
   for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
     {
     vtkSMRepresentationProxy* repr = 
@@ -419,24 +416,9 @@ void vtkSMViewProxy::UpdateAllRepresentations()
       // Invisible representations are not updated.
       continue;
       }
-
-    if (!enable_progress && repr->UpdateRequired())
-      {
-      // If a representation required an update, than it implies that the
-      // update will result in progress events. We don't to ignore those
-      // progress events, hence we enable progress handling.
-      pm->SendPrepareProgress(this->ConnectionID,
-        vtkProcessModule::CLIENT | vtkProcessModule::DATA_SERVER);
-      enable_progress = true;
-      }
-
     repr->Update(this);
     }
-
-  if (enable_progress)
-    {
-    pm->SendCleanupPendingProgress(this->ConnectionID);
-    }
+  pm->SendCleanupPendingProgress(this->ConnectionID);
 }
 
 //----------------------------------------------------------------------------
@@ -446,13 +428,6 @@ void vtkSMViewProxy::ProcessEvents(vtkObject* caller, unsigned long eventId,
   (void)caller;
   (void)eventId;
   (void)callData;
-
-  if (vtkSMRepresentationProxy::SafeDownCast(caller) && 
-    ( eventId == vtkCommand::ModifiedEvent  ||
-      eventId == vtkCommand::EndEvent))
-    {
-    this->InvalidateDataSizes();
-    }
 }
 
 //-----------------------------------------------------------------------------
@@ -496,8 +471,6 @@ unsigned long vtkSMViewProxy::GetVisibleDisplayedDataSize()
     {
     this->DisplayedDataSize = 0;
 
-    bool enable_progress = false;
-    vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
     vtkSmartPointer<vtkCollectionIterator> iter;
     iter.TakeReference(this->Representations->NewIterator());
     for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
@@ -509,23 +482,10 @@ unsigned long vtkSMViewProxy::GetVisibleDisplayedDataSize()
         // Skip invisible representations.
         continue;
         }
-      if (!enable_progress && repr->UpdateRequired())
-        {
-        // If a representation required an update, than it implies that the
-        // update will result in progress events. We don't to ignore those
-        // progress events, hence we enable progress handling.
-        pm->SendPrepareProgress(this->ConnectionID,
-          vtkProcessModule::CLIENT | vtkProcessModule::DATA_SERVER);
-        enable_progress = true;
-        }
       // This may partially update the representation pipeline to obtain correct
       // data size information.
       this->DisplayedDataSize += repr->GetDisplayedMemorySize();
       }
-    if (enable_progress)
-      {
-      pm->SendCleanupPendingProgress(this->ConnectionID);
-      }
     this->DisplayedDataSizeValid = true;
     }
 
@@ -539,8 +499,6 @@ unsigned long vtkSMViewProxy::GetVisibileFullResDataSize()
     {
     this->FullResDataSize = 0;
 
-    bool enable_progress = false;
-    vtkProcessModule* pm = vtkProcessModule::GetProcessModule();
     vtkSmartPointer<vtkCollectionIterator> iter;
     iter.TakeReference(this->Representations->NewIterator());
     for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); iter->GoToNextItem())
@@ -552,24 +510,11 @@ unsigned long vtkSMViewProxy::GetVisibileFullResDataSize()
         // Skip invisible representations.
         continue;
         }
-      if (!enable_progress && repr->UpdateRequired())
-        {
-        // If a representation required an update, than it implies that the
-        // update will result in progress events. We don't to ignore those
-        // progress events, hence we enable progress handling.
-        pm->SendPrepareProgress(this->ConnectionID,
-          vtkProcessModule::CLIENT | vtkProcessModule::DATA_SERVER);
-        enable_progress = true;
-        }
-
+    
       // This may partially update the representation pipeline to obtain correct
       // data size information.
       this->FullResDataSize += repr->GetFullResMemorySize();
       }
-    if (enable_progress)
-      {
-      pm->SendCleanupPendingProgress(this->ConnectionID);
-      }
     this->FullResDataSizeValid = true;
     }
 
