@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkSMViewProxy.h,v $
+  Module:    vtkSMViewProxy.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -42,7 +42,7 @@ class VTK_EXPORT vtkSMViewProxy : public vtkSMProxy
 {
 public:
   static vtkSMViewProxy* New();
-  vtkTypeRevisionMacro(vtkSMViewProxy, vtkSMProxy);
+  vtkTypeMacro(vtkSMViewProxy, vtkSMProxy);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -117,7 +117,7 @@ public:
   // Create a default representation for the given output port of source proxy.
   // Returns a new proxy.
   virtual vtkSMRepresentationProxy* CreateDefaultRepresentation(vtkSMProxy*, int opport);
-  virtual vtkSMRepresentationProxy* CreateDefaultRepresentation(vtkSMProxy* proxy)
+  vtkSMRepresentationProxy* CreateDefaultRepresentation(vtkSMProxy* proxy)
     { return this->CreateDefaultRepresentation(proxy, 0); }
 
 
@@ -157,6 +157,37 @@ public:
     return this->GetXMLName();
     }
 
+  // Description:
+  // Views keep this false to schedule additional passes.
+  virtual int GetDisplayDone() { return 1; }
+
+  // Description:
+  // Implementation to create a representation requested strategy. 
+  //DDM TODO Do I have to make this public?
+  virtual vtkSMRepresentationStrategy* NewStrategyInternal(
+    int vtkNotUsed(dataType))
+    { return 0; }
+
+  //Description:
+  // When set, strategy creation will defer to the otherView.
+  // Note this is not reference counted to avoid circular dependency
+  void SetNewStrategyHelper(vtkSMViewProxy *otherView)
+  {
+    this->NewStrategyHelper = otherView;
+  }
+  vtkGetObjectMacro(NewStrategyHelper, vtkSMViewProxy);
+
+  // Collection of representation objects added to this view.
+  vtkCollection* Representations; //DDM TODO Do I have to make this public?
+
+  // Description:
+  // Called by AddRepresentation(). Subclasses can override to add 
+  // observers etc. //DDM TODO Do I have to make this public?
+  virtual void AddRepresentationInternal(vtkSMRepresentationProxy* rep);
+
+  //Description: For streaming provide a hook to stop multipass rendering.
+  virtual void Interrupt() {};
+
 //BTX
 protected:
   vtkSMViewProxy();
@@ -203,11 +234,6 @@ protected:
   // Called at the end of CreateVTKObjects().
   virtual void EndCreateVTKObjects() {};
 
-  // Description:
-  // Called by AddRepresentation(). Subclasses can override to add 
-  // observers etc.
-  virtual void AddRepresentationInternal(vtkSMRepresentationProxy* rep);
-
   // Description:
   // Called by RemoveRepresentation(). Subclasses can override to remove 
   // observers etc.
@@ -228,12 +254,6 @@ protected:
   // Called to create the vtk objects.
   virtual void CreateVTKObjects();
 
-  // Description:
-  // Implementation to create a representation requested strategy.
-  virtual vtkSMRepresentationStrategy* NewStrategyInternal(
-    int vtkNotUsed(dataType))
-    { return 0; }
-
   // Description:
   // Equivaluent to 
   // vtkSMProxyProperty::SafeDownCast(consumer)->GetProperty(
@@ -270,9 +290,6 @@ protected:
   // Default implementation is empty.
   virtual void InitializeForMultiView(vtkSMViewProxy* vtkNotUsed(otherView)) {}
 
-  // Collection of representation objects added to this view.
-  vtkCollection* Representations;
-
   // Information object used to keep rendering specific information.
   // It is passed to the representations added to the view.
   vtkInformation* Information;
@@ -286,6 +303,9 @@ protected:
 
   vtkSetStringMacro(DefaultRepresentationName);
   char* DefaultRepresentationName;
+
+  vtkSMViewProxy *NewStrategyHelper;
+
 private:
   vtkSMViewProxy(const vtkSMViewProxy&); // Not implemented
   void operator=(const vtkSMViewProxy&); // Not implemented
