@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkClientServerInterpreter.cxx,v $
+  Module:    vtkClientServerInterpreter.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,13 +26,12 @@
 #include <sys/stat.h>
 
 vtkStandardNewMacro(vtkClientServerInterpreter);
-vtkCxxRevisionMacro(vtkClientServerInterpreter, "$Revision: 1.17 $");
 
 //----------------------------------------------------------------------------
 class vtkClientServerInterpreterInternals
 {
 public:
-  typedef vtkstd::vector<vtkClientServerNewInstanceFunction> NewInstanceFunctionsType;
+  typedef vtkstd::map<vtkstd::string, vtkClientServerNewInstanceFunction> NewInstanceFunctionsType;
   typedef vtkstd::map<vtkstd::string, vtkClientServerCommandFunction> ClassToFunctionMapType;
   typedef vtkstd::map<vtkTypeUInt32, vtkClientServerStream*> IDToMessageMapType;
   NewInstanceFunctionsType NewInstanceFunctions;
@@ -304,15 +303,10 @@ vtkClientServerInterpreter
 
     // Find a NewInstance function that knows about the class.
     int created = 0;
-    for(vtkClientServerInterpreterInternals::NewInstanceFunctionsType::iterator
-          it = this->Internal->NewInstanceFunctions.begin();
-        !created && it != this->Internal->NewInstanceFunctions.end(); ++it)
+    if(vtkClientServerNewInstanceFunction n = this->Internal->NewInstanceFunctions[cname])
       {
-      // Try this new-instance function.
-      if((*(*it))(this, cname, id))
-        {
-        created = 1;
-        }
+      this->NewInstance(n(),id);
+      created =1;
       }
     if(created)
       {
@@ -737,12 +731,11 @@ vtkClientServerInterpreter::GetCommandFunction(vtkObjectBase* obj)
     }
 }
 
-//----------------------------------------------------------------------------
 void
-vtkClientServerInterpreter
-::AddNewInstanceFunction(vtkClientServerNewInstanceFunction f)
+vtkClientServerInterpreter::AddNewInstanceFunction(const char* name,
+                                                   vtkClientServerNewInstanceFunction f)
 {
-  this->Internal->NewInstanceFunctions.push_back(f);
+  this->Internal->NewInstanceFunctions[name]=f;
 }
 
 //----------------------------------------------------------------------------
