@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVPythonInteractiveInterpretor.cxx,v $
+  Module:    vtkPVPythonInteractiveInterpretor.cxx
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -26,7 +26,6 @@ public:
 };
 
 vtkStandardNewMacro(vtkPVPythonInteractiveInterpretor);
-vtkCxxRevisionMacro(vtkPVPythonInteractiveInterpretor, "$Revision: 1.4 $");
 //----------------------------------------------------------------------------
 vtkPVPythonInteractiveInterpretor::vtkPVPythonInteractiveInterpretor()
 {
