@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   ParaView
-  Module:    $RCSfile: vtkPVPythonInterpretor.h,v $
+  Module:    vtkPVPythonInterpretor.h
 
   Copyright (c) Kitware, Inc.
   All rights reserved.
@@ -34,7 +34,7 @@ class VTK_EXPORT vtkPVPythonInterpretor : public vtkObject
 {
 public:
   static vtkPVPythonInterpretor* New();
-  vtkTypeRevisionMacro(vtkPVPythonInterpretor, vtkObject);
+  vtkTypeMacro(vtkPVPythonInterpretor, vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -115,6 +115,8 @@ protected:
   // Initialize the interpretor.
   virtual void InitializeInternal();
 
+  void AddPythonPathInternal(const char* path);
+
   char* ExecutablePath;
   vtkSetStringMacro(ExecutablePath);
 
@@ -124,6 +126,7 @@ protected:
 
   void DumpError(const char* string);
   void DumpOutput(const char* string);
+  vtkStdString GetInputLine();
   
 private:
   vtkPVPythonInterpretor(const vtkPVPythonInterpretor&); // Not implemented.
