@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkMath.h,v $
+  Module:    vtkMath.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -12,14 +12,14 @@
      PURPOSE.  See the above copyright notice for more information.
 
 =========================================================================
-  Copyright 2007 Sandia Corporation.
+  Copyright 2008 Sandia Corporation.
   Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
   license for use of this work by or on behalf of the
   U.S. Government. Redistribution and use in source and binary forms, with
   or without modification, are permitted provided that this Notice and any
   statement of authorship are reproduced on all copies.
 
-  Contact: pppebay@ca.sandia.gov,dcthomp@sandia.gov
+  Contact: pppebay@sandia.gov,dcthomp@sandia.gov
 
 =========================================================================*/
 // .NAME vtkMath - performs common math operations
@@ -28,12 +28,16 @@
 // include providing constants such as Pi; conversion from degrees to 
 // radians; vector operations such as dot and cross products and vector 
 // norm; matrix determinant for 2x2 and 3x3 matrices; univariate polynomial
-// solvers; and random number generation.
+// solvers; and for random number generation (for backward compatibility only).
+// .SECTION See Also
+// vtkMinimalStandardRandomSequence, vtkBoxMuellerRandomSequence
 
 #ifndef __vtkMath_h
 #define __vtkMath_h
 
 #include "vtkObject.h"
+#include "vtkPolynomialSolversUnivariate.h" // For backwards compatibility of old solvers
+
 #include <assert.h> // assert() in inline implementations.
 
 #ifndef DBL_EPSILON
@@ -43,37 +47,65 @@
 #endif  // DBL_EPSILON
 
 class vtkDataArray;
+class vtkPoints;
+class vtkMathInternal;
+class vtkMinimalStandardRandomSequence;
+class vtkBoxMuellerRandomSequence;
 
 class VTK_COMMON_EXPORT vtkMath : public vtkObject
 {
 public:
   static vtkMath *New();
-  vtkTypeRevisionMacro(vtkMath,vtkObject);
+  vtkTypeMacro(vtkMath,vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
-  // Useful constants.
-  static float Pi() {return 3.14159265358979f;};
-  static float DegreesToRadians() {return 0.017453292f;};
-  static float RadiansToDegrees() {return 57.2957795131f;};
+  // A mathematical constant. This version is 3.14159265358979f.
+  static float Pi() { return 3.14159265358979f; };
 
   // Description:
-  // Useful constants. (double-precision version)
-  static double DoubleDegreesToRadians() {return 0.017453292519943295;};
-  static double DoublePi() {return 3.1415926535897932384626;};
-  static double DoubleRadiansToDegrees() {return 57.29577951308232;};
+  // A mathematical constant (double-precision version). This version 
+  // is 6.283185307179586.
+  static double DoubleTwoPi() { return  6.283185307179586; };
+
+  // Description:
+  // A mathematical constant (double-precision version). This version
+  // is 3.1415926535897932384626.
+  static double DoublePi() { return 3.1415926535897932384626; };
+
+  // Description:
+  // Convert degrees into radians
+  static float RadiansFromDegrees( float degrees);
+  static double RadiansFromDegrees( double degrees);
+
+  // Description:
+  // Convert radians into degrees
+  static float DegreesFromRadians( float radians);
+  static double DegreesFromRadians( double radians);
+
+  // Description:
+  // @deprecated Replaced by vtkMath::RadiansFromDegrees() as of VTK 5.4.
+  VTK_LEGACY(static float DegreesToRadians());
+  VTK_LEGACY(static double DoubleDegreesToRadians());
+
+  // Description:
+  // @deprecated Replaced by vtkMath::DegreesFromRadians() as of VTK 5.4.
+  VTK_LEGACY(static float RadiansToDegrees());
+  VTK_LEGACY(static double DoubleRadiansToDegrees());
 
   // Description:
   // Rounds a float to the nearest integer.
   static int Round(float f) {
-    return static_cast<int>(f + (f >= 0 ? 0.5 : -0.5)); }
+    return static_cast<int>( f + ( f >= 0 ? 0.5 : -0.5 ) ); }
   static int Round(double f) {
-    return static_cast<int>(f + (f >= 0 ? 0.5 : -0.5)); }
+    return static_cast<int>( f + ( f >= 0 ? 0.5 : -0.5 ) ); }
 
+  // Description:
+  // Rounds a double to the nearest integer less than itself.
   static int Floor(double x);
   
   // Description:
-  // Compute N factorial, N! = N*(N-1)*(N-2)...*3*2*1.
+  // Compute N factorial, N! = N*(N-1) * (N-2)...*3*2*1.
   // 0! is taken to be 1.
   static vtkTypeInt64 Factorial( int N );
 
@@ -109,54 +141,179 @@ public:
   // Free the "iterator" array created by vtkMath::BeginCombination.
   static void FreeCombination( int* combination);
 
+  // Description:
+  // Initialize seed value. NOTE: Random() has the bad property that 
+  // the first random number returned after RandomSeed() is called 
+  // is proportional to the seed value! To help solve this, call 
+  // RandomSeed() a few times inside seed. This doesn't ruin the 
+  // repeatability of Random().
+  //
+  // DON'T USE Random(), RandomSeed(), GetSeed(), Gaussian()
+  // THIS IS STATIC SO THIS IS PRONE TO ERRORS (SPECIALLY FOR REGRESSION TESTS)
+  // THIS IS HERE FOR BACKWARD COMPATIBILITY ONLY.
+  // Instead, for a sequence of random numbers with a uniform distribution
+  // create a vtkMinimalStandardRandomSequence object.
+  // For a sequence of random numbers with a gaussian/normal distribution
+  // create a vtkBoxMuellerRandomSequence object.
+  static void RandomSeed(int s);  
+
+  // Description:
+  // Return the current seed used by the random number generator.
+  //
+  // DON'T USE Random(), RandomSeed(), GetSeed(), Gaussian()
+  // THIS IS STATIC SO THIS IS PRONE TO ERRORS (SPECIALLY FOR REGRESSION TESTS)
+  // THIS IS HERE FOR BACKWARD COMPATIBILITY ONLY.
+  // Instead, for a sequence of random numbers with a uniform distribution
+  // create a vtkMinimalStandardRandomSequence object.
+  // For a sequence of random numbers with a gaussian/normal distribution
+  // create a vtkBoxMuellerRandomSequence object.
+  static int GetSeed();
+  
+  // Description:
+  // Generate pseudo-random numbers distributed according to the uniform 
+  // distribution between 0.0 and 1.0.
+  // This is used to provide portability across different systems.
+  //
+  // DON'T USE Random(), RandomSeed(), GetSeed(), Gaussian()
+  // THIS IS STATIC SO THIS IS PRONE TO ERRORS (SPECIALLY FOR REGRESSION TESTS)
+  // THIS IS HERE FOR BACKWARD COMPATIBILITY ONLY.
+  // Instead, for a sequence of random numbers with a uniform distribution
+  // create a vtkMinimalStandardRandomSequence object.
+  // For a sequence of random numbers with a gaussian/normal distribution
+  // create a vtkBoxMuellerRandomSequence object.
+  static double Random();  
+
+  // Description:
+  // Generate  pseudo-random numbers distributed according to the uniform 
+  // distribution between \a min and \a max.
+  //
+  // DON'T USE Random(), RandomSeed(), GetSeed(), Gaussian()
+  // THIS IS STATIC SO THIS IS PRONE TO ERRORS (SPECIALLY FOR REGRESSION TESTS)
+  // THIS IS HERE FOR BACKWARD COMPATIBILITY ONLY.
+  // Instead, for a sequence of random numbers with a uniform distribution
+  // create a vtkMinimalStandardRandomSequence object.
+  // For a sequence of random numbers with a gaussian/normal distribution
+  // create a vtkBoxMuellerRandomSequence object.
+  static double Random( double min, double max );
+
+  // Description:
+  // Generate pseudo-random numbers distributed according to the standard
+  // normal distribution.
+  //
+  // DON'T USE Random(), RandomSeed(), GetSeed(), Gaussian()
+  // THIS IS STATIC SO THIS IS PRONE TO ERRORS (SPECIALLY FOR REGRESSION TESTS)
+  // THIS IS HERE FOR BACKWARD COMPATIBILITY ONLY.
+  // Instead, for a sequence of random numbers with a uniform distribution
+  // create a vtkMinimalStandardRandomSequence object.
+  // For a sequence of random numbers with a gaussian/normal distribution
+  // create a vtkBoxMuellerRandomSequence object.
+  static double Gaussian();  
+
+  // Description:
+  // Generate  pseudo-random numbers distributed according to the Gaussian
+  // distribution with mean \a mean and standard deviation \a std.
+  //
+  // DON'T USE Random(), RandomSeed(), GetSeed(), Gaussian()
+  // THIS IS STATIC SO THIS IS PRONE TO ERRORS (SPECIALLY FOR REGRESSION TESTS)
+  // THIS IS HERE FOR BACKWARD COMPATIBILITY ONLY.
+  // Instead, for a sequence of random numbers with a uniform distribution
+  // create a vtkMinimalStandardRandomSequence object.
+  // For a sequence of random numbers with a gaussian/normal distribution
+  // create a vtkBoxMuellerRandomSequence object.
+  static double Gaussian( double mean, double std );
+
+  // Description:
+  // Addition of two 3-vectors (float version). Result is stored in c.
+  static void Add(const float a[3], const float b[3], float c[3]) {
+    for (int i = 0; i < 3; ++i)
+      c[i] = a[i] + b[i];
+  }
+
+  // Description:
+  // Addition of two 3-vectors (double version). Result is stored in c.
+  static void Add(const double a[3], const double b[3], double c[3]) {
+    for (int i = 0; i < 3; ++i)
+      c[i] = a[i] + b[i];
+  }
+
+  // Description:
+  // Subtraction of two 3-vectors (float version). Result is stored in c according to c = a - b.
+  static void Subtract(const float a[3], const float b[3], float c[3]) {
+    for (int i = 0; i < 3; ++i)
+      c[i] = a[i] - b[i];
+  }
+
+  // Description:
+  // Subtraction of two 3-vectors (double version). Result is stored in c according to c = a - b.
+  static void Subtract(const double a[3], const double b[3], double c[3]) {
+    for (int i = 0; i < 3; ++i)
+      c[i] = a[i] - b[i];
+  }
+
+  // Description:
+  // Multiplies a 3-vector by a scalar (float version).
+  // This modifies the input 3-vector.
+  static void MultiplyScalar(float a[3], float s) {
+    for (int i = 0; i < 3; ++i)
+      a[i] *= s;
+  }
+
+  // Description:
+  // Multiplies a 3-vector by a scalar (double version).
+  // This modifies the input 3-vector.
+  static void MultiplyScalar(double a[3], double s) {
+    for (int i = 0; i < 3; ++i)
+      a[i] *= s;
+  }
+
   // Description:
   // Dot product of two 3-vectors (float version).
   static float Dot(const float x[3], const float y[3]) {
-    return (x[0]*y[0] + x[1]*y[1] + x[2]*y[2]);};
+    return ( x[0] * y[0] + x[1] * y[1] + x[2] * y[2] );};
 
   // Description:
   // Dot product of two 3-vectors (double-precision version).
   static double Dot(const double x[3], const double y[3]) {
-    return (x[0]*y[0] + x[1]*y[1] + x[2]*y[2]);};
+    return ( x[0] * y[0] + x[1] * y[1] + x[2] * y[2] );};
   
   // Description:
   // Outer product of two 3-vectors (float version).
   static void Outer(const float x[3], const float y[3], float A[3][3]) {
     for (int i=0; i < 3; i++)
       for (int j=0; j < 3; j++)
-        A[i][j] = x[i]*y[j];
+        A[i][j] = x[i] * y[j];
   }
   // Description:
   // Outer product of two 3-vectors (double-precision version).
   static void Outer(const double x[3], const double y[3], double A[3][3]) {
     for (int i=0; i < 3; i++)
       for (int j=0; j < 3; j++)
-        A[i][j] = x[i]*y[j];
+        A[i][j] = x[i] * y[j];
   }
 
   // Description:
-  // Cross product of two 3-vectors. Result vector in z[3].
+  // Cross product of two 3-vectors. Result (a x b) is stored in z.
   static void Cross(const float x[3], const float y[3], float z[3]);
 
   // Description:
-  // Cross product of two 3-vectors. Result vector in z[3]. (double-precision
+  // Cross product of two 3-vectors. Result (a x b) is stored in z. (double-precision
   // version)
   static void Cross(const double x[3], const double y[3], double z[3]);
 
   // Description:
-  // Compute the norm of n-vector.
+  // Compute the norm of n-vector. x is the vector, n is its length.
   static float Norm(const float* x, int n); 
   static double Norm(const double* x, int n); 
 
   // Description:
   // Compute the norm of 3-vector.
   static float Norm(const float x[3]) {
-    return static_cast<float> (sqrt(x[0]*x[0] + x[1]*x[1] + x[2]*x[2]));};
+    return static_cast<float> (sqrt( x[0] * x[0] + x[1] * x[1] + x[2] * x[2] ) );};
   
   // Description:
   // Compute the norm of 3-vector (double-precision version).
   static double Norm(const double x[3]) {
-    return sqrt(x[0]*x[0] + x[1]*x[1] + x[2]*x[2]);};
+    return sqrt( x[0] * x[0] + x[1] * x[1] + x[2] * x[2] );};
   
   // Description:
   // Normalize (in place) a 3-vector. Returns norm of vector.
@@ -179,81 +336,87 @@ public:
                              double theta);
 
   // Description:
-  // Compute distance squared between two points.
+  // Compute distance squared between two points x and y.
   static float Distance2BetweenPoints(const float x[3], const float y[3]);
 
   // Description:
-  // Compute distance squared between two points (double precision version).
+  // Compute distance squared between two points x and y(double precision version).
   static double Distance2BetweenPoints(const double x[3], const double y[3]);
 
   // Description:
-  // Dot product of two 2-vectors. The third (z) component is ignored.
-  static float Dot2D(const float x[3], const float y[3]) {
-    return (x[0]*y[0] + x[1]*y[1]);};
+  // Dot product of two 2-vectors.
+  static float Dot2D(const float x[2], const float y[2]) {
+    return ( x[0] * y[0] + x[1] * y[1] );};
   
   // Description:
-  // Dot product of two 2-vectors. The third (z) component is
-  // ignored (double-precision version).
-  static double Dot2D(const double x[3], const double y[3]) {
-    return (x[0]*y[0] + x[1]*y[1]);};
+  // Dot product of two 2-vectors. (double-precision version).
+  static double Dot2D(const double x[2], const double y[2]) {
+    return ( x[0] * y[0] + x[1] * y[1] );};
 
   // Description:
-  // Outer product of two 2-vectors (float version). z-comp is ignored
-  static void Outer2D(const float x[3], const float y[3], float A[3][3]) {
+  // Outer product of two 2-vectors (float version).
+  static void Outer2D(const float x[2], const float y[2], float A[2][2]) 
+    {
     for (int i=0; i < 2; i++)
+      {
       for (int j=0; j < 2; j++)
-        A[i][j] = x[i]*y[j];
-  }
+        {
+        A[i][j] = x[i] * y[j];
+        }
+      }
+    }
   // Description:
-  // Outer product of two 2-vectors (float version). z-comp is ignored
-  static void Outer2D(const double x[3], const double y[3], double A[3][3]) {
+  // Outer product of two 2-vectors (float version).
+  static void Outer2D(const double x[2], const double y[2], double A[2][2]) 
+    {
     for (int i=0; i < 2; i++)
+      {
       for (int j=0; j < 2; j++)
-        A[i][j] = x[i]*y[j];
-  }
+        {
+        A[i][j] = x[i] * y[j];
+        }
+      }
+    }
 
   // Description:
-  // Compute the norm of a 2-vector. Ignores z-component.
-  static float Norm2D(const float x[3]) {
-    return static_cast<float> (sqrt(x[0]*x[0] + x[1]*x[1]));};
+  // Compute the norm of a 2-vector.
+  static float Norm2D(const float x[2]) {
+    return static_cast<float> (sqrt( x[0] * x[0] + x[1] * x[1] ) );};
 
   // Description:
-  // Compute the norm of a 2-vector. Ignores z-component
+  // Compute the norm of a 2-vector.
   // (double-precision version).
-  static double Norm2D(const double x[3]) {
-    return sqrt(x[0]*x[0] + x[1]*x[1]);};
+  static double Norm2D(const double x[2]) {
+    return sqrt( x[0] * x[0] + x[1] * x[1] );};
 
   // Description:
-  // Normalize (in place) a 2-vector. Returns norm of vector. Ignores
-  // z-component.
-  static float Normalize2D(float x[3]);
+  // Normalize (in place) a 2-vector. Returns norm of vector.
+  static float Normalize2D(float x[2]);
 
   // Description:
-  // Normalize (in place) a 2-vector. Returns norm of vector. Ignores
-  // z-component (double-precision version).
-  static double Normalize2D(double x[3]);
+  // Normalize (in place) a 2-vector. Returns norm of vector.
+  // (double-precision version).
+  static double Normalize2D(double x[2]);
 
   // Description:
   // Compute determinant of 2x2 matrix. Two columns of matrix are input.
   static float Determinant2x2(const float c1[2], const float c2[2]) {
-    return (c1[0]*c2[1] - c2[0]*c1[1]);};
+    return (c1[0] * c2[1] - c2[0] * c1[1] );};
 
   // Description:
   // Calculate the determinant of a 2x2 matrix: | a b | | c d |
   static double Determinant2x2(double a, double b, double c, double d) {
     return (a * d - b * c);};
   static double Determinant2x2(const double c1[2], const double c2[2]) {
-    return (c1[0]*c2[1] - c2[0]*c1[1]);};
+    return (c1[0] * c2[1] - c2[0] * c1[1] );};
 
   // Description:
-  // LU Factorization of a 3x3 matrix.  The diagonal elements are the
-  // multiplicative inverse of those in the standard LU factorization.
+  // LU Factorization of a 3x3 matrix.
   static void LUFactor3x3(float A[3][3], int index[3]);
   static void LUFactor3x3(double A[3][3], int index[3]);
 
   // Description:
-  // LU back substitution for a 3x3 matrix.  The diagonal elements are the
-  // multiplicative inverse of those in the standard LU factorization.
+  // LU back substitution for a 3x3 matrix.
   static void LUSolve3x3(const float A[3][3], const int index[3], 
                          float x[3]);
   static void LUSolve3x3(const double A[3][3], const int index[3], 
@@ -291,12 +454,14 @@ public:
                              double **C);
 
   // Description:
-  // Transpose a 3x3 matrix.
+  // Transpose a 3x3 matrix. The input matrix is A. The output
+  // is stored in AT.
   static void Transpose3x3(const float A[3][3], float AT[3][3]);
   static void Transpose3x3(const double A[3][3], double AT[3][3]);
 
   // Description:
-  // Invert a 3x3 matrix.
+  // Invert a 3x3 matrix. The input matrix is A. The output is
+  // stored in AI.
   static void Invert3x3(const float A[3][3], float AI[3][3]);
   static void Invert3x3(const double A[3][3], double AI[3][3]);
 
@@ -429,27 +594,6 @@ public:
   // only: see Conte and de Boor, Elementary Numerical Analysis.)
   static double EstimateMatrixCondition(double **A, int size);
 
-  // Description:
-  // Initialize seed value. NOTE: Random() has the bad property that 
-  // the first random number returned after RandomSeed() is called 
-  // is proportional to the seed value! To help solve this, call 
-  // RandomSeed() a few times inside seed. This doesn't ruin the 
-  // repeatability of Random().
-  static void RandomSeed(long s);  
-
-  // Description:
-  // Return the current seed used by the random number generator.
-  static long GetSeed();
-  
-  // Description:
-  // Generate random numbers between 0.0 and 1.0.
-  // This is used to provide portability across different systems.
-  static double Random();  
-
-  // Description:
-  // Generate random number between (min,max).
-  static double Random(double min, double max);
-
   // Description:
   // Jacobi iteration for the solution of eigenvectors/eigenvalues of a 3x3
   // real symmetric matrix. Square 3x3 matrix a; output eigenvalues in w;
@@ -473,7 +617,7 @@ public:
   // Ed.  Return array contains number of (real) roots (counting multiple
   // roots as one) followed by roots themselves. The value in roots[4] is a
   // integer giving further information about the roots (see return codes for
-  // int SolveCubic()).
+  // int SolveCubic() ).
   static double* SolveCubic(double c0, double c1, double c2, double c3);
 
   // Description:
@@ -654,7 +798,7 @@ public:
   // Description:
   // Are the bounds initialized?
   static int AreBoundsInitialized(double bounds[6]){
-    if (bounds[1]-bounds[0]<0.0)
+    if ( bounds[1]-bounds[0]<0.0 )
       {
       return 0;
       }
@@ -716,23 +860,126 @@ public:
   // Bounds is x-min, x-max, y-min, y-max, z-min, z-max
   // Delta is the error margin along each axis (usually a small number)
   static int PointIsWithinBounds(double point[3], double bounds[6], double delta[3]);
+
+  // Description:
+  // Calculate \a num points, at a regular interval, along a parametric 
+  // spiral. Note this spiral is only in two dimensions having a constant
+  // z value.
+  static void SpiralPoints(vtkIdType num, vtkPoints * offsets);
   
   // Description:
-  // Special IEEE-754 numbers used to represent positive and negative infinity and Not-A-Number (Nan).
+  // In Euclidean space, there is a unique circle passing through any given 
+  // three non-collinear points P1, P2, and P3. Using Cartesian coordinates 
+  // to represent these points as spatial vectors, it is possible to use the 
+  // dot product and cross product to calculate the radius and center of the 
+  // circle. See: http://en.wikipedia.org/wiki/Circumcircle and more
+  // specifically the section Barycentric coordinates from cross- and 
+  // dot-products
+  static double Solve3PointCircle(const double p1[3], const double p2[3], const double p3[3], double center[3]);
+
+  // Description:
+  // Special IEEE-754 number used to represent positive infinity.
   static double Inf();
+
+  // Description:
+  // Special IEEE-754 number used to represent negative infinity.
   static double NegInf();
+
+  // Description:
+  // Special IEEE-754 number used to represent Not-A-Number (Nan).
   static double Nan();
 
+  // Description:
+  // Test if a number is equal to the special floating point value infinity.
+  static int IsInf(double x);
+
+  // Test if a number is equal to the special floating point value Not-A-Number (Nan).
+  static int IsNan(double x);
+
 protected:
   vtkMath() {};
   ~vtkMath() {};
   
-  static long Seed;
+  static vtkMathInternal Internal;
 private:
   vtkMath(const vtkMath&);  // Not implemented.
   void operator=(const vtkMath&);  // Not implemented.
 };
 
+//BTX
+class vtkMathInternal
+{
+public:
+  vtkMathInternal();
+  ~vtkMathInternal();
+  vtkMinimalStandardRandomSequence *Uniform;
+  vtkBoxMuellerRandomSequence *Gaussian;
+};
+//ETX
+
+//----------------------------------------------------------------------------
+inline float vtkMath::RadiansFromDegrees( float x )
+{
+  return x * 0.017453292f;
+}
+
+//----------------------------------------------------------------------------
+inline double vtkMath::RadiansFromDegrees( double x )
+{
+  return x * 0.017453292519943295;
+}
+
+//----------------------------------------------------------------------------
+inline float vtkMath::DegreesFromRadians( float x )
+{
+  return x * 57.2957795131f;
+}
+
+//----------------------------------------------------------------------------
+inline double vtkMath::DegreesFromRadians( double x )
+{
+  return x * 57.29577951308232;
+}
+
+#ifndef VTK_LEGACY_REMOVE
+//----------------------------------------------------------------------------
+inline float vtkMath::DegreesToRadians()
+{
+  VTK_LEGACY_REPLACED_BODY(vtkMath::DegreesToRadians, "VTK 5.4",
+                           vtkMath::RadiansFromDegrees);
+
+  return vtkMath::RadiansFromDegrees( 1.f );
+}
+
+//----------------------------------------------------------------------------
+inline double vtkMath::DoubleDegreesToRadians()
+{
+  VTK_LEGACY_REPLACED_BODY(vtkMath::DoubleDegreesToRadians, "VTK 5.4",
+                           vtkMath::RadiansFromDegrees);
+
+
+  return vtkMath::RadiansFromDegrees( 1. );
+}
+
+//----------------------------------------------------------------------------
+inline float vtkMath::RadiansToDegrees()
+{
+  VTK_LEGACY_REPLACED_BODY(vtkMath::RadiansToDegrees, "VTK 5.4",
+                           vtkMath::DegreesFromRadians);
+
+  return vtkMath::DegreesFromRadians( 1.f );
+}
+
+//----------------------------------------------------------------------------
+inline double vtkMath::DoubleRadiansToDegrees()
+{
+  VTK_LEGACY_REPLACED_BODY(vtkMath::DoubleRadiansToDegrees, "VTK 5.4",
+                           vtkMath::DegreesFromRadians);
+
+  return vtkMath::DegreesFromRadians( 1. );
+}
+#endif // #ifndef VTK_LEGACY_REMOVE
+
 //----------------------------------------------------------------------------
 inline vtkTypeInt64 vtkMath::Factorial( int N )
 {
@@ -758,7 +1005,7 @@ inline int vtkMath::Floor(double x)
   // round-to-nearest,even mode instead of round-to-nearest,+infinity
   return u.i[0] >> 1;
 #else
-  return static_cast<int>(floor(x));
+  return static_cast<int>(floor( x ) );
 #endif
 }
 
@@ -766,7 +1013,7 @@ inline int vtkMath::Floor(double x)
 inline float vtkMath::Normalize(float x[3])
 {
   float den; 
-  if ( (den = vtkMath::Norm(x)) != 0.0 )
+  if ( ( den = vtkMath::Norm( x ) ) != 0.0 )
     {
     for (int i=0; i < 3; i++)
       {
@@ -780,7 +1027,7 @@ inline float vtkMath::Normalize(float x[3])
 inline double vtkMath::Normalize(double x[3])
 {
   double den; 
-  if ( (den = vtkMath::Norm(x)) != 0.0 )
+  if ( ( den = vtkMath::Norm( x ) ) != 0.0 )
     {
     for (int i=0; i < 3; i++)
       {
@@ -794,7 +1041,7 @@ inline double vtkMath::Normalize(double x[3])
 inline float vtkMath::Normalize2D(float x[3])
 {
   float den; 
-  if ( (den = vtkMath::Norm2D(x)) != 0.0 )
+  if ( ( den = vtkMath::Norm2D( x ) ) != 0.0 )
     {
     for (int i=0; i < 2; i++)
       {
@@ -808,7 +1055,7 @@ inline float vtkMath::Normalize2D(float x[3])
 inline double vtkMath::Normalize2D(double x[3])
 {
   double den; 
-  if ( (den = vtkMath::Norm2D(x)) != 0.0 )
+  if ( ( den = vtkMath::Norm2D( x ) ) != 0.0 )
     {
     for (int i=0; i < 2; i++)
       {
@@ -823,8 +1070,8 @@ inline float vtkMath::Determinant3x3(const float c1[3],
                                      const float c2[3], 
                                      const float c3[3])
 {
-  return c1[0]*c2[1]*c3[2] + c2[0]*c3[1]*c1[2] + c3[0]*c1[1]*c2[2] -
-         c1[0]*c3[1]*c2[2] - c2[0]*c1[1]*c3[2] - c3[0]*c2[1]*c1[2];
+  return c1[0] * c2[1] * c3[2] + c2[0] * c3[1] * c1[2] + c3[0] * c1[1] * c2[2] -
+         c1[0] * c3[1] * c2[2] - c2[0] * c1[1] * c3[2] - c3[0] * c2[1] * c1[2];
 }
 
 //----------------------------------------------------------------------------
@@ -832,8 +1079,8 @@ inline double vtkMath::Determinant3x3(const double c1[3],
                                       const double c2[3], 
                                       const double c3[3])
 {
-  return c1[0]*c2[1]*c3[2] + c2[0]*c3[1]*c1[2] + c3[0]*c1[1]*c2[2] -
-         c1[0]*c3[1]*c2[2] - c2[0]*c1[1]*c3[2] - c3[0]*c2[1]*c1[2];
+  return c1[0] * c2[1] * c3[2] + c2[0] * c3[1] * c1[2] + c3[0] * c1[1] * c2[2] -
+         c1[0] * c3[1] * c2[2] - c2[0] * c1[1] * c3[2] - c3[0] * c2[1] * c1[2];
 }
 
 //----------------------------------------------------------------------------
@@ -850,41 +1097,37 @@ inline double vtkMath::Determinant3x3(double a1, double a2, double a3,
 inline float vtkMath::Distance2BetweenPoints(const float x[3], 
                                              const float y[3])
 {
-  return ((x[0]-y[0])*(x[0]-y[0]) + (x[1]-y[1])*(x[1]-y[1]) +
-          (x[2]-y[2])*(x[2]-y[2]));
+  return ( ( x[0] - y[0] ) * ( x[0] - y[0] ) 
+           + ( x[1] - y[1] ) * ( x[1] - y[1] ) 
+           + ( x[2] - y[2] ) * ( x[2] - y[2] ) );
 }
 
 //----------------------------------------------------------------------------
 inline double vtkMath::Distance2BetweenPoints(const double x[3], 
                                               const double y[3])
 {
-  return ((x[0]-y[0])*(x[0]-y[0]) + (x[1]-y[1])*(x[1]-y[1]) +
-          (x[2]-y[2])*(x[2]-y[2]));
+  return ( ( x[0] - y[0] ) * ( x[0] - y[0] ) 
+           + ( x[1] - y[1] ) * ( x[1] - y[1] ) 
+           + ( x[2] - y[2] ) * ( x[2] - y[2] ) );
 }
 
 //----------------------------------------------------------------------------
-inline double vtkMath::Random(double min, double max)
-{
-  return (min + vtkMath::Random()*(max-min));
-}
-
-//----------------------------------------------------------------------------
-// Cross product of two 3-vectors. Result vector in z[3].
+// Cross product of two 3-vectors. Result (a x b) is stored in z[3].
 inline void vtkMath::Cross(const float x[3], const float y[3], float z[3])
 {
-  float Zx = x[1]*y[2] - x[2]*y[1]; 
-  float Zy = x[2]*y[0] - x[0]*y[2];
-  float Zz = x[0]*y[1] - x[1]*y[0];
+  float Zx = x[1] * y[2] - x[2] * y[1]; 
+  float Zy = x[2] * y[0] - x[0] * y[2];
+  float Zz = x[0] * y[1] - x[1] * y[0];
   z[0] = Zx; z[1] = Zy; z[2] = Zz; 
 }
 
 //----------------------------------------------------------------------------
-// Cross product of two 3-vectors. Result vector in z[3].
+// Cross product of two 3-vectors. Result (a x b) is stored in z[3].
 inline void vtkMath::Cross(const double x[3], const double y[3], double z[3])
 {
-  double Zx = x[1]*y[2] - x[2]*y[1]; 
-  double Zy = x[2]*y[0] - x[0]*y[2];
-  double Zz = x[0]*y[1] - x[1]*y[0];
+  double Zx = x[1] * y[2] - x[2] * y[1]; 
+  double Zy = x[2] * y[0] - x[0] * y[2];
+  double Zz = x[0] * y[1] - x[1] * y[0];
   z[0] = Zx; z[1] = Zy; z[2] = Zz; 
 }
 
@@ -893,22 +1136,66 @@ inline void vtkMath::Cross(const double x[3], const double y[3], double z[3])
 template<class T>
 inline double vtkDeterminant3x3(T A[3][3])
 {
-  return A[0][0]*A[1][1]*A[2][2] + A[1][0]*A[2][1]*A[0][2] + 
-         A[2][0]*A[0][1]*A[1][2] - A[0][0]*A[2][1]*A[1][2] - 
-         A[1][0]*A[0][1]*A[2][2] - A[2][0]*A[1][1]*A[0][2];
+  return A[0][0] * A[1][1] * A[2][2] + A[1][0] * A[2][1] * A[0][2] + 
+         A[2][0] * A[0][1] * A[1][2] - A[0][0] * A[2][1] * A[1][2] - 
+         A[1][0] * A[0][1] * A[2][2] - A[2][0] * A[1][1] * A[0][2];
 }
 //ETX
 
 //----------------------------------------------------------------------------
 inline double vtkMath::Determinant3x3(float A[3][3])
 {
-  return vtkDeterminant3x3(A);
+  return vtkDeterminant3x3( A );
 }
 
 //----------------------------------------------------------------------------
 inline double vtkMath::Determinant3x3(double A[3][3])
 {
-  return vtkDeterminant3x3(A);
+  return vtkDeterminant3x3( A );
+}
+
+//----------------------------------------------------------------------------
+inline double* vtkMath::SolveCubic(double c0, double c1, double c2, double c3)
+{
+  return vtkPolynomialSolversUnivariate::SolveCubic( c0, c1, c2, c3 );
+}
+
+//----------------------------------------------------------------------------
+inline double* vtkMath::SolveQuadratic(double c0, double c1, double c2)
+{
+  return vtkPolynomialSolversUnivariate::SolveQuadratic( c0, c1, c2 );
+}
+
+//----------------------------------------------------------------------------
+inline double* vtkMath::SolveLinear(double c0, double c1)
+{
+  return vtkPolynomialSolversUnivariate::SolveLinear( c0, c1 );
+}
+
+//----------------------------------------------------------------------------
+inline int vtkMath::SolveCubic(double c0, double c1, double c2, double c3, 
+                               double *r1, double *r2, double *r3, int *num_roots)
+{
+  return vtkPolynomialSolversUnivariate::SolveCubic( c0, c1, c2, c3, r1, r2, r3, num_roots );
+}
+
+//----------------------------------------------------------------------------
+inline int vtkMath::SolveQuadratic(double c0, double c1, double c2, 
+                                   double *r1, double *r2, int *num_roots)
+{
+  return vtkPolynomialSolversUnivariate::SolveQuadratic( c0, c1, c2, r1, r2, num_roots );
+}
+  
+//----------------------------------------------------------------------------
+inline int vtkMath::SolveQuadratic( double* c, double* r, int* m )
+{
+  return vtkPolynomialSolversUnivariate::SolveQuadratic( c, r, m );
+}
+
+//----------------------------------------------------------------------------
+inline int vtkMath::SolveLinear(double c0, double c1, double *r1, int *num_roots)
+{
+  return vtkPolynomialSolversUnivariate::SolveLinear( c0, c1, r1, num_roots );
 }
 
 //----------------------------------------------------------------------------
@@ -979,7 +1266,7 @@ inline double vtkMath::ClampAndNormalizeValue(double value,
         }
 
       // normalize
-      result=(result-range[0])/(range[1]-range[0]);
+      result=( result - range[0] ) / ( range[1] - range[0] );
     }
 
   assert("post: valid_result" && result>=0.0 && result<=1.0);
