@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkStringArray.h,v $
+  Module:    vtkStringArray.h
   Language:  C++
-  Date:      $Date: 2008-07-17 13:22:30 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright 2004 Sandia Corporation.
   Under the terms of Contract DE-AC04-94AL85000, there is a non-exclusive
@@ -50,7 +50,7 @@ class VTK_COMMON_EXPORT vtkStringArray : public vtkAbstractArray
 {
 public:
   static vtkStringArray* New();
-  vtkTypeRevisionMacro(vtkStringArray,vtkAbstractArray);
+  vtkTypeMacro(vtkStringArray,vtkAbstractArray);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   //
@@ -169,7 +169,7 @@ public:
   // SetValue() method for fast insertion.
   void SetNumberOfValues(vtkIdType number);
 
-  int GetNumberOfValues() { return this->MaxId + 1; }
+  vtkIdType GetNumberOfValues() { return this->MaxId + 1; }
 
   int GetNumberOfElementComponents() { return 0; }
   int GetElementComponentSize() { return static_cast<int>(sizeof(vtkStdString::value_type)); }
@@ -249,7 +249,7 @@ public:
   // Returns the size of the data in DataTypeSize units. Thus, the number of bytes
   // for the data can be computed by GetDataSize() * GetDataTypeSize().
   // The size computation includes the string termination character for each string.
-  virtual unsigned long GetDataSize();
+  virtual vtkIdType GetDataSize();
   
   //BTX
   // Description:
