@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkVariantArray.cxx,v $
+  Module:    vtkVariantArray.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -76,7 +76,6 @@ public:
 // Standard functions
 //
 
-vtkCxxRevisionMacro(vtkVariantArray, "$Revision: 1.15 $");
 vtkStandardNewMacro(vtkVariantArray);
 //----------------------------------------------------------------------------
 void vtkVariantArray::PrintSelf(ostream& os, vtkIndent indent)
@@ -207,8 +206,8 @@ void vtkVariantArray::SetTuple(vtkIdType i, vtkIdType j, vtkAbstractArray* sourc
       // TODO : This just makes a double variant by default.
       //        We really should make the appropriate type of variant
       //        based on the subclass of vtkDataArray.
-      int tuple = (locj + cur) / a->GetNumberOfComponents();
-      int component = (locj + cur) % a->GetNumberOfComponents();
+      vtkIdType tuple = (locj + cur) / a->GetNumberOfComponents();
+      int component = static_cast<int>((locj + cur) % a->GetNumberOfComponents());
       this->SetValue(loci + cur, vtkVariant(a->GetComponent(tuple, component)));
       }
     }
@@ -249,8 +248,8 @@ void vtkVariantArray::InsertTuple(vtkIdType i, vtkIdType j, vtkAbstractArray* so
     vtkIdType locj = j * a->GetNumberOfComponents();
     for (vtkIdType cur = 0; cur < this->NumberOfComponents; cur++)
       {
-      int tuple = (locj + cur) / a->GetNumberOfComponents();
-      int component = (locj + cur) % a->GetNumberOfComponents();
+      vtkIdType tuple = (locj + cur) / a->GetNumberOfComponents();
+      int component = static_cast<int>((locj + cur) % a->GetNumberOfComponents());
       this->InsertValue(loci + cur, vtkVariant(a->GetComponent(tuple, component)));
       }
     }
@@ -289,8 +288,8 @@ vtkIdType vtkVariantArray::InsertNextTuple(vtkIdType j, vtkAbstractArray* source
     vtkIdType locj = j * a->GetNumberOfComponents();
     for (vtkIdType cur = 0; cur < this->NumberOfComponents; cur++)
       {
-      int tuple = (locj + cur) / a->GetNumberOfComponents();
-      int component = (locj + cur) % a->GetNumberOfComponents();
+      vtkIdType tuple = (locj + cur) / a->GetNumberOfComponents();
+      int component = static_cast<int>((locj + cur) % a->GetNumberOfComponents());
       this->InsertNextValue(vtkVariant(a->GetComponent(tuple, component)));
       }
     }
@@ -464,9 +463,9 @@ int vtkVariantArray::Resize(vtkIdType sz)
 
   if(this->Array)
     {
-    int numCopy = (newSize < this->Size ? newSize : this->Size);
+    vtkIdType numCopy = (newSize < this->Size ? newSize : this->Size);
 
-    for (int i = 0; i < numCopy; ++i)
+    for (vtkIdType i = 0; i < numCopy; ++i)
       {
       newArray[i] = this->Array[i];
       }
@@ -499,12 +498,13 @@ void vtkVariantArray::SetVoidArray(void *arr, vtkIdType size, int save)
 unsigned long vtkVariantArray::GetActualMemorySize()
 {
   // NOTE: Currently does not take into account the "pointed to" data.
-  unsigned long totalSize = 0;
-  unsigned long numPrims = this->GetSize();
+  size_t totalSize = 0;
+  size_t numPrims = static_cast<size_t>(this->GetSize());
 
   totalSize = numPrims*sizeof(vtkVariant);
 
-  return static_cast<unsigned long>(ceil(totalSize / 1024.0)); // kilobytes
+  return static_cast<unsigned long>(
+    ceil(static_cast<double>(totalSize) / 1024.0)); // kilobytes
 }
 
 //----------------------------------------------------------------------------
@@ -647,8 +647,8 @@ vtkVariant* vtkVariantArray::ResizeAndExtend(vtkIdType sz)
   if(this->Array)
     {
     // can't use memcpy here
-    int numCopy = (newSize < this->Size ? newSize : this->Size);
-    for (int i = 0; i < numCopy; ++i)
+    vtkIdType numCopy = (newSize < this->Size ? newSize : this->Size);
+    for (vtkIdType i = 0; i < numCopy; ++i)
       {
       newArray[i] = this->Array[i];
       }
@@ -730,8 +730,8 @@ vtkIdType vtkVariantArray::LookupValue(vtkVariant value)
     }
 
   // Perform a binary search of the sorted array using STL equal_range.
-  int numComps = this->GetNumberOfComponents();
-  vtkIdType numTuples = this->GetNumberOfTuples();
+  int numComps = this->Lookup->SortedArray->GetNumberOfComponents();
+  vtkIdType numTuples = this->Lookup->SortedArray->GetNumberOfTuples();
   vtkVariant* ptr = this->Lookup->SortedArray->GetPointer(0);
   vtkVariant* ptrEnd = ptr + numComps*numTuples;
   vtkVariant* found = vtkstd::lower_bound(
