@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkAlgorithm.h,v $
+  Module:    vtkAlgorithm.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -48,7 +48,7 @@ class VTK_FILTERING_EXPORT vtkAlgorithm : public vtkObject
 {
 public:
   static vtkAlgorithm *New();
-  vtkTypeRevisionMacro(vtkAlgorithm,vtkObject);
+  vtkTypeMacro(vtkAlgorithm,vtkObject);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -197,13 +197,13 @@ public:
   // association and name or attribute type (such as SCALARS). The
   // fieldAssociation refers to which field in the data object the array is
   // stored. See vtkDataObject::FieldAssociations for detail.
-  void SetInputArrayToProcess(int idx, int port, int connection, 
+  virtual void SetInputArrayToProcess(int idx, int port, int connection, 
                               int fieldAssociation, 
                               const char *name);
-  void SetInputArrayToProcess(int idx, int port, int connection, 
+  virtual void SetInputArrayToProcess(int idx, int port, int connection, 
                               int fieldAssociation, 
                               int fieldAttributeType);
-  void SetInputArrayToProcess(int idx, vtkInformation *info);
+  virtual void SetInputArrayToProcess(int idx, vtkInformation *info);
 
   // Description:
   // String based versions of SetInputArrayToProcess(). Because
@@ -227,7 +227,7 @@ public:
   // @endverbatim
   // If the last argument is not an attribute type, it is assumed to
   // be an array name.
-  void SetInputArrayToProcess(int idx, int port, int connection, 
+  virtual void SetInputArrayToProcess(int idx, int port, int connection, 
                               const char* fieldAssociation, 
                               const char* attributeTypeorName);
 
@@ -362,6 +362,16 @@ public:
   // skippable (REQUEST_DATA not needed) and 1.0 meaning important. 
   virtual double ComputePriority();
 
+  // Description:
+  // These are flags that can be set that let the pipeline keep accurate 
+  // meta-information for ComputePriority.
+  static vtkInformationIntegerKey* PRESERVES_DATASET();
+  static vtkInformationIntegerKey* PRESERVES_GEOMETRY();
+  static vtkInformationIntegerKey* PRESERVES_BOUNDS();
+  static vtkInformationIntegerKey* PRESERVES_TOPOLOGY();
+  static vtkInformationIntegerKey* PRESERVES_ATTRIBUTES();
+  static vtkInformationIntegerKey* PRESERVES_RANGES();
+
 protected:
   vtkAlgorithm();
   ~vtkAlgorithm();
@@ -398,7 +408,7 @@ protected:
   int OutputPortIndexInRange(int index, const char* action);
 
   // Description:
-  // Get the actual data array for the input array sepcified by idx, this is
+  // Get the actual data array for the input array specified by idx, this is
   // only reasonable during the REQUEST_DATA pass
   vtkDataArray *GetInputArrayToProcess(int idx,vtkInformationVector **inputVector);
 
@@ -417,7 +427,7 @@ protected:
 
 
   // Description:
-  // Get the actual data array for the input array sepcified by idx, this is
+  // Get the actual data array for the input array specified by idx, this is
   // only reasonable during the REQUEST_DATA pass
   vtkAbstractArray *GetInputAbstractArrayToProcess(int idx,vtkInformationVector **inputVector);
 
