@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkCompositeDataPipeline.cxx,v $
+Module:    vtkCompositeDataPipeline.cxx
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -16,25 +16,26 @@ PURPOSE.  See the above copyright notice for more information.
 
 #include "vtkAlgorithm.h"
 #include "vtkAlgorithmOutput.h"
-#include "vtkMultiGroupDataInformation.h"
-#include "vtkMultiGroupDataSet.h"
-#include "vtkInformation.h"
+#include "vtkCompositeDataIterator.h"
+#include "vtkImageData.h"
 #include "vtkInformationDoubleKey.h"
+#include "vtkInformationExecutivePortKey.h"
+#include "vtkInformationExecutivePortVectorKey.h"
+#include "vtkInformation.h"
+#include "vtkInformationIdTypeKey.h"
 #include "vtkInformationIntegerKey.h"
 #include "vtkInformationIntegerVectorKey.h"
 #include "vtkInformationKey.h"
 #include "vtkInformationObjectBaseKey.h"
 #include "vtkInformationStringKey.h"
 #include "vtkInformationVector.h"
-#include "vtkInformationIdTypeKey.h"
+#include "vtkMultiBlockDataSet.h"
 #include "vtkObjectFactory.h"
 #include "vtkPolyData.h"
-#include "vtkSmartPointer.h"
-#include "vtkTemporalDataSet.h"
-
-#include "vtkImageData.h"
 #include "vtkRectilinearGrid.h"
+#include "vtkSmartPointer.h"
 #include "vtkStructuredGrid.h"
+#include "vtkTemporalDataSet.h"
 #include "vtkUniformGrid.h"
 
 //----------------------------------------------------------------------------
@@ -80,12 +81,12 @@ PURPOSE.  See the above copyright notice for more information.
         !strcmp(name, "vtkTemporalStreamTracer")) \
       { \
 */
-vtkCxxRevisionMacro(vtkCompositeDataPipeline, "$Revision: 1.65 $");
 vtkStandardNewMacro(vtkCompositeDataPipeline);
 
-vtkInformationKeyMacro(vtkCompositeDataPipeline,COMPOSITE_DATA_INFORMATION,ObjectBase);
-vtkInformationKeyMacro(vtkCompositeDataPipeline,UPDATE_BLOCKS, ObjectBase);
 vtkInformationKeyMacro(vtkCompositeDataPipeline,REQUIRES_TIME_DOWNSTREAM, Integer);
+vtkInformationKeyMacro(vtkCompositeDataPipeline, COMPOSITE_DATA_META_DATA, ObjectBase);
+vtkInformationKeyMacro(vtkCompositeDataPipeline, UPDATE_COMPOSITE_INDICES, IntegerVector);
+vtkInformationKeyMacro(vtkCompositeDataPipeline, COMPOSITE_INDICES, IntegerVector);
 
 //----------------------------------------------------------------------------
 vtkCompositeDataPipeline::vtkCompositeDataPipeline()
@@ -128,8 +129,6 @@ vtkCompositeDataPipeline::vtkCompositeDataPipeline()
     vtkExecutive::FORWARD_DIRECTION(), vtkExecutive::RequestUpstream);
   // Algorithms process this request after it is forwarded.
   this->DataRequest->Set(vtkExecutive::ALGORITHM_AFTER_FORWARD(), 1);
-              
-              
 }
 
 //----------------------------------------------------------------------------
@@ -199,7 +198,7 @@ int vtkCompositeDataPipeline::ForwardUpstream(vtkInformation* request)
       // it is a NULL input.
       vtkExecutive* e;
       int producerPort;
-      info->Get(vtkExecutive::PRODUCER(), e, producerPort);
+      vtkExecutive::PRODUCER()->Get(info, e, producerPort);
       if(e)
         {
         request->Set(FROM_OUTPUT_PORT(), producerPort);
@@ -241,7 +240,8 @@ int vtkCompositeDataPipeline::ProcessRequest(vtkInformation* request,
     {
     vtkDebugMacro(<< "REQUEST_DATA_OBJECT()");
     // if we are up to date then short circuit
-    if (this->PipelineMTime < this->DataObjectTime.GetMTime())
+    if (this->PipelineMTime < this->DataObjectTime.GetMTime()
+        && ! request->Has(REQUEST_REGENERATE_INFORMATION()))
       {
       return 1;
       }
@@ -254,7 +254,8 @@ int vtkCompositeDataPipeline::ProcessRequest(vtkInformation* request,
     
     // Make sure our output data type is up-to-date.
     int result = 1;
-    if(this->PipelineMTime > this->DataObjectTime.GetMTime())
+    if(this->PipelineMTime > this->DataObjectTime.GetMTime()
+        || request->Has(REQUEST_REGENERATE_INFORMATION()))
       {
       // Request data type from the algorithm.
       result = this->ExecuteDataObject(request,inInfoVec,outInfoVec);
@@ -283,58 +284,9 @@ int vtkCompositeDataPipeline::ProcessRequest(vtkInformation* request,
   if(this->Algorithm && request->Has(REQUEST_INFORMATION()))
     {
     vtkDebugMacro(<< "REQUEST_INFORMATION()");
-    int appendKey = 1;
-    vtkInformationKey** keys = request->Get(vtkExecutive::KEYS_TO_COPY());
-    if (keys)
-      {
-      int len = request->Length(vtkExecutive::KEYS_TO_COPY());
-      for (int i=0; i<len; i++)
-        {
-        if (keys[i] == vtkCompositeDataPipeline::COMPOSITE_DATA_INFORMATION())
-          {
-          appendKey = 0;
-          break;
-          }
-        }
-      }
-    if (appendKey)
-      {
-      request->Append(vtkExecutive::KEYS_TO_COPY(), 
-                      vtkCompositeDataPipeline::COMPOSITE_DATA_INFORMATION());
-      }
-      
     return this->Superclass::ProcessRequest(request, inInfoVec,outInfoVec);
     }
 
-  if(this->Algorithm && request->Has(REQUEST_DATA()))
-    {
-    vtkDebugMacro(<< "REQUEST_DATA()");
-
-    // UPDATE_BLOCKS() is the key that tells filters downstream which
-    // blocks of a composite dataset are available. This consumers will then
-    // ask for these blocks if they have to loop (simple filters in the
-    // middle)
-    int appendKey = 1;
-    vtkInformationKey** keys = request->Get(vtkExecutive::KEYS_TO_COPY());
-    if (keys)
-      {
-      int len = request->Length(vtkExecutive::KEYS_TO_COPY());
-      for (int i=0; i<len; i++)
-        {
-        if (keys[i] == vtkCompositeDataPipeline::UPDATE_BLOCKS())
-          {
-          appendKey = 0;
-          break;
-          }
-        }
-      }
-    if (appendKey)
-      {
-      request->Append(vtkExecutive::KEYS_TO_COPY(), 
-                      vtkCompositeDataPipeline::UPDATE_BLOCKS());
-      }
-    }
-
   // Let the superclass handle other requests.
   return this->Superclass::ProcessRequest(request, inInfoVec, outInfoVec);
 }
@@ -422,12 +374,6 @@ int vtkCompositeDataPipeline::ExecuteData(vtkInformation* request,
   vtkDebugMacro(<< "ExecuteData");
   int result = 1;
 
-  for(int i=0; i < this->Algorithm->GetNumberOfOutputPorts(); ++i)
-    {
-    vtkInformation* info = outInfoVec->GetInformationObject(i);
-    info->Remove(UPDATE_BLOCKS());
-    }
-
   int compositePort;
   bool composite = this->ShouldIterateOverInput(compositePort);
   bool temporal = 
@@ -444,16 +390,6 @@ int vtkCompositeDataPipeline::ExecuteData(vtkInformation* request,
     result = this->Superclass::ExecuteData(request,inInfoVec,outInfoVec);
     }
 
-  for(int j=0; j < this->Algorithm->GetNumberOfOutputPorts(); ++j)
-    {
-    vtkInformation* info = this->GetOutputInformation(j);
-    vtkObject* dobj= info->Get(vtkDataObject::DATA_OBJECT());
-    if (dobj)
-      {
-      info->Set(UPDATE_BLOCKS(), dobj);
-      }
-    }
-
   return result;
 }
 
@@ -514,20 +450,41 @@ bool vtkCompositeDataPipeline::ShouldIterateOverInput(int& compositePort)
       {
       vtkInformation* inPortInfo = 
         this->Algorithm->GetInputPortInformation(i);
-      const char* inputType = 
-        inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE());
-      if (inputType)
+      if (inPortInfo->Has(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE()) 
+          && inPortInfo->Length(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE()) > 0)
         {
+        const char* inputType = inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), 0);
         // the filter upstream will iterate
         if (strcmp(inputType, "vtkTemporalDataSet") == 0)
           {
           vtkDebugMacro(<< "ShouldIterateOverInput returns 0 (Temporal)");
           return false;
           }
+
+        if (strcmp(inputType, "vtkCompositeDataSet") == 0 ||
+          strcmp(inputType, "vtkHierarchicalBoxDataSet") == 0 ||
+          strcmp(inputType, "vtkMultiBlockDataSet") == 0)
+          {
+          vtkDebugMacro(<< "ShouldIterateOverInput return 0 (Composite)");
+          return false;
+          }
+
         vtkInformation* inInfo = this->GetInputInformation(i, 0);
         vtkDataObject* input = inInfo->Get(vtkDataObject::DATA_OBJECT());
-        // If input does not match required input type
-        if (input && !input->IsA(inputType))
+        // If input does not match a required input type
+        bool foundMatch = false;
+        if(input)
+          {
+          int size = inPortInfo->Length(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE());
+          for(int j = 0; j < size; ++j)
+            {
+            if(input->IsA(inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), j)))
+              {
+              foundMatch = true;
+              }
+            }
+          }
+        if (input && !foundMatch)
           {
           // If input is composite
           if (vtkCompositeDataSet::SafeDownCast(input))
@@ -595,168 +552,6 @@ bool vtkCompositeDataPipeline::ShouldIterateTemporalData(
   return false;
 }
 
-//----------------------------------------------------------------------------
-vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
-  vtkInformationVector** inInfoVec,
-  vtkInformationVector* outInfoVec,
-  vtkInformation* inInfo,
-  vtkInformation* outInfo,
-  vtkInformation* request,  
-  vtkDataObject* dobj)
-{
-  vtkDebugMacro(<< "ExecuteSimpleAlgorithmForBlock");
-
-  // if we have an input and it is composite, then recurse
-  if (dobj && dobj->IsA("vtkMultiGroupDataSet"))
-    {
-    vtkMultiGroupDataSet* output = vtkMultiGroupDataSet::New();
-
-    vtkMultiGroupDataSet* mbInput = vtkMultiGroupDataSet::SafeDownCast(dobj);
-    unsigned int numGroups = mbInput->GetNumberOfGroups();
-    output->SetNumberOfGroups(numGroups);
-    for (unsigned int groupId=0; groupId<numGroups; groupId++)
-      {
-      unsigned int numBlocks = mbInput->GetNumberOfDataSets(groupId);
-      output->SetNumberOfDataSets(groupId, numBlocks);
-      for (unsigned int blockId=0; blockId<numBlocks; blockId++)
-        {
-        vtkDataObject* block = mbInput->GetDataSet(groupId, blockId);
-        vtkDataObject* outBlock = 0;
-        if (block)
-          {
-          outBlock = this->ExecuteSimpleAlgorithmForBlock(inInfoVec,
-                                                          outInfoVec,
-                                                          inInfo,
-                                                          outInfo,
-                                                          request,
-                                                          block);
-          }
-        output->SetDataSet(groupId, blockId, outBlock);
-        if (outBlock)
-          {
-          outBlock->Delete();
-          }
-        }
-      }
-    return output;
-    }
-  else
-    {
-    double time = 0;
-    int hasTime = outInfo->Length(UPDATE_TIME_STEPS());
-    if (hasTime)
-      {
-      time = outInfo->Get(UPDATE_TIME_STEPS())[0];
-      }
-
-    // There must be a bug somehwere. If this Remove()
-    // is not called, the following Set() has the effect
-    // of removing (!) the key.
-    if (inInfo)
-      {
-      inInfo->Remove(vtkDataObject::DATA_OBJECT());
-      inInfo->Set(vtkDataObject::DATA_OBJECT(), dobj);
-      
-      // Process the whole dataset
-      this->CopyFromDataToInformation(dobj, inInfo);
-      }
-
-    request->Set(REQUEST_DATA_OBJECT());
-    this->Superclass::ExecuteDataObject(
-      request, this->GetInputInformation(),this->GetOutputInformation());
-    request->Remove(REQUEST_DATA_OBJECT());
-    
-    request->Set(REQUEST_INFORMATION());
-
-    // Make sure that pipeline informations is in sync with the data
-    if (dobj)
-      {
-      dobj->CopyInformationToPipeline(request, 0, inInfo, 1);
-
-      // This should not be needed but since a lot of image filters do:
-      // img->GetScalarType(), it is necessary.
-      dobj->GetProducerPort(); // make sure there is pipeline info.
-      dobj->CopyInformationToPipeline
-        (request, 0, dobj->GetPipelineInformation(), 1);
-      }
-
-    this->Superclass::ExecuteInformation(request,inInfoVec,outInfoVec);
-    request->Remove(REQUEST_INFORMATION());
-    
-    int storedPiece = -1;
-    int storedNumPieces = -1;
-    for(int m=0; m < this->Algorithm->GetNumberOfOutputPorts(); ++m)
-      {
-      vtkInformation* info = this->GetOutputInformation(m);
-      // Update the whole thing
-      if (info->Has(
-                    vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()))
-        {
-        int extent[6] = {0,-1,0,-1,0,-1};
-        info->Get(
-          vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
-          extent);
-        info->Set(
-          vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), 
-          extent, 
-          6);
-        info->Set(
-          vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT_INITIALIZED(), 
-          1);
-        storedPiece = 
-          info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER());
-        storedNumPieces= 
-          info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES());
-        info->Set(
-          vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), 
-          1);
-        vtkDebugMacro(<< "UPDATE_PIECE_NUMBER() 0"  << " " << info);
-        info->Set(
-          vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), 0);
-        }
-      }
-
-    // if there was a time make sure that gets set in the RUE
-    if (hasTime)
-      {
-      outInfo->Set(UPDATE_TIME_STEPS(),&time,1);
-      }
-
-    request->Set(REQUEST_UPDATE_EXTENT());
-    this->CallAlgorithm(request, vtkExecutive::RequestUpstream,
-                        inInfoVec, outInfoVec);
-    request->Remove(REQUEST_UPDATE_EXTENT());
-    
-    request->Set(REQUEST_DATA());
-    this->Superclass::ExecuteData(request,inInfoVec,outInfoVec);
-    request->Remove(REQUEST_DATA());
-    
-    for(int m=0; m < this->Algorithm->GetNumberOfOutputPorts(); ++m)
-      {
-      vtkInformation* info = this->GetOutputInformation(m);
-      if (storedPiece!=-1)
-        {
-        info->Set(
-          vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), 
-          storedNumPieces);
-        vtkDebugMacro(<< "UPDATE_PIECE_NUMBER() 0"  << " " << info);
-        info->Set(
-          vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), 
-          storedPiece);
-        }
-      }
-
-    vtkDataObject* output = outInfo->Get(vtkDataObject::DATA_OBJECT());
-    if (!output)
-      {
-      return 0;
-      }
-    vtkDataObject* outputCopy = output->NewInstance();
-    outputCopy->ShallowCopy(output);
-    return outputCopy;
-    }
-}
-
 //----------------------------------------------------------------------------
 // Execute a simple (non-composite-aware) filter multiple times, once per
 // block. Collect the result in a composite dataset that is of the same
@@ -796,14 +591,10 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
   // assumption to start with.
   // TODO: Loop over all inputs
   vtkInformation* inInfo = 0;
-  vtkMultiGroupDataSet* updateInfo = 0;
   inInfo = this->GetInputInformation(compositePort, 0);
   vtkCompositeDataSet* input = vtkCompositeDataSet::SafeDownCast(
     inInfo->Get(vtkDataObject::DATA_OBJECT()));
   
-  updateInfo = vtkMultiGroupDataSet::SafeDownCast(
-    inInfo->Get(vtkCompositeDataPipeline::UPDATE_BLOCKS()));
-  
   vtkSmartPointer<vtkCompositeDataSet> compositeOutput = 
     vtkCompositeDataSet::SafeDownCast(
       outInfo->Get(vtkDataObject::DATA_OBJECT()));
@@ -819,14 +610,15 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
            sizeof(double)*numTimeSteps);
     }
 
-  if (input && updateInfo)
+  if (input && compositeOutput)
     {
-    int outputInitialized = 0;
+    compositeOutput->PrepareForNewData();
+    compositeOutput->CopyStructure(input);
 
     vtkSmartPointer<vtkInformation> r = 
       vtkSmartPointer<vtkInformation>::New();
 
-    r->Set(FROM_OUTPUT_PORT(), inInfo->GetPort(PRODUCER()));
+    r->Set(FROM_OUTPUT_PORT(), PRODUCER()->GetPort(outInfo));
 
     // The request is forwarded upstream through the pipeline.
     r->Set(vtkExecutive::FORWARD_DIRECTION(), vtkExecutive::RequestUpstream);
@@ -834,12 +626,6 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
     // Algorithms process this request after it is forwarded.
     r->Set(vtkExecutive::ALGORITHM_AFTER_FORWARD(), 1);
 
-    // iterate over time by default
-    unsigned int numGroups = numTimeSteps;
-    // if we have a composite input the use that instead
-    vtkSmartPointer<vtkDataObject> prevInput = 0;
-    numGroups = updateInfo->GetNumberOfGroups();
-    prevInput = inInfo->Get(vtkDataObject::DATA_OBJECT());
 
     // Store the information (whole_extent and maximum_number_of_pieces)
     // before looping. Otherwise, executeinformation will cause
@@ -854,45 +640,38 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
     // ExecuteDataStart() should NOT Initialize() the composite output.
     this->InLocalLoop = 1;
 
-    for (unsigned int k=0; k<numGroups; k++)
+    vtkSmartPointer<vtkCompositeDataIterator> iter;
+    iter.TakeReference(input->NewIterator());
+    iter->VisitOnlyLeavesOn();
+    for (iter->InitTraversal(); !iter->IsDoneWithTraversal(); 
+      iter->GoToNextItem())
       {
       // if it is a temporal input, set the time for each piece
       if (times)
         {
-        outInfo->Set(UPDATE_TIME_STEPS(),times,numTimeSteps);
+        outInfo->Set(UPDATE_TIME_STEPS(), times, numTimeSteps);
         }
-      unsigned int numDataSets = updateInfo->GetNumberOfDataSets(k);
-      for (unsigned l=0; l<numDataSets; l++)
+      vtkDataObject* dobj = iter->GetCurrentDataObject();
+      if (dobj)
         {
-        if (updateInfo->GetDataSet(k,l))
+        // Note that since VisitOnlyLeaves is ON on the iterator,
+        // this method is called only for leaves, hence, we are assured that
+        // neither dobj nor outObj are vtkCompositeDataSet subclasses.
+        vtkDataObject* outObj =
+          this->ExecuteSimpleAlgorithmForBlock(inInfoVec,
+                                               outInfoVec,
+                                               inInfo,
+                                               outInfo,
+                                               r,
+                                               dobj);
+        if (outObj)
           {
-          r->Set(vtkMultiGroupDataSet::GROUP(), k);
-          r->Set(vtkCompositeDataSet::INDEX(),    l);
-          vtkDataObject* dobj = input->GetDataSet(r);
-
-          vtkDataObject* outCopy = 0;
-          if (dobj)
-            {
-            outCopy = this->ExecuteSimpleAlgorithmForBlock(inInfoVec,
-                                                           outInfoVec,
-                                                           inInfo,
-                                                           outInfo,
-                                                           r,
-                                                           dobj);
-            }
-          if (!outputInitialized)
-            {
-            compositeOutput->PrepareForNewData();
-            outputInitialized = 1;
-            }
-          compositeOutput->AddDataSet(r, outCopy);
-          if (outCopy)
-            {
-            outCopy->Delete();
-            }
+          compositeOutput->SetDataSet(iter, outObj);
+          outObj->Delete();
           }
         }
       }
+
     // True when the pipeline is iterating over the current (simple)
     // filter to produce composite output. In this case,
     // ExecuteDataStart() should NOT Initialize() the composite output.
@@ -915,10 +694,10 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
                                  this->GetOutputInformation());
         
     vtkDataObject* curInput = inInfo->Get(vtkDataObject::DATA_OBJECT());
-    if (curInput != prevInput)
+    if (curInput != input)
       {
       inInfo->Remove(vtkDataObject::DATA_OBJECT());
-      inInfo->Set(vtkDataObject::DATA_OBJECT(), prevInput);
+      inInfo->Set(vtkDataObject::DATA_OBJECT(), input);
       }
     vtkDataObject* curOutput = outInfo->Get(vtkDataObject::DATA_OBJECT());
     if (curOutput != compositeOutput.GetPointer())
@@ -929,11 +708,147 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithm(
   this->ExecuteDataEnd(request,inInfoVec,outInfoVec);
 }
 
+//----------------------------------------------------------------------------
+vtkDataObject* vtkCompositeDataPipeline::ExecuteSimpleAlgorithmForBlock(
+  vtkInformationVector** inInfoVec,
+  vtkInformationVector* outInfoVec,
+  vtkInformation* inInfo,
+  vtkInformation* outInfo,
+  vtkInformation* request,  
+  vtkDataObject* dobj)
+{
+  vtkDebugMacro(<< "ExecuteSimpleAlgorithmForBlock");
+
+  if (dobj && dobj->IsA("vtkCompositeDataSet"))
+    {
+    vtkErrorMacro("ExecuteSimpleAlgorithmForBlock cannot be called "
+      "for a vtkCompositeDataSet");
+    return 0;
+    }
+
+  double time = 0;
+  int hasTime = outInfo->Length(UPDATE_TIME_STEPS());
+  if (hasTime)
+    {
+    time = outInfo->Get(UPDATE_TIME_STEPS())[0];
+    }
+
+  // There must be a bug somehwere. If this Remove()
+  // is not called, the following Set() has the effect
+  // of removing (!) the key.
+  if (inInfo)
+    {
+    inInfo->Remove(vtkDataObject::DATA_OBJECT());
+    inInfo->Set(vtkDataObject::DATA_OBJECT(), dobj);
+    
+    // Process the whole dataset
+    this->CopyFromDataToInformation(dobj, inInfo);
+    }
+
+  request->Set(REQUEST_DATA_OBJECT());
+  this->SuppressResetPipelineInformation = 1;
+  this->Superclass::ExecuteDataObject(
+    request, this->GetInputInformation(),this->GetOutputInformation());
+  this->SuppressResetPipelineInformation = 0;
+  request->Remove(REQUEST_DATA_OBJECT());
+  
+  request->Set(REQUEST_INFORMATION());
+
+  // Make sure that pipeline informations is in sync with the data
+  if (dobj)
+    {
+    dobj->CopyInformationToPipeline(request, 0, inInfo, 1);
+
+    // This should not be needed but since a lot of image filters do:
+    // img->GetScalarType(), it is necessary.
+    dobj->GetProducerPort(); // make sure there is pipeline info.
+    dobj->CopyInformationToPipeline
+      (request, 0, dobj->GetPipelineInformation(), 1);
+    }
+
+  this->Superclass::ExecuteInformation(request,inInfoVec,outInfoVec);
+  request->Remove(REQUEST_INFORMATION());
+  
+  int storedPiece = -1;
+  int storedNumPieces = -1;
+  for(int m=0; m < this->Algorithm->GetNumberOfOutputPorts(); ++m)
+    {
+    vtkInformation* info = this->GetOutputInformation(m);
+    // Update the whole thing
+    if (info->Has(
+                  vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT()))
+      {
+      int extent[6] = {0,-1,0,-1,0,-1};
+      info->Get(
+        vtkStreamingDemandDrivenPipeline::WHOLE_EXTENT(),
+        extent);
+      info->Set(
+        vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT(), 
+        extent, 
+        6);
+      info->Set(
+        vtkStreamingDemandDrivenPipeline::UPDATE_EXTENT_INITIALIZED(), 
+        1);
+      storedPiece = 
+        info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER());
+      storedNumPieces= 
+        info->Get(vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES());
+      info->Set(
+        vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), 
+        1);
+      vtkDebugMacro(<< "UPDATE_PIECE_NUMBER() 0"  << " " << info);
+      info->Set(
+        vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), 0);
+      }
+    }
+
+  // if there was a time make sure that gets set in the RUE
+  if (hasTime)
+    {
+    outInfo->Set(UPDATE_TIME_STEPS(),&time,1);
+    }
+
+  request->Set(REQUEST_UPDATE_EXTENT());
+  this->CallAlgorithm(request, vtkExecutive::RequestUpstream,
+                      inInfoVec, outInfoVec);
+  request->Remove(REQUEST_UPDATE_EXTENT());
+  
+  request->Set(REQUEST_DATA());
+  this->Superclass::ExecuteData(request,inInfoVec,outInfoVec);
+  request->Remove(REQUEST_DATA());
+  
+  for(int m=0; m < this->Algorithm->GetNumberOfOutputPorts(); ++m)
+    {
+    vtkInformation* info = this->GetOutputInformation(m);
+    if (storedPiece!=-1)
+      {
+      info->Set(
+        vtkStreamingDemandDrivenPipeline::UPDATE_NUMBER_OF_PIECES(), 
+        storedNumPieces);
+      vtkDebugMacro(<< "UPDATE_PIECE_NUMBER() 0"  << " " << info);
+      info->Set(
+        vtkStreamingDemandDrivenPipeline::UPDATE_PIECE_NUMBER(), 
+        storedPiece);
+      }
+    }
+
+  vtkDataObject* output = outInfo->Get(vtkDataObject::DATA_OBJECT());
+  if (!output)
+    {
+    return 0;
+    }
+  vtkDataObject* outputCopy = output->NewInstance();
+  outputCopy->ShallowCopy(output);
+  return outputCopy;
+}
+
 
 //----------------------------------------------------------------------------
 // Execute a simple (non-composite-aware) filter multiple times, once per
 // block. Collect the result in a composite dataset that is of the same
 // structure as the input.
+// Note that if this method is called we are assured that the input is not
+// composite.
 void vtkCompositeDataPipeline::ExecuteSimpleAlgorithmTime(
   vtkInformation* request,
   vtkInformationVector** inInfoVec,
@@ -952,8 +867,8 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithmTime(
     originalInformation->CopyEntry(outInfo,TIME_RANGE(), 0);
     }
 
-  vtkSmartPointer<vtkCompositeDataSet> temporalOutput = 
-    vtkCompositeDataSet::SafeDownCast(
+  vtkSmartPointer<vtkTemporalDataSet> temporalOutput = 
+    vtkTemporalDataSet::SafeDownCast(
       outInfo->Get(vtkDataObject::DATA_OBJECT()));
   
   // do we have a request for multiple time steps?
@@ -997,8 +912,6 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithmTime(
     // if it is a temporal input, set the time for each piece
     outInfo->Set(UPDATE_TIME_STEPS(), times+k, 1);
 
-    r->Set(vtkMultiGroupDataSet::GROUP(), k);
-    r->Set(vtkCompositeDataSet::INDEX(), 0);
     vtkDataObject* dobj = 0;
     
     vtkDataObject* outCopy = 
@@ -1014,7 +927,7 @@ void vtkCompositeDataPipeline::ExecuteSimpleAlgorithmTime(
         temporalOutput->PrepareForNewData();
         outputInitialized = 1;
         }
-      temporalOutput->AddDataSet(r, outCopy);
+      temporalOutput->SetTimeStep(k, outCopy);
       outCopy->Delete();
       }
     }
@@ -1100,6 +1013,12 @@ int vtkCompositeDataPipeline::NeedToExecuteData(
     {
     return 1;
     }
+  int dataGhostLevel = dataInfo->Get(vtkDataObject::DATA_NUMBER_OF_GHOST_LEVELS());
+  int updateGhostLevel = outInfo->Get(UPDATE_NUMBER_OF_GHOST_LEVELS());
+  if(dataGhostLevel < updateGhostLevel)
+    {
+    return 1;
+    }
   if (dataNumberOfPieces != 1)
     {
     int dataPiece = dataInfo->Get(vtkDataObject::DATA_PIECE_NUMBER());
@@ -1115,6 +1034,16 @@ int vtkCompositeDataPipeline::NeedToExecuteData(
     return 1;
     }
 
+  if (this->NeedToExecuteBasedOnFastPathData(outInfo))
+    {
+    return 1;
+    }
+
+  if (this->NeedToExecuteBasedOnCompositeIndices(outInfo))
+    {
+    return 1;
+    }
+
   // We do not need to execute.
   return 0;
 }
@@ -1151,6 +1080,59 @@ int vtkCompositeDataPipeline::NeedToExecuteBasedOnTime(
   return 0;
 }
 
+//----------------------------------------------------------------------------
+int vtkCompositeDataPipeline::NeedToExecuteBasedOnCompositeIndices(vtkInformation* outInfo)
+{
+  if (outInfo->Has(UPDATE_COMPOSITE_INDICES()))
+    {
+    if (!outInfo->Has(COMPOSITE_INDICES()))
+      {
+      return 1;
+      }
+    unsigned int* requested_ids = reinterpret_cast<unsigned int*>(
+      outInfo->Get(UPDATE_COMPOSITE_INDICES()));
+    unsigned int* existing_ids = reinterpret_cast<unsigned int*>(
+      outInfo->Get(COMPOSITE_INDICES()));
+    int length_req = outInfo->Length(UPDATE_COMPOSITE_INDICES());
+    int length_ex = outInfo->Length(COMPOSITE_INDICES());
+    if (length_req > length_ex)
+      {
+      // we are requesting more blocks than those generated.
+      return 1;
+      }
+    int ri=0, ei=0;
+    // NOTE: We are relying on the fact that both these id lists are sorted to
+    // do a more efficient comparison.
+    for (; ri < length_req; ri++)
+      {
+      while (ei < length_ex &&
+        existing_ids[ei] < requested_ids[ri])
+        {
+        ei++;
+        }
+      if (ei >= length_ex)
+        {
+        // we ran beyond the existing length.
+        return 1;
+        }
+      if (existing_ids[ei] != requested_ids[ri])
+        {
+        return 1;
+        }
+      }
+    }
+  else
+    {
+    if (outInfo->Has(COMPOSITE_INDICES()))
+      {
+      // earlier request asked for a some blocks, but the new request is asking
+      // for everything, so re-execute.
+      return 1;
+      }
+    }
+  return 0;
+}
+
 //----------------------------------------------------------------------------
 int vtkCompositeDataPipeline::ForwardUpstream(
   int i, int j, vtkInformation* request)
@@ -1195,32 +1177,25 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
   vtkInformationVector** inInfoVec,
   vtkInformationVector* outInfoVec)
 {
-  int hasUpdateBlocks = 0;
-  if(direction == vtkExecutive::RequestDownstream)
+  this->Superclass::CopyDefaultInformation(request, direction, 
+                                           inInfoVec, outInfoVec);
+
+  if (request->Has(REQUEST_INFORMATION()))
     {
-    vtkInformationKey** keys = request->Get(vtkExecutive::KEYS_TO_COPY());
-    if (keys)
+    if (this->GetNumberOfInputPorts() > 0)
       {
-      int len = request->Length(vtkExecutive::KEYS_TO_COPY());
-      for (int i=0; i<len; i++)
+      if (vtkInformation* inInfo = inInfoVec[0]->GetInformationObject(0))
         {
-        if (keys[i] == vtkCompositeDataPipeline::UPDATE_BLOCKS())
+        // Copy information from the first input to all outputs.
+        for(int i=0; i < outInfoVec->GetNumberOfInformationObjects(); ++i)
           {
-          hasUpdateBlocks = 1;
-          break;
+          vtkInformation* outInfo = outInfoVec->GetInformationObject(i);
+          outInfo->CopyEntry(inInfo, COMPOSITE_DATA_META_DATA());
           }
         }
-      if (hasUpdateBlocks)
-        {
-        request->Remove(vtkExecutive::KEYS_TO_COPY(),
-                        vtkCompositeDataPipeline::UPDATE_BLOCKS());
-        }
       }
     }
 
-  this->Superclass::CopyDefaultInformation(request, direction, 
-                                           inInfoVec, outInfoVec);
-
   if(request->Has(REQUEST_UPDATE_EXTENT()))
     {
     // Find the port that has a data that we will iterator over.
@@ -1255,38 +1230,21 @@ void vtkCompositeDataPipeline::CopyDefaultInformation(
           vtkInformation* inInfo = 
             inInfoVec[compositePort]->GetInformationObject(j);
             
-          if (outInfo->Has(UPDATE_TIME_STEPS()))
-            {
-            inInfo->CopyEntry(outInfo, UPDATE_TIME_STEPS());
-            }
-          if (outInfo->Has(FAST_PATH_OBJECT_ID()))
-            {
-            inInfo->CopyEntry(outInfo, FAST_PATH_OBJECT_ID());
-            }
-          if (outInfo->Has(FAST_PATH_ID_TYPE()))
-            {
-            inInfo->CopyEntry(outInfo, FAST_PATH_ID_TYPE());
-            }
-          if (outInfo->Has(FAST_PATH_OBJECT_TYPE()))
-            {
-            inInfo->CopyEntry(outInfo, FAST_PATH_OBJECT_TYPE());
-            }
+          inInfo->CopyEntry(outInfo, UPDATE_TIME_STEPS());
+          inInfo->CopyEntry(outInfo, FAST_PATH_OBJECT_ID());
+          inInfo->CopyEntry(outInfo, FAST_PATH_ID_TYPE());
+          inInfo->CopyEntry(outInfo, FAST_PATH_OBJECT_TYPE());
           vtkDebugMacro(<< "CopyEntry UPDATE_PIECE_NUMBER() " << outInfo->Get(UPDATE_PIECE_NUMBER()) << " " << outInfo);
 
           inInfo->CopyEntry(outInfo, UPDATE_PIECE_NUMBER());
           inInfo->CopyEntry(outInfo, UPDATE_NUMBER_OF_PIECES());
           inInfo->CopyEntry(outInfo, UPDATE_NUMBER_OF_GHOST_LEVELS());
           inInfo->CopyEntry(outInfo, UPDATE_EXTENT_INITIALIZED());
+          inInfo->CopyEntry(outInfo, UPDATE_COMPOSITE_INDICES());
           }
         }
       }
     }
-
-  if (hasUpdateBlocks)
-    {
-    request->Append(vtkExecutive::KEYS_TO_COPY(), 
-                    vtkCompositeDataPipeline::UPDATE_BLOCKS());
-    }
 }
 
 //----------------------------------------------------------------------------
@@ -1299,9 +1257,9 @@ void vtkCompositeDataPipeline::ResetPipelineInformation(int port,
     }
 
   this->Superclass::ResetPipelineInformation(port, info);
-  info->Remove(COMPOSITE_DATA_INFORMATION());
-  info->Remove(UPDATE_BLOCKS());
   info->Remove(REQUIRES_TIME_DOWNSTREAM());
+  info->Remove(COMPOSITE_DATA_META_DATA());
+  info->Remove(UPDATE_COMPOSITE_INDICES());
 }
 
 //----------------------------------------------------------------------------
@@ -1369,23 +1327,29 @@ int vtkCompositeDataPipeline::CheckCompositeData(
     {
     // This assumes that the first output of the filter is the one
     // that will have the composite data.
-    vtkDataObject* doOutput = 
-      outInfo->Get(vtkDataObject::DATA_OBJECT());
+    vtkDataObject* doOutput = outInfo->Get(vtkDataObject::DATA_OBJECT());
     vtkCompositeDataSet* output = vtkCompositeDataSet::SafeDownCast(doOutput);
     vtkTemporalDataSet* temporal = vtkTemporalDataSet::SafeDownCast(doOutput);
     if (!output || (temporaldownstream && !temporal))
       {
       if (temporaldownstream)
         {
-        vtkDebugMacro(<< "CheckCompositeData Created vtkTemporalDataSet output");
+        vtkDebugMacro(<< "CheckCompositeData created vtkTemporalDataSet output");
         output = vtkTemporalDataSet::New();
         }
       else
         {
-        vtkDebugMacro(<< "CheckCompositeData Created vtkMultiGroupDataSet output");
-        output = vtkMultiGroupDataSet::New();
+        output = this->CreateOutputCompositeDataSet(
+          vtkCompositeDataSet::SafeDownCast(this->GetInputData(compositePort, 0, inInfoVec)),
+            compositePort);
+        vtkDebugMacro(<< "CheckCompositeData created " <<
+          output->GetClassName() << "output");
         }
       output->SetPipelineInformation(outInfo);
+      // Copy extent type to the output port information because
+      // CreateOutputCompositeDataSet() changes it and some algorithms need it.
+      this->GetAlgorithm()->GetOutputPortInformation(port)->Set(
+        vtkDataObject::DATA_EXTENT_TYPE(), output->GetExtentType());
       output->Delete();
       }
     return 1;
@@ -1434,6 +1398,120 @@ vtkDataObject* vtkCompositeDataPipeline::GetCompositeOutputData(int port)
   return 0;
 }
 
+//----------------------------------------------------------------------------
+vtkCompositeDataSet* vtkCompositeDataPipeline::CreateOutputCompositeDataSet(
+  vtkCompositeDataSet* input, int compositePort)
+{
+  // pre: the algorithm is a non-composite algorithm.
+  // pre: we are not create vtkTemporalDataSet for the output, the question is
+  //      whether to create vtkHierarchicalBoxDataSet or vtkMultiBlockDataSet.
+  if (input->IsA("vtkHierarchicalBoxDataSet"))
+    {
+    vtkSmartPointer<vtkUniformGrid> tempInput = vtkSmartPointer<vtkUniformGrid>::New();
+
+    // Check if the algorithm can accept UniformGrid on the input port.
+    vtkInformation* inPortInfo = 
+      this->Algorithm->GetInputPortInformation(compositePort);
+    const char* inputType = 
+      inPortInfo->Get(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE());
+    if (!tempInput->IsA(inputType))
+      {
+      return vtkMultiBlockDataSet::New();
+      }
+
+    vtkInformation* inInfo = this->GetInputInformation(compositePort, 0);
+    vtkSmartPointer<vtkDataObject> curInput = inInfo->Get(vtkDataObject::DATA_OBJECT());
+
+
+    vtkSmartPointer<vtkInformation> request = 
+      vtkSmartPointer<vtkInformation>::New();
+    request->Set(FROM_OUTPUT_PORT(), PRODUCER()->GetPort(inInfo));
+
+    // Set the input to be vtkUniformGrid.
+    inInfo->Remove(vtkDataObject::DATA_OBJECT());
+    inInfo->Set(vtkDataObject::DATA_OBJECT(), tempInput);
+    // Process the whole dataset
+    this->CopyFromDataToInformation(tempInput, inInfo);
+    // The request is forwarded upstream through the pipeline.
+    request->Set(vtkExecutive::FORWARD_DIRECTION(), vtkExecutive::RequestUpstream);
+    // Algorithms process this request after it is forwarded.
+    request->Set(vtkExecutive::ALGORITHM_AFTER_FORWARD(), 1); 
+    request->Set(REQUEST_DATA_OBJECT());
+    this->SuppressResetPipelineInformation = 1;
+    this->Superclass::ExecuteDataObject(
+      request, this->GetInputInformation(),this->GetOutputInformation());
+    this->SuppressResetPipelineInformation = 0;
+    request->Remove(REQUEST_DATA_OBJECT());
+
+    // Restore input.
+    inInfo->Remove(vtkDataObject::DATA_OBJECT());
+    inInfo->Set(vtkDataObject::DATA_OBJECT(), curInput);
+    
+    // check the type of output data object created by the algorithm.
+    vtkInformation* outInfo = this->GetOutputInformation(0);
+    vtkDataObject* curOutput = outInfo->Get(vtkDataObject::DATA_OBJECT());
+    if (!curOutput->IsA("vtkUniformGrid"))
+      {
+      return vtkMultiBlockDataSet::New();
+      }
+    }
+
+  return input->NewInstance();
+}
+
+//----------------------------------------------------------------------------
+void vtkCompositeDataPipeline::MarkOutputsGenerated(
+  vtkInformation* request,
+  vtkInformationVector** inInfoVec,
+  vtkInformationVector* outInfoVec)
+{
+  this->Superclass::MarkOutputsGenerated(request,inInfoVec,outInfoVec);
+
+  // Save the information about COMPOSITE_INDICES() as needed in the data
+  // object.
+  int outputPort = 0;
+  if(request->Has(FROM_OUTPUT_PORT()))
+    {
+    outputPort = request->Get(FROM_OUTPUT_PORT());
+    outputPort = (outputPort >= 0 ? outputPort : 0);
+    }
+
+  for (int i=0; i < outInfoVec->GetNumberOfInformationObjects(); ++i)
+    {
+    vtkInformation* outInfo = outInfoVec->GetInformationObject(i);
+    vtkDataObject* data = outInfo->Get(vtkDataObject::DATA_OBJECT());
+    if (data && !outInfo->Get(DATA_NOT_GENERATED()))
+      {
+      vtkCompositeDataSet* cd = vtkCompositeDataSet::SafeDownCast(data);
+      if (outInfo->Has(UPDATE_COMPOSITE_INDICES()) && cd)
+        {
+        vtkCompositeDataIterator* iter = cd->NewIterator();
+        size_t count = 0;
+        for (iter->InitTraversal(); !iter->IsDoneWithTraversal();
+          iter->GoToNextItem())
+          {
+          count++;
+          }
+        int *indices = new int[count+1];
+        int index=0;
+        for (iter->InitTraversal(); !iter->IsDoneWithTraversal();
+          iter->GoToNextItem(), index++)
+          {
+          indices[index] = static_cast<int>(iter->GetCurrentFlatIndex());
+          }
+        iter->Delete();
+        outInfo->Set(COMPOSITE_INDICES(), indices,
+          static_cast<int>(count));
+        delete []indices;
+        }
+      else
+        {
+        outInfo->Remove(COMPOSITE_INDICES());
+        }
+      }
+    }
+}
+
 //----------------------------------------------------------------------------
 void vtkCompositeDataPipeline::PrintSelf(ostream& os, vtkIndent indent)
 {
