@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPolyData.h,v $
+  Module:    vtkPolyData.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -74,7 +74,7 @@ class VTK_FILTERING_EXPORT vtkPolyData : public vtkPointSet
 public:
   static vtkPolyData *New();
 
-  vtkTypeRevisionMacro(vtkPolyData,vtkPointSet);
+  vtkTypeMacro(vtkPolyData,vtkPointSet);
   void PrintSelf(ostream& os, vtkIndent indent);
 
   // Description:
@@ -288,6 +288,15 @@ public:
   void DeletePoint(vtkIdType ptId);
   void DeleteCell(vtkIdType cellId);
 
+  // Description:
+  // The cells marked by calls to DeleteCell are stored in the Cell Array
+  // VTK_EMPTY_CELL, but they still exist in the polys array.
+  // Calling RemoveDeletedCells will travers the poly array and remove/compact
+  // the cell array as well as any cell data thus truly removing the cells
+  // from the polydata object. WARNING. This only handles the polys 
+  // at the moment
+  void RemoveDeletedCells();
+
   // Description:
   // Add a point to the cell data structure (after cell pointers have been
   // built). This method adds the point and then allocates memory for the
@@ -396,6 +405,40 @@ public:
   static vtkPolyData* GetData(vtkInformationVector* v, int i=0);
   //ETX
 
+  // Description:
+  // Scalar field critical point classification (for manifold 2D meshes).
+  // Reference: J. Milnor "Morse Theory", Princeton University Press, 1963.
+  //     
+  // Given a pointId and an attribute representing a scalar field, this member 
+  // returns the index of the critical point:
+  // vtkPolyData::MINIMUM (index 0): local minimum;
+  // vtkPolyData::SADDLE  (index 1): local saddle;
+  // vtkPolyData::MAXIMUM (index 2): local maximum.
+  //
+  // Other returned values are:
+  // vtkPolyData::REGULAR_POINT: regular point (the gradient does not vanish);
+  // vtkPolyData::ERR_NON_MANIFOLD_STAR: the star of the considered vertex is
+  // not manifold (could not evaluate the index)
+  // vtkPolyData::ERR_INCORRECT_FIELD: the number of entries in the scalar field
+  // array is different form the number of vertices in the mesh.
+  // vtkPolyData::ERR_NO_SUCH_FIELD: the specified scalar field does not exist.
+  //BTX
+  enum
+    {
+    ERR_NO_SUCH_FIELD = -4,
+    ERR_INCORRECT_FIELD = -3,
+    ERR_NON_MANIFOLD_STAR = -2,
+    REGULAR_POINT = -1,
+    MINIMUM = 0,
+    SADDLE = 1,
+    MAXIMUM = 2
+    };
+  //ETX
+  int GetScalarFieldCriticalIndex (vtkIdType pointId, 
+                                   vtkDataArray *scalarField);
+  int GetScalarFieldCriticalIndex (vtkIdType pointId, int fieldId);
+  int GetScalarFieldCriticalIndex (vtkIdType pointId, const char* fieldName);
+
 protected:
   vtkPolyData();
   ~vtkPolyData();
@@ -441,6 +484,8 @@ private:
   void GetCellNeighbors(vtkIdType cellId, vtkIdList& ptIds, vtkIdList& cellIds)
     {this->GetCellNeighbors(cellId, &ptIds, &cellIds);}
 
+  void Cleanup();
+
 private:
   vtkPolyData(const vtkPolyData&);  // Not implemented.
   void operator=(const vtkPolyData&);  // Not implemented.
