@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkStreamingDemandDrivenPipeline.cxx,v $
+  Module:    vtkStreamingDemandDrivenPipeline.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -25,6 +25,7 @@
 #include "vtkInformationIntegerKey.h"
 #include "vtkInformationStringKey.h"
 #include "vtkInformationIdTypeKey.h"
+#include "vtkInformationInformationVectorKey.h"
 #include "vtkInformationIntegerVectorKey.h"
 #include "vtkInformationObjectBaseKey.h"
 #include "vtkInformationRequestKey.h"
@@ -32,13 +33,13 @@
 #include "vtkObjectFactory.h"
 #include "vtkSmartPointer.h"
 
-vtkCxxRevisionMacro(vtkStreamingDemandDrivenPipeline, "$Revision: 1.58 $");
 vtkStandardNewMacro(vtkStreamingDemandDrivenPipeline);
 
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, CONTINUE_EXECUTING, Integer);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, EXACT_EXTENT, Integer);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, REQUEST_UPDATE_EXTENT, Request);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, REQUEST_UPDATE_EXTENT_INFORMATION, Request);
+vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, REQUEST_RESOLUTION_PROPAGATE, Request);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, MAXIMUM_NUMBER_OF_PIECES, Integer);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, UPDATE_EXTENT_INITIALIZED, Integer);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, UPDATE_PIECE_NUMBER, Integer);
@@ -51,12 +52,16 @@ vtkInformationKeyRestrictedMacro(vtkStreamingDemandDrivenPipeline,
                                  EXTENT_TRANSLATOR, ObjectBase,
                                  "vtkExtentTranslator");
 vtkInformationKeyRestrictedMacro(vtkStreamingDemandDrivenPipeline, WHOLE_BOUNDING_BOX, DoubleVector, 6);
-vtkInformationKeyRestrictedMacro(vtkStreamingDemandDrivenPipeline, PIECE_BOUNDING_BOX, DoubleVector, 6);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, TIME_STEPS, DoubleVector);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, UPDATE_TIME_STEPS, DoubleVector);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, PREVIOUS_UPDATE_TIME_STEPS, DoubleVector);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, TIME_RANGE, DoubleVector);
+
+vtkInformationKeyRestrictedMacro(vtkStreamingDemandDrivenPipeline, PIECE_BOUNDING_BOX, DoubleVector, 6);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, PRIORITY, Double);
+vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, UPDATE_RESOLUTION, Double);
+vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, REMOVE_ATTRIBUTE_INFORMATION, Integer);
+
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, FAST_PATH_FOR_TEMPORAL_DATA, Integer);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, FAST_PATH_OBJECT_TYPE, String);
 vtkInformationKeyMacro(vtkStreamingDemandDrivenPipeline, FAST_PATH_ID_TYPE, String);
@@ -129,7 +134,42 @@ int vtkStreamingDemandDrivenPipeline
 
     // If we need to execute, propagate the update extent.
     int result = 1;
-    if(this->NeedToExecuteData(outputPort,inInfoVec,outInfoVec))
+    int N2E = this->NeedToExecuteData(outputPort,inInfoVec,outInfoVec);
+    if (!N2E && 
+        outputPort>-1 && 
+        this->GetNumberOfInputPorts() &&
+        inInfoVec[0]->GetNumberOfInformationObjects () > 0)
+      {
+      vtkInformation* outInfo = outInfoVec->GetInformationObject(outputPort);
+      vtkInformation* inInfo = inInfoVec[0]->GetInformationObject(0);
+      int outNumberOfPieces = outInfo->Get(UPDATE_NUMBER_OF_PIECES());
+      int inNumberOfPieces = inInfo->Get(UPDATE_NUMBER_OF_PIECES());
+      if(inNumberOfPieces != outNumberOfPieces)
+        {
+        N2E = 1;
+        }
+      else
+        {
+        if (outNumberOfPieces != 1)
+          {
+          int outPiece = outInfo->Get(UPDATE_PIECE_NUMBER()); 
+          int inPiece = inInfo->Get(UPDATE_PIECE_NUMBER());
+          if (inPiece != outPiece)
+            {
+            N2E = 1;
+            }
+          else
+            {
+            if (outInfo->Get(UPDATE_RESOLUTION()) !=
+                inInfo->Get(UPDATE_RESOLUTION()))
+              {
+              N2E = 1;
+              }
+            }
+          }
+        }      
+      }
+    if(N2E)
       {
       // Make sure input types are valid before algorithm does anything.
       if(!this->InputCountIsValid(inInfoVec) || 
@@ -325,8 +365,6 @@ vtkStreamingDemandDrivenPipeline
           outInfo->CopyEntry(inInfo, EXTENT_TRANSLATOR());
           outInfo->CopyEntry(inInfo, TIME_STEPS());
           outInfo->CopyEntry(inInfo, TIME_RANGE());
-          outInfo->CopyEntry(inInfo, PIECE_BOUNDING_BOX());
-          outInfo->CopyEntry(inInfo, vtkDataObject::FIELD_RANGE());
           }
         }
       }
@@ -382,6 +420,7 @@ vtkStreamingDemandDrivenPipeline
     }
   if(request->Has(REQUEST_UPDATE_EXTENT()))
     {
+    //Copy requested resolution back
     // Get the output port from which to copy the extent.
     int outputPort = -1;
     if(request->Has(FROM_OUTPUT_PORT()))
@@ -450,6 +489,8 @@ vtkStreamingDemandDrivenPipeline
             continue;
             }
 
+          //Copy requested resolution back
+          inInfo->CopyEntry(outInfo, UPDATE_RESOLUTION());
 
           // Consider all combinations of extent types.
           if(inData->GetExtentType() == VTK_PIECES_EXTENT)
@@ -516,6 +557,136 @@ vtkStreamingDemandDrivenPipeline
         }
       }
     }
+  if(request->Has(REQUEST_UPDATE_EXTENT_INFORMATION()))
+    {
+    // Copy the meta information across that algorithm as long as 
+    // the algorithm doesn't change the information that the meta-information
+    // is about.
+    if(this->GetNumberOfInputPorts() > 0 &&
+       inInfoVec[0]->GetNumberOfInformationObjects() > 0)
+      {
+      vtkInformation* inInfo = inInfoVec[0]->GetInformationObject(0);
+      int oiobj = outInfoVec->GetNumberOfInformationObjects();
+      for(int i=0; i < oiobj; ++i)
+        {
+        vtkInformation* outInfo = outInfoVec->GetInformationObject(i);
+
+        // Copy the priority result always, algorithms can modify it in RUEI if needed
+        outInfo->CopyEntry(inInfo, PRIORITY());
+
+        // Copy the attribute meta information when algorithm is known not to modify it
+        vtkInformation *algsProps = this->GetAlgorithm()->GetInformation();
+        if (
+            algsProps->Has(vtkAlgorithm::PRESERVES_RANGES()) ||
+            algsProps->Has(vtkAlgorithm::PRESERVES_ATTRIBUTES()) ||
+            algsProps->Has(vtkAlgorithm::PRESERVES_DATASET())
+            )
+          {
+          if (inInfo->Has(vtkDataObject::CELL_DATA_VECTOR()))
+            {
+            outInfo->CopyEntry(inInfo, vtkDataObject::CELL_DATA_VECTOR(), 1);
+            }
+          if (inInfo->Has(vtkDataObject::POINT_DATA_VECTOR()))
+            {
+            outInfo->CopyEntry(inInfo, vtkDataObject::POINT_DATA_VECTOR(), 1);
+            }
+          }
+        else
+          {
+          //RI normally passes it on always, so this flag says remove it downstream
+          request->Set(REMOVE_ATTRIBUTE_INFORMATION(), 1);
+          }
+
+        //remove the attribute range information downstream
+        if(request->Has(REMOVE_ATTRIBUTE_INFORMATION()))
+          {
+          vtkInformationVector *miv;
+          miv = outInfo->Get(vtkDataObject::CELL_DATA_VECTOR());
+          if (miv)
+            {
+            int nArrays = miv->GetNumberOfInformationObjects();
+            for (int n = 0; n < nArrays; n++)
+              {
+              vtkInformation *oArray = miv->GetInformationObject(n);
+              oArray->Remove(vtkDataObject::PIECE_FIELD_RANGE());
+              }
+            }
+          miv = outInfo->Get(vtkDataObject::POINT_DATA_VECTOR());
+          if (miv)
+            {
+            int nArrays = miv->GetNumberOfInformationObjects();
+            for (int n = 0; n < nArrays; n++)
+              {
+              vtkInformation *oArray = miv->GetInformationObject(n);
+              oArray->Remove(vtkDataObject::PIECE_FIELD_RANGE());
+              }
+            }
+          }
+
+        // Copy the geometric meta information when algorithm is known not to modify it
+        if (
+            algsProps->Has(vtkAlgorithm::PRESERVES_BOUNDS()) ||
+            algsProps->Has(vtkAlgorithm::PRESERVES_GEOMETRY()) ||
+            algsProps->Has(vtkAlgorithm::PRESERVES_DATASET())
+            )
+          {
+          outInfo->CopyEntry(inInfo, PIECE_BOUNDING_BOX());          
+          }        
+
+        // Copy the topological meta information when algorithm is known not to modify it
+        if (
+            algsProps->Has(vtkAlgorithm::PRESERVES_TOPOLOGY()) ||
+            algsProps->Has(vtkAlgorithm::PRESERVES_DATASET())
+            )
+          {
+          outInfo->CopyEntry(inInfo, vtkDataObject::DATA_GEOMETRY_UNMODIFIED());
+          }        
+        }
+      }
+    }
+
+  if(request->Has(REQUEST_RESOLUTION_PROPAGATE()))
+    {
+    // Get the output port from which to copy the extent.
+    int outputPort = -1;
+    if(request->Has(FROM_OUTPUT_PORT()))
+      {
+      outputPort = request->Get(FROM_OUTPUT_PORT());
+      }
+
+    // Setup default information for the inputs.
+    if(outInfoVec->GetNumberOfInformationObjects() > 0)
+      {
+      // Copy information from the output port that made the request.
+      // Since VerifyOutputInformation has already been called we know
+      // there is output information with a data object.
+      vtkInformation* outInfo =
+        outInfoVec->GetInformationObject((outputPort >= 0)? outputPort : 0);
+
+      // Loop over all input ports.
+      for(int i=0; i < this->Algorithm->GetNumberOfInputPorts(); ++i)
+        {
+        // Loop over all connections on this input port.
+        int numInConnections = inInfoVec[i]->GetNumberOfInformationObjects();
+        for (int j=0; j<numInConnections; j++)
+          {
+          // Get the pipeline information for this input connection.
+          vtkInformation* inInfo = inInfoVec[i]->GetInformationObject(j);
+
+          //Copy requested resolution back
+          inInfo->CopyEntry(outInfo, UPDATE_RESOLUTION());
+
+          vtkDataObject *inData = inInfo->Get(vtkDataObject::DATA_OBJECT());
+          if (inData)
+            {
+            vtkInformation* dataInfo = inData->GetInformation();
+            dataInfo->Set(vtkDataObject::DATA_RESOLUTION(), -1.0);
+            }
+          }
+        }
+      }
+    }
+
 }
 
 //----------------------------------------------------------------------------
@@ -531,6 +702,7 @@ vtkStreamingDemandDrivenPipeline
   info->Remove(UPDATE_EXTENT_INITIALIZED());
   info->Remove(UPDATE_EXTENT());
   info->Remove(UPDATE_PIECE_NUMBER());
+  info->Remove(UPDATE_RESOLUTION());
   info->Remove(UPDATE_NUMBER_OF_PIECES());
   info->Remove(UPDATE_NUMBER_OF_GHOST_LEVELS());
   info->Remove(UPDATE_EXTENT_TRANSLATED());
@@ -690,18 +862,21 @@ int vtkStreamingDemandDrivenPipeline
         updateExtent[2] <= updateExtent[3] &&
         updateExtent[4] <= updateExtent[5]))
       {
-      // Update extent is outside the whole extent and is not empty.
-      vtkErrorMacro("The update extent specified in the "
-                    "information for output port " << outputPort
-                    << " on algorithm " << this->Algorithm->GetClassName()
-                    << "(" << this->Algorithm << ") is "
-                    << updateExtent[0] << " " << updateExtent[1] << " "
-                    << updateExtent[2] << " " << updateExtent[3] << " "
-                    << updateExtent[4] << " " << updateExtent[5]
-                    << ", which is outside the whole extent "
-                    << wholeExtent[0] << " " << wholeExtent[1] << " "
-                    << wholeExtent[2] << " " << wholeExtent[3] << " "
-                    << wholeExtent[4] << " " << wholeExtent[5] << ".");
+      if (!outInfo->Has(UPDATE_RESOLUTION()))
+        {
+        // Update extent is outside the whole extent and is not empty.
+        vtkErrorMacro("The update extent specified in the "
+                      "information for output port " << outputPort
+                      << " on algorithm " << this->Algorithm->GetClassName()
+                      << "(" << this->Algorithm << ") is "
+                      << updateExtent[0] << " " << updateExtent[1] << " "
+                      << updateExtent[2] << " " << updateExtent[3] << " "
+                      << updateExtent[4] << " " << updateExtent[5]
+                      << ", which is outside the whole extent "
+                      << wholeExtent[0] << " " << wholeExtent[1] << " "
+                      << wholeExtent[2] << " " << wholeExtent[3] << " "
+                      << wholeExtent[4] << " " << wholeExtent[5] << ".");
+        }
       return 0;
       }
     }
@@ -843,6 +1018,25 @@ vtkStreamingDemandDrivenPipeline
         dataInfo->Set(vtkDataObject::DATA_NUMBER_OF_GHOST_LEVELS(), ghostLevel);
         }
         
+      if (!dataInfo->Has(vtkDataObject::DATA_RESOLUTION()) &&
+          outInfo->Has(UPDATE_RESOLUTION()))
+        {
+        // It does not. 
+        // Does the input have it? If yes, copy it.
+        vtkDataObject* input = 0;
+        if (this->GetNumberOfInputPorts() > 0)
+          {
+          input = this->GetInputData(0, 0);
+          }
+        if (input && 
+            input->GetInformation()->Has(vtkDataObject::DATA_RESOLUTION()))
+          {
+          dataInfo->CopyEntry(input->GetInformation(),
+                              vtkDataObject::DATA_RESOLUTION(),
+                              1);
+          }
+        }
+
       // In this block, we make sure that DATA_TIME_STEPS() is set if:
       // * There was someone upstream that supports time (TIME_RANGE() key
       //   is present)
@@ -959,6 +1153,13 @@ int vtkStreamingDemandDrivenPipeline
   vtkInformation* outInfo = outInfoVec->GetInformationObject(outputPort);
   vtkDataObject* dataObject = outInfo->Get(vtkDataObject::DATA_OBJECT());
   vtkInformation* dataInfo = dataObject->GetInformation();
+  double updateResolution = outInfo->Get(UPDATE_RESOLUTION());
+  double dataResolution = dataInfo->Get(vtkDataObject::DATA_RESOLUTION());
+  if (dataResolution == -1.0 || updateResolution > dataResolution)
+    {
+    return 1;
+    }
+
   if(dataInfo->Get(vtkDataObject::DATA_EXTENT_TYPE()) == VTK_PIECES_EXTENT
      || dataInfo->Get(vtkDataObject::DATA_EXTENT_TYPE()) == VTK_TIME_EXTENT)
     {
@@ -1436,6 +1637,31 @@ int vtkStreamingDemandDrivenPipeline
   return modified;
 }
 
+//----------------------------------------------------------------------------
+int vtkStreamingDemandDrivenPipeline
+::SetUpdateResolution(int port, double resolution)
+{
+  return this->SetUpdateResolution(GetOutputInformation(port), resolution);
+}
+
+//----------------------------------------------------------------------------
+int vtkStreamingDemandDrivenPipeline
+::SetUpdateResolution(vtkInformation *info, double resolution)
+{
+  if(!info)
+    {
+    vtkErrorMacro("SetUpdateResolution on invalid output");
+    return 0;
+    }
+  int modified = 0;
+  if(this->GetUpdateResolution(info) != resolution)
+    {
+    info->Set(UPDATE_RESOLUTION(), resolution);
+    modified = 1;
+    }
+  return modified;
+}
+
 //----------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline::SetUpdateTimeStep(int port, double time)
 {
@@ -1508,6 +1734,22 @@ int vtkStreamingDemandDrivenPipeline
   return info->Get(UPDATE_PIECE_NUMBER());
 }
 
+//----------------------------------------------------------------------------
+double vtkStreamingDemandDrivenPipeline
+::GetUpdateResolution(vtkInformation *info)
+{
+  if(!info)
+    {
+    vtkErrorMacro("GetUpdateResolution on invalid output");
+    return 0;
+    }
+  if(!info->Has(UPDATE_RESOLUTION()))
+    {
+    info->Set(UPDATE_RESOLUTION(), 1.0);
+    }
+  return info->Get(UPDATE_RESOLUTION());
+}
+
 //----------------------------------------------------------------------------
 int vtkStreamingDemandDrivenPipeline
 ::SetUpdateNumberOfPieces(vtkInformation *info, int n)
@@ -1688,18 +1930,8 @@ int vtkStreamingDemandDrivenPipeline::SetWholeBoundingBox(int port,
 //----------------------------------------------------------------------------
 void vtkStreamingDemandDrivenPipeline::GetWholeBoundingBox(int port, double extent[6])
 {
-  static double emptyBoundingBox[6] = {0,-1,0,-1,0,-1};
-  if(!this->OutputPortIndexInRange(port, "get whole bounding box from"))
-    {
-    memcpy(extent, emptyBoundingBox, sizeof(double)*6);
-    return;
-    }
-  vtkInformation* info = this->GetOutputInformation(port);
-  if(!info->Has(WHOLE_BOUNDING_BOX()))
-    {
-    info->Set(WHOLE_BOUNDING_BOX(), emptyBoundingBox, 6);
-    }
-  info->Get(WHOLE_BOUNDING_BOX(), extent);
+  double *bbox = this->GetWholeBoundingBox(port);
+  memcpy(extent, bbox, 6*sizeof(double));
 }
 
 //----------------------------------------------------------------------------
@@ -1718,16 +1950,88 @@ double* vtkStreamingDemandDrivenPipeline::GetWholeBoundingBox(int port)
   return info->Get(WHOLE_BOUNDING_BOX());
 }
 
+//----------------------------------------------------------------------------
+int vtkStreamingDemandDrivenPipeline::SetPieceBoundingBox(int port, 
+                                                          double extent[6])
+{
+  if(!this->OutputPortIndexInRange(port, "set piece bounding box on"))
+    {
+    return 0;
+    }
+  vtkInformation* info = this->GetOutputInformation(port);
+  int modified = 0;
+  double oldBoundingBox[6];
+  this->GetPieceBoundingBox(port, oldBoundingBox);
+  if(oldBoundingBox[0] != extent[0] || oldBoundingBox[1] != extent[1] ||
+     oldBoundingBox[2] != extent[2] || oldBoundingBox[3] != extent[3] ||
+     oldBoundingBox[4] != extent[4] || oldBoundingBox[5] != extent[5])
+    {
+    modified = 1;
+    info->Set(PIECE_BOUNDING_BOX(), extent, 6);
+    }
+  return modified;
+}
+
+//----------------------------------------------------------------------------
+void vtkStreamingDemandDrivenPipeline::GetPieceBoundingBox(int port, double extent[6])
+{
+  double *bbox = this->GetPieceBoundingBox(port);
+  memcpy(extent, bbox, 6*sizeof(double));
+}
+
+//----------------------------------------------------------------------------
+double* vtkStreamingDemandDrivenPipeline::GetPieceBoundingBox(int port)
+{
+  static double emptyBoundingBox[6] = {0,-1,0,-1,0,-1};
+  if(!this->OutputPortIndexInRange(port, "get piece bounding box from"))
+    {
+    return emptyBoundingBox;
+    }
+  vtkInformation* info = this->GetOutputInformation(port);
+  if(!info->Has(PIECE_BOUNDING_BOX()))
+    {
+    info->Set(PIECE_BOUNDING_BOX(), emptyBoundingBox, 6);
+    }
+  return info->Get(PIECE_BOUNDING_BOX());
+}
+
 //----------------------------------------------------------------------------
 double vtkStreamingDemandDrivenPipeline::ComputePriority(int port)
 {
   vtkInformation* rqst;
-
   vtkInformationVector **inVec = this->GetInputInformation();
   vtkInformationVector *outVec = this->GetOutputInformation();
 
+  //tell pipeline what piece to ask about
+  rqst = vtkInformation::New();
+  rqst->Set(REQUEST_RESOLUTION_PROPAGATE());
+  rqst->Set(vtkExecutive::FORWARD_DIRECTION(),
+            vtkExecutive::RequestUpstream);
+  rqst->Set(vtkExecutive::ALGORITHM_BEFORE_FORWARD(), 1);
+  rqst->Set(vtkExecutive::FROM_OUTPUT_PORT(), port);
+  this->ProcessRequest(rqst, inVec, outVec);
+  rqst->Delete();
+
   //make sure global information is up to date
-  this->UpdateInformation();
+  rqst = vtkInformation::New();
+  rqst->Set(REQUEST_DATA_OBJECT());
+  rqst->Set(REQUEST_REGENERATE_INFORMATION(), 1);
+  rqst->Set(vtkExecutive::FORWARD_DIRECTION(),
+            vtkExecutive::RequestUpstream);
+  rqst->Set(vtkExecutive::ALGORITHM_AFTER_FORWARD(), 1);
+  rqst->Set(vtkExecutive::FROM_OUTPUT_PORT(), port);
+  this->ProcessRequest(rqst, inVec, outVec);
+  rqst->Delete();
+
+  rqst = vtkInformation::New();
+  rqst->Set(REQUEST_INFORMATION());
+  rqst->Set(REQUEST_REGENERATE_INFORMATION(), 1);
+  rqst->Set(vtkExecutive::FORWARD_DIRECTION(),
+            vtkExecutive::RequestUpstream);
+  rqst->Set(vtkExecutive::ALGORITHM_AFTER_FORWARD(), 1);
+  rqst->Set(vtkExecutive::FROM_OUTPUT_PORT(), port);
+  this->ProcessRequest(rqst, inVec, outVec);
+  rqst->Delete();
 
   //tell pipeline what piece to ask about
   rqst = vtkInformation::New();
@@ -1746,13 +2050,6 @@ double vtkStreamingDemandDrivenPipeline::ComputePriority(int port)
             vtkExecutive::RequestUpstream);
   rqst->Set(vtkExecutive::ALGORITHM_AFTER_FORWARD(), 1);
   rqst->Set(vtkExecutive::FROM_OUTPUT_PORT(), port);
-  //be sure pipeline propagates
-  //scalar ranges
-  rqst->Append(vtkExecutive::KEYS_TO_COPY(), vtkDataObject::FIELD_RANGE());
-  //geometric extent
-  rqst->Append(vtkExecutive::KEYS_TO_COPY(), PIECE_BOUNDING_BOX());
-  //result
-  rqst->Append(vtkExecutive::KEYS_TO_COPY(), PRIORITY());
   this->ProcessRequest(rqst, inVec, outVec);
   rqst->Delete();
 
@@ -1763,7 +2060,6 @@ double vtkStreamingDemandDrivenPipeline::ComputePriority(int port)
     {
     priority = info->Get(PRIORITY());
     }
-
   return priority;
 }
 
@@ -1783,9 +2079,10 @@ void vtkStreamingDemandDrivenPipeline::ResetUpdateInformation(
       vtkInformation* inInfo = inInfoVec[cc]->GetInformationObject(kk);
       if (inInfo)
         {
-        inInfo->Remove(vtkStreamingDemandDrivenPipeline::FAST_PATH_OBJECT_ID());
-        inInfo->Remove(vtkStreamingDemandDrivenPipeline::FAST_PATH_OBJECT_TYPE());
-        inInfo->Remove(vtkStreamingDemandDrivenPipeline::FAST_PATH_ID_TYPE());
+        inInfo->Remove(FAST_PATH_OBJECT_ID());
+        inInfo->Remove(FAST_PATH_OBJECT_TYPE());
+        inInfo->Remove(FAST_PATH_ID_TYPE());
+        inInfo->Remove(UPDATE_RESOLUTION());
         }
       }
     }
