@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkExtractSelectedIds.cxx,v $
+  Module:    vtkExtractSelectedIds.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -18,9 +18,6 @@
 #include "vtkCellData.h"
 #include "vtkCellType.h"
 #include "vtkExtractCells.h"
-#include "vtkSignedCharArray.h"
-#include "vtkSortDataArray.h"
-#include "vtkSmartPointer.h"
 #include "vtkIdList.h"
 #include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
@@ -29,10 +26,14 @@
 #include "vtkPointData.h"
 #include "vtkPolyData.h"
 #include "vtkSelection.h"
+#include "vtkSelectionNode.h"
+#include "vtkSignedCharArray.h"
+#include "vtkSmartPointer.h"
+#include "vtkSortDataArray.h"
 #include "vtkStdString.h"
+#include "vtkStringArray.h"
 #include "vtkUnstructuredGrid.h"
 
-vtkCxxRevisionMacro(vtkExtractSelectedIds, "$Revision: 1.28 $");
 vtkStandardNewMacro(vtkExtractSelectedIds);
 
 //----------------------------------------------------------------------------
@@ -46,6 +47,20 @@ vtkExtractSelectedIds::~vtkExtractSelectedIds()
 {
 }
 
+//----------------------------------------------------------------------------
+int vtkExtractSelectedIds::FillInputPortInformation(
+  int port, vtkInformation* info)
+{
+  this->Superclass::FillInputPortInformation(port, info);
+  if (port==0)
+    {
+    // this filter can only work with datasets.
+    info->Remove(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE()); 
+    info->Set(vtkAlgorithm::INPUT_REQUIRED_DATA_TYPE(), "vtkDataSet"); 
+    }
+  return 1;
+}
+
 //----------------------------------------------------------------------------
 int vtkExtractSelectedIds::RequestData(
   vtkInformation *vtkNotUsed(request),
@@ -73,17 +88,23 @@ int vtkExtractSelectedIds::RequestData(
     }
   vtkSelection *sel = vtkSelection::SafeDownCast(
     selInfo->Get(vtkDataObject::DATA_OBJECT()));
-  if (!sel->GetProperties()->Has(vtkSelection::CONTENT_TYPE())
-      || 
-      (
-        sel->GetProperties()->Get(vtkSelection::CONTENT_TYPE()) != vtkSelection::GLOBALIDS &&
-        sel->GetProperties()->Get(vtkSelection::CONTENT_TYPE()) != vtkSelection::PEDIGREEIDS &&
-        sel->GetProperties()->Get(vtkSelection::CONTENT_TYPE()) != vtkSelection::VALUES &&  
-        sel->GetProperties()->Get(vtkSelection::CONTENT_TYPE()) != vtkSelection::INDICES
-        )
-    )
+  vtkSelectionNode *node = 0;
+  if (sel->GetNumberOfNodes() == 1)
     {
-    vtkErrorMacro("Missing or incompatible CONTENT_TYPE.");
+    node = sel->GetNode(0);
+    }
+  if (!node)
+    {
+    vtkErrorMacro("Selection must have a single node.");
+    return 0;
+    }
+  if (node->GetContentType() != vtkSelectionNode::GLOBALIDS &&
+      node->GetContentType() != vtkSelectionNode::PEDIGREEIDS &&
+      node->GetContentType() != vtkSelectionNode::VALUES &&  
+      node->GetContentType() != vtkSelectionNode::INDICES
+      )
+    {
+    vtkErrorMacro("Incompatible CONTENT_TYPE.");
     return 0;
     }
 
@@ -92,18 +113,18 @@ int vtkExtractSelectedIds::RequestData(
 
   vtkDebugMacro(<< "Extracting from dataset");
   
-  int fieldType = vtkSelection::CELL;
-  if (sel->GetProperties()->Has(vtkSelection::FIELD_TYPE()))
+  int fieldType = vtkSelectionNode::CELL;
+  if (node->GetProperties()->Has(vtkSelectionNode::FIELD_TYPE()))
     {
-    fieldType = sel->GetProperties()->Get(vtkSelection::FIELD_TYPE());
+    fieldType = node->GetProperties()->Get(vtkSelectionNode::FIELD_TYPE());
     }
   switch (fieldType)
     {
-    case vtkSelection::CELL:
-      return this->ExtractCells(sel, input, output);
+    case vtkSelectionNode::CELL:
+      return this->ExtractCells(node, input, output);
       break;
-    case vtkSelection::POINT:
-      return this->ExtractPoints(sel, input, output);
+    case vtkSelectionNode::POINT:
+      return this->ExtractPoints(node, input, output);
     }
   return 1;
 }
@@ -186,9 +207,107 @@ void vtkExtractSelectedIdsCopyCells(vtkDataSet* input, T* output,
   ptIds->Delete();
 }
 
+#define vtkESI_ExtendedTemplateMacro(t1, t2, call)\
+  switch (t1)\
+    {\
+    vtkTemplateMacro(\
+      typedef VTK_TT VTK_TT1;\
+      switch (t2)\
+        {\
+        vtkTemplateMacro(\
+          typedef VTK_TT VTK_TT2;\
+          call;);\
+        }\
+    );\
+    \
+  case VTK_STRING:\
+     {\
+     typedef vtkStdString VTK_TT1;\
+     typedef vtkStdString VTK_TT2;\
+     call;\
+     }\
+    }
+
+namespace
+{
+  template <class T>
+  void vtkESIDeepCopyImpl(T* out, T* in, int compno, int num_comps,
+    vtkIdType numTuples)
+    {
+    if (compno < 0)
+      {
+      for (vtkIdType cc=0; cc < numTuples; cc++)
+        {
+        double mag = 0;
+        for (int comp=0; comp < num_comps; comp++)
+          {
+          mag += in[comp]*in[comp];
+          }
+        mag = sqrt(mag);
+        *out = static_cast<T>(mag);
+        out++;
+        in += num_comps;
+        }
+      }
+    else
+      {
+      for (vtkIdType cc=0; cc < numTuples; cc++)
+        {
+        *out = in[compno];
+        out++;
+        in += num_comps;
+        }
+      }
+    }
+
+  void vtkESIDeepCopyImpl(vtkStdString* out, vtkStdString* in,
+    int compno, int num_comps, vtkIdType numTuples)
+    {
+    if (compno < 0)
+      {
+      // we cannot compute magnitudes for string arrays!
+      compno = 0;
+      }
+    for (vtkIdType cc=0; cc < numTuples; cc++)
+      {
+      *out = in[compno];
+      out++;
+      in += num_comps;
+      }
+    }
+
+  // Deep copies a specified component (or magnitude of compno < 0).
+  static void vtkESIDeepCopy(vtkAbstractArray* out, vtkAbstractArray* in, int compno)
+    {
+    if (in->GetNumberOfComponents() == 1)
+      {
+      //trivial case.
+      out->DeepCopy(in);
+      return;
+      }
+
+    vtkIdType numTuples = in->GetNumberOfTuples();
+    out->SetNumberOfComponents(1);
+    out->SetNumberOfTuples(numTuples);
+    switch (in->GetDataType())
+      {
+      vtkTemplateMacro(
+        vtkESIDeepCopyImpl<VTK_TT>(
+          static_cast<VTK_TT*>(out->GetVoidPointer(0)),
+          static_cast<VTK_TT*>(in->GetVoidPointer(0)),
+          compno, in->GetNumberOfComponents(), numTuples));
+    case VTK_STRING:
+      vtkESIDeepCopyImpl(
+        static_cast<vtkStdString*>(out->GetVoidPointer(0)),
+        static_cast<vtkStdString*>(in->GetVoidPointer(0)),
+        compno, in->GetNumberOfComponents(), numTuples);
+      break;
+      }
+    }
+};
 //----------------------------------------------------------------------------
 int vtkExtractSelectedIds::ExtractCells(
-  vtkSelection *sel,  vtkDataSet *input,
+  vtkSelectionNode *sel,  vtkDataSet *input,
   vtkDataSet *output)
 {
   int passThrough = 0;
@@ -198,9 +317,9 @@ int vtkExtractSelectedIds::ExtractCells(
     }
 
   int invert = 0;
-  if (sel->GetProperties()->Has(vtkSelection::INVERSE()))
+  if (sel->GetProperties()->Has(vtkSelectionNode::INVERSE()))
     {
-    invert = sel->GetProperties()->Get(vtkSelection::INVERSE());
+    invert = sel->GetProperties()->Get(vtkSelectionNode::INVERSE());
     }
 
   vtkIdType i, numPts = input->GetNumberOfPoints();
@@ -237,17 +356,17 @@ int vtkExtractSelectedIds::ExtractCells(
 
   //decide what the IDS mean
   vtkAbstractArray *labelArray = NULL;
-  int selType = sel->GetProperties()->Get(vtkSelection::CONTENT_TYPE());
-  if (selType == vtkSelection::GLOBALIDS)
+  int selType = sel->GetProperties()->Get(vtkSelectionNode::CONTENT_TYPE());
+  if (selType == vtkSelectionNode::GLOBALIDS)
     {
     labelArray = vtkIdTypeArray::SafeDownCast(
       input->GetCellData()->GetGlobalIds());
     }
-  else if (selType == vtkSelection::PEDIGREEIDS)
+  else if (selType == vtkSelectionNode::PEDIGREEIDS)
     {
     labelArray = input->GetCellData()->GetPedigreeIds();
     }
-  else if (selType == vtkSelection::VALUES &&
+  else if (selType == vtkSelectionNode::VALUES &&
            sel->GetSelectionList()->GetName())
     {
     //user chose a specific label array
@@ -255,7 +374,7 @@ int vtkExtractSelectedIds::ExtractCells(
         sel->GetSelectionList()->GetName());
     }    
   
-  if (labelArray == NULL && selType != vtkSelection::INDICES)
+  if (labelArray == NULL && selType != vtkSelectionNode::INDICES)
     {
     return 1;
     }
@@ -269,10 +388,21 @@ int vtkExtractSelectedIds::ExtractCells(
     }
 
   if (labelArray)
-    {
+    {    
+    int component_no = 0;
+    if (sel->GetProperties()->Has(vtkSelectionNode::COMPONENT_NUMBER()))
+      {
+      component_no =
+        sel->GetProperties()->Get(vtkSelectionNode::COMPONENT_NUMBER());
+      if (component_no >= labelArray->GetNumberOfComponents())
+        {
+        component_no = 0;
+        }
+      }
+
     vtkAbstractArray* sortedArray = 
       vtkAbstractArray::CreateArray(labelArray->GetDataType());
-    sortedArray->DeepCopy(labelArray);
+    vtkESIDeepCopy(sortedArray, labelArray, component_no);
     vtkSortDataArray::Sort(sortedArray, idxArray);
     labelArray = sortedArray;
     }
@@ -326,8 +456,9 @@ int vtkExtractSelectedIds::ExtractCells(
     return 1;
     }
   
-  // Array types must match
-  if (idArray->GetDataType() != labelArray->GetDataType())
+  // Array types must match if they are string arrays.
+  if (vtkStringArray::SafeDownCast(labelArray) &&
+    vtkStringArray::SafeDownCast(idArray) == NULL)
     {
     labelArray->Delete();
     idxArray->Delete();
@@ -340,12 +471,15 @@ int vtkExtractSelectedIds::ExtractCells(
       {
       delete[] cellCounter;
       }
-    vtkWarningMacro("array types don't match");
+    vtkWarningMacro(
+      "Array types don't match. They must match for vtkStringArray.");
     return 0;
     }
 
   void *idVoid = idArray->GetVoidPointer(0);
   void *labelVoid = labelArray->GetVoidPointer(0);
+  int idArrayType = idArray->GetDataType();
+  int labelArrayType = labelArray->GetDataType();
 
   // Check each cell to see if it's selected
   while (labelArrayIndex < numCells)
@@ -355,13 +489,12 @@ int vtkExtractSelectedIds::ExtractCells(
     bool idLessThanLabel = false;
     if (idArrayIndex < numIds)
       {
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idLessThanLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] <
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idLessThanLabel = 
+        (static_cast<VTK_TT1*>(idVoid)[idArrayIndex]) <
+        static_cast<VTK_TT1>(
+          (static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex])));
       }
     while ((idArrayIndex < numIds) && idLessThanLabel)
       {
@@ -370,13 +503,12 @@ int vtkExtractSelectedIds::ExtractCells(
         {
         break;
         }
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idLessThanLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] <
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idLessThanLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
 
     if (idArrayIndex >= numIds)
@@ -391,13 +523,12 @@ int vtkExtractSelectedIds::ExtractCells(
     bool idEqualToLabel = false;
     if (labelArrayIndex < numCells)
       {
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idEqualToLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] ==
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idEqualToLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] ==
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
     while ((labelArrayIndex < numCells) && idEqualToLabel)
       {
@@ -425,13 +556,12 @@ int vtkExtractSelectedIds::ExtractCells(
         {
         break;
         }
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idEqualToLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] ==
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idEqualToLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] ==
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
       
 
@@ -440,13 +570,12 @@ int vtkExtractSelectedIds::ExtractCells(
     bool labelLessThanId = false;
     if (labelArrayIndex < numCells)
       {
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          labelLessThanId = 
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex] <
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        labelArrayType, idArrayType,
+        labelLessThanId = 
+        static_cast<VTK_TT1*>(labelVoid)[labelArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(idVoid)[idArrayIndex]));
       }
     while ((labelArrayIndex < numCells) && labelLessThanId)
       {
@@ -455,13 +584,11 @@ int vtkExtractSelectedIds::ExtractCells(
         {
         break;
         }
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          labelLessThanId = 
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex] <
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(labelArrayType, idArrayType,
+        labelLessThanId = 
+        static_cast<VTK_TT1*>(labelVoid)[labelArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(idVoid)[idArrayIndex]));
       }
     }
 
@@ -516,7 +643,7 @@ int vtkExtractSelectedIds::ExtractCells(
 
 //----------------------------------------------------------------------------
 int vtkExtractSelectedIds::ExtractPoints(
-  vtkSelection *sel,  vtkDataSet *input,
+  vtkSelectionNode *sel,  vtkDataSet *input,
   vtkDataSet *output)
 {
   int passThrough = 0;
@@ -526,15 +653,15 @@ int vtkExtractSelectedIds::ExtractPoints(
     }
 
   int containingCells = 0;
-  if (sel->GetProperties()->Has(vtkSelection::CONTAINING_CELLS()))
+  if (sel->GetProperties()->Has(vtkSelectionNode::CONTAINING_CELLS()))
     {
-    containingCells = sel->GetProperties()->Get(vtkSelection::CONTAINING_CELLS());
+    containingCells = sel->GetProperties()->Get(vtkSelectionNode::CONTAINING_CELLS());
     }
 
   int invert = 0;
-  if (sel->GetProperties()->Has(vtkSelection::INVERSE()))
+  if (sel->GetProperties()->Has(vtkSelectionNode::INVERSE()))
     {
-    invert = sel->GetProperties()->Get(vtkSelection::INVERSE());
+    invert = sel->GetProperties()->Get(vtkSelectionNode::INVERSE());
     }
 
   vtkIdType i, numPts = input->GetNumberOfPoints();
@@ -578,24 +705,24 @@ int vtkExtractSelectedIds::ExtractPoints(
 
   //decide what the IDS mean
   vtkAbstractArray *labelArray = NULL;
-  int selType = sel->GetProperties()->Get(vtkSelection::CONTENT_TYPE());
-  if (selType == vtkSelection::GLOBALIDS)
+  int selType = sel->GetProperties()->Get(vtkSelectionNode::CONTENT_TYPE());
+  if (selType == vtkSelectionNode::GLOBALIDS)
     {
     labelArray = vtkIdTypeArray::SafeDownCast(
       input->GetPointData()->GetGlobalIds());
     }
-  else if (selType == vtkSelection::PEDIGREEIDS)
+  else if (selType == vtkSelectionNode::PEDIGREEIDS)
     {
     labelArray = input->GetPointData()->GetPedigreeIds();
     }
-  else if (selType == vtkSelection::VALUES &&
+  else if (selType == vtkSelectionNode::VALUES &&
            sel->GetSelectionList()->GetName())
     {
     //user chose a specific label array
     labelArray = input->GetPointData()->GetAbstractArray(
       sel->GetSelectionList()->GetName());
     }
-  if (labelArray == NULL && selType != vtkSelection::INDICES)
+  if (labelArray == NULL && selType != vtkSelectionNode::INDICES)
     {
     return 1;
     }
@@ -610,9 +737,20 @@ int vtkExtractSelectedIds::ExtractPoints(
 
   if (labelArray)
     {
+    int component_no = 0;
+    if (sel->GetProperties()->Has(vtkSelectionNode::COMPONENT_NUMBER()))
+      {
+      component_no =
+        sel->GetProperties()->Get(vtkSelectionNode::COMPONENT_NUMBER());
+      if (component_no >= labelArray->GetNumberOfComponents())
+        {
+        component_no = 0;
+        }
+      }
+
     vtkAbstractArray* sortedArray = 
       vtkAbstractArray::CreateArray(labelArray->GetDataType());
-    sortedArray->DeepCopy(labelArray);
+    vtkESIDeepCopy(sortedArray, labelArray, component_no);
     vtkSortDataArray::Sort(sortedArray, idxArray);
     labelArray = sortedArray;
     }
@@ -639,10 +777,12 @@ int vtkExtractSelectedIds::ExtractPoints(
     return 1;
     }
 
-  // Array types must match
-  if (idArray->GetDataType() != labelArray->GetDataType())
+  // Array types must match if they are string arrays.
+  if (vtkStringArray::SafeDownCast(labelArray) &&
+    vtkStringArray::SafeDownCast(idArray) == NULL)
     {
-    vtkWarningMacro("array types don't match");
+    vtkWarningMacro(
+      "Array types don't match. They must match for vtkStringArray.");
     labelArray->Delete();
     idxArray->Delete();
     ptCells->Delete();
@@ -659,6 +799,8 @@ int vtkExtractSelectedIds::ExtractPoints(
 
   void *idVoid = idArray->GetVoidPointer(0);
   void *labelVoid = labelArray->GetVoidPointer(0);
+  int idArrayType = idArray->GetDataType();
+  int labelArrayType = labelArray->GetDataType();
 
   // Check each point to see if it's selected
   while (labelArrayIndex < numPts)
@@ -668,13 +810,12 @@ int vtkExtractSelectedIds::ExtractPoints(
     bool idLessThanLabel = false;
     if (idArrayIndex < numIds)
       {
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idLessThanLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] <
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idLessThanLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
     while ((idArrayIndex < numIds) && idLessThanLabel)
       {
@@ -683,13 +824,12 @@ int vtkExtractSelectedIds::ExtractPoints(
         {
         break;
         }
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idLessThanLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] <
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idLessThanLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
 
     this->UpdateProgress(static_cast<double>(idArrayIndex) / (numIds * (passThrough + 1)));
@@ -704,13 +844,12 @@ int vtkExtractSelectedIds::ExtractPoints(
     bool idEqualToLabel = false;
     if (labelArrayIndex < numPts)
       {
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idEqualToLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] ==
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idEqualToLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] ==
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
     while ((labelArrayIndex < numPts) && idEqualToLabel)
       {
@@ -741,13 +880,12 @@ int vtkExtractSelectedIds::ExtractPoints(
         {
         break;
         }
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          idEqualToLabel = 
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex] ==
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        idArrayType, labelArrayType,
+        idEqualToLabel = 
+        static_cast<VTK_TT1*>(idVoid)[idArrayIndex] ==
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(labelVoid)[labelArrayIndex]));
       }
 
     // Advance through point labels until we find
@@ -755,13 +893,12 @@ int vtkExtractSelectedIds::ExtractPoints(
     bool labelLessThanId = false;
     if (labelArrayIndex < numPts)
       {
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          labelLessThanId = 
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex] <
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(
+        labelArrayType, idArrayType,
+        labelLessThanId = 
+        static_cast<VTK_TT1*>(labelVoid)[labelArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(idVoid)[idArrayIndex]));
       }
     while ((labelArrayIndex < numPts) && labelLessThanId)
       {
@@ -770,13 +907,11 @@ int vtkExtractSelectedIds::ExtractPoints(
         {
         break;
         }
-      switch(idArray->GetDataType())
-        {
-        vtkExtendedTemplateMacro(
-          labelLessThanId = 
-            static_cast<VTK_TT*>(labelVoid)[labelArrayIndex] <
-            static_cast<VTK_TT*>(idVoid)[idArrayIndex]);
-        }
+      vtkESI_ExtendedTemplateMacro(labelArrayType, idArrayType,
+        labelLessThanId = 
+        static_cast<VTK_TT1*>(labelVoid)[labelArrayIndex] <
+        static_cast<VTK_TT1>(
+          static_cast<VTK_TT2*>(idVoid)[idArrayIndex]));
       }
     }
 
