@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkGlyph3D.cxx,v $
+  Module:    vtkGlyph3D.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -15,6 +15,7 @@
 #include "vtkGlyph3D.h"
 
 #include "vtkCell.h"
+#include "vtkCellData.h"
 #include "vtkDataSet.h"
 #include "vtkFloatArray.h"
 #include "vtkIdList.h"
@@ -29,7 +30,6 @@
 #include "vtkTransform.h"
 #include "vtkUnsignedCharArray.h"
 
-vtkCxxRevisionMacro(vtkGlyph3D, "$Revision: 1.124 $");
 vtkStandardNewMacro(vtkGlyph3D);
 
 //----------------------------------------------------------------------------
@@ -53,6 +53,7 @@ vtkGlyph3D::vtkGlyph3D()
   this->PointIdsName = NULL;
   this->SetPointIdsName("InputPointIds");
   this->SetNumberOfInputPorts(2);
+  this->FillCellData = 0;
 
   // by default process active point scalars
   this->SetInputArrayToProcess(0,0,0,vtkDataObject::FIELD_ASSOCIATION_POINTS,
@@ -87,7 +88,7 @@ int vtkGlyph3D::RequestData(
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
+  // get the input and output
   vtkDataSet *input = vtkDataSet::SafeDownCast(
     inInfo->Get(vtkDataObject::DATA_OBJECT()));
   vtkPolyData *output = vtkPolyData::SafeDownCast(
@@ -115,10 +116,11 @@ int vtkGlyph3D::RequestData(
   vtkIdList *cellPts;
   int npts;
   vtkIdList *pts;
-  vtkIdType ptIncr, cellId;
+  vtkIdType ptIncr, cellIncr, cellId;
   int haveVectors, haveNormals, haveTCoords = 0;
   double scalex,scaley,scalez, den;
-  vtkPointData *outputPD = output->GetPointData();
+  vtkPointData* outputPD = output->GetPointData();
+  vtkCellData* outputCD = output->GetCellData();
   int numberOfSources = this->GetNumberOfInputConnections(1);
   vtkPolyData *defaultSource = NULL;
   vtkIdTypeArray *pointIds=0;
@@ -151,7 +153,7 @@ int vtkGlyph3D::RequestData(
     }
   else
     {
-    inGhostLevels = ((vtkUnsignedCharArray*)temp)->GetPointer(0);
+    inGhostLevels =static_cast<vtkUnsignedCharArray *>(temp)->GetPointer(0);
     }
 
   requestedGhostLevel =
@@ -283,6 +285,10 @@ int vtkGlyph3D::RequestData(
     // Prepare to copy output.
     pd = input->GetPointData();
     outputPD->CopyAllocate(pd,numPts*numSourcePts);
+    if (this->FillCellData)
+      {
+      outputCD->CopyAllocate(pd,numPts*numSourceCells);
+      }
     }
 
   newPts = vtkPoints::New();
@@ -356,12 +362,13 @@ int vtkGlyph3D::RequestData(
   // point attributes.
   //
   ptIncr=0;
+  cellIncr=0;
   for (inPtId=0; inPtId < numPts; inPtId++)
     {
     scalex = scaley = scalez = 1.0;
     if ( ! (inPtId % 10000) )
       {
-      this->UpdateProgress ((double)inPtId/numPts);
+      this->UpdateProgress(static_cast<double>(inPtId)/numPts);
       if (this->GetAbortExecute())
         {
         break;
@@ -432,7 +439,7 @@ int vtkGlyph3D::RequestData(
         value = vMag;
         }
       
-      index = (int) ((double)(value - this->Range[0]) * numberOfSources / den);
+      index = static_cast<int>((value - this->Range[0])*numberOfSources / den);
       index = (index < 0 ? 0 :
               (index >= numberOfSources ? (numberOfSources-1) : index));
       
@@ -512,7 +519,7 @@ int vtkGlyph3D::RequestData(
           vNew[0] = (v[0]+vMag) / 2.0;
           vNew[1] = v[1] / 2.0;
           vNew[2] = v[2] / 2.0;
-          trans->RotateWXYZ((double)180.0,vNew[0],vNew[1],vNew[2]);
+          trans->RotateWXYZ(180.0,vNew[0],vNew[1],vNew[2]);
           }
         }
       }
@@ -594,6 +601,13 @@ int vtkGlyph3D::RequestData(
         {
         outputPD->CopyData(pd,inPtId,ptIncr+i);
         }
+      if (this->FillCellData)
+        {
+        for (i=0; i < numSourceCells; i++)
+          {
+          outputCD->CopyData(pd,inPtId,cellIncr+i);
+          }
+        }
       }
 
     // If point ids are to be generated, do it here
@@ -606,6 +620,7 @@ int vtkGlyph3D::RequestData(
       }
 
     ptIncr += numSourcePts;
+    cellIncr += numSourceCells;
     } 
   
   // Update ourselves and release memory
@@ -784,6 +799,8 @@ void vtkGlyph3D::PrintSelf(ostream& os, vtkIndent indent)
     {
     os << "Indexing off\n";
     }
+
+  os << indent << "Fill Cell Data: " << (this->FillCellData ? "On\n" : "Off\n");
 }
 
 int vtkGlyph3D::RequestUpdateExtent(
