@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkHyperOctreeDualGridContourFilter.cxx,v $
+  Module:    vtkHyperOctreeDualGridContourFilter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -44,6 +44,7 @@
 #include <vtkstd/set>
 #include "vtkBitArray.h"
 #include "vtkTimerLog.h"
+#include "vtkIncrementalPointLocator.h"
 
 
 
@@ -72,7 +73,6 @@ public:
   vtkstd::set<vtkIdType> Set;
 };
 
-vtkCxxRevisionMacro(vtkHyperOctreeDualGridContourFilter, "$Revision: 1.2 $");
 vtkStandardNewMacro(vtkHyperOctreeDualGridContourFilter);
 
 //----------------------------------------------------------------------------
@@ -357,13 +357,16 @@ void vtkHyperOctreeDualGridContourFilter::EvaluatePoint(
     {
     // Note: we have to extent points on boundary of tree !!!
     scalars[iter] = this->InScalars->GetComponent(vertMap[iter],0);
-    levelDim = (double)(1<<neighborhood[iter].GetLevel());
+    levelDim = static_cast<double>(1<<neighborhood[iter].GetLevel());
     points[HEX_VOX_PERMUTATION[iter]][0] 
-       = this->Origin[0] + ((double)(*xyzIds++)+0.5)*(this->Size[0])/levelDim;
+       = this->Origin[0] +
+      (static_cast<double>(*xyzIds++)+0.5)*(this->Size[0])/levelDim;
     points[HEX_VOX_PERMUTATION[iter]][1] 
-       = this->Origin[1] + ((double)(*xyzIds++)+0.5)*(this->Size[1])/levelDim;
+       = this->Origin[1] +
+      (static_cast<double>(*xyzIds++)+0.5)*(this->Size[1])/levelDim;
     points[HEX_VOX_PERMUTATION[iter]][2] 
-       = this->Origin[2] + ((double)(*xyzIds++)+0.5)*(this->Size[2])/levelDim;
+       = this->Origin[2] +
+      (static_cast<double>(*xyzIds++)+0.5)*(this->Size[2])/levelDim;
     // We need to skip over unused 4th id.
     ++xyzIds;
     }
@@ -604,7 +607,7 @@ int vtkHyperOctreeDualGridContourFilter::RequestData(
 //----------------------------------------------------------------------------
 // Specify a spatial locator for merging points. By default, 
 // an instance of vtkMergePoints is used.
-void vtkHyperOctreeDualGridContourFilter::SetLocator(vtkPointLocator *locator)
+void vtkHyperOctreeDualGridContourFilter::SetLocator(vtkIncrementalPointLocator *locator)
 {
   if ( this->Locator == locator)
     {
