@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkQuadricClustering.cxx,v $
+  Module:    vtkQuadricClustering.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -26,15 +26,17 @@
 #include "vtkPolyData.h"
 #include "vtkTimerLog.h"
 #include "vtkTriangle.h"
-#include <vtkstd/set> // keep track of inserted triangles
+#include <vtksys/hash_set.hxx> // keep track of inserted triangles
 
-vtkCxxRevisionMacro(vtkQuadricClustering, "$Revision: 1.83 $");
 vtkStandardNewMacro(vtkQuadricClustering);
 
 //----------------------------------------------------------------------------
 // PIMPLd STL set for keeping track of inserted cells
-class vtkCellSet : public vtkstd::set<vtkIdType> {};
-typedef vtkstd::set<vtkIdType>::iterator vtkCellSetIterator;
+struct vtkQuadricClusteringIdTypeHash {
+  size_t operator()(vtkIdType val) const { return static_cast<size_t>(val); }
+};
+class vtkQuadricClusteringCellSet : public vtksys::hash_set<vtkIdType, vtkQuadricClusteringIdTypeHash> {};
+typedef vtkQuadricClusteringCellSet::iterator vtkQuadricClusteringCellSetIterator;
 
 
 //----------------------------------------------------------------------------
@@ -86,6 +88,9 @@ vtkQuadricClustering::vtkQuadricClustering()
 
   this->InCellCount = this->OutCellCount = 0;
   this->CopyCellData = 0;
+
+  this->GetInformation()->Set(vtkAlgorithm::PRESERVES_RANGES(), 1);
+  this->GetInformation()->Set(vtkAlgorithm::PRESERVES_BOUNDS(), 1);
 }
 
 //----------------------------------------------------------------------------
@@ -127,7 +132,7 @@ int vtkQuadricClustering::RequestData(
   vtkInformation *inInfo = inputVector[0]->GetInformationObject(0);
   vtkInformation *outInfo = outputVector->GetInformationObject(0);
 
-  // get the input and ouptut
+  // get the input and output
   vtkPolyData *input = 0;
   if (inInfo)
     {
@@ -228,7 +233,7 @@ void vtkQuadricClustering::StartAppend(double *bounds)
   // If there are duplicate triangles. remove them
   if ( this->PreventDuplicateCells )
     {
-    this->CellSet = new vtkCellSet;
+    this->CellSet = new vtkQuadricClusteringCellSet;
     this->NumberOfBins = 
       this->NumberOfDivisions[0]*this->NumberOfDivisions[1]*this->NumberOfDivisions[2];
     }
@@ -291,6 +296,10 @@ void vtkQuadricClustering::StartAppend(double *bounds)
   this->YBinSize = (this->Bounds[3]-this->Bounds[2])/this->NumberOfDivisions[1];
   this->ZBinSize = (this->Bounds[5]-this->Bounds[4])/this->NumberOfDivisions[2];
 
+  this->XBinStep = (this->XBinSize > 0.0) ? (1.0/this->XBinSize) : 0.0;
+  this->YBinStep = (this->YBinSize > 0.0) ? (1.0/this->YBinSize) : 0.0;
+  this->ZBinStep = (this->ZBinSize > 0.0) ? (1.0/this->ZBinSize) : 0.0;
+
   this->NumberOfBinsUsed = 0;
   if (this->QuadricArray)
     {
@@ -480,6 +489,17 @@ void vtkQuadricClustering::AddTriangle(vtkIdType *binIds, double *pt0, double *p
   vtkIdType triPtIds[3];
   double quadric[9], quadric4x4[4][4];
   vtkIdType minIdx, midIdx, maxIdx, idx;
+
+  // Special condition for fast execution.
+  // Only add triangles that traverse three bins to quadrics.
+  if (this->UseInternalTriangles == 0)
+    {
+    if (binIds[0] == binIds[1] || binIds[0] == binIds[2] ||
+        binIds[1] == binIds[2])
+      {
+      return;
+      }
+    }
  
   // Compute the quadric.
   vtkTriangle::ComputeQuadric(pt0, pt1, pt2, quadric4x4);
@@ -493,17 +513,6 @@ void vtkQuadricClustering::AddTriangle(vtkIdType *binIds, double *pt0, double *p
   quadric[7] = quadric4x4[2][2];
   quadric[8] = quadric4x4[2][3];
 
-  // Special condition for fast execution.
-  // Only add triangles that traverse three bins to quadrics.
-  if (this->UseInternalTriangles == 0)
-    {
-    if (binIds[0] == binIds[1] || binIds[0] == binIds[2] ||
-        binIds[1] == binIds[2])
-      {
-      return;
-      }
-    }
-
   // Add the quadric to each of the three corner bins.
   for (i = 0; i < 3; ++i)
     {
@@ -875,50 +884,38 @@ void vtkQuadricClustering::AddQuadric(vtkIdType binId, double quadric[9])
 vtkIdType vtkQuadricClustering::HashPoint(double point[3])
 {
   vtkIdType binId;
-  int xBinCoord = 0;
-  int yBinCoord = 0;
-  int zBinCoord = 0;
+  int xBinCoord;
+  int yBinCoord;
+  int zBinCoord;
   
-  if (this->XBinSize > 0.0)
+  xBinCoord = static_cast<int>((point[0] - this->Bounds[0])*this->XBinStep);
+  if (xBinCoord < 0)
     {
-    xBinCoord = 
-      static_cast<int>((point[0] - this->Bounds[0]) / this->XBinSize);
-    if (xBinCoord < 0)
-      {
-      xBinCoord = 0;
-      }
-    else if (xBinCoord >= this->NumberOfDivisions[0])
-      {
-      xBinCoord = this->NumberOfDivisions[0] - 1;
-      }
+    xBinCoord = 0;
+    }
+  else if (xBinCoord >= this->NumberOfDivisions[0])
+    {
+    xBinCoord = this->NumberOfDivisions[0] - 1;
     }
   
-  if (this->YBinSize > 0.0)
+  yBinCoord = static_cast<int>((point[1] - this->Bounds[2])*this->YBinStep);
+  if (yBinCoord < 0)
     {
-    yBinCoord = 
-      static_cast<int>((point[1] - this->Bounds[2]) / this->YBinSize);
-    if (yBinCoord < 0)
-      {
-      yBinCoord = 0;
-      }
-    else if (yBinCoord >= this->NumberOfDivisions[1])
-      {
-      yBinCoord = this->NumberOfDivisions[1] - 1;
-      }
+    yBinCoord = 0;
+    }
+  else if (yBinCoord >= this->NumberOfDivisions[1])
+    {
+    yBinCoord = this->NumberOfDivisions[1] - 1;
     }
 
-  if (this->ZBinSize > 0.0)
+  zBinCoord = static_cast<int>((point[2] - this->Bounds[4])*this->ZBinStep);
+  if (zBinCoord < 0)
     {
-    zBinCoord = 
-      static_cast<int>((point[2] - this->Bounds[4]) / this->ZBinSize);
-    if (zBinCoord < 0)
-      {
-      zBinCoord = 0;
-      }
-    else if (zBinCoord >= this->NumberOfDivisions[2])
-      {
-      zBinCoord = this->NumberOfDivisions[2] - 1;
-      }
+    zBinCoord = 0;
+    }
+  else if (zBinCoord >= this->NumberOfDivisions[2])
+    {
+    zBinCoord = this->NumberOfDivisions[2] - 1;
     }
   
   // vary x fastest, then y, then z
@@ -1390,7 +1387,7 @@ void vtkQuadricClustering::EndAppendVertexGeometry(vtkPolyData *input,
       {
       if (tmp)
         {
-        delete tmp;
+        delete[] tmp;
         }
       tmp = new vtkIdType[numPts];
       tmpLength = numPts;
@@ -1493,7 +1490,7 @@ void vtkQuadricClustering::FindFeaturePoints(vtkCellArray *edges,
   double featureEdges[2][3];
   double point1[3], point2[3];
   vtkIdType *cellPointIds;
-  double radAngle = vtkMath::DegreesToRadians() * this->FeaturePointsAngle;
+  double radAngle = vtkMath::RadiansFromDegrees( this->FeaturePointsAngle );
   
   this->FeaturePoints->Allocate(numPts);
   
