@@ -1,7 +1,7 @@
 /*=========================================================================
 
 Program:   Visualization Toolkit
-Module:    $RCSfile: vtkStreamTracer.cxx,v $
+Module:    vtkStreamTracer.cxx
 
 Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
 All rights reserved.
@@ -27,7 +27,11 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkIntArray.h"
+#include "vtkCellLocator.h"
+#include "vtkModifiedBSPTree.h"
 #include "vtkInterpolatedVelocityField.h"
+#include "vtkAbstractInterpolatedVelocityField.h"
+#include "vtkCellLocatorInterpolatedVelocityField.h"
 #include "vtkMath.h"
 #include "vtkMultiBlockDataSet.h"
 #include "vtkObjectFactory.h"
@@ -40,10 +44,9 @@ PURPOSE.  See the above copyright notice for more information.
 #include "vtkRungeKutta45.h"
 #include "vtkSmartPointer.h"
 
-vtkCxxRevisionMacro(vtkStreamTracer, "$Revision: 1.45 $");
 vtkStandardNewMacro(vtkStreamTracer);
 vtkCxxSetObjectMacro(vtkStreamTracer,Integrator,vtkInitialValueProblemSolver);
-vtkCxxSetObjectMacro(vtkStreamTracer,InterpolatorPrototype,vtkInterpolatedVelocityField);
+vtkCxxSetObjectMacro(vtkStreamTracer,InterpolatorPrototype,vtkAbstractInterpolatedVelocityField);
 
 const double vtkStreamTracer::EPSILON = 1.0E-12;
 
@@ -55,33 +58,26 @@ vtkStreamTracer::vtkStreamTracer()
     {
     this->StartPosition[i] = 0.0;
     }
-  this->MaximumPropagation.Unit = LENGTH_UNIT;
-  this->MaximumPropagation.Interval = 1.0;
-
-  this->MinimumIntegrationStep.Unit = CELL_LENGTH_UNIT;
-  this->MinimumIntegrationStep.Interval = 1.0E-2;
-
-  this->MaximumIntegrationStep.Unit = CELL_LENGTH_UNIT;
-  this->MaximumIntegrationStep.Interval = 1.0;
-
-  this->InitialIntegrationStep.Unit = CELL_LENGTH_UNIT;
-  this->InitialIntegrationStep.Interval = 0.5;
-
-  this->MaximumError = 1.0e-6;
+  
+  this->MaximumPropagation     = 1.0;
+  this->IntegrationStepUnit    = CELL_LENGTH_UNIT; 
+  this->InitialIntegrationStep = 0.5;
+  this->MinimumIntegrationStep = 1.0E-2;
+  this->MaximumIntegrationStep = 1.0;
 
+  this->MaximumError         = 1.0e-6;
   this->MaximumNumberOfSteps = 2000;
+  this->TerminalSpeed        = EPSILON;
 
-  this->TerminalSpeed = EPSILON;
+  this->ComputeVorticity = true;
+  this->RotationScale    = 1.0;
 
-  this->ComputeVorticity = 1;
-  this->RotationScale = 1.0;
+  this->LastUsedStepSize = 0.0;
 
-  this->LastUsedTimeStep = 0.0;
-
-  this->GenerateNormalsInIntegrate = 1;
+  this->GenerateNormalsInIntegrate = true;
 
   this->InterpolatorPrototype = 0;
-
+  
   this->SetNumberOfInputPorts(2);
 
   // by default process active point vectors
@@ -90,7 +86,7 @@ vtkStreamTracer::vtkStreamTracer()
 }
 
 vtkStreamTracer::~vtkStreamTracer()
-{
+{ 
   this->SetIntegrator(0);
   this->SetInterpolatorPrototype(0);
 }
@@ -136,6 +132,42 @@ int vtkStreamTracer::GetIntegratorType()
   return UNKNOWN;
 }
 
+void vtkStreamTracer::SetInterpolatorTypeToDataSetPointLocator()
+{
+  this->SetInterpolatorType
+    (  static_cast<int> ( INTERPOLATOR_WITH_DATASET_POINT_LOCATOR )  );
+}
+  
+void vtkStreamTracer::SetInterpolatorTypeToCellLocator()
+{
+  this->SetInterpolatorType
+    (  static_cast<int> ( INTERPOLATOR_WITH_CELL_LOCATOR )  );
+}
+
+void vtkStreamTracer::SetInterpolatorType( int interpType )
+{
+  if ( interpType == INTERPOLATOR_WITH_CELL_LOCATOR )
+    {
+    // create an interpolator equipped with a cell locator
+    vtkSmartPointer< vtkCellLocatorInterpolatedVelocityField > cellLoc =
+    vtkSmartPointer< vtkCellLocatorInterpolatedVelocityField >::New();
+    
+    // specify the type of the cell locator attached to the interpolator                     
+    vtkSmartPointer< vtkModifiedBSPTree > cellLocType = 
+    vtkSmartPointer< vtkModifiedBSPTree >::New();
+    cellLoc->SetCellLocatorPrototype( cellLocType.GetPointer() );
+    
+    this->SetInterpolatorPrototype( cellLoc.GetPointer() );
+    }
+  else
+    {
+    // create an interpolator equipped with a point locator (by default)
+    vtkSmartPointer< vtkInterpolatedVelocityField > pntLoc =
+    vtkSmartPointer< vtkInterpolatedVelocityField >::New();
+    this->SetInterpolatorPrototype( pntLoc.GetPointer() );
+    }
+}
+
 void vtkStreamTracer::SetIntegratorType(int type)
 {
   vtkInitialValueProblemSolver* ivp=0;
@@ -161,247 +193,101 @@ void vtkStreamTracer::SetIntegratorType(int type)
     }
 }
 
-void vtkStreamTracer::SetIntervalInformation(
-  int unit, vtkStreamTracer::IntervalInformation& currentValues)
-{
-  if ( unit == currentValues.Unit )
+void vtkStreamTracer::SetMaximumPropagation( double max )
+{   
+  if ( max == this->MaximumPropagation )
     {
     return;
     }
-
-  if ( (unit < TIME_UNIT) || (unit > CELL_LENGTH_UNIT) )
-    {
-    vtkWarningMacro("Unrecognized unit. Using TIME_UNIT instead.");
-    currentValues.Unit = TIME_UNIT;
-    }
-  else
-    {
-    currentValues.Unit = unit;
-    }
-
+  this->MaximumPropagation = max; 
   this->Modified();
 }
 
-void vtkStreamTracer::SetIntervalInformation(
-  int unit, double interval, vtkStreamTracer::IntervalInformation& currentValues)
-{
-  if ( (unit == currentValues.Unit) && (interval == currentValues.Interval) )
+void vtkStreamTracer::SetIntegrationStepUnit( int unit )
+{ 
+  if ( unit != LENGTH_UNIT && unit != CELL_LENGTH_UNIT )
+    {
+    unit = CELL_LENGTH_UNIT;
+    }
+    
+  if ( unit == this->IntegrationStepUnit )
     {
     return;
     }
-
-  this->SetIntervalInformation(unit, currentValues);
-
-  currentValues.Interval = interval;
+  
+  this->IntegrationStepUnit = unit; 
   this->Modified();
-}
+}   
 
-void vtkStreamTracer::SetMaximumPropagation(int unit, double max)
+void vtkStreamTracer::SetMinimumIntegrationStep( double step )
 {
-  this->SetIntervalInformation(unit, max, this->MaximumPropagation);
-}
-void vtkStreamTracer::SetMaximumPropagation( double max)
-{
-  if ( max == this->MaximumPropagation.Interval )
+  if ( step == this->MinimumIntegrationStep )
     {
     return;
     }
-  this->MaximumPropagation.Interval = max;
+  this->MinimumIntegrationStep = step;
   this->Modified();
 }
-void vtkStreamTracer::SetMaximumPropagationUnit(int unit)
-{
-  this->SetIntervalInformation(unit, this->MaximumPropagation);
-}
-int vtkStreamTracer::GetMaximumPropagationUnit()
-{
-  return this->MaximumPropagation.Unit;
-}
-double vtkStreamTracer::GetMaximumPropagation()
-{
-  return this->MaximumPropagation.Interval;
-}
 
-void vtkStreamTracer::SetMinimumIntegrationStep(int unit, double step)
+void vtkStreamTracer::SetMaximumIntegrationStep( double step )
 {
-  this->SetIntervalInformation(unit, step, this->MinimumIntegrationStep);
-}
-void vtkStreamTracer::SetMinimumIntegrationStepUnit(int unit)
-{
-  this->SetIntervalInformation(unit, this->MinimumIntegrationStep);
-}
-void vtkStreamTracer::SetMinimumIntegrationStep(double step)
-{
-  if ( step == this->MinimumIntegrationStep.Interval )
+  if ( step == this->MaximumIntegrationStep )
     {
     return;
     }
-  this->MinimumIntegrationStep.Interval = step;
+  this->MaximumIntegrationStep = step;
   this->Modified();
 }
-int vtkStreamTracer::GetMinimumIntegrationStepUnit()
-{
-  return this->MinimumIntegrationStep.Unit;
-}
-double vtkStreamTracer::GetMinimumIntegrationStep()
-{
-  return this->MinimumIntegrationStep.Interval;
-}
 
-void vtkStreamTracer::SetMaximumIntegrationStep(int unit, double step)
+void vtkStreamTracer::SetInitialIntegrationStep( double step )
 {
-  this->SetIntervalInformation(unit, step, this->MaximumIntegrationStep);
-}
-void vtkStreamTracer::SetMaximumIntegrationStepUnit(int unit)
-{
-  this->SetIntervalInformation(unit, this->MaximumIntegrationStep);
-}
-void vtkStreamTracer::SetMaximumIntegrationStep(double step)
-{
-  if ( step == this->MaximumIntegrationStep.Interval )
+  if ( step == this->InitialIntegrationStep )
     {
     return;
     }
-  this->MaximumIntegrationStep.Interval = step;
+  this->InitialIntegrationStep = step;
   this->Modified();
 }
-int vtkStreamTracer::GetMaximumIntegrationStepUnit()
-{
-  return this->MaximumIntegrationStep.Unit;
-}
-double vtkStreamTracer::GetMaximumIntegrationStep()
-{
-  return this->MaximumIntegrationStep.Interval;
-}
 
-void vtkStreamTracer::SetInitialIntegrationStep(int unit, double step)
-{
-  this->SetIntervalInformation(unit, step, this->InitialIntegrationStep);
-}
-void vtkStreamTracer::SetInitialIntegrationStepUnit(int unit)
-{
-  this->SetIntervalInformation(unit, this->InitialIntegrationStep);
-}
-void vtkStreamTracer::SetInitialIntegrationStep(double step)
-{
-  if ( step == this->InitialIntegrationStep.Interval )
-    {
-    return;
-    }
-  this->InitialIntegrationStep.Interval = step;
-  this->Modified();
-}
-int vtkStreamTracer::GetInitialIntegrationStepUnit()
-{
-  return this->InitialIntegrationStep.Unit;
-}
-double vtkStreamTracer::GetInitialIntegrationStep()
-{
-  return this->InitialIntegrationStep.Interval;
-}
-
-double vtkStreamTracer::ConvertToTime(
-  vtkStreamTracer::IntervalInformation& interval, double cellLength, double speed)
+double vtkStreamTracer::ConvertToLength(
+  double interval, int unit, double cellLength )
 {
   double retVal = 0.0;
-  switch (interval.Unit)
+  if ( unit == LENGTH_UNIT )
     {
-    case TIME_UNIT:
-      retVal = interval.Interval;
-      break;
-    case LENGTH_UNIT:
-      retVal = interval.Interval/speed; 
-      break;
-    case CELL_LENGTH_UNIT:
-      retVal = interval.Interval*cellLength/speed; 
-      break;
+    retVal = interval;
+    }
+  else
+  if ( unit == CELL_LENGTH_UNIT )
+    {
+    retVal = interval * cellLength;
     }
   return retVal;
 }
 
 double vtkStreamTracer::ConvertToLength(
-  vtkStreamTracer::IntervalInformation& interval, double cellLength, double speed)
+  vtkStreamTracer::IntervalInformation& interval, double cellLength )
 {
-  double retVal = 0.0;
-  switch (interval.Unit)
-    {
-    case TIME_UNIT:
-      retVal = interval.Interval * speed;
-      break;
-    case LENGTH_UNIT:
-      retVal = interval.Interval; 
-      break;
-    case CELL_LENGTH_UNIT:
-      retVal = interval.Interval*cellLength; 
-      break;
-    }
-  return retVal;
+  return ConvertToLength( interval.Interval, interval.Unit, cellLength );
 }
 
-double vtkStreamTracer::ConvertToCellLength(
-  vtkStreamTracer::IntervalInformation& interval, double cellLength, double speed)
+void vtkStreamTracer::ConvertIntervals( double& step, double& minStep, 
+  double& maxStep, int direction, double cellLength )
 {
-  double retVal = 0.0;
-  switch (interval.Unit)
+  minStep = maxStep = step = 
+    direction * this->ConvertToLength( this->InitialIntegrationStep,
+                                       this->IntegrationStepUnit, cellLength );
+ 
+  if ( this->MinimumIntegrationStep > 0.0 )
     {
-    case TIME_UNIT:
-      retVal = (interval.Interval * speed)/cellLength;
-      break;
-    case LENGTH_UNIT:
-      retVal = interval.Interval/cellLength; 
-      break;
-    case CELL_LENGTH_UNIT:
-      retVal = interval.Interval; 
-      break;
+    minStep = this->ConvertToLength( this->MinimumIntegrationStep,
+                                     this->IntegrationStepUnit, cellLength );
     }
-  return retVal;
-}
-
-double vtkStreamTracer::ConvertToUnit(
-  vtkStreamTracer::IntervalInformation& interval, 
-  int unit, 
-  double cellLength, 
-  double speed)
-{
-  double retVal = 0.0;
-  switch (unit)
+  
+  if ( this->MaximumIntegrationStep > 0.0 )
     {
-    case TIME_UNIT:
-      retVal = ConvertToTime(interval, cellLength, speed);
-      break;
-    case LENGTH_UNIT:
-      retVal = ConvertToLength(interval, cellLength, speed);
-      break;
-    case CELL_LENGTH_UNIT:
-      retVal = ConvertToCellLength(interval, cellLength, speed);
-      break;
-    }
-  return retVal;
-}
-
-void vtkStreamTracer::ConvertIntervals(double& step, double& minStep,
-                                       double& maxStep, int direction,
-                                       double cellLength, double speed)
-{
-  step = direction * this->ConvertToTime(
-    this->InitialIntegrationStep, cellLength, speed);
-  if ( this->MinimumIntegrationStep.Interval <= 0.0 )
-    {
-    minStep = step;
-    }
-  else
-    {
-    minStep = this->ConvertToTime(this->MinimumIntegrationStep, cellLength,  
-                                  speed);
-    }
-  if ( this->MaximumIntegrationStep.Interval <= 0.0 )
-    {
-    maxStep = step;
-    }
-  else
-    {
-    maxStep = this->ConvertToTime(this->MaximumIntegrationStep,cellLength, 
-                                  speed);
+    maxStep = this->ConvertToLength( this->MaximumIntegrationStep,
+                                     this->IntegrationStepUnit, cellLength );
     }
 }
 
@@ -537,9 +423,8 @@ int vtkStreamTracer::SetupOutput(vtkInformation* inInfo,
     vtkDataSet* copy = dsInput->NewInstance();
     copy->ShallowCopy(dsInput);
     vtkMultiBlockDataSet* mb = vtkMultiBlockDataSet::New();
-    mb->SetNumberOfBlocks(1);
-    mb->SetNumberOfDataSets(0, numPieces);
-    mb->SetDataSet(0, piece, copy);
+    mb->SetNumberOfBlocks(numPieces);
+    mb->SetBlock(piece, copy);
     copy->Delete();
     this->InputData = mb;
     mb->Register(this);
@@ -586,7 +471,7 @@ int vtkStreamTracer::RequestData(
   if (seeds)
     {
     double lastPoint[3];
-    vtkInterpolatedVelocityField* func;
+    vtkAbstractInterpolatedVelocityField * func;
     int maxCellSize = 0;
     if (this->CheckInputs(func, &maxCellSize) != VTK_OK)
       {
@@ -633,7 +518,7 @@ int vtkStreamTracer::RequestData(
   return 1;
 }
 
-int vtkStreamTracer::CheckInputs(vtkInterpolatedVelocityField*& func,
+int vtkStreamTracer::CheckInputs(vtkAbstractInterpolatedVelocityField*& func,
                                    int* maxCellSize)
 {
   if (!this->InputData)
@@ -650,11 +535,20 @@ int vtkStreamTracer::CheckInputs(vtkInterpolatedVelocityField*& func,
     {
     return VTK_ERROR;
     }
-
+  
   // Set the function set to be integrated
-  if (!this->InterpolatorPrototype)
+  if ( !this->InterpolatorPrototype )
     {
     func = vtkInterpolatedVelocityField::New();
+    
+    // turn on the following segment, in place of the above line, if an 
+    // interpolator equipped with a cell locator is dedired as the default
+    //
+    // func = vtkCellLocatorInterpolatedVelocityField::New();
+    // vtkSmartPointer< vtkModifiedBSPTree > locator = 
+    // vtkSmartPointer< vtkModifiedBSPTree >::New();
+    // vtkCellLocatorInterpolatedVelocityField::SafeDownCast( func )
+    //   ->SetCellLocatorPrototype( locator.GetPointer() );
     }
   else
     {
@@ -684,6 +578,7 @@ int vtkStreamTracer::CheckInputs(vtkInterpolatedVelocityField*& func,
         {
         vtkDebugMacro("One of the input blocks does not contain a "
                       "velocity vector.");
+        iterP->GoToNextItem();
         continue;
         }
       int cellSize = inp->GetMaxCellSize();
@@ -710,7 +605,7 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
                                 vtkIdList* seedIds,
                                 vtkIntArray* integrationDirections,
                                 double lastPoint[3],
-                                vtkInterpolatedVelocityField* func,
+                                vtkAbstractInterpolatedVelocityField* func,
                                 int maxCellSize,
                                 const char *vecName,
                                 double& inPropagation,
@@ -759,7 +654,7 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
   vtkPoints* outputPoints = vtkPoints::New();
   vtkCellArray* outputLines = vtkCellArray::New();
 
-  // We will keep track of time in this array
+  // We will keep track of integration time in this array
   vtkDoubleArray* time = vtkDoubleArray::New();
   time->SetName("IntegrationTime");
 
@@ -833,8 +728,8 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
       continue;
       }
 
-    if (propagation >= this->MaximumPropagation.Interval ||
-        numSteps > this->MaximumNumberOfSteps)
+    if ( propagation >= this->MaximumPropagation ||
+         numSteps    >  this->MaximumNumberOfSteps)
       {
       continue;
       }
@@ -844,35 +739,34 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
     vtkIdType nextPoint = outputPoints->InsertNextPoint(point1);
     time->InsertNextValue(0.0);
 
-    // We will always pass a time step to the integrator.
-    // If the user specifies a step size with another unit, we will 
-    // have to convert it to time.
-    IntervalInformation delT;
-    delT.Unit = TIME_UNIT;
-    delT.Interval = 0;
-    IntervalInformation aStep;
-    aStep.Unit = this->MaximumPropagation.Unit;
+    // We will always pass an arc-length step size to the integrator.
+    // If the user specifies a step size in cell length unit, we will 
+    // have to convert it to arc length.
+    IntervalInformation stepSize;  // either positive or negative
+    stepSize.Unit  = LENGTH_UNIT;
+    stepSize.Interval = 0;
+    IntervalInformation aStep; // always positive
+    aStep.Unit = LENGTH_UNIT;
     double step, minStep=0, maxStep=0;
     double stepTaken, accumTime=0;
     double speed;
     double cellLength;
-    int retVal=OUT_OF_TIME, tmp;
+    int retVal=OUT_OF_LENGTH, tmp; 
 
-    // Make sure we use the dataset found by the vtkInterpolatedVelocityField
+    // Make sure we use the dataset found by the vtkAbstractInterpolatedVelocityField
     input = func->GetLastDataSet();
     inputPD = input->GetPointData();
     inVectors = inputPD->GetVectors(vecName);
 
-    // Convert intervals to time unit
+    // Convert intervals to arc-length unit
     input->GetCell(func->GetLastCellId(), cell);
     cellLength = sqrt(static_cast<double>(cell->GetLength2()));
     speed = vtkMath::Norm(velocity);
-
     // Never call conversion methods if speed == 0
-    if (speed != 0.0)
+    if ( speed != 0.0 )
       {
-      this->ConvertIntervals(delT.Interval, minStep, maxStep, direction, 
-                             cellLength, speed);
+      this->ConvertIntervals( stepSize.Interval, minStep, maxStep, 
+                              direction, cellLength );
       }
 
     // Interpolate all point attributes on first point
@@ -907,7 +801,7 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
     // Integrate until the maximum propagation length is reached, 
     // maximum number of steps is reached or until a boundary is encountered.
     // Begin Integration
-    while ( propagation < this->MaximumPropagation.Interval )
+    while ( propagation < this->MaximumPropagation )
       {
 
       if (numSteps > this->MaximumNumberOfSteps)
@@ -919,8 +813,7 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
       if ( numSteps++ % 1000 == 1 )
         {
         progress = 
-          (currentLine + propagation / this->MaximumPropagation.Interval) /
-          numLines ;
+          ( currentLine + propagation / this->MaximumPropagation ) / numLines;
         this->UpdateProgress(progress);
 
         if (this->GetAbortExecute())
@@ -939,31 +832,31 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
 
       // If, with the next step, propagation will be larger than
       // max, reduce it so that it is (approximately) equal to max.
-      aStep.Interval = fabs(this->ConvertToUnit(delT, 
-                                                this->MaximumPropagation.Unit,
-                                                cellLength, speed));
-      if ( (propagation + aStep.Interval) >  
-           this->MaximumPropagation.Interval )
+      aStep.Interval = fabs( stepSize.Interval );
+        
+      if ( ( propagation + aStep.Interval ) > this->MaximumPropagation )
         {
-        aStep.Interval = this->MaximumPropagation.Interval - propagation;
-        if (delT.Interval >= 0)
+        aStep.Interval = this->MaximumPropagation - propagation;
+        if ( stepSize.Interval >= 0 )
           {
-          delT.Interval = this->ConvertToTime(aStep, cellLength, speed);
+          stepSize.Interval = this->ConvertToLength( aStep, cellLength );
           }
         else
           {
-          delT.Interval = -1.0 * this->ConvertToTime(aStep, cellLength, speed);
+          stepSize.Interval = this->ConvertToLength( aStep, cellLength ) * ( -1.0 );
           }
-        maxStep = delT.Interval;
+        maxStep = stepSize.Interval;
         }
-      this->LastUsedTimeStep = delT.Interval;
+      this->LastUsedStepSize = stepSize.Interval;
           
       // Calculate the next step using the integrator provided
       // Break if the next point is out of bounds.
-      if ((tmp=
-           integrator->ComputeNextStep(point1, point2, 0, delT.Interval, 
-                                       stepTaken, minStep, maxStep, 
-                                       this->MaximumError, error)) != 0)
+      func->SetNormalizeVector( true );
+      tmp = integrator->ComputeNextStep( point1, point2, 0, stepSize.Interval, 
+                                         stepTaken, minStep, maxStep, 
+                                         this->MaximumError, error );
+      func->SetNormalizeVector( false );
+      if ( tmp != 0 )
         {
         retVal = tmp;
         memcpy(lastPoint, point2, 3*sizeof(double));
@@ -971,27 +864,23 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
         }
 
       // It is not enough to use the starting point for stagnation calculation
-      // Use delX/delT to calculate speed and check if it is below
+      // Use delX/stepSize to calculate speed and check if it is below
       // stagnation threshold
       double disp[3];
       for (i=0; i<3; i++)
         {
         disp[i] = point2[i] - point1[i];
         }
-      if ( (delT.Interval == 0) ||  
-           (vtkMath::Norm(disp) / fabs(delT.Interval) <= this->TerminalSpeed) )
+      if ( (stepSize.Interval == 0) ||  
+           (vtkMath::Norm(disp) / fabs(stepSize.Interval) <= this->TerminalSpeed) )
         {
         retVal = STAGNATION;
         break;
         }
 
-      accumTime += stepTaken;
+      accumTime += stepTaken / speed;
       // Calculate propagation (using the same units as MaximumPropagation
-      propagation += fabs(this->ConvertToUnit(delT, 
-                                              this->MaximumPropagation.Unit,
-                                              cellLength, speed));
-
-
+      propagation += fabs( stepSize.Interval );
 
       // This is the next starting point
       for(i=0; i<3; i++)
@@ -1006,7 +895,7 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
         memcpy(lastPoint, point2, 3*sizeof(double));
         break;
         }
-      // Make sure we use the dataset found by the vtkInterpolatedVelocityField
+      // Make sure we use the dataset found by the vtkAbstractInterpolatedVelocityField
       input = func->GetLastDataSet();
       inputPD = input->GetPointData();
       inVectors = inputPD->GetVectors(vecName);
@@ -1021,7 +910,6 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
       input->GetCell(func->GetLastCellId(), cell);
       cellLength = sqrt(static_cast<double>(cell->GetLength2()));
       speed = vtkMath::Norm(velocity);
-
       // Interpolate all point attributes on current point
       func->GetLastWeights(weights);
       outputPD->InterpolatePoint(inputPD, nextPoint, cell->PointIds, weights);
@@ -1036,7 +924,7 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
         vorticity->InsertNextTuple(vort);
         // rotation
         // angular velocity = vorticity . unit tangent ( i.e. velocity/speed )
-        // rotation = sum ( angular velocity * delT )
+        // rotation = sum ( angular velocity * stepSize )
         omega = vtkMath::Dot(vort, velocity);
         omega /= speed;
         omega *= this->RotationScale;
@@ -1053,30 +941,31 @@ void vtkStreamTracer::Integrate(vtkDataSet *input0,
         break;
         }
 
-      // Convert all intervals to time
-      this->ConvertIntervals(step, minStep, maxStep, direction, 
-                             cellLength, speed);
+      // Convert all intervals to arc length
+      this->ConvertIntervals( step, minStep, maxStep, direction, cellLength );
 
 
-      // If the solver is adaptive and the next time step (delT.Interval)
+      // If the solver is adaptive and the next step size (stepSize.Interval)
       // that the solver wants to use is smaller than minStep or larger 
       // than maxStep, re-adjust it. This has to be done every step
       // because minStep and maxStep can change depending on the cell
-      // size (unless it is specified in time units)
+      // size (unless it is specified in arc-length unit)
       if (integrator->IsAdaptive())
         {
-        if (fabs(delT.Interval) < fabs(minStep))
+        if (fabs(stepSize.Interval) < fabs(minStep))
           {
-          delT.Interval = fabs(minStep) * delT.Interval/fabs(delT.Interval);
+          stepSize.Interval = fabs( minStep ) * 
+                                stepSize.Interval / fabs( stepSize.Interval );
           }
-        else if (fabs(delT.Interval) > fabs(maxStep))
+        else if (fabs(stepSize.Interval) > fabs(maxStep))
           {
-          delT.Interval = fabs(maxStep) * delT.Interval/fabs(delT.Interval);
+          stepSize.Interval = fabs( maxStep ) * 
+                                stepSize.Interval / fabs( stepSize.Interval );
           }
         }
       else
         {
-        delT.Interval = step;
+        stepSize.Interval = step;
         }
 
       // End Integration
@@ -1240,8 +1129,8 @@ void vtkStreamTracer::GenerateNormals(vtkPolyData* output, double* firstNormal,
 // than Integrate.
 void vtkStreamTracer::SimpleIntegrate(double seed[3], 
                                       double lastPoint[3], 
-                                      double delt,
-                                      vtkInterpolatedVelocityField* func)
+                                      double stepSize,
+                                      vtkAbstractInterpolatedVelocityField* func)
 {
   vtkIdType numSteps = 0;
   vtkIdType maxSteps = 20;
@@ -1250,6 +1139,7 @@ void vtkStreamTracer::SimpleIntegrate(double seed[3],
   double point1[3], point2[3];
   double velocity[3];
   double speed;
+  int    stepResult;
 
   (void)seed; // Seed is not used
 
@@ -1270,10 +1160,13 @@ void vtkStreamTracer::SimpleIntegrate(double seed[3],
 
     // Calculate the next step using the integrator provided
     // Break if the next point is out of bounds.
-    if (integrator->ComputeNextStep(point1, point2, 0, delt, 
-                                    stepTaken, 0, 0, 0, error) != 0)
+    func->SetNormalizeVector( true );
+    stepResult = integrator->ComputeNextStep( point1, point2, 0, stepSize, 
+                                              stepTaken, 0, 0, 0, error );
+    func->SetNormalizeVector( false );
+    if ( stepResult != 0 )
       {
-      memcpy(lastPoint, point2, 3*sizeof(double));
+      memcpy( lastPoint, point2, 3 * sizeof(double) );
       break;
       }
 
@@ -1328,72 +1221,22 @@ void vtkStreamTracer::PrintSelf(ostream& os, vtkIndent indent)
      << this->StartPosition[1] << " "
      << this->StartPosition[2] << endl;
   os << indent << "Terminal speed: " << this->TerminalSpeed << endl;
-  os << indent << "Maximum propagation: " << this->MaximumPropagation.Interval
-     << " unit: ";
-  switch (this->MaximumPropagation.Unit)
-    {
-    case TIME_UNIT:
-      os << "time.";
-      break;
-    case LENGTH_UNIT:
-      os << "length.";
-      break;
-    case CELL_LENGTH_UNIT:
-      os << "cell length.";
-      break;
-    }
-  os << endl;
   
-  os << indent << "Min. integration step: " 
-     << this->MinimumIntegrationStep.Interval
-     << " unit: ";
-  switch (this->MinimumIntegrationStep.Unit)
-    {
-    case TIME_UNIT:
-      os << "time.";
-      break;
-    case LENGTH_UNIT:
-      os << "length.";
-      break;
-    case CELL_LENGTH_UNIT:
-      os << "cell length.";
-      break;
-    }
-  os << endl;
+  os << indent << "Maximum propagation: " << this->MaximumPropagation
+     << " unit: length." << endl;
+  
+  os << indent << "Integration step unit: "
+     << ( ( this->IntegrationStepUnit == LENGTH_UNIT )
+          ? "length." : "cell length." ) << endl;
+     
+  os << indent << "Initial integration step: "
+     << this->InitialIntegrationStep << endl;
+  
+  os << indent << "Minimum integration step: "
+     << this->MinimumIntegrationStep << endl;
 
-  os << indent << "Max. integration step: " 
-     << this->MaximumIntegrationStep.Interval
-     << " unit: ";
-  switch (this->MaximumIntegrationStep.Unit)
-    {
-    case TIME_UNIT:
-      os << "time.";
-      break;
-    case LENGTH_UNIT:
-      os << "length.";
-      break;
-    case CELL_LENGTH_UNIT:
-      os << "cell length.";
-      break;
-    }
-  os << endl;
-
-  os << indent << "Initial integration step: " 
-     << this->InitialIntegrationStep.Interval
-     << " unit: ";
-  switch (this->InitialIntegrationStep.Unit)
-    {
-    case TIME_UNIT:
-      os << "time.";
-      break;
-    case LENGTH_UNIT:
-      os << "length.";
-      break;
-    case CELL_LENGTH_UNIT:
-      os << "cell length.";
-      break;
-    }
-  os << endl;
+  os << indent << "Maximum integration step: "
+     << this->MaximumIntegrationStep << endl;
 
   os << indent << "Integration direction: ";
   switch (this->IntegrationDirection)
@@ -1404,12 +1247,15 @@ void vtkStreamTracer::PrintSelf(ostream& os, vtkIndent indent)
     case BACKWARD:
       os << "backward.";
       break;
+    case BOTH:
+      os << "both directions.";
+      break;
     }
   os << endl;
 
   os << indent << "Integrator: " << this->Integrator << endl;
   os << indent << "Maximum error: " << this->MaximumError << endl;
-  os << indent << "Max. number of steps: " << this->MaximumNumberOfSteps 
+  os << indent << "Maximum number of steps: " << this->MaximumNumberOfSteps 
      << endl;
   os << indent << "Vorticity computation: " 
      << (this->ComputeVorticity ? " On" : " Off") << endl;
