@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: TestSQLiteDatabase.cxx,v $
+  Module:    TestSQLiteDatabase.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -34,13 +34,79 @@
 
 int TestSQLiteDatabase( int /*argc*/, char* /*argv*/[])
 {
+  bool status;
+
+  cerr << ">>>>> Testing creation modes." << endl;
+
+  vtkSQLiteDatabase* db1 = vtkSQLiteDatabase::SafeDownCast( vtkSQLDatabase::CreateFromURL( "sqlite://local.db" ) );
+  status = db1->Open("", vtkSQLiteDatabase::CREATE_OR_CLEAR);
+  vtkSQLQuery* query1 = db1->GetQueryInstance();
+  query1->SetQuery("CREATE TABLE test (id INTEGER)");
+  if (!query1->Execute())
+    {
+      cerr << "Create query failed" << endl;
+      return 1;
+    }
+  if ( ! status )
+    {
+    cerr << "Couldn't open database using CREATE_OR_CLEAR.\n";
+    return 1;
+    }
+  db1->Delete();
+  query1->Delete();
+
+  vtkSQLiteDatabase* db2 = vtkSQLiteDatabase::SafeDownCast( vtkSQLDatabase::CreateFromURL( "sqlite://local.db" ) );
+  status = db2->Open("", vtkSQLiteDatabase::CREATE);
+  if ( status )
+    {
+    cerr << "Using CREATE on an existing file should have failed but did not.\n";
+    return 1;
+    }
+  db2->Delete();
+
+  vtkSQLiteDatabase* db3 = vtkSQLiteDatabase::SafeDownCast( vtkSQLDatabase::CreateFromURL( "sqlite://local.db" ) );
+  status = db3->Open("", vtkSQLiteDatabase::USE_EXISTING_OR_CREATE);
+  if ( !status )
+    {
+    cerr << "Using USE_EXISTING_OR_CREATE did not work.\n";
+    return 1;
+    }
+  vtkSQLQuery* query3 = db3->GetQueryInstance();
+  query3->SetQuery("SELECT * from test");
+  if (!query3->Execute())
+    {
+      cerr << "Select query failed" << endl;
+      return 1;
+    }
+  db3->Delete();
+  query3->Delete();
+
+  vtkSQLiteDatabase* db4 = vtkSQLiteDatabase::SafeDownCast( vtkSQLDatabase::CreateFromURL( "sqlite://local.db" ) );
+  status = db4->Open("", vtkSQLiteDatabase::CREATE_OR_CLEAR);
+  if ( !status )
+    {
+    cerr << "Using CREATE_OR_CLEAR did not work.\n";
+    return 1;
+    }
+  vtkSQLQuery* query4 = db4->GetQueryInstance();
+  query4->SetQuery("SELECT * from test");
+  if (query4->Execute())
+    {
+      cerr << "Select query succeeded when it shouldn't have." << endl;
+      return 1;
+    }
+  db4->Delete();
+  query4->Delete();
+
+  cerr << ">>>>> Testing database functions" << endl;
+
   vtkSQLiteDatabase* db = vtkSQLiteDatabase::SafeDownCast( vtkSQLDatabase::CreateFromURL( "sqlite://:memory:" ) );
-  bool status = db->Open("");
+  status = db->Open("");
 
   if ( ! status )
     {
-      cerr << "Couldn't open database.\n";
-      return 1;
+    cerr << "Couldn't open database.\n";
+    return 1;
     }
 
   vtkSQLQuery* query = db->GetQueryInstance();
@@ -53,12 +119,13 @@ int TestSQLiteDatabase( int /*argc*/, char* /*argv*/[])
       cerr << "Create query failed" << endl;
       return 1;
     }
-
-  for ( int i = 0; i < 40; i++)
+  
+  int i;
+  for ( i = 0; i < 20; i++)
     {
       char insertQuery[200];
-      sprintf( insertQuery, "INSERT INTO people VALUES('John Doe %d', %d, %d)",
-        i, i, 10*i );
+      sprintf( insertQuery, "INSERT INTO people (name, age, weight) VALUES('John Doe %d', %d, %f)",
+        i, i, 10.1*i );
       cout << insertQuery << endl;
       query->SetQuery( insertQuery );
       if (!query->Execute())
@@ -68,6 +135,30 @@ int TestSQLiteDatabase( int /*argc*/, char* /*argv*/[])
         }
     }
 
+  
+  const char *placeholders = "INSERT INTO people (name, age, weight) VALUES (?, ?, ?)";
+  query->SetQuery(placeholders);
+  for ( i = 21; i < 40; i++ )
+    {
+    char name[20];
+    sprintf(name, "John Doe %d", i);
+    bool bind1 = query->BindParameter(0, name);
+    bool bind2 = query->BindParameter(1, i);
+    bool bind3 = query->BindParameter(2, 10.1*i);
+    if (!(bind1 && bind2 && bind3))
+      {
+      cerr << "Parameter binding failed on query " << i
+           << ": " << bind1 << " " << bind2 << " " << bind3 << endl;
+      return 1;
+      }
+    cout << query->GetQuery() << endl;
+    if (!query->Execute())
+      {
+      cerr << "Insert query " << i << " failed" << endl;
+      return 1;
+      }
+    }
+
   const char *queryText = "SELECT name, age, weight FROM people WHERE age <= 20";
   query->SetQuery( queryText );
   cerr << endl << "Running query: " << query->GetQuery() << endl;
