@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkEnSightReader.h,v $
+  Module:    vtkEnSightReader.h
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -28,7 +28,7 @@ class vtkMultiBlockDataSet;
 class VTK_IO_EXPORT vtkEnSightReader : public vtkGenericEnSightReader
 {
 public:
-  vtkTypeRevisionMacro(vtkEnSightReader, vtkGenericEnSightReader);
+  vtkTypeMacro(vtkEnSightReader, vtkGenericEnSightReader);
   void PrintSelf(ostream& os, vtkIndent indent);
   
   //BTX
@@ -321,6 +321,21 @@ protected:
   int ParticleCoordinatesByIndex;
   
   double ActualTimeValue;
+  
+  //BTX
+  enum { FORWARD_TIME_STEP_SHIFT_NON = 0, 
+         FORWARD_TIME_STEP_SHIFT_YES = 1, 
+         FORWARD_TIME_STEP_SHIFT_END = 2 
+       };
+  //ETX
+  
+  // Whether (non-zero) or not (zero) the next time step is a successor 
+  // (unnecessarily immediate) of the previous one in the same geometry
+  // file. Specifically a value of 2 means that the file just ends with
+  // the the next time step.
+  int       PreviousTimeStepInFile;
+  int       ForwardTimeStepShiftMode;
+  istream * ForwardTimeStepShiftIS;
 
 private:
   vtkEnSightReader(const vtkEnSightReader&);  // Not implemented.
