@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkImageStencilData.cxx,v $
+  Module:    vtkImageStencilData.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -25,7 +25,6 @@
 
 #include <math.h>
 
-vtkCxxRevisionMacro(vtkImageStencilData, "$Revision: 1.30 $");
 vtkStandardNewMacro(vtkImageStencilData);
 
 //----------------------------------------------------------------------------
@@ -446,6 +445,36 @@ int vtkImageStencilData::GetNextExtent(int &r1, int &r2,
 
   return 1;
 }
+//----------------------------------------------------------------------------
+//  Fills the stencil.  Extents must be set.
+void vtkImageStencilData::Fill( void )
+{
+  int extent[6];
+  this->GetExtent(extent);
+
+  int yExt = extent[3] - extent[2] + 1;
+  for (int idz=extent[4]; idz<=extent[5]; idz++)
+    {
+    int zIdx = idz - extent[4];
+    for (int idy = extent[2]; idy <= extent[3]; idy++)
+      {
+      int yIdx = idy - extent[2];
+
+      // get the ExtentList and ExtentListLength for this yIdx,zIdx
+      int incr = zIdx*yExt + yIdx;
+      this->ExtentListLengths[incr] = 0;
+      delete [] this->ExtentLists[incr];
+      this->ExtentLists[incr] = NULL;
+
+      int &clistlen = this->ExtentListLengths[incr];
+      int *&clist = this->ExtentLists[incr];
+    
+      clist = new int[2];
+      clist[clistlen++] = extent[0];
+      clist[clistlen++] = extent[1] + 1;
+      }
+    }
+}
 
 //----------------------------------------------------------------------------
 // Insert a sub extent [r1,r2] on to the list for the x row at (yIdx,zIdx).
@@ -923,6 +952,52 @@ void vtkImageStencilData::Subtract( vtkImageStencilData * stencil1 )
   this->Modified();
 } 
 
+//----------------------------------------------------------------------------
+void vtkImageStencilData::Replace( vtkImageStencilData * stencil1 )
+{
+  int extent[6], extent1[6], extent2[6], r1, r2, idy, idz, iter=0;
+  stencil1->GetExtent(extent1);
+  this->GetExtent(extent2);
+
+  if ((extent1[0] > extent2[1]) || (extent1[1] < extent2[0]) || 
+      (extent1[2] > extent2[3]) || (extent1[3] < extent2[2]) || 
+      (extent1[4] > extent2[5]) || (extent1[5] < extent2[4]))
+    {
+    // The extents don't intersect.. No subraction needed
+    return;
+    }
+
+  // Find the smallest box intersection of the extents
+  extent[0] = (extent1[0] < extent2[0]) ? extent2[0] : extent1[0];
+  extent[1] = (extent1[1] > extent2[1]) ? extent2[1] : extent1[1];
+  extent[2] = (extent1[2] < extent2[2]) ? extent2[2] : extent1[2];
+  extent[3] = (extent1[3] > extent2[3]) ? extent2[3] : extent1[3];
+  extent[4] = (extent1[4] < extent2[4]) ? extent2[4] : extent1[4];
+  extent[5] = (extent1[5] > extent2[5]) ? extent2[5] : extent1[5];
+
+  for (idz=extent[4]; idz<=extent[5]; idz++, iter=0)
+    {
+    for (idy = extent[2]; idy <= extent[3]; idy++, iter=0)
+      {
+      this->RemoveExtent(extent[0], extent[1], idy, idz); 
+
+      int moreSubExtents = 1;
+      while( moreSubExtents )
+        {
+        moreSubExtents = stencil1->GetNextExtent( 
+          r1, r2, extent[0], extent[1], idy, idz, iter);
+
+        if (r1 <= r2 ) // sanity check 
+          { 
+          this->InsertAndMergeExtent(r1, r2, idy, idz);
+          }
+        }
+      }
+    }
+
+  this->Modified();
+} 
+
 //----------------------------------------------------------------------------
 int vtkImageStencilData::Clip( int extent[6] )
 {
