@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkTableToTreeFilter.cxx,v $
+  Module:    vtkTableToTreeFilter.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -20,6 +20,7 @@
 
 #include "vtkTableToTreeFilter.h"
 
+#include "vtkIdTypeArray.h"
 #include "vtkInformation.h"
 #include "vtkInformationVector.h"
 #include "vtkMutableDirectedGraph.h"
@@ -35,7 +36,6 @@
 #include <vtkstd/vector>
 #include <vtkstd/string>
 
-vtkCxxRevisionMacro(vtkTableToTreeFilter, "$Revision: 1.5 $");
 vtkStandardNewMacro(vtkTableToTreeFilter);
 
 
@@ -83,28 +83,34 @@ int vtkTableToTreeFilter::RequestData(
   vtkTree* tree = vtkTree::SafeDownCast(
     outInfo->Get(vtkDataObject::DATA_OBJECT()));
 
+  vtkSmartPointer<vtkTable> new_table = vtkSmartPointer<vtkTable>::New();
+  new_table->DeepCopy( table );
+  
   // Create a mutable graph for building the tree
   vtkSmartPointer<vtkMutableDirectedGraph> builder =
     vtkSmartPointer<vtkMutableDirectedGraph>::New();
 
-  // The tree will have one more vertex than the number of rows
-  // in the table (the extra vertex is the new root.
-  for (vtkIdType v = 0; v <= table->GetNumberOfRows(); ++v)
+  // Check for a corner case where we have a table with 0 rows
+  if (new_table->GetNumberOfRows() != 0)
     {
-    builder->AddVertex();
-    }
 
-  // Make a star, originating at the new root (the last vertex).
-  vtkIdType root = table->GetNumberOfRows();
-  for (vtkIdType v = 0; v < table->GetNumberOfRows(); ++v)
-    {
-    builder->AddEdge(root, v);
-    }
+    // The tree will have one more vertex than the number of rows
+    // in the table (the extra vertex is the new root).
+    for (vtkIdType v = 0; v <= new_table->GetNumberOfRows(); ++v)
+      {
+      builder->AddVertex();
+      }
 
-  // Insert a row in the table for the new root.
-  // This modifies the input, but it might be ok because we are 
-  // just extending the arrays.
-  table->InsertNextBlankRow();
+    // Make a star, originating at the new root (the last vertex).
+    vtkIdType root = new_table->GetNumberOfRows();
+    for (vtkIdType v = 0; v < new_table->GetNumberOfRows(); ++v)
+      {
+      builder->AddEdge(root, v);
+      }
+
+    // Insert a row in the table for the new root.
+    new_table->InsertNextBlankRow(-1);
+    }
 
   // Move the structure of the mutable graph into the tree.
   if (!tree->CheckedShallowCopy(builder))
@@ -114,7 +120,19 @@ int vtkTableToTreeFilter::RequestData(
     }
 
   // Copy the table data into the tree vertex data
-  tree->GetVertexData()->PassData(table->GetRowData());
- 
+  tree->GetVertexData()->PassData(new_table->GetRowData());
+
+  // The edge data should at least have a pedigree id array.
+  vtkSmartPointer<vtkIdTypeArray> edgeIds =
+    vtkSmartPointer<vtkIdTypeArray>::New();
+  edgeIds->SetName("TableToTree edge");
+  vtkIdType numEdges = tree->GetNumberOfEdges();
+  edgeIds->SetNumberOfTuples(numEdges);
+  for (vtkIdType i = 0; i < numEdges; ++i)
+    {
+    edgeIds->SetValue(i, i);
+    }
+  tree->GetEdgeData()->SetPedigreeIds(edgeIds);
+
   return 1;
 }
