@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkAssembly.cxx,v $
+  Module:    vtkAssembly.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -22,7 +22,6 @@
 #include "vtkRenderWindow.h"
 #include "vtkVolume.h"
 
-vtkCxxRevisionMacro(vtkAssembly, "$Revision: 1.59 $");
 vtkStandardNewMacro(vtkAssembly);
 
 // Construct object with no children.
@@ -371,7 +370,7 @@ double *vtkAssembly::GetBounds()
   for ( this->Paths->InitTraversal(sit); (path = this->Paths->GetNextPath(sit)); )
     {
     prop3D = static_cast<vtkProp3D *>(path->GetLastNode()->GetViewProp());
-    if ( prop3D->GetVisibility() )
+    if ( prop3D->GetVisibility() && prop3D->GetUseBounds() )
       {
       propVisible = 1;
       prop3D->PokeMatrix(path->GetLastNode()->GetMatrix());
