@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkInteractorStyle.cxx,v $
+  Module:    vtkInteractorStyle.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -32,9 +32,10 @@
 #include "vtkRenderer.h"
 #include "vtkTextProperty.h"
 #include "vtkEventForwarderCommand.h"
+#include "vtkTDxInteractorStyleCamera.h"
 
-vtkCxxRevisionMacro(vtkInteractorStyle, "$Revision: 1.102 $");
 vtkStandardNewMacro(vtkInteractorStyle);
+vtkCxxSetObjectMacro(vtkInteractorStyle,TDxStyle,vtkTDxInteractorStyle);
 
 //----------------------------------------------------------------------------
 vtkInteractorStyle::vtkInteractorStyle()
@@ -75,6 +76,8 @@ vtkInteractorStyle::vtkInteractorStyle()
   
   this->TimerDuration = 10;
   this->EventForwarder = vtkEventForwarderCommand::New();
+  
+  this->TDxStyle=vtkTDxInteractorStyleCamera::New();
 }
 
 //----------------------------------------------------------------------------
@@ -103,6 +106,11 @@ vtkInteractorStyle::~vtkInteractorStyle()
 
   this->SetCurrentRenderer(NULL);
   this->EventForwarder->Delete();
+  
+  if(this->TDxStyle!=0)
+    {
+    this->TDxStyle->Delete();
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -238,6 +246,17 @@ void vtkInteractorStyle::SetInteractor(vtkRenderWindowInteractor *i)
     i->AddObserver(vtkCommand::DeleteEvent, 
                    this->EventCallbackCommand, 
                    this->Priority);
+    i->AddObserver(vtkCommand::TDxMotionEvent, 
+                   this->EventCallbackCommand, 
+                   this->Priority);
+    
+    i->AddObserver(vtkCommand::TDxButtonPressEvent, 
+                   this->EventCallbackCommand, 
+                   this->Priority);
+    
+    i->AddObserver(vtkCommand::TDxButtonReleaseEvent, 
+                   this->EventCallbackCommand, 
+                   this->Priority);
     }
   
   this->EventForwarder->SetTarget(this->Interactor);
@@ -721,7 +740,7 @@ void vtkInteractorStyle::OnChar()
         {
         for (anActor->InitPathTraversal(); (path=anActor->GetNextPath()); ) 
           {
-          aPart=(vtkActor *)path->GetLastNode()->GetViewProp();
+          aPart=static_cast<vtkActor *>(path->GetLastNode()->GetViewProp());
           aPart->GetProperty()->SetRepresentationToWireframe();
           }
         }
@@ -743,7 +762,7 @@ void vtkInteractorStyle::OnChar()
         {
         for (anActor->InitPathTraversal(); (path=anActor->GetNextPath()); ) 
           {
-          aPart=(vtkActor *)path->GetLastNode()->GetViewProp();
+          aPart=static_cast<vtkActor *>(path->GetLastNode()->GetViewProp());
           aPart->GetProperty()->SetRepresentationToSurface();
           }
         }
@@ -835,6 +854,26 @@ void vtkInteractorStyle::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "MouseWheelMotionFactor: " << this->MouseWheelMotionFactor << endl;
 
   os << indent << "Timer Duration: " << this->TimerDuration << endl;
+  
+  os << indent << "TDxStyle: ";
+  if(this->TDxStyle==0)
+    {
+    os << "(none)" << endl;
+    }
+  else
+    {
+    this->TDxStyle->PrintSelf(os,indent.GetNextIndent());
+    }
+}
+
+// ----------------------------------------------------------------------------
+void vtkInteractorStyle::DelegateTDxEvent(unsigned long event,
+                                          void *calldata)
+{
+  if(this->TDxStyle!=0)
+    {
+    this->TDxStyle->ProcessEvent(this->CurrentRenderer,event,calldata);
+    }
 }
 
 //----------------------------------------------------------------------------
@@ -904,7 +943,7 @@ void vtkInteractorStyle::ProcessEvents(vtkObject* vtkNotUsed(object),
       if (self->HandleObservers && 
           self->HasObserver(vtkCommand::TimerEvent)) 
         {
-        self->InvokeEvent(vtkCommand::TimerEvent,(void*)&timerId);
+        self->InvokeEvent(vtkCommand::TimerEvent,&timerId);
         }
       else 
         {
@@ -1062,6 +1101,11 @@ void vtkInteractorStyle::ProcessEvents(vtkObject* vtkNotUsed(object),
     case vtkCommand::DeleteEvent:
       self->SetInteractor(0);
       break;
+      
+    case vtkCommand::TDxMotionEvent:
+    case vtkCommand::TDxButtonPressEvent:
+    case vtkCommand::TDxButtonReleaseEvent:
+      self->DelegateTDxEvent(event,calldata);
+      break;
     }
 }
-
