@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkRenderWindowInteractor.cxx,v $
+  Module:    vtkRenderWindowInteractor.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -27,7 +27,6 @@
 #include "vtkObserverMediator.h"
 #include <vtkstd/map>
 
-vtkCxxRevisionMacro(vtkRenderWindowInteractor, "$Revision: 1.120 $");
 
 // PIMPL'd class to keep track of timers. It maps the ids returned by CreateTimer()
 // to the platform-specific representation for timer ids.
@@ -72,6 +71,7 @@ vtkRenderWindowInteractor::vtkRenderWindowInteractor()
   this->LightFollowCamera = 1;
   this->Initialized = 0;
   this->Enabled = 0;
+  this->EnableRender = true;
   this->DesiredUpdateRate = 15;
   // default limit is 3 hours per frame
   this->StillUpdateRate = 0.0001;
@@ -107,6 +107,8 @@ vtkRenderWindowInteractor::vtkRenderWindowInteractor()
   this->TimerDuration = 10;
   this->ObserverMediator = 0;
   this->HandleEventLoop = false;
+  
+  this->UseTDx=false; // 3DConnexion device.
 }
 
 //----------------------------------------------------------------------
@@ -152,7 +154,7 @@ vtkRenderWindowInteractor *vtkRenderWindowInteractor::New()
 //----------------------------------------------------------------------
 void vtkRenderWindowInteractor::Render()
 {
-  if (this->RenderWindow && this->Enabled)
+  if (this->RenderWindow && this->Enabled && this->EnableRender)
     {
     this->RenderWindow->Render();
     }
@@ -595,6 +597,7 @@ void vtkRenderWindowInteractor::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "StillUpdateRate: " << this->StillUpdateRate << "\n";
   os << indent << "Initialized: " << this->Initialized << "\n";
   os << indent << "Enabled: " << this->Enabled << "\n";
+  os << indent << "EnableRender: " << this->EnableRender << "\n";
   os << indent << "EventPosition: " << "( " << this->EventPosition[0] <<
     ", " << this->EventPosition[1] << " )\n";
   os << indent << "LastEventPosition: " << "( " << this->LastEventPosition[0] 
@@ -617,6 +620,7 @@ void vtkRenderWindowInteractor::PrintSelf(ostream& os, vtkIndent indent)
   os << indent << "TimerEventType: " << this->TimerEventType << "\n";
   os << indent << "TimerEventDuration: " << this->TimerEventDuration << "\n";
   os << indent << "TimerEventPlatformId: " << this->TimerEventPlatformId << "\n";
+  os << indent << "UseTDx: " << this->UseTDx << endl;
 }
 
 //----------------------------------------------------------------------------
