@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   MetaIO
-  Module:    $RCSfile: metaDTITube.cxx,v $
+  Module:    metaDTITube.cxx
   Language:  C++
-  Date:      $Date: 2007/06/01 13:07:52 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -342,7 +342,7 @@ M_SetupWriteFields(void)
     m_Fields.push_back(mF);
     }
 
-  m_NPoints = m_PointList.size();
+  m_NPoints = (int)m_PointList.size();
   mF = new MET_FieldRecordType;
   MET_InitWriteField(mF, "NPoints", MET_INT,m_NPoints);
   m_Fields.push_back(mF);
@@ -692,7 +692,7 @@ M_Write(void)
     unsigned int pntDim = m_NDims+6; 
     const DTITubePnt::FieldListType & extraList =
                                     (*(m_PointList.begin()))->GetExtraFields();
-    pntDim += extraList.size();
+    pntDim += static_cast<unsigned int>(extraList.size());
 
     char* data = new char[pntDim*m_NPoints*elementSize];
     int i=0;
