@@ -1,10 +1,10 @@
 /*=========================================================================
 
   Program:   MetaIO
-  Module:    $RCSfile: metaImageUtils.cxx,v $
+  Module:    metaImageUtils.cxx
   Language:  C++
-  Date:      $Date: 2007/05/10 19:17:20 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -16,6 +16,12 @@
 =========================================================================*/
 #include <stdio.h>
 
+#ifdef _MSC_VER
+#pragma warning(disable:4702)
+#pragma warning(disable:4996)
+#endif
+
+
 #include "metaImageTypes.h"
 #include <string.h>
 
