@@ -1,21 +1,22 @@
 /*=========================================================================
 
   Program:   MetaIO
-  Module:    $RCSfile: metaUtils.cxx,v $
+  Module:    metaUtils.cxx
   Language:  C++
-  Date:      $Date: 2007/08/06 19:20:33 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date$
+  Version:   $Revision$
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
 #ifdef _MSC_VER
 #pragma warning(disable:4702)
+#pragma warning(disable:4996)
 #endif
 
 #include "metaUtils.h"
@@ -34,6 +35,7 @@
 #endif
 
 #include <stdlib.h>
+#include <string.h>
 #include <string>
 
 #if defined (__BORLANDC__) && (__BORLANDC__ >= 0x0580)
@@ -48,7 +50,7 @@ int META_DEBUG = 0;
 
 char MET_SeperatorChar = '=';
 
-MET_FieldRecordType * 
+MET_FieldRecordType *
 MET_GetFieldRecord(const char * _fieldName,
                    METAIO_STL::vector<MET_FieldRecordType *> * _fields)
   {
@@ -121,7 +123,7 @@ bool MET_SystemByteOrderMSB(void)
 //
 METAIO_STL::string MET_ReadForm(METAIO_STREAM::istream &_fp)
   {
-  unsigned int pos = _fp.tellg();
+  METAIO_STL::streampos pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
   MET_FieldRecordType* mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "Form", MET_STRING, false);
@@ -140,7 +142,7 @@ METAIO_STL::string MET_ReadForm(METAIO_STREAM::istream &_fp)
     delete mF;
     return value;
     }
-    
+
   value[0] = '\0';
   delete mF;
   return value;
@@ -151,7 +153,7 @@ METAIO_STL::string MET_ReadForm(METAIO_STREAM::istream &_fp)
 //
 METAIO_STL::string MET_ReadType(METAIO_STREAM::istream &_fp)
   {
-  unsigned int pos = _fp.tellg();
+  METAIO_STL::streampos pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
   MET_FieldRecordType* mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "ObjectType", MET_STRING, false);
@@ -170,7 +172,7 @@ METAIO_STL::string MET_ReadType(METAIO_STREAM::istream &_fp)
     delete mF;
     return value;
     }
-    
+
   value[0] = '\0';
   delete mF;
   return value;
@@ -181,9 +183,9 @@ METAIO_STL::string MET_ReadType(METAIO_STREAM::istream &_fp)
 //
 char* MET_ReadSubType(METAIO_STREAM::istream &_fp)
   {
-  unsigned int pos = _fp.tellg();
+  METAIO_STL::streampos pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
-  MET_FieldRecordType* mF;  
+  MET_FieldRecordType* mF;
   mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "ObjectType", MET_STRING, false);
   mF->required = false;
@@ -195,8 +197,8 @@ char* MET_ReadSubType(METAIO_STREAM::istream &_fp)
   char s[1024];
   _fp.getline( s, 500 );
   METAIO_STL::string value = s;
-  int position = value.find("=");
-  if(position!=-1)
+  size_t position = value.find("=");
+  if(position!=METAIO_STL::string::npos)
     {
     value = value.substr(position+2,value.size()-position);
     }
@@ -224,8 +226,8 @@ bool MET_StringToType(const char *_s, MET_ValueEnumType *_vType)
       return true;
       }
     }
-    
-  *_vType = MET_OTHER;  
+
+  *_vType = MET_OTHER;
   return false;
   }
 
@@ -239,7 +241,7 @@ bool MET_TypeToString(MET_ValueEnumType _vType, char *_s)
     strcpy(_s, MET_ValueTypeName[_vType]);
     return true;
     }
-  
+
   return false;
   }
 
@@ -248,7 +250,8 @@ bool MET_TypeToString(MET_ValueEnumType _vType, char *_s)
 //
 // Value to Double
 //
-bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, int _index,
+bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, 
+                       METAIO_STL::streamoff _index,
                        double *_value)
   {
   switch(_type)
@@ -321,7 +324,7 @@ bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, int _index,
 bool MET_DoubleToValue(double _value,
                        MET_ValueEnumType _type,
                        void *_data,
-                       int _index)
+                       METAIO_STL::streamoff _index)
   {
   switch(_type)
     {
@@ -384,7 +387,7 @@ bool MET_DoubleToValue(double _value,
   }
 
 bool MET_ValueToValue(MET_ValueEnumType _fromType, const void *_fromData,
-                      int _index,
+                      METAIO_STL::streamoff _index,
                       MET_ValueEnumType _toType, void *_toData,
                       double _fromMin, double _fromMax,
                       double _toMin, double _toMax)
@@ -463,12 +466,215 @@ bool MET_ValueToValue(MET_ValueEnumType _fromType, const void *_fromData,
     }
   }
 
+// Uncompress a stream given an uncompressedSeekPosition
+METAIO_EXPORT
+METAIO_STL::streamoff MET_UncompressStream(METAIO_STREAM::ifstream * stream,
+                          METAIO_STL::streamoff uncompressedSeekPosition,
+                          unsigned char * uncompressedData,
+                          METAIO_STL::streamoff uncompressedDataSize,
+                          METAIO_STL::streamoff compressedDataSize,
+                          MET_CompressionTableType * compressionTable
+                          )
+{
+  // Keep the currentpos of the string
+  METAIO_STL::streampos currentPos = stream->tellg();
+  if(currentPos == METAIO_STL::streampos(-1))
+    {
+    METAIO_STREAM::cout << "MET_UncompressStream: ERROR Stream is not valid!" << METAIO_STREAM::endl;
+    return -1;
+    }
+
+  METAIO_STL::streamoff read = 0;
+
+  //METAIO_STREAM::cout << "Wanted Seek = " << uncompressedSeekPosition << METAIO_STREAM::endl;
+  //METAIO_STREAM::cout << "Wanted size = " << uncompressedDataSize << METAIO_STREAM::endl;
+
+  // Size of the output buffer
+  METAIO_STL::streamoff buffersize = 1000;
+
+  // We try to guess the compression rate
+  // Note that sometime the size of the input buffer
+  // has to be bigger than the output buffer (bad compression)
+  // We assume that they are equal
+  double compressionRate = 1;
+
+  METAIO_STL::streamoff zseekpos = 0;
+  METAIO_STL::streamoff seekpos = 0;
+  bool firstchunk = true;
+
+  // Allocate the stream if necessary
+  z_stream* d_stream = compressionTable->compressedStream;
+  if(compressionTable->compressedStream == NULL)
+    {
+    d_stream = new z_stream;
+    d_stream->zalloc = (alloc_func)0;
+    d_stream->zfree = (free_func)0;
+    d_stream->opaque = (voidpf)0;
+    inflateInit(d_stream);
+    compressionTable->compressedStream = d_stream;
+    compressionTable->buffer = new char[1001];
+    compressionTable->bufferSize = 0;
+    }
+
+
+  // Try to find the current seek position in the compressed
+  // and uncompressed stream from the compressionTable
+  // The table is stored in order
+  if(compressionTable->offsetList.size()>0)
+    {
+    MET_CompressionOffsetListType::const_iterator it = compressionTable->offsetList.end();
+    it--;
+
+    if(uncompressedSeekPosition < (*it).uncompressedOffset)
+      {
+      if((*it).uncompressedOffset-uncompressedSeekPosition > compressionTable->bufferSize)
+        {
+        METAIO_STREAM::cout << "ERROR: Cannot go backward by more than the buffer size (1000)"
+                  << METAIO_STREAM::endl;
+        return 0;
+        }
+
+      char* buffer = compressionTable->buffer;
+      METAIO_STL::streamoff start = uncompressedSeekPosition-((*it).uncompressedOffset-compressionTable->bufferSize);
+      buffer += start;
+
+      METAIO_STL::streamoff readSize = uncompressedDataSize;
+      METAIO_STL::streamoff sizeInBuffer = compressionTable->bufferSize-start;
+      if(readSize>sizeInBuffer)
+        {
+        memcpy(uncompressedData,buffer,(size_t)sizeInBuffer);
+        uncompressedData += sizeInBuffer;
+        zseekpos = (*it).compressedOffset;
+        seekpos = (*it).uncompressedOffset;
+        uncompressedSeekPosition += sizeInBuffer;
+        uncompressedDataSize -= sizeInBuffer;
+        }
+      else // read from buffer and return
+        {
+        memcpy(uncompressedData,buffer,(size_t)readSize);
+        return uncompressedDataSize;
+        }
+      }
+    else
+      {
+      zseekpos = (*it).compressedOffset;
+      seekpos = (*it).uncompressedOffset;
+      }
+    }
+
+  //METAIO_STREAM::cout << "Using = " << seekpos << " : " << zseekpos << METAIO_STREAM::endl;
+
+  while(seekpos < uncompressedSeekPosition+uncompressedDataSize)
+    {
+    // If we are reading the current buffer we read everything
+    if(seekpos >= uncompressedSeekPosition)
+      {
+      buffersize = uncompressedSeekPosition+uncompressedDataSize-seekpos;
+      firstchunk = false;
+      }
+
+    unsigned char* outdata = new unsigned char[buffersize];
+
+    d_stream->avail_out = (uInt)( buffersize );
+
+    // How many byte from compressed streamed should we read
+    METAIO_STL::streamoff inputBufferSize = (METAIO_STL::streamoff)(buffersize/compressionRate);
+
+    if(inputBufferSize == 0)
+      {
+      inputBufferSize = 1;
+      }
+    if((currentPos+zseekpos+inputBufferSize) > compressedDataSize)
+      {
+      inputBufferSize = compressedDataSize-zseekpos;
+      }
+
+    unsigned char* inputBuffer = new unsigned char[inputBufferSize];
+    stream->seekg(currentPos+zseekpos,METAIO_STREAM::ios::beg);
+    stream->read((char *)inputBuffer, (size_t)inputBufferSize);
+
+    d_stream->next_in  = inputBuffer;
+    d_stream->avail_in = stream->gcount();
+    d_stream->next_out = outdata;
+
+    inflate(d_stream, Z_NO_FLUSH);
+
+    METAIO_STL::streampos previousSeekpos = seekpos;
+
+    seekpos += buffersize-d_stream->avail_out;
+    zseekpos += stream->gcount()-d_stream->avail_in;
+
+    // Store the last buffer into memory in case we need it
+    // in the near future.
+    METAIO_STL::streamoff previousBufferSize = seekpos-previousSeekpos;
+    if(previousBufferSize>1000)
+      {
+      // WARNING: We probably need to offset outdata at some point...
+      previousBufferSize = 1000;
+      }
+
+    memcpy(compressionTable->buffer,outdata,(size_t)previousBufferSize);
+    compressionTable->bufferSize = previousBufferSize;
+
+    //METAIO_STREAM::cout << "Current pos = " << seekpos << " : " << zseekpos << METAIO_STREAM::endl;
+
+    // If go further than the uncompressedSeekPosition we start writing the stream
+    if(seekpos >= uncompressedSeekPosition)
+      {
+      if(firstchunk)
+        {
+        outdata += uncompressedSeekPosition-previousSeekpos;
+        METAIO_STL::streamoff writeSize = seekpos-uncompressedSeekPosition;
+
+        if(writeSize > uncompressedDataSize)
+          {
+          writeSize = uncompressedDataSize;
+          }
+
+        memcpy(uncompressedData,outdata,(size_t)writeSize);
+
+        // Restore the position of the buffer
+        outdata -= uncompressedSeekPosition-previousSeekpos;
+
+        uncompressedData += writeSize;
+        read += writeSize;
+
+        firstchunk = false;
+        }
+      else // read everything
+        {
+        METAIO_STL::streamoff writeSize = seekpos-previousSeekpos;
+        memcpy(uncompressedData,outdata,(size_t)writeSize);
+        if(writeSize > uncompressedDataSize)
+          {
+          writeSize = uncompressedDataSize;
+          }
+        uncompressedData += writeSize;
+        read += writeSize;
+        }
+      }
+    delete [] outdata;
+    delete [] inputBuffer;
+    }
+
+  // Save the state of the compression for later use
+  MET_CompressionOffsetType offset;
+  offset.compressedOffset = zseekpos; // compressed
+  offset.uncompressedOffset = seekpos; // uncompressed
+  compressionTable->offsetList.push_back(offset);
+
+  // Seek to the current position
+  stream->seekg(currentPos,METAIO_STREAM::ios::beg);
+  return read;
+}
+
+
 //
 //
 //
 unsigned char * MET_PerformCompression(const unsigned char * source,
-                                       int sourceSize,
-                                       unsigned int * compressedDataSize)
+                                       METAIO_STL::streamoff sourceSize,
+                                       METAIO_STL::streamoff * compressedDataSize)
   {
   unsigned char * compressedData;
 
@@ -481,7 +687,7 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
   // Choices are Z_BEST_SPEED,Z_BEST_COMPRESSION,Z_DEFAULT_COMPRESSION
   int compression_rate = Z_DEFAULT_COMPRESSION;
 
-  int             buffer_size     = sourceSize;
+  METAIO_STL::streamoff             buffer_size     = sourceSize;
   unsigned char * input_buffer    = const_cast<unsigned char *>(source);
   unsigned char * output_buffer   = new unsigned char[buffer_size];
 
@@ -489,39 +695,56 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
 
   deflateInit(&z, compression_rate);
 
-  z.avail_in   = buffer_size;
+  z.avail_in   = (uInt)buffer_size;
   z.next_in    = input_buffer;
   z.next_out   = output_buffer;
-  z.avail_out  = buffer_size;
-   
-  int count;
-  unsigned long j=0;
-  // Perform the compression 
-  for ( ; ; ) 
+  z.avail_out  = (uInt)buffer_size;
+
+  METAIO_STL::streamoff count;
+  METAIO_STL::streamoff j=0;
+  // Perform the compression
+  for ( ; ; )
     {
-    if ( z.avail_in == 0 ) 
+    if ( z.avail_in == 0 )
       {
       deflate( &z, Z_FINISH );
       count = buffer_size - z.avail_out;
-      if ( count ) 
+      if ( count )
         {
-        memcpy((char*)compressedData+j, (char *)output_buffer, count);
+        // if we don't have enough allocation for the output buffer
+        // when the output is bigger than the input (true for small images)
+        if(j+count>=buffer_size) 
+          {
+          unsigned char* compressedDataTemp = new unsigned char[j+count+1];
+          memcpy(compressedDataTemp,compressedData,(size_t)buffer_size);
+          delete [] compressedData;
+          compressedData = compressedDataTemp;
+          }
+        
+        memcpy((char*)compressedData+j, (char *)output_buffer, (size_t)count);
         }
       break;
       }
 
     deflate( &z, Z_NO_FLUSH );
     count = buffer_size - z.avail_out;
-    if ( count ) 
+    if ( count )
       {
-      memcpy((char*)compressedData+j, (char*)output_buffer, count);
+      if(j+count>=buffer_size) 
+        {
+        unsigned char* compressedDataTemp = new unsigned char[j+count+1];
+        memcpy(compressedDataTemp,compressedData,(size_t)buffer_size);
+        delete [] compressedData;
+        compressedData = compressedDataTemp;
+        }
+      memcpy((char*)compressedData+j, (char*)output_buffer, (size_t)count);
       }
 
     j += count;
     z.next_out = output_buffer;
-    z.avail_out = buffer_size;
+    z.avail_out = (uInt)buffer_size;
     }
-    
+
   delete [] output_buffer;
 
   *compressedDataSize = z.total_out;
@@ -536,31 +759,39 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
 //
 //
 bool MET_PerformUncompression(const unsigned char * sourceCompressed,
-                              int sourceCompressedSize,
+                              METAIO_STL::streamoff sourceCompressedSize,
                               unsigned char * uncompressedData,
-                              int uncompressedDataSize)
+                              METAIO_STL::streamoff uncompressedDataSize)
   {
   z_stream d_stream;
- 
+
   d_stream.zalloc = (alloc_func)0;
   d_stream.zfree = (free_func)0;
   d_stream.opaque = (voidpf)0;
-  
+
   inflateInit(&d_stream);
   d_stream.next_in  = const_cast<unsigned char *>(sourceCompressed);
-  d_stream.avail_in = sourceCompressedSize;
- 
-  for (;;) 
+  d_stream.avail_in = (uInt)sourceCompressedSize;
+  
+  for (;;)
     {
-    d_stream.next_out = (unsigned char *)uncompressedData; 
-    d_stream.avail_out = uncompressedDataSize;
+    d_stream.next_out = (unsigned char *)uncompressedData;
+    d_stream.avail_out = (uInt)uncompressedDataSize;
     int err = inflate(&d_stream, Z_NO_FLUSH);
-    if((err == Z_STREAM_END))
+        
+    if((err == Z_STREAM_END)
+       || (err == Z_BUF_ERROR) // Sometimes inflate returns this non fatal.
+       )
       {
       break;
       }
+    else if(err < 0)
+      {
+      METAIO_STREAM::cerr << "Uncompress failed" << METAIO_STREAM::endl;
+      break;
+      }  
     }
-
+    
   inflateEnd(&d_stream);
 
   return true;
@@ -571,16 +802,16 @@ bool MET_PerformUncompression(const unsigned char * sourceCompressed,
 //
 bool MET_StringToWordArray(const char *s, int *n, char ***val)
 {
-  long l = static_cast<long>( strlen(s) );
+  ptrdiff_t l = strlen(s);
 
-  int p = 0;
+  ptrdiff_t p = 0;
   while(p<l && s[p] == ' ')
     {
     p++;
     }
-  
+
   *n = 0;
-  int pp = p;
+  ptrdiff_t pp = p;
   bool space = false;
   while(pp<l)
     {
@@ -596,7 +827,7 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
     pp++;
     }
   pp=l-1;
-  if(s[pp] == ' ')   
+  if(s[pp] == ' ')
     {
     while(pp>=0 && s[pp] == ' ')
       {
@@ -608,17 +839,17 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
     {
     (*n)++;
     }
-  
+
   *val = new char *[*n];
-  
-  long i, j;
-  for(i=0; i<*n; i++) 
+
+  ptrdiff_t i, j;
+  for(i=0; i<*n; i++)
     {
     if(p == l)
       {
       return false;
       }
-    
+
     (*val)[i] = new char [80];
     while(p<l && s[p] == ' ')
       {
@@ -631,7 +862,7 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
       }
     (*val)[i][j] = '\0';
     }
-  
+
   return true;
 }
 
@@ -641,13 +872,13 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
 bool MET_GetFilePath(const char *_fName, char *_fPath)
   {
   long i;
-  
-  long l = static_cast<long>( strlen(_fName) );
-  
-  for(i=l-1; i>=0; i--)
+
+  size_t l = strlen(_fName);
+
+  for(i=(long)l-1; i>=0; i--)
     if(_fName[i] == '\\' || _fName[i] == '/')
       break;
-    
+
     if(i >= 0 && (_fName[i] == '/' || _fName[i] == '\\'))
       {
       strcpy(_fPath, _fName);
@@ -713,9 +944,9 @@ bool MET_SetFileSuffix(char *_fName, const char *_suf)
 //
 //
 //
-bool MET_InitWriteField(MET_FieldRecordType * _mf, 
-                        const char *_name, 
-                        MET_ValueEnumType _type, 
+bool MET_InitWriteField(MET_FieldRecordType * _mf,
+                        const char *_name,
+                        MET_ValueEnumType _type,
                         double _v)
   {
   strcpy(_mf->name, _name);
@@ -729,12 +960,12 @@ bool MET_InitWriteField(MET_FieldRecordType * _mf,
   return true;
   }
 
-bool MET_InitReadField(MET_FieldRecordType * _mf, 
-                                  const char *_name, 
-                                  MET_ValueEnumType _type, 
+bool MET_InitReadField(MET_FieldRecordType * _mf,
+                                  const char *_name,
+                                  MET_ValueEnumType _type,
                                   bool _required,
-                                  int _dependsOn, 
-                                  int _length)
+                                  int _dependsOn,
+                                  size_t _length)
   {
   strcpy(_mf->name, _name);
   _mf->type = _type;
@@ -742,7 +973,7 @@ bool MET_InitReadField(MET_FieldRecordType * _mf,
   _mf->dependsOn = _dependsOn;
   _mf->required = _required;
   _mf->terminateRead = false;
-  _mf->length = _length;
+  _mf->length = static_cast<int>(_length);
   _mf->value[0] = 0;
   return true;
   }
@@ -757,7 +988,7 @@ bool MET_SkipToVal(METAIO_STREAM::istream &fp)
     {
     return false;
     }
-  
+
   c = fp.get();
 
   while( c != MET_SeperatorChar && c != ':' && !fp.eof() )
@@ -769,14 +1000,14 @@ bool MET_SkipToVal(METAIO_STREAM::istream &fp)
     {
     c = fp.get();
     }
-  
+
   if( fp.eof() )
     {
-    METAIO_STREAM::cerr << "Incomplete file record definition" 
+    METAIO_STREAM::cerr << "Incomplete file record definition"
                         << METAIO_STREAM::endl;
     return false;
     }
-  
+
   fp.putback(c);
 
   return true;
@@ -792,7 +1023,7 @@ bool MET_IsComplete(METAIO_STL::vector<MET_FieldRecordType *> * fields)
     {
     if((*fieldIter)->required && !(*fieldIter)->defined)
       {
-      METAIO_STREAM::cerr << (*fieldIter)->name << " required and not defined." 
+      METAIO_STREAM::cerr << (*fieldIter)->name << " required and not defined."
                 << METAIO_STREAM::endl;
       return false;
       }
@@ -807,14 +1038,15 @@ bool MET_Read(METAIO_STREAM::istream &fp,
   {
 
   char s[1024];
-  int i, j;
+  int i;
+  size_t j;
 
   METAIO_STL::vector<MET_FieldRecordType *>::iterator fieldIter;
-  
+
   MET_SeperatorChar = _MET_SeperatorChar;
-  
+
   bool found;
-  
+
   unsigned char c;
   while(!fp.eof())
     {
@@ -836,7 +1068,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
       }
     fp.putback(c);
     s[i] = '\0';
-    
+
     i--;
     while((s[i] == ' ' || s[i] == '\t') && i>0)
       {
@@ -851,9 +1083,9 @@ bool MET_Read(METAIO_STREAM::istream &fp,
         if((*fieldIter)->dependsOn >= 0)
           if(!(*fields)[(*fieldIter)->dependsOn]->defined)
             {
-            METAIO_STREAM::cerr << (*fieldIter)->name 
+            METAIO_STREAM::cerr << (*fieldIter)->name
                                 << " defined prior to defining ";
-            METAIO_STREAM::cerr << (*fields)[(*fieldIter)->dependsOn]->name 
+            METAIO_STREAM::cerr << (*fields)[(*fieldIter)->dependsOn]->name
                                 << METAIO_STREAM::endl;
             return false;
             }
@@ -906,7 +1138,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               }
             MET_CHAR_TYPE * str = (MET_CHAR_TYPE *)((*fieldIter)->value);
             fp.getline( str, 500 );
-            j = static_cast<long>( strlen(str) ) - 1;
+            j = strlen(str) - 1;
             while(!isprint(str[j]) || isspace(str[j]))
               {
               str[j--] = '\0';
@@ -936,7 +1168,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               {
               (*fieldIter)->length =
                     (int)((*fields)[(*fieldIter)->dependsOn]->value[0]);
-              for(j=0; j<(*fieldIter)->length; j++) 
+              for(j=0; j<(size_t)(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -945,12 +1177,12 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               {
               if((*fieldIter)->length <= 0)
                 {
-                METAIO_STREAM::cerr << 
+                METAIO_STREAM::cerr <<
                   "Arrays must have dependency or pre-specified lengths"
                   << METAIO_STREAM::endl;
                 return false;
                 }
-              for(j=0; j<(*fieldIter)->length; j++)
+              for(j=0; j<(size_t)(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -969,8 +1201,8 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               {
               (*fieldIter)->length =
                     (int)((*fields)[(*fieldIter)->dependsOn]->value[0]);
-              for(j=0; j<(*fieldIter)->length*(*fieldIter)->length;
-                  j++) 
+              for(j=0; j<(size_t)(*fieldIter)->length*(*fieldIter)->length;
+                  j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -979,12 +1211,12 @@ bool MET_Read(METAIO_STREAM::istream &fp,
               {
               if((*fieldIter)->length <= 0)
                 {
-                METAIO_STREAM::cerr << 
+                METAIO_STREAM::cerr <<
                   "Arrays must have dependency or pre-specified lengths"
                   << METAIO_STREAM::endl;
                 return false;
                 }
-              for(j=0; j<(*fieldIter)->length*(*fieldIter)->length; j++)
+              for(j=0; j<(size_t)(*fieldIter)->length*(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -1011,7 +1243,7 @@ bool MET_Read(METAIO_STREAM::istream &fp,
       {
       if(display_warnings)
         {
-        METAIO_STREAM::cerr << "Skipping unrecognized field " 
+        METAIO_STREAM::cerr << "Skipping unrecognized field "
                             << s << METAIO_STREAM::endl;
         }
       fp.getline( s, 500 );
@@ -1021,17 +1253,17 @@ bool MET_Read(METAIO_STREAM::istream &fp,
       return MET_IsComplete(fields);
       }
     }
-    
+
   return MET_IsComplete(fields);
   }
-  
+
 //
 bool MET_Write(METAIO_STREAM::ostream &fp,
                METAIO_STL::vector<MET_FieldRecordType *> * fields,
                char _MET_SeperatorChar)
   {
   MET_SeperatorChar = _MET_SeperatorChar;
-  
+
   int j;
   METAIO_STL::vector<MET_FieldRecordType *>::iterator fieldIter;
   for(fieldIter=fields->begin(); fieldIter!=fields->end(); fieldIter++)
@@ -1040,7 +1272,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
       {
       case MET_NONE:
         {
-        fp << (*fieldIter)->name << " " << MET_SeperatorChar << " " 
+        fp << (*fieldIter)->name << " " << MET_SeperatorChar << " "
            << METAIO_STREAM::endl;
         break;
         }
@@ -1063,7 +1295,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         {
 #if defined(_MSC_VER) || defined(__HP_aCC)
         // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
-        fp << (double)((MET_LONG_LONG_TYPE)((*fieldIter)->value[0])) 
+        fp << (double)((MET_LONG_LONG_TYPE)((*fieldIter)->value[0]))
            << METAIO_STREAM::endl;
         METAIO_STREAM::cerr << "Programs compiled using MSV6 or HPUX cannot"
                             << " write 64 bit ints" << METAIO_STREAM::endl;
@@ -1071,7 +1303,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
                             << "  Loss of precision results."
                             << METAIO_STREAM::endl;
 #else
-        fp << (MET_LONG_LONG_TYPE)((*fieldIter)->value[0]) 
+        fp << (MET_LONG_LONG_TYPE)((*fieldIter)->value[0])
            << METAIO_STREAM::endl;
 #endif
         break;
@@ -1090,16 +1322,16 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
 #if defined(_MSC_VER) || defined(__HP_aCC)
         // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
         fp << (double)((MET_LONG_LONG_TYPE)((MET_ULONG_LONG_TYPE)
-                       ((*fieldIter)->value[0]))) 
+                       ((*fieldIter)->value[0])))
            << METAIO_STREAM::endl;
         METAIO_STREAM::cerr << "Programs compiled using MSV6 or HPUX"
-                            << " cannot write 64 bit ints" 
+                            << " cannot write 64 bit ints"
                             << METAIO_STREAM::endl;
         METAIO_STREAM::cerr << "  Writing as double instead."
                             << "  Loss of precision results."
                             << METAIO_STREAM::endl;
 #else
-        fp << (MET_ULONG_LONG_TYPE)((*fieldIter)->value[0]) 
+        fp << (MET_ULONG_LONG_TYPE)((*fieldIter)->value[0])
            << METAIO_STREAM::endl;
 #endif
         break;
@@ -1114,9 +1346,9 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
       case MET_STRING:
         {
         fp << (*fieldIter)->name << " " << MET_SeperatorChar << " ";
-        if((*fieldIter)->dependsOn >= 0) 
+        if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning:";
@@ -1137,7 +1369,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1158,7 +1390,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1194,7 +1426,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1215,7 +1447,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1250,7 +1482,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1270,7 +1502,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1295,15 +1527,15 @@ bool MET_Write(METAIO_STREAM::ostream &fp,
 }
 
 bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
-                          MET_ValueEnumType _pType, int _n, const void *_v)
+                          MET_ValueEnumType _pType, size_t _n, const void *_v)
   {
-  int i;
+  size_t i;
   MET_FieldRecordType f;
-  
+
   sprintf(f.name, "%s", _fieldName);
   f.defined = false;
   f.dependsOn = -1;
-  f.length = _n;
+  f.length = static_cast<int>(_n);
   f.required = false;
   f.type = _pType;
   switch(_pType)
@@ -1411,12 +1643,12 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
     default:
       break;
     }
-  
+
   METAIO_STL::vector<MET_FieldRecordType *> l;
   l.clear();
   l.push_back(&f);
   MET_Write(_fp, &l);
-  
+
   return true;
   }
 
@@ -1424,7 +1656,7 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
   MET_ValueEnumType _pType, double _v)
   {
   MET_FieldRecordType f;
-  
+
   sprintf(f.name, "%s", _fieldName);
   f.defined = false;
   f.dependsOn = -1;
@@ -1432,12 +1664,12 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
   f.required = false;
   f.type = _pType;
   f.value[0] = _v;
-  
+
   METAIO_STL::vector<MET_FieldRecordType *> l;
   l.clear();
   l.push_back(&f);
   MET_Write(_fp, &l);
-  
+
   return true;
   }
 
@@ -1472,14 +1704,14 @@ void MET_SwapByteIfSystemMSB(void* val, MET_ValueEnumType _type)
       {
       return;
       }
-  
+
     int eSize;
-    MET_SizeOfType(_type, &eSize);    
+    MET_SizeOfType(_type, &eSize);
     switch(eSize)
       {
       default:
       case 0:
-      case 1: 
+      case 1:
         {
         break;
         }
