@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkCaptionRepresentation.cxx,v $
+  Module:    vtkCaptionRepresentation.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -26,7 +26,6 @@
 #include "vtkTextMapper.h"
 #include "vtkFreeTypeUtilities.h"
 
-vtkCxxRevisionMacro(vtkCaptionRepresentation, "$Revision: 1.7 $");
 vtkStandardNewMacro(vtkCaptionRepresentation);
 
 //-------------------------------------------------------------------------
@@ -143,7 +142,7 @@ void vtkCaptionRepresentation::BuildRepresentation()
 
     if(!this->Moving && this->CaptionActor2D 
         && this->CaptionActor2D->GetCaption()
-        && (   !this->CaptionActor2D->GetTextActor()->GetTextScaleMode()
+        && (this->CaptionActor2D->GetTextActor()->GetTextScaleMode()
             == vtkTextActor::TEXT_SCALE_MODE_NONE ))
       {
       // Create a dummy text mapper for getting font sizes
