@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkLineRepresentation.cxx,v $
+  Module:    vtkLineRepresentation.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -15,6 +15,7 @@
 #include "vtkLineRepresentation.h"
 #include "vtkPointHandleRepresentation3D.h"
 #include "vtkActor.h"
+#include "vtkCamera.h"
 #include "vtkLineSource.h"
 #include "vtkSphereSource.h"
 #include "vtkPolyDataMapper.h"
@@ -30,9 +31,11 @@
 #include "vtkLine.h"
 #include "vtkWindow.h"
 #include "vtkObjectFactory.h"
+#include "vtkVectorText.h"
+#include "vtkFollower.h"
+#include "vtkCellPicker.h"
+#include "vtkPolyDataMapper.h"
 
-
-vtkCxxRevisionMacro(vtkLineRepresentation, "$Revision: 1.13 $");
 vtkStandardNewMacro(vtkLineRepresentation);
 
 vtkCxxSetObjectMacro(vtkLineRepresentation,HandleRepresentation,vtkPointHandleRepresentation3D);
@@ -87,8 +90,8 @@ vtkLineRepresentation::vtkLineRepresentation()
   // Pass the initial properties to the actors.
   this->Handle[0]->SetProperty(this->EndPointProperty);
   this->Point1Representation->SetProperty(this->EndPointProperty);
-  this->Handle[1]->SetProperty(this->EndPointProperty);
-  this->Point2Representation->SetProperty(this->EndPointProperty);
+  this->Handle[1]->SetProperty(this->EndPoint2Property);
+  this->Point2Representation->SetProperty(this->EndPoint2Property);
   this->LineHandleRepresentation->SetProperty(this->EndPointProperty);
   this->LineActor->SetProperty(this->LineProperty);
 
@@ -102,17 +105,40 @@ vtkLineRepresentation::vtkLineRepresentation()
   bounds[5] = 0.5;
   this->PlaceFactor = 1.0; //overload parent's value
 
+  // The distance text annotation
+  this->DistanceAnnotationVisibility = 0;
+  this->Distance = 0.0;
+  this->DistanceAnnotationFormat = new char[8]; 
+  sprintf(this->DistanceAnnotationFormat,"%s","%-#6.3g");  
+  this->TextInput = vtkVectorText::New();
+  this->TextInput->SetText( "0" );
+  this->TextMapper = vtkPolyDataMapper::New();
+  this->TextMapper->SetInput( this->TextInput->GetOutput() );
+  this->TextActor = vtkFollower::New();
+  this->TextActor->SetMapper(this->TextMapper);
+  this->TextActor->GetProperty()->SetColor( 1.0, 0.1, 0.0 );  
+  
   // This needs to be initialized before PlaceWidget is called.
   this->InitializedDisplayPosition = 0;
-
-  // Initial creation of the widget, serves to initialize it
-  this->PlaceWidget(bounds);
+  
   this->ClampToBounds = 0;
 
   // The bounding box
   this->BoundingBox = vtkBox::New();
 
+  this->LinePicker = vtkCellPicker::New();
+  this->LinePicker->SetTolerance(0.005); //need some fluff
+  this->LinePicker->AddPickList( this->LineActor );
+  this->LinePicker->PickFromListOn();
+
   this->RepresentationState = vtkLineRepresentation::Outside;
+  this->AnnotationTextScaleInitialized = false;
+  
+  // Initial creation of the widget, serves to initialize it.
+  // Call PlaceWidget() LAST in the constructor, as this method depends on ivar
+  // values.
+  this->PlaceWidget(bounds);
+
 }
 
 //----------------------------------------------------------------------------
@@ -151,10 +177,28 @@ vtkLineRepresentation::~vtkLineRepresentation()
 
   this->EndPointProperty->Delete();
   this->SelectedEndPointProperty->Delete();
+  this->EndPoint2Property->Delete();
+  this->SelectedEndPoint2Property->Delete();
   this->LineProperty->Delete();
   this->SelectedLineProperty->Delete();
 
   this->BoundingBox->Delete();
+
+  if (this->DistanceAnnotationFormat) 
+    {
+    delete [] this->DistanceAnnotationFormat;
+    this->DistanceAnnotationFormat = NULL;
+    }
+  this->TextInput->Delete();
+  this->TextMapper->Delete();
+  this->TextActor->Delete();
+  this->LinePicker->Delete();
+}
+
+//----------------------------------------------------------------------
+double vtkLineRepresentation::GetDistance()
+{
+  return this->Distance;
 }
 
 //----------------------------------------------------------------------
@@ -502,15 +546,15 @@ int vtkLineRepresentation::ComputeInteractionState(int X, int Y, int vtkNotUsed(
 
   // Check if we are on edges
   int onLine = (vtkLine::DistanceToLine(xyz,p1,p2,t,closest) <= tol2);
-  if ( onLine )
+  if ( onLine && t < 1.0 && t > 0.0 )
     {
     this->InteractionState = vtkLineRepresentation::OnLine;
     this->SetRepresentationState(vtkLineRepresentation::OnLine);
     this->GetPoint1WorldPosition(pos1);
     this->GetPoint2WorldPosition(pos2);
-    closest[0] = pos1[0] + t*(pos2[0]-pos1[0]);
-    closest[1] = pos1[1] + t*(pos2[1]-pos1[1]);
-    closest[2] = pos1[2] + t*(pos2[2]-pos1[2]);
+
+    this->LinePicker->Pick(X,Y,0.0,this->Renderer);
+    this->LinePicker->GetPickPosition(closest);
     this->LineHandleRepresentation->SetWorldPosition(closest);
     }
   else
@@ -591,6 +635,12 @@ void vtkLineRepresentation::CreateDefaultProperties()
   this->SelectedEndPointProperty = vtkProperty::New();
   this->SelectedEndPointProperty->SetColor(0,1,0);
 
+  this->EndPoint2Property = vtkProperty::New();
+  this->EndPoint2Property->SetColor(1,1,1);
+
+  this->SelectedEndPoint2Property = vtkProperty::New();
+  this->SelectedEndPoint2Property->SetColor(0,1,0);
+  
   // Line properties
   this->LineProperty = vtkProperty::New();
   this->LineProperty->SetAmbient(1.0);
@@ -623,7 +673,8 @@ void vtkLineRepresentation::BuildRepresentation()
        this->Point2Representation->GetMTime() > this->BuildTime ||
        this->LineHandleRepresentation->GetMTime() > this->BuildTime ||
        (this->Renderer && this->Renderer->GetVTKWindow() &&
-        this->Renderer->GetVTKWindow()->GetMTime() > this->BuildTime) )
+        (this->Renderer->GetVTKWindow()->GetMTime() > this->BuildTime ||
+        this->Renderer->GetActiveCamera()->GetMTime() > this->BuildTime)) )
     {
     if ( ! this->InitializedDisplayPosition && this->Renderer )
       {
@@ -633,15 +684,38 @@ void vtkLineRepresentation::BuildRepresentation()
       this->InitializedDisplayPosition = 1;
       }
 
-    double x[3];
-    this->GetPoint1WorldPosition(x);
-    this->LineSource->SetPoint1(x);
-    this->HandleGeometry[0]->SetCenter(x);
+    double x1[3], x2[3];
+    this->GetPoint1WorldPosition(x1);
+    this->LineSource->SetPoint1(x1);
+    this->HandleGeometry[0]->SetCenter(x1);
 
-    this->GetPoint2WorldPosition(x);
-    this->LineSource->SetPoint2(x);
-    this->HandleGeometry[1]->SetCenter(x);
+    this->GetPoint2WorldPosition(x2);
+    this->LineSource->SetPoint2(x2);
+    this->HandleGeometry[1]->SetCenter(x2);
 
+    this->Distance = sqrt(vtkMath::Distance2BetweenPoints( x1, x2 ));
+
+    // Place the DistanceAnnotation right in between the two points.
+    double x[3] = { (x1[0] + x2[0])/2.0, 
+                    (x1[1] + x2[1])/2.0, 
+                    (x1[2] + x2[2])/2.0 };
+    char string[512];
+    sprintf(string, this->DistanceAnnotationFormat, this->Distance);
+    this->TextInput->SetText( string );
+    this->TextActor->SetPosition( x );
+    if (this->Renderer)
+      {
+      this->TextActor->SetCamera( this->Renderer->GetActiveCamera() );
+      }
+    
+    if (!this->AnnotationTextScaleInitialized)
+      {
+      // If a font size hasn't been specified by the user, scale the text 
+      // (font size) according to the length of the line widget.
+      this->TextActor->SetScale( 
+          this->Distance/10.0, this->Distance/10.0, this->Distance/10.0 );
+      }
+    
     this->SizeHandles();
     this->BuildTime.Modified();
     }
@@ -667,13 +741,13 @@ void vtkLineRepresentation::HighlightPoint(int ptId, int highlight)
     {
     if ( highlight )
       {
-      this->Handle[1]->SetProperty(this->SelectedEndPointProperty);
-      this->Point2Representation->SetSelectedProperty(this->SelectedEndPointProperty);
+      this->Handle[1]->SetProperty(this->SelectedEndPoint2Property);
+      this->Point2Representation->SetSelectedProperty(this->SelectedEndPoint2Property);
       }
     else
       {
-      this->Handle[1]->SetProperty(this->EndPointProperty);
-      this->Point2Representation->SetProperty(this->EndPointProperty);
+      this->Handle[1]->SetProperty(this->EndPoint2Property);
+      this->Point2Representation->SetProperty(this->EndPoint2Property);
       }
     }
   else //if ( ptId == 2 )
@@ -702,6 +776,15 @@ void vtkLineRepresentation::HighlightLine(int highlight)
     }
 }
 
+//----------------------------------------------------------------------------
+void vtkLineRepresentation::SetLineColor(double r, double g, double b)
+{
+  if(this->GetLineProperty())
+    {
+    this->GetLineProperty()->SetColor(r, g, b);
+    }
+}  
+
 //----------------------------------------------------------------------------
 void vtkLineRepresentation::ClampPosition(double x[3])
 {
@@ -732,12 +815,22 @@ int vtkLineRepresentation::InBounds(double x[3])
   return 1;
 }
 
+//----------------------------------------------------------------------
+void vtkLineRepresentation::GetActors(vtkPropCollection *pc)
+{
+  this->LineActor->GetActors(pc);
+  this->Handle[0]->GetActors(pc);
+  this->Handle[1]->GetActors(pc);
+  this->TextActor->GetActors(pc);
+}
+
 //----------------------------------------------------------------------------
 void vtkLineRepresentation::ReleaseGraphicsResources(vtkWindow *w)
 {
   this->LineActor->ReleaseGraphicsResources(w);
   this->Handle[0]->ReleaseGraphicsResources(w);
   this->Handle[1]->ReleaseGraphicsResources(w);
+  this->TextActor->ReleaseGraphicsResources(w);
 }
 
 //----------------------------------------------------------------------------
@@ -748,6 +841,10 @@ int vtkLineRepresentation::RenderOpaqueGeometry(vtkViewport *v)
   count += this->LineActor->RenderOpaqueGeometry(v);
   count += this->Handle[0]->RenderOpaqueGeometry(v);
   count += this->Handle[1]->RenderOpaqueGeometry(v);
+  if (this->DistanceAnnotationVisibility)
+    {
+    count += this->TextActor->RenderOpaqueGeometry(v);
+    }
   
   return count;
 }
@@ -760,6 +857,10 @@ int vtkLineRepresentation::RenderTranslucentPolygonalGeometry(vtkViewport *v)
   count += this->LineActor->RenderTranslucentPolygonalGeometry(v);
   count += this->Handle[0]->RenderTranslucentPolygonalGeometry(v);
   count += this->Handle[1]->RenderTranslucentPolygonalGeometry(v);
+  if (this->DistanceAnnotationVisibility)
+    {
+    count += this->TextActor->RenderTranslucentPolygonalGeometry(v);
+    }
   
   return count;
 }
@@ -772,6 +873,10 @@ int vtkLineRepresentation::HasTranslucentPolygonalGeometry()
   result |= this->LineActor->HasTranslucentPolygonalGeometry();
   result |= this->Handle[0]->HasTranslucentPolygonalGeometry();
   result |= this->Handle[1]->HasTranslucentPolygonalGeometry();
+  if (this->DistanceAnnotationVisibility)
+    {
+    result |= this->TextActor->HasTranslucentPolygonalGeometry();
+    }
   
   return result;
 }
@@ -790,6 +895,25 @@ unsigned long vtkLineRepresentation::GetMTime()
   return mTime;
 }
 
+//----------------------------------------------------------------------
+void vtkLineRepresentation::SetDistanceAnnotationScale( double scale[3] )
+{
+  this->TextActor->SetScale( scale );
+  this->AnnotationTextScaleInitialized = true;
+}
+
+//----------------------------------------------------------------------
+double * vtkLineRepresentation::GetDistanceAnnotationScale()
+{
+  return this->TextActor->GetScale();
+}
+
+//----------------------------------------------------------------------------
+vtkProperty * vtkLineRepresentation::GetDistanceAnnotationProperty()
+{
+  return this->TextActor->GetProperty();
+}
+
 //----------------------------------------------------------------------------
 void vtkLineRepresentation::PrintSelf(ostream& os, vtkIndent indent)
 {
@@ -830,6 +954,23 @@ void vtkLineRepresentation::PrintSelf(ostream& os, vtkIndent indent)
     os << indent << "Selected End Point Property: (none)\n";
     }
 
+  if ( this->EndPoint2Property )
+    {
+    os << indent << "End Point Property: " << this->EndPoint2Property << "\n";
+    }
+  else
+    {
+    os << indent << "End Point Property: (none)\n";
+    }
+  if ( this->SelectedEndPoint2Property )
+    {
+    os << indent << "Selected End Point Property: " << this->SelectedEndPoint2Property << "\n";
+    }
+  else
+    {
+    os << indent << "Selected End Point Property: (none)\n";
+    }  
+
   os << indent << "Tolerance: " << this->Tolerance << "\n";
 
   os << indent << "Constrain To Bounds: "
@@ -857,6 +998,36 @@ void vtkLineRepresentation::PrintSelf(ostream& os, vtkIndent indent)
   this->LineHandleRepresentation->PrintSelf(os,indent.GetNextIndent());
   
   os << indent << "Representation State: " << this->RepresentationState << "\n";
+
+  os << indent << "DistanceAnnotationVisibility: ";
+  if ( this->DistanceAnnotationVisibility )
+    {
+    os << this->DistanceAnnotationVisibility << "\n";
+    }
+  else
+    {
+    os << "(none)\n";
+    }
+  
+  os << indent << "DistanceAnnotationFormat: ";
+  if ( this->DistanceAnnotationFormat )
+    {
+    os << this->DistanceAnnotationFormat << "\n";
+    }
+  else
+    {
+    os << "(none)\n";
+    }  
+
+  os << indent << "TextActor: ";
+  if ( this->TextActor )
+    {
+    os << this->TextActor << "\n";
+    }
+  else
+    {
+    os << "(none)\n";
+    }
   
   // this->InteractionState is printed in superclass
   // this is commented to avoid PrintSelf errors
