@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkPointHandleRepresentation2D.cxx,v $
+  Module:    vtkPointHandleRepresentation2D.cxx
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -31,7 +31,6 @@
 #include "vtkCamera.h"
 #include "vtkPointPlacer.h"
 
-vtkCxxRevisionMacro(vtkPointHandleRepresentation2D, "$Revision: 1.8 $");
 vtkStandardNewMacro(vtkPointHandleRepresentation2D);
 
 vtkCxxSetObjectMacro(vtkPointHandleRepresentation2D,Property,vtkProperty2D);
@@ -347,6 +346,21 @@ void vtkPointHandleRepresentation2D::ShallowCopy(vtkProp *prop)
   this->Superclass::ShallowCopy(prop);
 }
 
+//----------------------------------------------------------------------
+void vtkPointHandleRepresentation2D::DeepCopy(vtkProp *prop)
+{
+  vtkPointHandleRepresentation2D *rep = 
+    vtkPointHandleRepresentation2D::SafeDownCast(prop);
+  if ( rep )
+    {
+    this->SetCursorShape(rep->GetCursorShape());
+    this->Property->DeepCopy(rep->GetProperty());
+    this->SelectedProperty->DeepCopy(rep->GetSelectedProperty());
+    this->Actor->SetProperty(this->Property);
+    }
+  this->Superclass::DeepCopy(prop);
+}
+
 //----------------------------------------------------------------------
 void vtkPointHandleRepresentation2D::GetActors2D(vtkPropCollection *pc)
 {
