@@ -1,7 +1,7 @@
 /*=========================================================================
 
   Program:   Visualization Toolkit
-  Module:    $RCSfile: vtkWrapTcl.c,v $
+  Module:    vtkWrapTcl.c
 
   Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
   All rights reserved.
@@ -39,7 +39,7 @@ static const char *quote_string(const char *comment, int maxlen)
       {
       free(result);
       }
-    result = (char *)malloc(maxlen+1);
+    result = (char *)malloc((size_t)(maxlen+1));
     oldmaxlen = maxlen;
     }
 
@@ -317,7 +317,7 @@ void use_hints(FILE *fp)
   fprintf(fp,INDENT "  }\n");
   fprintf(fp,INDENT "else\n");
   fprintf(fp,INDENT "  {\n");
-  fprintf(fp,INDENT "  Tcl_SetResult(interp, (char *)(\"\"), TCL_VOLATILE);\n");
+  fprintf(fp,INDENT "  Tcl_SetResult(interp, const_cast<char *>(\"\"), TCL_VOLATILE);\n");
   fprintf(fp,INDENT "  }\n");
 
 #undef INDENT
@@ -469,7 +469,7 @@ void return_result(FILE *fp)
       use_hints(fp);
       break;
     default:
-      fprintf(fp,"    Tcl_SetResult(interp, (char *)(\"unable to return result.\"), TCL_VOLATILE);\n");
+      fprintf(fp,"    Tcl_SetResult(interp, const_cast<char *>(\"unable to return result.\"), TCL_VOLATILE);\n");
       break;
     }
 }
@@ -527,7 +527,7 @@ void get_args(FILE *fp, int i)
               start_arg); 
       fprintf(fp,"    temp%i = static_cast<unsigned char>(tempi);\n",i);
       break;
-    case 0x14: case 0x1A: case 0x1B: case 0x1C:
+    case 0x14: case 0x1A:
       fprintf(fp,"    if (Tcl_GetInt(interp,argv[%i],&tempi) != TCL_OK) error = 1;\n",
               start_arg); 
       fprintf(fp,"    temp%i = static_cast<unsigned int>(tempi);\n",i);
@@ -542,12 +542,17 @@ void get_args(FILE *fp, int i)
               start_arg); 
       fprintf(fp,"    temp%i = static_cast<unsigned long>(tempi);\n",i);
       break;
+    case 0x1B: case 0x1C:
+      fprintf(fp,"    if (Tcl_GetInt(interp,argv[%i],&tempi) != TCL_OK) error = 1;\n",
+              start_arg); 
+      fprintf(fp,"    temp%i = static_cast<unsigned long long>(tempi);\n",i);
+      break;
     case 0x303:
       fprintf(fp,"    temp%i = argv[%i];\n",i,start_arg);
       break;
     case 0x109:
     case 0x309:
-      fprintf(fp,"    temp%i = (%s *)(vtkTclGetPointerFromObject(argv[%i],(char *)(\"%s\"),interp,error));\n",i,currentFunction->ArgClasses[i],start_arg,
+      fprintf(fp,"    temp%i = (%s *)(vtkTclGetPointerFromObject(argv[%i],const_cast<char *>(\"%s\"),interp,error));\n",i,currentFunction->ArgClasses[i],start_arg,
               currentFunction->ArgClasses[i]);
       break;
     case 0x2:    
@@ -642,15 +647,28 @@ void outputFunction(FILE *fp, FileInfo *data)
         (currentFunction->ArgTypes[i] != 0x14)&&
         (currentFunction->ArgTypes[i] != 0x15)&&
         (currentFunction->ArgTypes[i] != 0x16)&&
-        (currentFunction->ArgTypes[i] != 0x1A)) args_ok = 0;
+        (currentFunction->ArgTypes[i] != 0x1A)&&
+        (currentFunction->ArgTypes[i] != 0x1B))
+      {
+      args_ok = 0;
+      }
+    }
+  if ((currentFunction->ReturnType % 0x10) == 0x8)
+    {
+    args_ok = 0;
     }
-  if ((currentFunction->ReturnType % 0x10) == 0x8) args_ok = 0;
   if (((currentFunction->ReturnType % 0x1000)/0x100 != 0x3)&&
       ((currentFunction->ReturnType % 0x1000)/0x100 != 0x1)&&
-      ((currentFunction->ReturnType % 0x1000)/0x100)) args_ok = 0;
+      ((currentFunction->ReturnType % 0x1000)/0x100))
+    {
+    args_ok = 0;
+    }
   if (currentFunction->NumberOfArguments && 
       (currentFunction->ArgTypes[0] == 0x5000)
-      &&(currentFunction->NumberOfArguments != 1)) args_ok = 0;
+      &&(currentFunction->NumberOfArguments != 1))
+    {
+    args_ok = 0;
+    }
 
   /* we can't handle void * return types */
   if ((currentFunction->ReturnType % 0x1000) == 0x302) 
@@ -833,7 +851,7 @@ void vtkParseOutput(FILE *fp, FileInfo *data)
   fprintf(fp,"  tempd = 0; tempd = tempd;\n");
   fprintf(fp,"  temps[0] = 0; temps[0] = temps[0];\n\n");
 
-  fprintf(fp,"  if (argc < 2)\n    {\n    Tcl_SetResult(interp,(char *)(\"Could not find requested method.\"), TCL_VOLATILE);\n    return TCL_ERROR;\n    }\n");
+  fprintf(fp,"  if (argc < 2)\n    {\n    Tcl_SetResult(interp,const_cast<char *>(\"Could not find requested method.\"), TCL_VOLATILE);\n    return TCL_ERROR;\n    }\n");
 
   /* stick in the typecasting and delete functionality here */
   fprintf(fp,"  if (!interp)\n    {\n");
@@ -857,7 +875,7 @@ void vtkParseOutput(FILE *fp, FileInfo *data)
     {
     fprintf(fp,"  if (!strcmp(\"GetSuperClassName\",argv[1]))\n");
     fprintf(fp,"    {\n");
-    fprintf(fp,"    Tcl_SetResult(interp,(char *)(\"%s\"), TCL_VOLATILE);\n",data->SuperClasses[0]);
+    fprintf(fp,"    Tcl_SetResult(interp,const_cast<char *>(\"%s\"), TCL_VOLATILE);\n",data->SuperClasses[0]);
     fprintf(fp,"    return TCL_OK;\n");
     fprintf(fp,"    }\n\n");      
     }
@@ -931,11 +949,11 @@ void vtkParseOutput(FILE *fp, FileInfo *data)
   /* add the DescribeMethods method */
   fprintf(fp,"\n  if (!strcmp(\"DescribeMethods\",argv[1]))\n    {\n");
   fprintf(fp,"    if(argc>3) {\n" );
-  fprintf(fp,"      Tcl_SetResult ( interp, (char*)\"Wrong number of arguments: object DescribeMethods <MethodName>\", TCL_VOLATILE ); \n" );
+  fprintf(fp,"      Tcl_SetResult ( interp, const_cast<char*>(\"Wrong number of arguments: object DescribeMethods <MethodName>\"), TCL_VOLATILE ); \n" );
   fprintf(fp,"      return TCL_ERROR;\n }\n" );
   
   fprintf(fp,"    if(argc==2) {\n" );
-  // Return a list of methods
+  /* Return a list of methods */
   fprintf(fp,"\n  Tcl_DString dString, dStringParent;\n");
   fprintf(fp,"\n  Tcl_DStringInit ( &dString );\n" );
   fprintf(fp,"\n  Tcl_DStringInit ( &dStringParent );\n" );
@@ -980,7 +998,7 @@ void vtkParseOutput(FILE *fp, FileInfo *data)
             data->SuperClasses[i]);
     fprintf(fp,"    if ( SuperClassStatus == TCL_OK ) { return TCL_OK; }\n" );
     }
-  // Now we handle it ourselves
+  /* Now we handle it ourselves */
   for (k = 0; k < numberOfWrappedFunctions; k++)
     {
       currentFunction = wrappedFunctions[k];
@@ -1087,7 +1105,7 @@ void vtkParseOutput(FILE *fp, FileInfo *data)
         }
     }
   /* Didn't find anything, return an error */
-  fprintf(fp,"   Tcl_SetResult ( interp, (char*)\"Could not find method\", TCL_VOLATILE ); \n" );
+  fprintf(fp,"   Tcl_SetResult ( interp, const_cast<char*>(\"Could not find method\"), TCL_VOLATILE ); \n" );
   fprintf(fp,"   return TCL_ERROR;\n" );
   fprintf(fp,"   }\n" );
   fprintf(fp," }\n" );
@@ -1146,8 +1164,8 @@ void vtkParseOutput(FILE *fp, FileInfo *data)
     fprintf(fp,"    }\n");
     }
 
-  // i.e. If this is vtkObjectBase (or whatever the top of the class hierarchy will be)
-  // then report the error
+  /* i.e. If this is vtkObjectBase (or whatever the top of the class hierarchy will be) */
+  /* then report the error */
   if (data->NumberOfSuperClasses == 0)
     {
     fprintf(fp,"\n  if (argc >= 2)\n    {\n");
